#include <assert.h>

#include <aterm2.h>
#include <deprecated.h>
#include "PTMEPT.h"

/**
 * Converts a string to an ATermList of integers (ASCII values). 
 * \param[in] str An ASCII string
 * \return An ATermList containing the ASCII values of #arg as ATermInts
 */
ATerm PTPT_stringToChars(const char *str) {
  int len = strlen(str);
  int i;
  ATermList result = ATempty;

  for (i = len - 1; i >= 0; i--) {
    result = ATinsert(result, (ATerm) ATmakeInt(str[i]));
  }

  return (ATerm) result;
}

/**
 * Converts an ASCII char to an ATermInt. 
 * \param[in] ch an ASCII character
 * \return An ATerm representing the ASCII value of #arg
 */
ATerm PTPT_byteToChar(char ch) {
    return (ATerm) ATmakeInt(ch);
}

/**
 * Converts a list of integers (ASCII values) to a C string. 
 * \param[in] arg An ATermList with ATermInts, such as [32,32,10]
 * \return String containing the characters from #arg as characters
 */
char *PTPT_charsToString(ATerm arg) {
  ATermList list = (ATermList) arg;
  int len = ATgetLength(list);
  int i;
  char *str;

  str = (char *) malloc(len+1);
  if (str == NULL) {
      return NULL;
  }

  for (i = 0; !ATisEmpty(list); list = ATgetNext(list), i++) {
    str[i] = (char) ATgetInt((ATermInt) ATgetFirst(list));
  }
  str[i] = '\0';

  return str;
}

char PTPT_charToByte(ATerm arg) {
    return (char) ATgetInt((ATermInt) arg);
}


typedef struct ATerm _PTPT_OptLayout;
typedef struct ATerm _PTPT_Layout;
typedef struct ATerm _PTPT_LexLayoutList;
typedef struct ATerm _PTPT_Tree;
typedef struct ATerm _PTPT_Attributes;
typedef struct ATerm _PTPT_Attrs;
typedef struct ATerm _PTPT_Attr;
typedef struct ATerm _PTPT_Associativity;
typedef struct ATerm _PTPT_AttrList;
typedef struct ATerm _PTPT_ParseTree;
typedef struct ATerm _PTPT_Symbol;
typedef struct ATerm _PTPT_Symbols;
typedef struct ATerm _PTPT_CharRanges;
typedef struct ATerm _PTPT_CharRange;
typedef struct ATerm _PTPT_Start;
typedef struct ATerm _PTPT_SymbolList;
typedef struct ATerm _PTPT_CharRangeList;
typedef struct ATerm _PTPT_Args;
typedef struct ATerm _PTPT_Production;
typedef struct ATerm _PTPT_TreeList;
typedef struct ATerm _PTPT_AFun;
typedef struct ATerm _PTPT_ATerm;
typedef struct ATerm _PTPT_Annotation;
typedef struct ATerm _PTPT_ATermArgs;
typedef struct ATerm _PTPT_ATermElems;
typedef struct ATerm _PTPT_ATermAnnos;
typedef struct ATerm _PTPT_IntCon;
typedef struct ATerm _PTPT_OptExp;
typedef struct ATerm _PTPT_RealCon;
typedef struct ATerm _PTPT_LexStrChar;
typedef struct ATerm _PTPT_StrChar;
typedef struct ATerm _PTPT_LexStrCon;
typedef struct ATerm _PTPT_StrCon;
typedef struct ATerm _PTPT_LexStrCharChars;
typedef struct ATerm _PTPT_LexNatCon;
typedef struct ATerm _PTPT_NatCon;
typedef struct ATerm _PTPT_LexIdCon;
typedef struct ATerm _PTPT_IdCon;
typedef struct ATerm _PTPT_LexLayout;


/**
 * Initializes the full API. Forgetting to call this function before using the API will lead to strange behaviour. ATinit() needs to be called before this function.
 */
void _PTPT_initPTMEPTApi(void) {
  init_PTMEPT_dict();

}

/**
 * Protect a PTPT_OptLayout from the ATerm garbage collector. Every PTPT_OptLayout that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a PTPT_OptLayout
 */
void _PTPT_protectOptLayout(PTPT_OptLayout *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a PTPT_OptLayout from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a PTPT_OptLayout
 */
void _PTPT_unprotectOptLayout(PTPT_OptLayout *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a PTPT_Layout from the ATerm garbage collector. Every PTPT_Layout that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a PTPT_Layout
 */
void _PTPT_protectLayout(PTPT_Layout *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a PTPT_Layout from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a PTPT_Layout
 */
void _PTPT_unprotectLayout(PTPT_Layout *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a PTPT_LexLayoutList from the ATerm garbage collector. Every PTPT_LexLayoutList that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a PTPT_LexLayoutList
 */
void _PTPT_protectLexLayoutList(PTPT_LexLayoutList *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a PTPT_LexLayoutList from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a PTPT_LexLayoutList
 */
void _PTPT_unprotectLexLayoutList(PTPT_LexLayoutList *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a PTPT_Tree from the ATerm garbage collector. Every PTPT_Tree that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a PTPT_Tree
 */
void _PTPT_protectTree(PTPT_Tree *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a PTPT_Tree from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a PTPT_Tree
 */
void _PTPT_unprotectTree(PTPT_Tree *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a PTPT_Attributes from the ATerm garbage collector. Every PTPT_Attributes that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a PTPT_Attributes
 */
void _PTPT_protectAttributes(PTPT_Attributes *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a PTPT_Attributes from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a PTPT_Attributes
 */
void _PTPT_unprotectAttributes(PTPT_Attributes *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a PTPT_Attrs from the ATerm garbage collector. Every PTPT_Attrs that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a PTPT_Attrs
 */
void _PTPT_protectAttrs(PTPT_Attrs *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a PTPT_Attrs from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a PTPT_Attrs
 */
void _PTPT_unprotectAttrs(PTPT_Attrs *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a PTPT_Attr from the ATerm garbage collector. Every PTPT_Attr that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a PTPT_Attr
 */
void _PTPT_protectAttr(PTPT_Attr *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a PTPT_Attr from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a PTPT_Attr
 */
void _PTPT_unprotectAttr(PTPT_Attr *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a PTPT_Associativity from the ATerm garbage collector. Every PTPT_Associativity that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a PTPT_Associativity
 */
void _PTPT_protectAssociativity(PTPT_Associativity *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a PTPT_Associativity from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a PTPT_Associativity
 */
void _PTPT_unprotectAssociativity(PTPT_Associativity *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a PTPT_AttrList from the ATerm garbage collector. Every PTPT_AttrList that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a PTPT_AttrList
 */
void _PTPT_protectAttrList(PTPT_AttrList *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a PTPT_AttrList from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a PTPT_AttrList
 */
void _PTPT_unprotectAttrList(PTPT_AttrList *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a PTPT_ParseTree from the ATerm garbage collector. Every PTPT_ParseTree that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a PTPT_ParseTree
 */
void _PTPT_protectParseTree(PTPT_ParseTree *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a PTPT_ParseTree from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a PTPT_ParseTree
 */
void _PTPT_unprotectParseTree(PTPT_ParseTree *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a PTPT_Symbol from the ATerm garbage collector. Every PTPT_Symbol that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a PTPT_Symbol
 */
void _PTPT_protectSymbol(PTPT_Symbol *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a PTPT_Symbol from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a PTPT_Symbol
 */
void _PTPT_unprotectSymbol(PTPT_Symbol *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a PTPT_Symbols from the ATerm garbage collector. Every PTPT_Symbols that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a PTPT_Symbols
 */
void _PTPT_protectSymbols(PTPT_Symbols *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a PTPT_Symbols from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a PTPT_Symbols
 */
void _PTPT_unprotectSymbols(PTPT_Symbols *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a PTPT_CharRanges from the ATerm garbage collector. Every PTPT_CharRanges that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a PTPT_CharRanges
 */
void _PTPT_protectCharRanges(PTPT_CharRanges *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a PTPT_CharRanges from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a PTPT_CharRanges
 */
void _PTPT_unprotectCharRanges(PTPT_CharRanges *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a PTPT_CharRange from the ATerm garbage collector. Every PTPT_CharRange that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a PTPT_CharRange
 */
void _PTPT_protectCharRange(PTPT_CharRange *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a PTPT_CharRange from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a PTPT_CharRange
 */
void _PTPT_unprotectCharRange(PTPT_CharRange *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a PTPT_Start from the ATerm garbage collector. Every PTPT_Start that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a PTPT_Start
 */
void _PTPT_protectStart(PTPT_Start *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a PTPT_Start from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a PTPT_Start
 */
void _PTPT_unprotectStart(PTPT_Start *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a PTPT_SymbolList from the ATerm garbage collector. Every PTPT_SymbolList that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a PTPT_SymbolList
 */
void _PTPT_protectSymbolList(PTPT_SymbolList *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a PTPT_SymbolList from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a PTPT_SymbolList
 */
void _PTPT_unprotectSymbolList(PTPT_SymbolList *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a PTPT_CharRangeList from the ATerm garbage collector. Every PTPT_CharRangeList that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a PTPT_CharRangeList
 */
void _PTPT_protectCharRangeList(PTPT_CharRangeList *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a PTPT_CharRangeList from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a PTPT_CharRangeList
 */
void _PTPT_unprotectCharRangeList(PTPT_CharRangeList *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a PTPT_Args from the ATerm garbage collector. Every PTPT_Args that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a PTPT_Args
 */
void _PTPT_protectArgs(PTPT_Args *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a PTPT_Args from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a PTPT_Args
 */
void _PTPT_unprotectArgs(PTPT_Args *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a PTPT_Production from the ATerm garbage collector. Every PTPT_Production that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a PTPT_Production
 */
void _PTPT_protectProduction(PTPT_Production *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a PTPT_Production from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a PTPT_Production
 */
void _PTPT_unprotectProduction(PTPT_Production *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a PTPT_TreeList from the ATerm garbage collector. Every PTPT_TreeList that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a PTPT_TreeList
 */
void _PTPT_protectTreeList(PTPT_TreeList *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a PTPT_TreeList from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a PTPT_TreeList
 */
void _PTPT_unprotectTreeList(PTPT_TreeList *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a PTPT_AFun from the ATerm garbage collector. Every PTPT_AFun that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a PTPT_AFun
 */
void _PTPT_protectAFun(PTPT_AFun *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a PTPT_AFun from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a PTPT_AFun
 */
void _PTPT_unprotectAFun(PTPT_AFun *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a PTPT_ATerm from the ATerm garbage collector. Every PTPT_ATerm that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a PTPT_ATerm
 */
void _PTPT_protectATerm(PTPT_ATerm *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a PTPT_ATerm from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a PTPT_ATerm
 */
void _PTPT_unprotectATerm(PTPT_ATerm *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a PTPT_Annotation from the ATerm garbage collector. Every PTPT_Annotation that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a PTPT_Annotation
 */
void _PTPT_protectAnnotation(PTPT_Annotation *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a PTPT_Annotation from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a PTPT_Annotation
 */
void _PTPT_unprotectAnnotation(PTPT_Annotation *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a PTPT_ATermArgs from the ATerm garbage collector. Every PTPT_ATermArgs that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a PTPT_ATermArgs
 */
void _PTPT_protectATermArgs(PTPT_ATermArgs *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a PTPT_ATermArgs from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a PTPT_ATermArgs
 */
void _PTPT_unprotectATermArgs(PTPT_ATermArgs *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a PTPT_ATermElems from the ATerm garbage collector. Every PTPT_ATermElems that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a PTPT_ATermElems
 */
void _PTPT_protectATermElems(PTPT_ATermElems *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a PTPT_ATermElems from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a PTPT_ATermElems
 */
void _PTPT_unprotectATermElems(PTPT_ATermElems *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a PTPT_ATermAnnos from the ATerm garbage collector. Every PTPT_ATermAnnos that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a PTPT_ATermAnnos
 */
void _PTPT_protectATermAnnos(PTPT_ATermAnnos *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a PTPT_ATermAnnos from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a PTPT_ATermAnnos
 */
void _PTPT_unprotectATermAnnos(PTPT_ATermAnnos *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a PTPT_IntCon from the ATerm garbage collector. Every PTPT_IntCon that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a PTPT_IntCon
 */
void _PTPT_protectIntCon(PTPT_IntCon *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a PTPT_IntCon from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a PTPT_IntCon
 */
void _PTPT_unprotectIntCon(PTPT_IntCon *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a PTPT_OptExp from the ATerm garbage collector. Every PTPT_OptExp that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a PTPT_OptExp
 */
void _PTPT_protectOptExp(PTPT_OptExp *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a PTPT_OptExp from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a PTPT_OptExp
 */
void _PTPT_unprotectOptExp(PTPT_OptExp *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a PTPT_RealCon from the ATerm garbage collector. Every PTPT_RealCon that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a PTPT_RealCon
 */
void _PTPT_protectRealCon(PTPT_RealCon *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a PTPT_RealCon from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a PTPT_RealCon
 */
void _PTPT_unprotectRealCon(PTPT_RealCon *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a PTPT_LexStrChar from the ATerm garbage collector. Every PTPT_LexStrChar that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a PTPT_LexStrChar
 */
void _PTPT_protectLexStrChar(PTPT_LexStrChar *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a PTPT_LexStrChar from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a PTPT_LexStrChar
 */
void _PTPT_unprotectLexStrChar(PTPT_LexStrChar *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a PTPT_StrChar from the ATerm garbage collector. Every PTPT_StrChar that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a PTPT_StrChar
 */
void _PTPT_protectStrChar(PTPT_StrChar *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a PTPT_StrChar from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a PTPT_StrChar
 */
void _PTPT_unprotectStrChar(PTPT_StrChar *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a PTPT_LexStrCon from the ATerm garbage collector. Every PTPT_LexStrCon that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a PTPT_LexStrCon
 */
void _PTPT_protectLexStrCon(PTPT_LexStrCon *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a PTPT_LexStrCon from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a PTPT_LexStrCon
 */
void _PTPT_unprotectLexStrCon(PTPT_LexStrCon *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a PTPT_StrCon from the ATerm garbage collector. Every PTPT_StrCon that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a PTPT_StrCon
 */
void _PTPT_protectStrCon(PTPT_StrCon *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a PTPT_StrCon from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a PTPT_StrCon
 */
void _PTPT_unprotectStrCon(PTPT_StrCon *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a PTPT_LexStrCharChars from the ATerm garbage collector. Every PTPT_LexStrCharChars that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a PTPT_LexStrCharChars
 */
void _PTPT_protectLexStrCharChars(PTPT_LexStrCharChars *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a PTPT_LexStrCharChars from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a PTPT_LexStrCharChars
 */
void _PTPT_unprotectLexStrCharChars(PTPT_LexStrCharChars *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a PTPT_LexNatCon from the ATerm garbage collector. Every PTPT_LexNatCon that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a PTPT_LexNatCon
 */
void _PTPT_protectLexNatCon(PTPT_LexNatCon *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a PTPT_LexNatCon from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a PTPT_LexNatCon
 */
void _PTPT_unprotectLexNatCon(PTPT_LexNatCon *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a PTPT_NatCon from the ATerm garbage collector. Every PTPT_NatCon that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a PTPT_NatCon
 */
void _PTPT_protectNatCon(PTPT_NatCon *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a PTPT_NatCon from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a PTPT_NatCon
 */
void _PTPT_unprotectNatCon(PTPT_NatCon *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a PTPT_LexIdCon from the ATerm garbage collector. Every PTPT_LexIdCon that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a PTPT_LexIdCon
 */
void _PTPT_protectLexIdCon(PTPT_LexIdCon *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a PTPT_LexIdCon from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a PTPT_LexIdCon
 */
void _PTPT_unprotectLexIdCon(PTPT_LexIdCon *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a PTPT_IdCon from the ATerm garbage collector. Every PTPT_IdCon that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a PTPT_IdCon
 */
void _PTPT_protectIdCon(PTPT_IdCon *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a PTPT_IdCon from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a PTPT_IdCon
 */
void _PTPT_unprotectIdCon(PTPT_IdCon *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a PTPT_LexLayout from the ATerm garbage collector. Every PTPT_LexLayout that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a PTPT_LexLayout
 */
void _PTPT_protectLexLayout(PTPT_LexLayout *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a PTPT_LexLayout from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a PTPT_LexLayout
 */
void _PTPT_unprotectLexLayout(PTPT_LexLayout *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Transforms an ATerm to a PTPT_OptLayout. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return PTPT_OptLayout that was encoded by \arg
 */
PTPT_OptLayout _PTPT_OptLayoutFromTerm(ATerm t) {
  return (PTPT_OptLayout)t;
}

/**
 * Transforms a PTPT_OptLayoutto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg PTPT_OptLayout to be converted
 * \return ATerm that represents the PTPT_OptLayout
 */
ATerm _PTPT_OptLayoutToTerm(PTPT_OptLayout arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a PTPT_Layout. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return PTPT_Layout that was encoded by \arg
 */
PTPT_Layout _PTPT_LayoutFromTerm(ATerm t) {
  return (PTPT_Layout)t;
}

/**
 * Transforms a PTPT_Layoutto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg PTPT_Layout to be converted
 * \return ATerm that represents the PTPT_Layout
 */
ATerm _PTPT_LayoutToTerm(PTPT_Layout arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a PTPT_LexLayoutList. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return PTPT_LexLayoutList that was encoded by \arg
 */
PTPT_LexLayoutList _PTPT_LexLayoutListFromTerm(ATerm t) {
  return (PTPT_LexLayoutList)t;
}

/**
 * Transforms a PTPT_LexLayoutListto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg PTPT_LexLayoutList to be converted
 * \return ATerm that represents the PTPT_LexLayoutList
 */
ATerm _PTPT_LexLayoutListToTerm(PTPT_LexLayoutList arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a PTPT_Tree. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return PTPT_Tree that was encoded by \arg
 */
PTPT_Tree _PTPT_TreeFromTerm(ATerm t) {
  return (PTPT_Tree)t;
}

/**
 * Transforms a PTPT_Treeto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg PTPT_Tree to be converted
 * \return ATerm that represents the PTPT_Tree
 */
ATerm _PTPT_TreeToTerm(PTPT_Tree arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a PTPT_Attributes. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return PTPT_Attributes that was encoded by \arg
 */
PTPT_Attributes _PTPT_AttributesFromTerm(ATerm t) {
  return (PTPT_Attributes)t;
}

/**
 * Transforms a PTPT_Attributesto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg PTPT_Attributes to be converted
 * \return ATerm that represents the PTPT_Attributes
 */
ATerm _PTPT_AttributesToTerm(PTPT_Attributes arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a PTPT_Attrs. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return PTPT_Attrs that was encoded by \arg
 */
PTPT_Attrs _PTPT_AttrsFromTerm(ATerm t) {
  return (PTPT_Attrs)t;
}

/**
 * Transforms a PTPT_Attrsto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg PTPT_Attrs to be converted
 * \return ATerm that represents the PTPT_Attrs
 */
ATerm _PTPT_AttrsToTerm(PTPT_Attrs arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a PTPT_Attr. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return PTPT_Attr that was encoded by \arg
 */
PTPT_Attr _PTPT_AttrFromTerm(ATerm t) {
  return (PTPT_Attr)t;
}

/**
 * Transforms a PTPT_Attrto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg PTPT_Attr to be converted
 * \return ATerm that represents the PTPT_Attr
 */
ATerm _PTPT_AttrToTerm(PTPT_Attr arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a PTPT_Associativity. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return PTPT_Associativity that was encoded by \arg
 */
PTPT_Associativity _PTPT_AssociativityFromTerm(ATerm t) {
  return (PTPT_Associativity)t;
}

/**
 * Transforms a PTPT_Associativityto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg PTPT_Associativity to be converted
 * \return ATerm that represents the PTPT_Associativity
 */
ATerm _PTPT_AssociativityToTerm(PTPT_Associativity arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a PTPT_AttrList. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return PTPT_AttrList that was encoded by \arg
 */
PTPT_AttrList _PTPT_AttrListFromTerm(ATerm t) {
  return (PTPT_AttrList)t;
}

/**
 * Transforms a PTPT_AttrListto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg PTPT_AttrList to be converted
 * \return ATerm that represents the PTPT_AttrList
 */
ATerm _PTPT_AttrListToTerm(PTPT_AttrList arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a PTPT_ParseTree. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return PTPT_ParseTree that was encoded by \arg
 */
PTPT_ParseTree _PTPT_ParseTreeFromTerm(ATerm t) {
  return (PTPT_ParseTree)t;
}

/**
 * Transforms a PTPT_ParseTreeto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg PTPT_ParseTree to be converted
 * \return ATerm that represents the PTPT_ParseTree
 */
ATerm _PTPT_ParseTreeToTerm(PTPT_ParseTree arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a PTPT_Symbol. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return PTPT_Symbol that was encoded by \arg
 */
PTPT_Symbol _PTPT_SymbolFromTerm(ATerm t) {
  return (PTPT_Symbol)t;
}

/**
 * Transforms a PTPT_Symbolto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg PTPT_Symbol to be converted
 * \return ATerm that represents the PTPT_Symbol
 */
ATerm _PTPT_SymbolToTerm(PTPT_Symbol arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a PTPT_Symbols. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return PTPT_Symbols that was encoded by \arg
 */
PTPT_Symbols _PTPT_SymbolsFromTerm(ATerm t) {
  return (PTPT_Symbols)t;
}

/**
 * Transforms a PTPT_Symbolsto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg PTPT_Symbols to be converted
 * \return ATerm that represents the PTPT_Symbols
 */
ATerm _PTPT_SymbolsToTerm(PTPT_Symbols arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a PTPT_CharRanges. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return PTPT_CharRanges that was encoded by \arg
 */
PTPT_CharRanges _PTPT_CharRangesFromTerm(ATerm t) {
  return (PTPT_CharRanges)t;
}

/**
 * Transforms a PTPT_CharRangesto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg PTPT_CharRanges to be converted
 * \return ATerm that represents the PTPT_CharRanges
 */
ATerm _PTPT_CharRangesToTerm(PTPT_CharRanges arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a PTPT_CharRange. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return PTPT_CharRange that was encoded by \arg
 */
PTPT_CharRange _PTPT_CharRangeFromTerm(ATerm t) {
  return (PTPT_CharRange)t;
}

/**
 * Transforms a PTPT_CharRangeto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg PTPT_CharRange to be converted
 * \return ATerm that represents the PTPT_CharRange
 */
ATerm _PTPT_CharRangeToTerm(PTPT_CharRange arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a PTPT_Start. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return PTPT_Start that was encoded by \arg
 */
PTPT_Start _PTPT_StartFromTerm(ATerm t) {
  return (PTPT_Start)t;
}

/**
 * Transforms a PTPT_Startto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg PTPT_Start to be converted
 * \return ATerm that represents the PTPT_Start
 */
ATerm _PTPT_StartToTerm(PTPT_Start arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a PTPT_SymbolList. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return PTPT_SymbolList that was encoded by \arg
 */
PTPT_SymbolList _PTPT_SymbolListFromTerm(ATerm t) {
  return (PTPT_SymbolList)t;
}

/**
 * Transforms a PTPT_SymbolListto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg PTPT_SymbolList to be converted
 * \return ATerm that represents the PTPT_SymbolList
 */
ATerm _PTPT_SymbolListToTerm(PTPT_SymbolList arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a PTPT_CharRangeList. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return PTPT_CharRangeList that was encoded by \arg
 */
PTPT_CharRangeList _PTPT_CharRangeListFromTerm(ATerm t) {
  return (PTPT_CharRangeList)t;
}

/**
 * Transforms a PTPT_CharRangeListto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg PTPT_CharRangeList to be converted
 * \return ATerm that represents the PTPT_CharRangeList
 */
ATerm _PTPT_CharRangeListToTerm(PTPT_CharRangeList arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a PTPT_Args. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return PTPT_Args that was encoded by \arg
 */
PTPT_Args _PTPT_ArgsFromTerm(ATerm t) {
  return (PTPT_Args)t;
}

/**
 * Transforms a PTPT_Argsto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg PTPT_Args to be converted
 * \return ATerm that represents the PTPT_Args
 */
ATerm _PTPT_ArgsToTerm(PTPT_Args arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a PTPT_Production. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return PTPT_Production that was encoded by \arg
 */
PTPT_Production _PTPT_ProductionFromTerm(ATerm t) {
  return (PTPT_Production)t;
}

/**
 * Transforms a PTPT_Productionto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg PTPT_Production to be converted
 * \return ATerm that represents the PTPT_Production
 */
ATerm _PTPT_ProductionToTerm(PTPT_Production arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a PTPT_TreeList. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return PTPT_TreeList that was encoded by \arg
 */
PTPT_TreeList _PTPT_TreeListFromTerm(ATerm t) {
  return (PTPT_TreeList)t;
}

/**
 * Transforms a PTPT_TreeListto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg PTPT_TreeList to be converted
 * \return ATerm that represents the PTPT_TreeList
 */
ATerm _PTPT_TreeListToTerm(PTPT_TreeList arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a PTPT_AFun. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return PTPT_AFun that was encoded by \arg
 */
PTPT_AFun _PTPT_AFunFromTerm(ATerm t) {
  return (PTPT_AFun)t;
}

/**
 * Transforms a PTPT_AFunto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg PTPT_AFun to be converted
 * \return ATerm that represents the PTPT_AFun
 */
ATerm _PTPT_AFunToTerm(PTPT_AFun arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a PTPT_ATerm. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return PTPT_ATerm that was encoded by \arg
 */
PTPT_ATerm _PTPT_ATermFromTerm(ATerm t) {
  return (PTPT_ATerm)t;
}

/**
 * Transforms a PTPT_ATermto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg PTPT_ATerm to be converted
 * \return ATerm that represents the PTPT_ATerm
 */
ATerm _PTPT_ATermToTerm(PTPT_ATerm arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a PTPT_Annotation. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return PTPT_Annotation that was encoded by \arg
 */
PTPT_Annotation _PTPT_AnnotationFromTerm(ATerm t) {
  return (PTPT_Annotation)t;
}

/**
 * Transforms a PTPT_Annotationto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg PTPT_Annotation to be converted
 * \return ATerm that represents the PTPT_Annotation
 */
ATerm _PTPT_AnnotationToTerm(PTPT_Annotation arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a PTPT_ATermArgs. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return PTPT_ATermArgs that was encoded by \arg
 */
PTPT_ATermArgs _PTPT_ATermArgsFromTerm(ATerm t) {
  return (PTPT_ATermArgs)t;
}

/**
 * Transforms a PTPT_ATermArgsto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg PTPT_ATermArgs to be converted
 * \return ATerm that represents the PTPT_ATermArgs
 */
ATerm _PTPT_ATermArgsToTerm(PTPT_ATermArgs arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a PTPT_ATermElems. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return PTPT_ATermElems that was encoded by \arg
 */
PTPT_ATermElems _PTPT_ATermElemsFromTerm(ATerm t) {
  return (PTPT_ATermElems)t;
}

/**
 * Transforms a PTPT_ATermElemsto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg PTPT_ATermElems to be converted
 * \return ATerm that represents the PTPT_ATermElems
 */
ATerm _PTPT_ATermElemsToTerm(PTPT_ATermElems arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a PTPT_ATermAnnos. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return PTPT_ATermAnnos that was encoded by \arg
 */
PTPT_ATermAnnos _PTPT_ATermAnnosFromTerm(ATerm t) {
  return (PTPT_ATermAnnos)t;
}

/**
 * Transforms a PTPT_ATermAnnosto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg PTPT_ATermAnnos to be converted
 * \return ATerm that represents the PTPT_ATermAnnos
 */
ATerm _PTPT_ATermAnnosToTerm(PTPT_ATermAnnos arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a PTPT_IntCon. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return PTPT_IntCon that was encoded by \arg
 */
PTPT_IntCon _PTPT_IntConFromTerm(ATerm t) {
  return (PTPT_IntCon)t;
}

/**
 * Transforms a PTPT_IntConto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg PTPT_IntCon to be converted
 * \return ATerm that represents the PTPT_IntCon
 */
ATerm _PTPT_IntConToTerm(PTPT_IntCon arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a PTPT_OptExp. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return PTPT_OptExp that was encoded by \arg
 */
PTPT_OptExp _PTPT_OptExpFromTerm(ATerm t) {
  return (PTPT_OptExp)t;
}

/**
 * Transforms a PTPT_OptExpto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg PTPT_OptExp to be converted
 * \return ATerm that represents the PTPT_OptExp
 */
ATerm _PTPT_OptExpToTerm(PTPT_OptExp arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a PTPT_RealCon. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return PTPT_RealCon that was encoded by \arg
 */
PTPT_RealCon _PTPT_RealConFromTerm(ATerm t) {
  return (PTPT_RealCon)t;
}

/**
 * Transforms a PTPT_RealConto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg PTPT_RealCon to be converted
 * \return ATerm that represents the PTPT_RealCon
 */
ATerm _PTPT_RealConToTerm(PTPT_RealCon arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a PTPT_LexStrChar. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return PTPT_LexStrChar that was encoded by \arg
 */
PTPT_LexStrChar _PTPT_LexStrCharFromTerm(ATerm t) {
  return (PTPT_LexStrChar)t;
}

/**
 * Transforms a PTPT_LexStrCharto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg PTPT_LexStrChar to be converted
 * \return ATerm that represents the PTPT_LexStrChar
 */
ATerm _PTPT_LexStrCharToTerm(PTPT_LexStrChar arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a PTPT_StrChar. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return PTPT_StrChar that was encoded by \arg
 */
PTPT_StrChar _PTPT_StrCharFromTerm(ATerm t) {
  return (PTPT_StrChar)t;
}

/**
 * Transforms a PTPT_StrCharto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg PTPT_StrChar to be converted
 * \return ATerm that represents the PTPT_StrChar
 */
ATerm _PTPT_StrCharToTerm(PTPT_StrChar arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a PTPT_LexStrCon. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return PTPT_LexStrCon that was encoded by \arg
 */
PTPT_LexStrCon _PTPT_LexStrConFromTerm(ATerm t) {
  return (PTPT_LexStrCon)t;
}

/**
 * Transforms a PTPT_LexStrConto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg PTPT_LexStrCon to be converted
 * \return ATerm that represents the PTPT_LexStrCon
 */
ATerm _PTPT_LexStrConToTerm(PTPT_LexStrCon arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a PTPT_StrCon. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return PTPT_StrCon that was encoded by \arg
 */
PTPT_StrCon _PTPT_StrConFromTerm(ATerm t) {
  return (PTPT_StrCon)t;
}

/**
 * Transforms a PTPT_StrConto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg PTPT_StrCon to be converted
 * \return ATerm that represents the PTPT_StrCon
 */
ATerm _PTPT_StrConToTerm(PTPT_StrCon arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a PTPT_LexStrCharChars. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return PTPT_LexStrCharChars that was encoded by \arg
 */
PTPT_LexStrCharChars _PTPT_LexStrCharCharsFromTerm(ATerm t) {
  return (PTPT_LexStrCharChars)t;
}

/**
 * Transforms a PTPT_LexStrCharCharsto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg PTPT_LexStrCharChars to be converted
 * \return ATerm that represents the PTPT_LexStrCharChars
 */
ATerm _PTPT_LexStrCharCharsToTerm(PTPT_LexStrCharChars arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a PTPT_LexNatCon. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return PTPT_LexNatCon that was encoded by \arg
 */
PTPT_LexNatCon _PTPT_LexNatConFromTerm(ATerm t) {
  return (PTPT_LexNatCon)t;
}

/**
 * Transforms a PTPT_LexNatConto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg PTPT_LexNatCon to be converted
 * \return ATerm that represents the PTPT_LexNatCon
 */
ATerm _PTPT_LexNatConToTerm(PTPT_LexNatCon arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a PTPT_NatCon. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return PTPT_NatCon that was encoded by \arg
 */
PTPT_NatCon _PTPT_NatConFromTerm(ATerm t) {
  return (PTPT_NatCon)t;
}

/**
 * Transforms a PTPT_NatConto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg PTPT_NatCon to be converted
 * \return ATerm that represents the PTPT_NatCon
 */
ATerm _PTPT_NatConToTerm(PTPT_NatCon arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a PTPT_LexIdCon. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return PTPT_LexIdCon that was encoded by \arg
 */
PTPT_LexIdCon _PTPT_LexIdConFromTerm(ATerm t) {
  return (PTPT_LexIdCon)t;
}

/**
 * Transforms a PTPT_LexIdConto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg PTPT_LexIdCon to be converted
 * \return ATerm that represents the PTPT_LexIdCon
 */
ATerm _PTPT_LexIdConToTerm(PTPT_LexIdCon arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a PTPT_IdCon. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return PTPT_IdCon that was encoded by \arg
 */
PTPT_IdCon _PTPT_IdConFromTerm(ATerm t) {
  return (PTPT_IdCon)t;
}

/**
 * Transforms a PTPT_IdConto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg PTPT_IdCon to be converted
 * \return ATerm that represents the PTPT_IdCon
 */
ATerm _PTPT_IdConToTerm(PTPT_IdCon arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a PTPT_LexLayout. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return PTPT_LexLayout that was encoded by \arg
 */
PTPT_LexLayout _PTPT_LexLayoutFromTerm(ATerm t) {
  return (PTPT_LexLayout)t;
}

/**
 * Transforms a PTPT_LexLayoutto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg PTPT_LexLayout to be converted
 * \return ATerm that represents the PTPT_LexLayout
 */
ATerm _PTPT_LexLayoutToTerm(PTPT_LexLayout arg) {
  return (ATerm)arg;
}

/**
 * Retrieve the length of a PTPT_LexLayoutList. 
 * \param[in] arg input PTPT_LexLayoutList
 * \return The number of elements in the PTPT_LexLayoutList
 */
int _PTPT_getLexLayoutListLength(PTPT_LexLayoutList arg) {
  return ATgetLength((ATermList) arg);
}

/**
 * Reverse a PTPT_LexLayoutList. 
 * \param[in] arg PTPT_LexLayoutList to be reversed
 * \return a reversed #arg
 */
PTPT_LexLayoutList _PTPT_reverseLexLayoutList(PTPT_LexLayoutList arg) {
  return (PTPT_LexLayoutList) ATreverse((ATermList) arg);
}

/**
 * Append a PTPT_LexLayout to the end of a PTPT_LexLayoutList. 
 * \param[in] arg PTPT_LexLayoutList to append the PTPT_LexLayout to
 * \param[in] elem PTPT_LexLayout to be appended
 * \return new PTPT_LexLayoutList with #elem appended
 */
PTPT_LexLayoutList _PTPT_appendLexLayoutList(PTPT_LexLayoutList arg, PTPT_LexLayout elem) {
  return (PTPT_LexLayoutList) ATappend((ATermList) arg, (ATerm) ((ATerm) elem));
}

/**
 * Concatenate two PTPT_LexLayoutLists. 
 * \param[in] arg0 first PTPT_LexLayoutList
 * \param[in] arg1 second PTPT_LexLayoutList
 * \return PTPT_LexLayoutList with the elements of #arg0 before the elements of #arg1
 */
PTPT_LexLayoutList _PTPT_concatLexLayoutList(PTPT_LexLayoutList arg0, PTPT_LexLayoutList arg1) {
  return (PTPT_LexLayoutList) ATconcat((ATermList) arg0, (ATermList) arg1);
}

/**
 * Extract a sublist from a PTPT_LexLayoutList. 
 * \param[in] arg PTPT_LexLayoutList to extract a slice from
 * \param[in] start inclusive start index of the sublist
 * \param[in] end exclusive end index of the sublist
 * \return new PTPT_LexLayoutList with a first element the element at index #start from #arg, and as last element the element at index (#end - 1).
 */
PTPT_LexLayoutList _PTPT_sliceLexLayoutList(PTPT_LexLayoutList arg, int start, int end) {
  return (PTPT_LexLayoutList) ATgetSlice((ATermList) arg, start, end);
}

/**
 * Retrieve the PTPT_LexLayout at #index from a PTPT_LexLayoutList. 
 * \param[in] arg PTPT_LexLayoutList to retrieve the PTPT_LexLayout from
 * \param[in] index index to use to point in the PTPT_LexLayoutList
 * \return PTPT_LexLayout at position #index in #arg
 */
PTPT_LexLayout _PTPT_getLexLayoutListLexLayoutAt(PTPT_LexLayoutList arg, int index) {
 return (PTPT_LexLayout)ATelementAt((ATermList) arg,index);
}

/**
 * Replace the PTPT_LexLayout at #index from a PTPT_LexLayoutList by a new one. 
 * \param[in] arg PTPT_LexLayoutList to retrieve the PTPT_LexLayout from
 * \param[in] elem new PTPT_LexLayout to replace another
 * \param[in] index index to use to point in the PTPT_LexLayoutList
 * \return A new PTPT_LexLayoutListwith #elem replaced in #arg at position #index
 */
PTPT_LexLayoutList _PTPT_replaceLexLayoutListLexLayoutAt(PTPT_LexLayoutList arg, PTPT_LexLayout elem, int index) {
 return (PTPT_LexLayoutList) ATreplace((ATermList) arg, (ATerm) ((ATerm) elem), index);
}

/**
 * Builds a PTPT_LexLayoutList of 2 consecutive elements. 
 * \param[in] elem1 One PTPT_LexLayout element of the new PTPT_LexLayoutList
 * \param[in] elem2 One PTPT_LexLayout element of the new PTPT_LexLayoutList
 * \return A new PTPT_LexLayoutList consisting of 2 PTPT_LexLayouts
 */
PTPT_LexLayoutList _PTPT_makeLexLayoutList2(PTPT_LexLayout elem1, PTPT_LexLayout elem2) {
  return (PTPT_LexLayoutList) ATmakeList2((ATerm) ((ATerm) elem1), (ATerm) ((ATerm) elem2));
}

/**
 * Builds a PTPT_LexLayoutList of 3 consecutive elements. 
 * \param[in] elem1 One PTPT_LexLayout element of the new PTPT_LexLayoutList
 * \param[in] elem2 One PTPT_LexLayout element of the new PTPT_LexLayoutList
 * \param[in] elem3 One PTPT_LexLayout element of the new PTPT_LexLayoutList
 * \return A new PTPT_LexLayoutList consisting of 3 PTPT_LexLayouts
 */
PTPT_LexLayoutList _PTPT_makeLexLayoutList3(PTPT_LexLayout elem1, PTPT_LexLayout elem2, PTPT_LexLayout elem3) {
  return (PTPT_LexLayoutList) ATmakeList3((ATerm) ((ATerm) elem1), (ATerm) ((ATerm) elem2), (ATerm) ((ATerm) elem3));
}

/**
 * Builds a PTPT_LexLayoutList of 4 consecutive elements. 
 * \param[in] elem1 One PTPT_LexLayout element of the new PTPT_LexLayoutList
 * \param[in] elem2 One PTPT_LexLayout element of the new PTPT_LexLayoutList
 * \param[in] elem3 One PTPT_LexLayout element of the new PTPT_LexLayoutList
 * \param[in] elem4 One PTPT_LexLayout element of the new PTPT_LexLayoutList
 * \return A new PTPT_LexLayoutList consisting of 4 PTPT_LexLayouts
 */
PTPT_LexLayoutList _PTPT_makeLexLayoutList4(PTPT_LexLayout elem1, PTPT_LexLayout elem2, PTPT_LexLayout elem3, PTPT_LexLayout elem4) {
  return (PTPT_LexLayoutList) ATmakeList4((ATerm) ((ATerm) elem1), (ATerm) ((ATerm) elem2), (ATerm) ((ATerm) elem3), (ATerm) ((ATerm) elem4));
}

/**
 * Builds a PTPT_LexLayoutList of 5 consecutive elements. 
 * \param[in] elem1 One PTPT_LexLayout element of the new PTPT_LexLayoutList
 * \param[in] elem2 One PTPT_LexLayout element of the new PTPT_LexLayoutList
 * \param[in] elem3 One PTPT_LexLayout element of the new PTPT_LexLayoutList
 * \param[in] elem4 One PTPT_LexLayout element of the new PTPT_LexLayoutList
 * \param[in] elem5 One PTPT_LexLayout element of the new PTPT_LexLayoutList
 * \return A new PTPT_LexLayoutList consisting of 5 PTPT_LexLayouts
 */
PTPT_LexLayoutList _PTPT_makeLexLayoutList5(PTPT_LexLayout elem1, PTPT_LexLayout elem2, PTPT_LexLayout elem3, PTPT_LexLayout elem4, PTPT_LexLayout elem5) {
  return (PTPT_LexLayoutList) ATmakeList5((ATerm) ((ATerm) elem1), (ATerm) ((ATerm) elem2), (ATerm) ((ATerm) elem3), (ATerm) ((ATerm) elem4), (ATerm) ((ATerm) elem5));
}

/**
 * Builds a PTPT_LexLayoutList of 6 consecutive elements. 
 * \param[in] elem1 One PTPT_LexLayout element of the new PTPT_LexLayoutList
 * \param[in] elem2 One PTPT_LexLayout element of the new PTPT_LexLayoutList
 * \param[in] elem3 One PTPT_LexLayout element of the new PTPT_LexLayoutList
 * \param[in] elem4 One PTPT_LexLayout element of the new PTPT_LexLayoutList
 * \param[in] elem5 One PTPT_LexLayout element of the new PTPT_LexLayoutList
 * \param[in] elem6 One PTPT_LexLayout element of the new PTPT_LexLayoutList
 * \return A new PTPT_LexLayoutList consisting of 6 PTPT_LexLayouts
 */
PTPT_LexLayoutList _PTPT_makeLexLayoutList6(PTPT_LexLayout elem1, PTPT_LexLayout elem2, PTPT_LexLayout elem3, PTPT_LexLayout elem4, PTPT_LexLayout elem5, PTPT_LexLayout elem6) {
  return (PTPT_LexLayoutList) ATmakeList6((ATerm) ((ATerm) elem1), (ATerm) ((ATerm) elem2), (ATerm) ((ATerm) elem3), (ATerm) ((ATerm) elem4), (ATerm) ((ATerm) elem5), (ATerm) ((ATerm) elem6));
}

/**
 * Retrieve the number of elements in a PTPT_AttrList. 
 * \param[in] arg input PTPT_AttrList
 * \return The number of elements in #arg, excluding any separators
 */
int _PTPT_getAttrListLength(PTPT_AttrList arg) {
  if (ATisEmpty((ATermList) arg)) {
    return 0;
  }
  return (ATgetLength((ATermList) arg) / 4) + 1;
}

/**
 * Reverses the elements of a PTPT_AttrList. Note that separators are reversed with the list, but the order in which each set of separators inbetween two elements occurs does not change
 * \param[in] arg PTPT_AttrList to be reversed
 * \return #arg reversed
 */
PTPT_AttrList PTPT_reverseAttrList(PTPT_AttrList arg) {
  ATermList list = (ATermList) arg;
  ATerm head;
  ATerm sep0;
  ATerm sep1;
  ATerm sep2;
  ATermList result;

 if (ATisEmpty(list) || ATgetLength(list) == 1) {
    return arg;
  }

  result = ATmakeList1(ATgetFirst(list));
      list = ATgetNext(list);
  sep0 = ATgetFirst(list);
  list = ATgetNext(list);
  sep1 = ATgetFirst(list);
  list = ATgetNext(list);
  sep2 = ATgetFirst(list);
  list = ATgetNext(list);

  while (!ATisEmpty(list)) {
    result = ATinsert(result, sep2);
    result = ATinsert(result, sep1);
    result = ATinsert(result, sep0);

   head = ATgetFirst(list);
   result = ATinsert(result, head);
    list = ATgetNext(list);

   if (!ATisEmpty(list)) {
  sep0 = ATgetFirst(list);
  list = ATgetNext(list);
  sep1 = ATgetFirst(list);
  list = ATgetNext(list);
  sep2 = ATgetFirst(list);
  list = ATgetNext(list);
   }
  }

  return (PTPT_AttrList) result;
}

/**
 * Append a PTPT_Attr to the end of a PTPT_AttrList. 
 * \param[in] arg PTPT_AttrList to append the PTPT_Attr to
 * \param[in] elem PTPT_Attr to be appended
 * \return new PTPT_AttrList with #elem appended after the separators
 */
PTPT_AttrList PTPT_appendAttrList(PTPT_AttrList arg0, PTPT_OptLayout wsAfterHead, PTPT_OptLayout wsAfterSep, PTPT_Attr arg1) {
  return PTPT_concatAttrList(arg0, wsAfterHead, wsAfterSep, PTPT_makeAttrListSingle(arg1));
}

/**
 * Concatenate two PTPT_AttrLists. 
 * \param[in] arg0 first PTPT_AttrList
 * \param[in] arg1 second PTPT_AttrList
 * \return PTPT_AttrList with the elements of #arg0 before the elements of #arg1, with the separators in between.
 */
PTPT_AttrList PTPT_concatAttrList(PTPT_AttrList arg0, PTPT_OptLayout wsAfterHead, PTPT_OptLayout wsAfterSep, PTPT_AttrList arg1) {
  if (ATisEmpty((ATermList) arg0)) {
    return arg1;
  }
  arg1 = PTPT_makeAttrListMany((PTPT_Attr)ATgetFirst((ATermList) arg0), wsAfterHead, wsAfterSep,  arg1);
  arg1 = (PTPT_AttrList) ATgetNext((ATermList) arg1);
  return (PTPT_AttrList) ATconcat((ATermList) arg0, (ATermList) arg1);
}

/**
 * Extract a sublist from a PTPT_AttrList. 
 * \param[in] arg PTPT_AttrList to extract a slice from
 * \param[in] start inclusive start index of the sublist
 * \param[in] end exclusive end index of the sublist
 * \return new PTPT_AttrList with a first element the element at index #start from #arg, and as last element the element at index (#end - 1).
 */
PTPT_AttrList _PTPT_sliceAttrList(PTPT_AttrList arg, int start, int end) {
  return (PTPT_AttrList) ATgetSlice((ATermList) arg, start * 4, end * 4);
}

/**
 * Retrieve the PTPT_Attr at #index from a PTPT_AttrList. 
 * \param[in] arg PTPT_AttrList to retrieve the PTPT_Attr from
 * \param[in] index index to use to point in the PTPT_AttrList
 * \return PTPT_Attr at position #index in #arg
 */
PTPT_Attr _PTPT_getAttrListAttrAt(PTPT_AttrList arg, int index) {
 return (PTPT_Attr)ATelementAt((ATermList) arg,index * 4);
}

/**
 * Replace the PTPT_Attr at #index from a PTPT_AttrList by a new one. 
 * \param[in] arg PTPT_AttrList to retrieve the PTPT_Attr from
 * \param[in] elem new PTPT_Attr to replace another
 * \param[in] index index to use to point in the PTPT_AttrList
 * \return A new PTPT_AttrListwith #elem replaced in #arg at position #index
 */
PTPT_AttrList _PTPT_replaceAttrListAttrAt(PTPT_AttrList arg, PTPT_Attr elem, int index) {
 return (PTPT_AttrList) ATreplace((ATermList) arg, (ATerm) ((ATerm) elem), index * 4);
}

/**
 * Builds a PTPT_AttrList of 2 consecutive elements. The elements are separated.
 * \param[in] elem1 One PTPT_Attr element of the new PTPT_AttrList
 * \param[in] elem2 One PTPT_Attr element of the new PTPT_AttrList
 * \return A new PTPT_AttrList consisting of 2 PTPT_Attrs
 */
PTPT_AttrList PTPT_makeAttrList2(PTPT_OptLayout wsAfterHead, PTPT_OptLayout wsAfterSep, PTPT_Attr elem1, PTPT_Attr elem2) {
  return PTPT_makeAttrListMany(elem1, wsAfterHead, wsAfterSep, PTPT_makeAttrListSingle(elem2));
}

/**
 * Builds a PTPT_AttrList of 3 consecutive elements. The elements are separated.
 * \param[in] elem1 One PTPT_Attr element of the new PTPT_AttrList
 * \param[in] elem2 One PTPT_Attr element of the new PTPT_AttrList
 * \param[in] elem3 One PTPT_Attr element of the new PTPT_AttrList
 * \return A new PTPT_AttrList consisting of 3 PTPT_Attrs
 */
PTPT_AttrList PTPT_makeAttrList3(PTPT_OptLayout wsAfterHead, PTPT_OptLayout wsAfterSep, PTPT_Attr elem1, PTPT_Attr elem2, PTPT_Attr elem3) {
  return PTPT_makeAttrListMany(elem1, wsAfterHead, wsAfterSep, PTPT_makeAttrList2(wsAfterHead, wsAfterSep, elem2, elem3));
}

/**
 * Builds a PTPT_AttrList of 4 consecutive elements. The elements are separated.
 * \param[in] elem1 One PTPT_Attr element of the new PTPT_AttrList
 * \param[in] elem2 One PTPT_Attr element of the new PTPT_AttrList
 * \param[in] elem3 One PTPT_Attr element of the new PTPT_AttrList
 * \param[in] elem4 One PTPT_Attr element of the new PTPT_AttrList
 * \return A new PTPT_AttrList consisting of 4 PTPT_Attrs
 */
PTPT_AttrList PTPT_makeAttrList4(PTPT_OptLayout wsAfterHead, PTPT_OptLayout wsAfterSep, PTPT_Attr elem1, PTPT_Attr elem2, PTPT_Attr elem3, PTPT_Attr elem4) {
  return PTPT_makeAttrListMany(elem1, wsAfterHead, wsAfterSep, PTPT_makeAttrList3(wsAfterHead, wsAfterSep, elem2, elem3, elem4));
}

/**
 * Builds a PTPT_AttrList of 5 consecutive elements. The elements are separated.
 * \param[in] elem1 One PTPT_Attr element of the new PTPT_AttrList
 * \param[in] elem2 One PTPT_Attr element of the new PTPT_AttrList
 * \param[in] elem3 One PTPT_Attr element of the new PTPT_AttrList
 * \param[in] elem4 One PTPT_Attr element of the new PTPT_AttrList
 * \param[in] elem5 One PTPT_Attr element of the new PTPT_AttrList
 * \return A new PTPT_AttrList consisting of 5 PTPT_Attrs
 */
PTPT_AttrList PTPT_makeAttrList5(PTPT_OptLayout wsAfterHead, PTPT_OptLayout wsAfterSep, PTPT_Attr elem1, PTPT_Attr elem2, PTPT_Attr elem3, PTPT_Attr elem4, PTPT_Attr elem5) {
  return PTPT_makeAttrListMany(elem1, wsAfterHead, wsAfterSep, PTPT_makeAttrList4(wsAfterHead, wsAfterSep, elem2, elem3, elem4, elem5));
}

/**
 * Builds a PTPT_AttrList of 6 consecutive elements. The elements are separated.
 * \param[in] elem1 One PTPT_Attr element of the new PTPT_AttrList
 * \param[in] elem2 One PTPT_Attr element of the new PTPT_AttrList
 * \param[in] elem3 One PTPT_Attr element of the new PTPT_AttrList
 * \param[in] elem4 One PTPT_Attr element of the new PTPT_AttrList
 * \param[in] elem5 One PTPT_Attr element of the new PTPT_AttrList
 * \param[in] elem6 One PTPT_Attr element of the new PTPT_AttrList
 * \return A new PTPT_AttrList consisting of 6 PTPT_Attrs
 */
PTPT_AttrList PTPT_makeAttrList6(PTPT_OptLayout wsAfterHead, PTPT_OptLayout wsAfterSep, PTPT_Attr elem1, PTPT_Attr elem2, PTPT_Attr elem3, PTPT_Attr elem4, PTPT_Attr elem5, PTPT_Attr elem6) {
  return PTPT_makeAttrListMany(elem1, wsAfterHead, wsAfterSep, PTPT_makeAttrList5(wsAfterHead, wsAfterSep, elem2, elem3, elem4, elem5, elem6));
}

/**
 * Retrieve the number of elements in a PTPT_SymbolList. 
 * \param[in] arg input PTPT_SymbolList
 * \return The number of elements in #arg, excluding any separators
 */
int _PTPT_getSymbolListLength(PTPT_SymbolList arg) {
  if (ATisEmpty((ATermList) arg)) {
    return 0;
  }
  return (ATgetLength((ATermList) arg) / 4) + 1;
}

/**
 * Reverses the elements of a PTPT_SymbolList. Note that separators are reversed with the list, but the order in which each set of separators inbetween two elements occurs does not change
 * \param[in] arg PTPT_SymbolList to be reversed
 * \return #arg reversed
 */
PTPT_SymbolList PTPT_reverseSymbolList(PTPT_SymbolList arg) {
  ATermList list = (ATermList) arg;
  ATerm head;
  ATerm sep0;
  ATerm sep1;
  ATerm sep2;
  ATermList result;

 if (ATisEmpty(list) || ATgetLength(list) == 1) {
    return arg;
  }

  result = ATmakeList1(ATgetFirst(list));
      list = ATgetNext(list);
  sep0 = ATgetFirst(list);
  list = ATgetNext(list);
  sep1 = ATgetFirst(list);
  list = ATgetNext(list);
  sep2 = ATgetFirst(list);
  list = ATgetNext(list);

  while (!ATisEmpty(list)) {
    result = ATinsert(result, sep2);
    result = ATinsert(result, sep1);
    result = ATinsert(result, sep0);

   head = ATgetFirst(list);
   result = ATinsert(result, head);
    list = ATgetNext(list);

   if (!ATisEmpty(list)) {
  sep0 = ATgetFirst(list);
  list = ATgetNext(list);
  sep1 = ATgetFirst(list);
  list = ATgetNext(list);
  sep2 = ATgetFirst(list);
  list = ATgetNext(list);
   }
  }

  return (PTPT_SymbolList) result;
}

/**
 * Append a PTPT_Symbol to the end of a PTPT_SymbolList. 
 * \param[in] arg PTPT_SymbolList to append the PTPT_Symbol to
 * \param[in] elem PTPT_Symbol to be appended
 * \return new PTPT_SymbolList with #elem appended after the separators
 */
PTPT_SymbolList PTPT_appendSymbolList(PTPT_SymbolList arg0, PTPT_OptLayout wsAfterHead, PTPT_OptLayout wsAfterSep, PTPT_Symbol arg1) {
  return PTPT_concatSymbolList(arg0, wsAfterHead, wsAfterSep, PTPT_makeSymbolListSingle(arg1));
}

/**
 * Concatenate two PTPT_SymbolLists. 
 * \param[in] arg0 first PTPT_SymbolList
 * \param[in] arg1 second PTPT_SymbolList
 * \return PTPT_SymbolList with the elements of #arg0 before the elements of #arg1, with the separators in between.
 */
PTPT_SymbolList PTPT_concatSymbolList(PTPT_SymbolList arg0, PTPT_OptLayout wsAfterHead, PTPT_OptLayout wsAfterSep, PTPT_SymbolList arg1) {
  if (ATisEmpty((ATermList) arg0)) {
    return arg1;
  }
  arg1 = PTPT_makeSymbolListMany((PTPT_Symbol)ATgetFirst((ATermList) arg0), wsAfterHead, wsAfterSep,  arg1);
  arg1 = (PTPT_SymbolList) ATgetNext((ATermList) arg1);
  return (PTPT_SymbolList) ATconcat((ATermList) arg0, (ATermList) arg1);
}

/**
 * Extract a sublist from a PTPT_SymbolList. 
 * \param[in] arg PTPT_SymbolList to extract a slice from
 * \param[in] start inclusive start index of the sublist
 * \param[in] end exclusive end index of the sublist
 * \return new PTPT_SymbolList with a first element the element at index #start from #arg, and as last element the element at index (#end - 1).
 */
PTPT_SymbolList _PTPT_sliceSymbolList(PTPT_SymbolList arg, int start, int end) {
  return (PTPT_SymbolList) ATgetSlice((ATermList) arg, start * 4, end * 4);
}

/**
 * Retrieve the PTPT_Symbol at #index from a PTPT_SymbolList. 
 * \param[in] arg PTPT_SymbolList to retrieve the PTPT_Symbol from
 * \param[in] index index to use to point in the PTPT_SymbolList
 * \return PTPT_Symbol at position #index in #arg
 */
PTPT_Symbol _PTPT_getSymbolListSymbolAt(PTPT_SymbolList arg, int index) {
 return (PTPT_Symbol)ATelementAt((ATermList) arg,index * 4);
}

/**
 * Replace the PTPT_Symbol at #index from a PTPT_SymbolList by a new one. 
 * \param[in] arg PTPT_SymbolList to retrieve the PTPT_Symbol from
 * \param[in] elem new PTPT_Symbol to replace another
 * \param[in] index index to use to point in the PTPT_SymbolList
 * \return A new PTPT_SymbolListwith #elem replaced in #arg at position #index
 */
PTPT_SymbolList _PTPT_replaceSymbolListSymbolAt(PTPT_SymbolList arg, PTPT_Symbol elem, int index) {
 return (PTPT_SymbolList) ATreplace((ATermList) arg, (ATerm) ((ATerm) elem), index * 4);
}

/**
 * Builds a PTPT_SymbolList of 2 consecutive elements. The elements are separated.
 * \param[in] elem1 One PTPT_Symbol element of the new PTPT_SymbolList
 * \param[in] elem2 One PTPT_Symbol element of the new PTPT_SymbolList
 * \return A new PTPT_SymbolList consisting of 2 PTPT_Symbols
 */
PTPT_SymbolList PTPT_makeSymbolList2(PTPT_OptLayout wsAfterHead, PTPT_OptLayout wsAfterSep, PTPT_Symbol elem1, PTPT_Symbol elem2) {
  return PTPT_makeSymbolListMany(elem1, wsAfterHead, wsAfterSep, PTPT_makeSymbolListSingle(elem2));
}

/**
 * Builds a PTPT_SymbolList of 3 consecutive elements. The elements are separated.
 * \param[in] elem1 One PTPT_Symbol element of the new PTPT_SymbolList
 * \param[in] elem2 One PTPT_Symbol element of the new PTPT_SymbolList
 * \param[in] elem3 One PTPT_Symbol element of the new PTPT_SymbolList
 * \return A new PTPT_SymbolList consisting of 3 PTPT_Symbols
 */
PTPT_SymbolList PTPT_makeSymbolList3(PTPT_OptLayout wsAfterHead, PTPT_OptLayout wsAfterSep, PTPT_Symbol elem1, PTPT_Symbol elem2, PTPT_Symbol elem3) {
  return PTPT_makeSymbolListMany(elem1, wsAfterHead, wsAfterSep, PTPT_makeSymbolList2(wsAfterHead, wsAfterSep, elem2, elem3));
}

/**
 * Builds a PTPT_SymbolList of 4 consecutive elements. The elements are separated.
 * \param[in] elem1 One PTPT_Symbol element of the new PTPT_SymbolList
 * \param[in] elem2 One PTPT_Symbol element of the new PTPT_SymbolList
 * \param[in] elem3 One PTPT_Symbol element of the new PTPT_SymbolList
 * \param[in] elem4 One PTPT_Symbol element of the new PTPT_SymbolList
 * \return A new PTPT_SymbolList consisting of 4 PTPT_Symbols
 */
PTPT_SymbolList PTPT_makeSymbolList4(PTPT_OptLayout wsAfterHead, PTPT_OptLayout wsAfterSep, PTPT_Symbol elem1, PTPT_Symbol elem2, PTPT_Symbol elem3, PTPT_Symbol elem4) {
  return PTPT_makeSymbolListMany(elem1, wsAfterHead, wsAfterSep, PTPT_makeSymbolList3(wsAfterHead, wsAfterSep, elem2, elem3, elem4));
}

/**
 * Builds a PTPT_SymbolList of 5 consecutive elements. The elements are separated.
 * \param[in] elem1 One PTPT_Symbol element of the new PTPT_SymbolList
 * \param[in] elem2 One PTPT_Symbol element of the new PTPT_SymbolList
 * \param[in] elem3 One PTPT_Symbol element of the new PTPT_SymbolList
 * \param[in] elem4 One PTPT_Symbol element of the new PTPT_SymbolList
 * \param[in] elem5 One PTPT_Symbol element of the new PTPT_SymbolList
 * \return A new PTPT_SymbolList consisting of 5 PTPT_Symbols
 */
PTPT_SymbolList PTPT_makeSymbolList5(PTPT_OptLayout wsAfterHead, PTPT_OptLayout wsAfterSep, PTPT_Symbol elem1, PTPT_Symbol elem2, PTPT_Symbol elem3, PTPT_Symbol elem4, PTPT_Symbol elem5) {
  return PTPT_makeSymbolListMany(elem1, wsAfterHead, wsAfterSep, PTPT_makeSymbolList4(wsAfterHead, wsAfterSep, elem2, elem3, elem4, elem5));
}

/**
 * Builds a PTPT_SymbolList of 6 consecutive elements. The elements are separated.
 * \param[in] elem1 One PTPT_Symbol element of the new PTPT_SymbolList
 * \param[in] elem2 One PTPT_Symbol element of the new PTPT_SymbolList
 * \param[in] elem3 One PTPT_Symbol element of the new PTPT_SymbolList
 * \param[in] elem4 One PTPT_Symbol element of the new PTPT_SymbolList
 * \param[in] elem5 One PTPT_Symbol element of the new PTPT_SymbolList
 * \param[in] elem6 One PTPT_Symbol element of the new PTPT_SymbolList
 * \return A new PTPT_SymbolList consisting of 6 PTPT_Symbols
 */
PTPT_SymbolList PTPT_makeSymbolList6(PTPT_OptLayout wsAfterHead, PTPT_OptLayout wsAfterSep, PTPT_Symbol elem1, PTPT_Symbol elem2, PTPT_Symbol elem3, PTPT_Symbol elem4, PTPT_Symbol elem5, PTPT_Symbol elem6) {
  return PTPT_makeSymbolListMany(elem1, wsAfterHead, wsAfterSep, PTPT_makeSymbolList5(wsAfterHead, wsAfterSep, elem2, elem3, elem4, elem5, elem6));
}

/**
 * Retrieve the number of elements in a PTPT_CharRangeList. 
 * \param[in] arg input PTPT_CharRangeList
 * \return The number of elements in #arg, excluding any separators
 */
int _PTPT_getCharRangeListLength(PTPT_CharRangeList arg) {
  if (ATisEmpty((ATermList) arg)) {
    return 0;
  }
  return (ATgetLength((ATermList) arg) / 4) + 1;
}

/**
 * Reverses the elements of a PTPT_CharRangeList. Note that separators are reversed with the list, but the order in which each set of separators inbetween two elements occurs does not change
 * \param[in] arg PTPT_CharRangeList to be reversed
 * \return #arg reversed
 */
PTPT_CharRangeList PTPT_reverseCharRangeList(PTPT_CharRangeList arg) {
  ATermList list = (ATermList) arg;
  ATerm head;
  ATerm sep0;
  ATerm sep1;
  ATerm sep2;
  ATermList result;

 if (ATisEmpty(list) || ATgetLength(list) == 1) {
    return arg;
  }

  result = ATmakeList1(ATgetFirst(list));
      list = ATgetNext(list);
  sep0 = ATgetFirst(list);
  list = ATgetNext(list);
  sep1 = ATgetFirst(list);
  list = ATgetNext(list);
  sep2 = ATgetFirst(list);
  list = ATgetNext(list);

  while (!ATisEmpty(list)) {
    result = ATinsert(result, sep2);
    result = ATinsert(result, sep1);
    result = ATinsert(result, sep0);

   head = ATgetFirst(list);
   result = ATinsert(result, head);
    list = ATgetNext(list);

   if (!ATisEmpty(list)) {
  sep0 = ATgetFirst(list);
  list = ATgetNext(list);
  sep1 = ATgetFirst(list);
  list = ATgetNext(list);
  sep2 = ATgetFirst(list);
  list = ATgetNext(list);
   }
  }

  return (PTPT_CharRangeList) result;
}

/**
 * Append a PTPT_CharRange to the end of a PTPT_CharRangeList. 
 * \param[in] arg PTPT_CharRangeList to append the PTPT_CharRange to
 * \param[in] elem PTPT_CharRange to be appended
 * \return new PTPT_CharRangeList with #elem appended after the separators
 */
PTPT_CharRangeList PTPT_appendCharRangeList(PTPT_CharRangeList arg0, PTPT_OptLayout wsAfterHead, PTPT_OptLayout wsAfterSep, PTPT_CharRange arg1) {
  return PTPT_concatCharRangeList(arg0, wsAfterHead, wsAfterSep, PTPT_makeCharRangeListSingle(arg1));
}

/**
 * Concatenate two PTPT_CharRangeLists. 
 * \param[in] arg0 first PTPT_CharRangeList
 * \param[in] arg1 second PTPT_CharRangeList
 * \return PTPT_CharRangeList with the elements of #arg0 before the elements of #arg1, with the separators in between.
 */
PTPT_CharRangeList PTPT_concatCharRangeList(PTPT_CharRangeList arg0, PTPT_OptLayout wsAfterHead, PTPT_OptLayout wsAfterSep, PTPT_CharRangeList arg1) {
  if (ATisEmpty((ATermList) arg0)) {
    return arg1;
  }
  arg1 = PTPT_makeCharRangeListMany((PTPT_CharRange)ATgetFirst((ATermList) arg0), wsAfterHead, wsAfterSep,  arg1);
  arg1 = (PTPT_CharRangeList) ATgetNext((ATermList) arg1);
  return (PTPT_CharRangeList) ATconcat((ATermList) arg0, (ATermList) arg1);
}

/**
 * Extract a sublist from a PTPT_CharRangeList. 
 * \param[in] arg PTPT_CharRangeList to extract a slice from
 * \param[in] start inclusive start index of the sublist
 * \param[in] end exclusive end index of the sublist
 * \return new PTPT_CharRangeList with a first element the element at index #start from #arg, and as last element the element at index (#end - 1).
 */
PTPT_CharRangeList _PTPT_sliceCharRangeList(PTPT_CharRangeList arg, int start, int end) {
  return (PTPT_CharRangeList) ATgetSlice((ATermList) arg, start * 4, end * 4);
}

/**
 * Retrieve the PTPT_CharRange at #index from a PTPT_CharRangeList. 
 * \param[in] arg PTPT_CharRangeList to retrieve the PTPT_CharRange from
 * \param[in] index index to use to point in the PTPT_CharRangeList
 * \return PTPT_CharRange at position #index in #arg
 */
PTPT_CharRange _PTPT_getCharRangeListCharRangeAt(PTPT_CharRangeList arg, int index) {
 return (PTPT_CharRange)ATelementAt((ATermList) arg,index * 4);
}

/**
 * Replace the PTPT_CharRange at #index from a PTPT_CharRangeList by a new one. 
 * \param[in] arg PTPT_CharRangeList to retrieve the PTPT_CharRange from
 * \param[in] elem new PTPT_CharRange to replace another
 * \param[in] index index to use to point in the PTPT_CharRangeList
 * \return A new PTPT_CharRangeListwith #elem replaced in #arg at position #index
 */
PTPT_CharRangeList _PTPT_replaceCharRangeListCharRangeAt(PTPT_CharRangeList arg, PTPT_CharRange elem, int index) {
 return (PTPT_CharRangeList) ATreplace((ATermList) arg, (ATerm) ((ATerm) elem), index * 4);
}

/**
 * Builds a PTPT_CharRangeList of 2 consecutive elements. The elements are separated.
 * \param[in] elem1 One PTPT_CharRange element of the new PTPT_CharRangeList
 * \param[in] elem2 One PTPT_CharRange element of the new PTPT_CharRangeList
 * \return A new PTPT_CharRangeList consisting of 2 PTPT_CharRanges
 */
PTPT_CharRangeList PTPT_makeCharRangeList2(PTPT_OptLayout wsAfterHead, PTPT_OptLayout wsAfterSep, PTPT_CharRange elem1, PTPT_CharRange elem2) {
  return PTPT_makeCharRangeListMany(elem1, wsAfterHead, wsAfterSep, PTPT_makeCharRangeListSingle(elem2));
}

/**
 * Builds a PTPT_CharRangeList of 3 consecutive elements. The elements are separated.
 * \param[in] elem1 One PTPT_CharRange element of the new PTPT_CharRangeList
 * \param[in] elem2 One PTPT_CharRange element of the new PTPT_CharRangeList
 * \param[in] elem3 One PTPT_CharRange element of the new PTPT_CharRangeList
 * \return A new PTPT_CharRangeList consisting of 3 PTPT_CharRanges
 */
PTPT_CharRangeList PTPT_makeCharRangeList3(PTPT_OptLayout wsAfterHead, PTPT_OptLayout wsAfterSep, PTPT_CharRange elem1, PTPT_CharRange elem2, PTPT_CharRange elem3) {
  return PTPT_makeCharRangeListMany(elem1, wsAfterHead, wsAfterSep, PTPT_makeCharRangeList2(wsAfterHead, wsAfterSep, elem2, elem3));
}

/**
 * Builds a PTPT_CharRangeList of 4 consecutive elements. The elements are separated.
 * \param[in] elem1 One PTPT_CharRange element of the new PTPT_CharRangeList
 * \param[in] elem2 One PTPT_CharRange element of the new PTPT_CharRangeList
 * \param[in] elem3 One PTPT_CharRange element of the new PTPT_CharRangeList
 * \param[in] elem4 One PTPT_CharRange element of the new PTPT_CharRangeList
 * \return A new PTPT_CharRangeList consisting of 4 PTPT_CharRanges
 */
PTPT_CharRangeList PTPT_makeCharRangeList4(PTPT_OptLayout wsAfterHead, PTPT_OptLayout wsAfterSep, PTPT_CharRange elem1, PTPT_CharRange elem2, PTPT_CharRange elem3, PTPT_CharRange elem4) {
  return PTPT_makeCharRangeListMany(elem1, wsAfterHead, wsAfterSep, PTPT_makeCharRangeList3(wsAfterHead, wsAfterSep, elem2, elem3, elem4));
}

/**
 * Builds a PTPT_CharRangeList of 5 consecutive elements. The elements are separated.
 * \param[in] elem1 One PTPT_CharRange element of the new PTPT_CharRangeList
 * \param[in] elem2 One PTPT_CharRange element of the new PTPT_CharRangeList
 * \param[in] elem3 One PTPT_CharRange element of the new PTPT_CharRangeList
 * \param[in] elem4 One PTPT_CharRange element of the new PTPT_CharRangeList
 * \param[in] elem5 One PTPT_CharRange element of the new PTPT_CharRangeList
 * \return A new PTPT_CharRangeList consisting of 5 PTPT_CharRanges
 */
PTPT_CharRangeList PTPT_makeCharRangeList5(PTPT_OptLayout wsAfterHead, PTPT_OptLayout wsAfterSep, PTPT_CharRange elem1, PTPT_CharRange elem2, PTPT_CharRange elem3, PTPT_CharRange elem4, PTPT_CharRange elem5) {
  return PTPT_makeCharRangeListMany(elem1, wsAfterHead, wsAfterSep, PTPT_makeCharRangeList4(wsAfterHead, wsAfterSep, elem2, elem3, elem4, elem5));
}

/**
 * Builds a PTPT_CharRangeList of 6 consecutive elements. The elements are separated.
 * \param[in] elem1 One PTPT_CharRange element of the new PTPT_CharRangeList
 * \param[in] elem2 One PTPT_CharRange element of the new PTPT_CharRangeList
 * \param[in] elem3 One PTPT_CharRange element of the new PTPT_CharRangeList
 * \param[in] elem4 One PTPT_CharRange element of the new PTPT_CharRangeList
 * \param[in] elem5 One PTPT_CharRange element of the new PTPT_CharRangeList
 * \param[in] elem6 One PTPT_CharRange element of the new PTPT_CharRangeList
 * \return A new PTPT_CharRangeList consisting of 6 PTPT_CharRanges
 */
PTPT_CharRangeList PTPT_makeCharRangeList6(PTPT_OptLayout wsAfterHead, PTPT_OptLayout wsAfterSep, PTPT_CharRange elem1, PTPT_CharRange elem2, PTPT_CharRange elem3, PTPT_CharRange elem4, PTPT_CharRange elem5, PTPT_CharRange elem6) {
  return PTPT_makeCharRangeListMany(elem1, wsAfterHead, wsAfterSep, PTPT_makeCharRangeList5(wsAfterHead, wsAfterSep, elem2, elem3, elem4, elem5, elem6));
}

/**
 * Retrieve the number of elements in a PTPT_TreeList. 
 * \param[in] arg input PTPT_TreeList
 * \return The number of elements in #arg, excluding any separators
 */
int _PTPT_getTreeListLength(PTPT_TreeList arg) {
  if (ATisEmpty((ATermList) arg)) {
    return 0;
  }
  return (ATgetLength((ATermList) arg) / 4) + 1;
}

/**
 * Reverses the elements of a PTPT_TreeList. Note that separators are reversed with the list, but the order in which each set of separators inbetween two elements occurs does not change
 * \param[in] arg PTPT_TreeList to be reversed
 * \return #arg reversed
 */
PTPT_TreeList PTPT_reverseTreeList(PTPT_TreeList arg) {
  ATermList list = (ATermList) arg;
  ATerm head;
  ATerm sep0;
  ATerm sep1;
  ATerm sep2;
  ATermList result;

 if (ATisEmpty(list) || ATgetLength(list) == 1) {
    return arg;
  }

  result = ATmakeList1(ATgetFirst(list));
      list = ATgetNext(list);
  sep0 = ATgetFirst(list);
  list = ATgetNext(list);
  sep1 = ATgetFirst(list);
  list = ATgetNext(list);
  sep2 = ATgetFirst(list);
  list = ATgetNext(list);

  while (!ATisEmpty(list)) {
    result = ATinsert(result, sep2);
    result = ATinsert(result, sep1);
    result = ATinsert(result, sep0);

   head = ATgetFirst(list);
   result = ATinsert(result, head);
    list = ATgetNext(list);

   if (!ATisEmpty(list)) {
  sep0 = ATgetFirst(list);
  list = ATgetNext(list);
  sep1 = ATgetFirst(list);
  list = ATgetNext(list);
  sep2 = ATgetFirst(list);
  list = ATgetNext(list);
   }
  }

  return (PTPT_TreeList) result;
}

/**
 * Append a PTPT_Tree to the end of a PTPT_TreeList. 
 * \param[in] arg PTPT_TreeList to append the PTPT_Tree to
 * \param[in] elem PTPT_Tree to be appended
 * \return new PTPT_TreeList with #elem appended after the separators
 */
PTPT_TreeList PTPT_appendTreeList(PTPT_TreeList arg0, PTPT_OptLayout wsAfterHead, PTPT_OptLayout wsAfterSep, PTPT_Tree arg1) {
  return PTPT_concatTreeList(arg0, wsAfterHead, wsAfterSep, PTPT_makeTreeListSingle(arg1));
}

/**
 * Concatenate two PTPT_TreeLists. 
 * \param[in] arg0 first PTPT_TreeList
 * \param[in] arg1 second PTPT_TreeList
 * \return PTPT_TreeList with the elements of #arg0 before the elements of #arg1, with the separators in between.
 */
PTPT_TreeList PTPT_concatTreeList(PTPT_TreeList arg0, PTPT_OptLayout wsAfterHead, PTPT_OptLayout wsAfterSep, PTPT_TreeList arg1) {
  if (ATisEmpty((ATermList) arg0)) {
    return arg1;
  }
  arg1 = PTPT_makeTreeListMany((PTPT_Tree)ATgetFirst((ATermList) arg0), wsAfterHead, wsAfterSep,  arg1);
  arg1 = (PTPT_TreeList) ATgetNext((ATermList) arg1);
  return (PTPT_TreeList) ATconcat((ATermList) arg0, (ATermList) arg1);
}

/**
 * Extract a sublist from a PTPT_TreeList. 
 * \param[in] arg PTPT_TreeList to extract a slice from
 * \param[in] start inclusive start index of the sublist
 * \param[in] end exclusive end index of the sublist
 * \return new PTPT_TreeList with a first element the element at index #start from #arg, and as last element the element at index (#end - 1).
 */
PTPT_TreeList _PTPT_sliceTreeList(PTPT_TreeList arg, int start, int end) {
  return (PTPT_TreeList) ATgetSlice((ATermList) arg, start * 4, end * 4);
}

/**
 * Retrieve the PTPT_Tree at #index from a PTPT_TreeList. 
 * \param[in] arg PTPT_TreeList to retrieve the PTPT_Tree from
 * \param[in] index index to use to point in the PTPT_TreeList
 * \return PTPT_Tree at position #index in #arg
 */
PTPT_Tree _PTPT_getTreeListTreeAt(PTPT_TreeList arg, int index) {
 return (PTPT_Tree)ATelementAt((ATermList) arg,index * 4);
}

/**
 * Replace the PTPT_Tree at #index from a PTPT_TreeList by a new one. 
 * \param[in] arg PTPT_TreeList to retrieve the PTPT_Tree from
 * \param[in] elem new PTPT_Tree to replace another
 * \param[in] index index to use to point in the PTPT_TreeList
 * \return A new PTPT_TreeListwith #elem replaced in #arg at position #index
 */
PTPT_TreeList _PTPT_replaceTreeListTreeAt(PTPT_TreeList arg, PTPT_Tree elem, int index) {
 return (PTPT_TreeList) ATreplace((ATermList) arg, (ATerm) ((ATerm) elem), index * 4);
}

/**
 * Builds a PTPT_TreeList of 2 consecutive elements. The elements are separated.
 * \param[in] elem1 One PTPT_Tree element of the new PTPT_TreeList
 * \param[in] elem2 One PTPT_Tree element of the new PTPT_TreeList
 * \return A new PTPT_TreeList consisting of 2 PTPT_Trees
 */
PTPT_TreeList PTPT_makeTreeList2(PTPT_OptLayout wsAfterHead, PTPT_OptLayout wsAfterSep, PTPT_Tree elem1, PTPT_Tree elem2) {
  return PTPT_makeTreeListMany(elem1, wsAfterHead, wsAfterSep, PTPT_makeTreeListSingle(elem2));
}

/**
 * Builds a PTPT_TreeList of 3 consecutive elements. The elements are separated.
 * \param[in] elem1 One PTPT_Tree element of the new PTPT_TreeList
 * \param[in] elem2 One PTPT_Tree element of the new PTPT_TreeList
 * \param[in] elem3 One PTPT_Tree element of the new PTPT_TreeList
 * \return A new PTPT_TreeList consisting of 3 PTPT_Trees
 */
PTPT_TreeList PTPT_makeTreeList3(PTPT_OptLayout wsAfterHead, PTPT_OptLayout wsAfterSep, PTPT_Tree elem1, PTPT_Tree elem2, PTPT_Tree elem3) {
  return PTPT_makeTreeListMany(elem1, wsAfterHead, wsAfterSep, PTPT_makeTreeList2(wsAfterHead, wsAfterSep, elem2, elem3));
}

/**
 * Builds a PTPT_TreeList of 4 consecutive elements. The elements are separated.
 * \param[in] elem1 One PTPT_Tree element of the new PTPT_TreeList
 * \param[in] elem2 One PTPT_Tree element of the new PTPT_TreeList
 * \param[in] elem3 One PTPT_Tree element of the new PTPT_TreeList
 * \param[in] elem4 One PTPT_Tree element of the new PTPT_TreeList
 * \return A new PTPT_TreeList consisting of 4 PTPT_Trees
 */
PTPT_TreeList PTPT_makeTreeList4(PTPT_OptLayout wsAfterHead, PTPT_OptLayout wsAfterSep, PTPT_Tree elem1, PTPT_Tree elem2, PTPT_Tree elem3, PTPT_Tree elem4) {
  return PTPT_makeTreeListMany(elem1, wsAfterHead, wsAfterSep, PTPT_makeTreeList3(wsAfterHead, wsAfterSep, elem2, elem3, elem4));
}

/**
 * Builds a PTPT_TreeList of 5 consecutive elements. The elements are separated.
 * \param[in] elem1 One PTPT_Tree element of the new PTPT_TreeList
 * \param[in] elem2 One PTPT_Tree element of the new PTPT_TreeList
 * \param[in] elem3 One PTPT_Tree element of the new PTPT_TreeList
 * \param[in] elem4 One PTPT_Tree element of the new PTPT_TreeList
 * \param[in] elem5 One PTPT_Tree element of the new PTPT_TreeList
 * \return A new PTPT_TreeList consisting of 5 PTPT_Trees
 */
PTPT_TreeList PTPT_makeTreeList5(PTPT_OptLayout wsAfterHead, PTPT_OptLayout wsAfterSep, PTPT_Tree elem1, PTPT_Tree elem2, PTPT_Tree elem3, PTPT_Tree elem4, PTPT_Tree elem5) {
  return PTPT_makeTreeListMany(elem1, wsAfterHead, wsAfterSep, PTPT_makeTreeList4(wsAfterHead, wsAfterSep, elem2, elem3, elem4, elem5));
}

/**
 * Builds a PTPT_TreeList of 6 consecutive elements. The elements are separated.
 * \param[in] elem1 One PTPT_Tree element of the new PTPT_TreeList
 * \param[in] elem2 One PTPT_Tree element of the new PTPT_TreeList
 * \param[in] elem3 One PTPT_Tree element of the new PTPT_TreeList
 * \param[in] elem4 One PTPT_Tree element of the new PTPT_TreeList
 * \param[in] elem5 One PTPT_Tree element of the new PTPT_TreeList
 * \param[in] elem6 One PTPT_Tree element of the new PTPT_TreeList
 * \return A new PTPT_TreeList consisting of 6 PTPT_Trees
 */
PTPT_TreeList PTPT_makeTreeList6(PTPT_OptLayout wsAfterHead, PTPT_OptLayout wsAfterSep, PTPT_Tree elem1, PTPT_Tree elem2, PTPT_Tree elem3, PTPT_Tree elem4, PTPT_Tree elem5, PTPT_Tree elem6) {
  return PTPT_makeTreeListMany(elem1, wsAfterHead, wsAfterSep, PTPT_makeTreeList5(wsAfterHead, wsAfterSep, elem2, elem3, elem4, elem5, elem6));
}

/**
 * Retrieve the number of elements in a PTPT_ATermArgs. 
 * \param[in] arg input PTPT_ATermArgs
 * \return The number of elements in #arg, excluding any separators
 */
int _PTPT_getATermArgsLength(PTPT_ATermArgs arg) {
  if (ATisEmpty((ATermList) arg)) {
    return 0;
  }
  return (ATgetLength((ATermList) arg) / 4) + 1;
}

/**
 * Reverses the elements of a PTPT_ATermArgs. Note that separators are reversed with the list, but the order in which each set of separators inbetween two elements occurs does not change
 * \param[in] arg PTPT_ATermArgs to be reversed
 * \return #arg reversed
 */
PTPT_ATermArgs PTPT_reverseATermArgs(PTPT_ATermArgs arg) {
  ATermList list = (ATermList) arg;
  ATerm head;
  ATerm sep0;
  ATerm sep1;
  ATerm sep2;
  ATermList result;

 if (ATisEmpty(list) || ATgetLength(list) == 1) {
    return arg;
  }

  result = ATmakeList1(ATgetFirst(list));
      list = ATgetNext(list);
  sep0 = ATgetFirst(list);
  list = ATgetNext(list);
  sep1 = ATgetFirst(list);
  list = ATgetNext(list);
  sep2 = ATgetFirst(list);
  list = ATgetNext(list);

  while (!ATisEmpty(list)) {
    result = ATinsert(result, sep2);
    result = ATinsert(result, sep1);
    result = ATinsert(result, sep0);

   head = ATgetFirst(list);
   result = ATinsert(result, head);
    list = ATgetNext(list);

   if (!ATisEmpty(list)) {
  sep0 = ATgetFirst(list);
  list = ATgetNext(list);
  sep1 = ATgetFirst(list);
  list = ATgetNext(list);
  sep2 = ATgetFirst(list);
  list = ATgetNext(list);
   }
  }

  return (PTPT_ATermArgs) result;
}

/**
 * Append a PTPT_ATerm to the end of a PTPT_ATermArgs. 
 * \param[in] arg PTPT_ATermArgs to append the PTPT_ATerm to
 * \param[in] elem PTPT_ATerm to be appended
 * \return new PTPT_ATermArgs with #elem appended after the separators
 */
PTPT_ATermArgs PTPT_appendATermArgs(PTPT_ATermArgs arg0, PTPT_OptLayout wsAfterHead, PTPT_OptLayout wsAfterSep, PTPT_ATerm arg1) {
  return PTPT_concatATermArgs(arg0, wsAfterHead, wsAfterSep, PTPT_makeATermArgsSingle(arg1));
}

/**
 * Concatenate two PTPT_ATermArgss. 
 * \param[in] arg0 first PTPT_ATermArgs
 * \param[in] arg1 second PTPT_ATermArgs
 * \return PTPT_ATermArgs with the elements of #arg0 before the elements of #arg1, with the separators in between.
 */
PTPT_ATermArgs PTPT_concatATermArgs(PTPT_ATermArgs arg0, PTPT_OptLayout wsAfterHead, PTPT_OptLayout wsAfterSep, PTPT_ATermArgs arg1) {
  if (ATisEmpty((ATermList) arg0)) {
    return arg1;
  }
  arg1 = PTPT_makeATermArgsMany((PTPT_ATerm)ATgetFirst((ATermList) arg0), wsAfterHead, wsAfterSep,  arg1);
  arg1 = (PTPT_ATermArgs) ATgetNext((ATermList) arg1);
  return (PTPT_ATermArgs) ATconcat((ATermList) arg0, (ATermList) arg1);
}

/**
 * Extract a sublist from a PTPT_ATermArgs. 
 * \param[in] arg PTPT_ATermArgs to extract a slice from
 * \param[in] start inclusive start index of the sublist
 * \param[in] end exclusive end index of the sublist
 * \return new PTPT_ATermArgs with a first element the element at index #start from #arg, and as last element the element at index (#end - 1).
 */
PTPT_ATermArgs _PTPT_sliceATermArgs(PTPT_ATermArgs arg, int start, int end) {
  return (PTPT_ATermArgs) ATgetSlice((ATermList) arg, start * 4, end * 4);
}

/**
 * Retrieve the PTPT_ATerm at #index from a PTPT_ATermArgs. 
 * \param[in] arg PTPT_ATermArgs to retrieve the PTPT_ATerm from
 * \param[in] index index to use to point in the PTPT_ATermArgs
 * \return PTPT_ATerm at position #index in #arg
 */
PTPT_ATerm _PTPT_getATermArgsATermAt(PTPT_ATermArgs arg, int index) {
 return (PTPT_ATerm)ATelementAt((ATermList) arg,index * 4);
}

/**
 * Replace the PTPT_ATerm at #index from a PTPT_ATermArgs by a new one. 
 * \param[in] arg PTPT_ATermArgs to retrieve the PTPT_ATerm from
 * \param[in] elem new PTPT_ATerm to replace another
 * \param[in] index index to use to point in the PTPT_ATermArgs
 * \return A new PTPT_ATermArgswith #elem replaced in #arg at position #index
 */
PTPT_ATermArgs _PTPT_replaceATermArgsATermAt(PTPT_ATermArgs arg, PTPT_ATerm elem, int index) {
 return (PTPT_ATermArgs) ATreplace((ATermList) arg, (ATerm) ((ATerm) elem), index * 4);
}

/**
 * Builds a PTPT_ATermArgs of 2 consecutive elements. The elements are separated.
 * \param[in] elem1 One PTPT_ATerm element of the new PTPT_ATermArgs
 * \param[in] elem2 One PTPT_ATerm element of the new PTPT_ATermArgs
 * \return A new PTPT_ATermArgs consisting of 2 PTPT_ATerms
 */
PTPT_ATermArgs PTPT_makeATermArgs2(PTPT_OptLayout wsAfterHead, PTPT_OptLayout wsAfterSep, PTPT_ATerm elem1, PTPT_ATerm elem2) {
  return PTPT_makeATermArgsMany(elem1, wsAfterHead, wsAfterSep, PTPT_makeATermArgsSingle(elem2));
}

/**
 * Builds a PTPT_ATermArgs of 3 consecutive elements. The elements are separated.
 * \param[in] elem1 One PTPT_ATerm element of the new PTPT_ATermArgs
 * \param[in] elem2 One PTPT_ATerm element of the new PTPT_ATermArgs
 * \param[in] elem3 One PTPT_ATerm element of the new PTPT_ATermArgs
 * \return A new PTPT_ATermArgs consisting of 3 PTPT_ATerms
 */
PTPT_ATermArgs PTPT_makeATermArgs3(PTPT_OptLayout wsAfterHead, PTPT_OptLayout wsAfterSep, PTPT_ATerm elem1, PTPT_ATerm elem2, PTPT_ATerm elem3) {
  return PTPT_makeATermArgsMany(elem1, wsAfterHead, wsAfterSep, PTPT_makeATermArgs2(wsAfterHead, wsAfterSep, elem2, elem3));
}

/**
 * Builds a PTPT_ATermArgs of 4 consecutive elements. The elements are separated.
 * \param[in] elem1 One PTPT_ATerm element of the new PTPT_ATermArgs
 * \param[in] elem2 One PTPT_ATerm element of the new PTPT_ATermArgs
 * \param[in] elem3 One PTPT_ATerm element of the new PTPT_ATermArgs
 * \param[in] elem4 One PTPT_ATerm element of the new PTPT_ATermArgs
 * \return A new PTPT_ATermArgs consisting of 4 PTPT_ATerms
 */
PTPT_ATermArgs PTPT_makeATermArgs4(PTPT_OptLayout wsAfterHead, PTPT_OptLayout wsAfterSep, PTPT_ATerm elem1, PTPT_ATerm elem2, PTPT_ATerm elem3, PTPT_ATerm elem4) {
  return PTPT_makeATermArgsMany(elem1, wsAfterHead, wsAfterSep, PTPT_makeATermArgs3(wsAfterHead, wsAfterSep, elem2, elem3, elem4));
}

/**
 * Builds a PTPT_ATermArgs of 5 consecutive elements. The elements are separated.
 * \param[in] elem1 One PTPT_ATerm element of the new PTPT_ATermArgs
 * \param[in] elem2 One PTPT_ATerm element of the new PTPT_ATermArgs
 * \param[in] elem3 One PTPT_ATerm element of the new PTPT_ATermArgs
 * \param[in] elem4 One PTPT_ATerm element of the new PTPT_ATermArgs
 * \param[in] elem5 One PTPT_ATerm element of the new PTPT_ATermArgs
 * \return A new PTPT_ATermArgs consisting of 5 PTPT_ATerms
 */
PTPT_ATermArgs PTPT_makeATermArgs5(PTPT_OptLayout wsAfterHead, PTPT_OptLayout wsAfterSep, PTPT_ATerm elem1, PTPT_ATerm elem2, PTPT_ATerm elem3, PTPT_ATerm elem4, PTPT_ATerm elem5) {
  return PTPT_makeATermArgsMany(elem1, wsAfterHead, wsAfterSep, PTPT_makeATermArgs4(wsAfterHead, wsAfterSep, elem2, elem3, elem4, elem5));
}

/**
 * Builds a PTPT_ATermArgs of 6 consecutive elements. The elements are separated.
 * \param[in] elem1 One PTPT_ATerm element of the new PTPT_ATermArgs
 * \param[in] elem2 One PTPT_ATerm element of the new PTPT_ATermArgs
 * \param[in] elem3 One PTPT_ATerm element of the new PTPT_ATermArgs
 * \param[in] elem4 One PTPT_ATerm element of the new PTPT_ATermArgs
 * \param[in] elem5 One PTPT_ATerm element of the new PTPT_ATermArgs
 * \param[in] elem6 One PTPT_ATerm element of the new PTPT_ATermArgs
 * \return A new PTPT_ATermArgs consisting of 6 PTPT_ATerms
 */
PTPT_ATermArgs PTPT_makeATermArgs6(PTPT_OptLayout wsAfterHead, PTPT_OptLayout wsAfterSep, PTPT_ATerm elem1, PTPT_ATerm elem2, PTPT_ATerm elem3, PTPT_ATerm elem4, PTPT_ATerm elem5, PTPT_ATerm elem6) {
  return PTPT_makeATermArgsMany(elem1, wsAfterHead, wsAfterSep, PTPT_makeATermArgs5(wsAfterHead, wsAfterSep, elem2, elem3, elem4, elem5, elem6));
}

/**
 * Retrieve the number of elements in a PTPT_ATermElems. 
 * \param[in] arg input PTPT_ATermElems
 * \return The number of elements in #arg, excluding any separators
 */
int _PTPT_getATermElemsLength(PTPT_ATermElems arg) {
  if (ATisEmpty((ATermList) arg)) {
    return 0;
  }
  return (ATgetLength((ATermList) arg) / 4) + 1;
}

/**
 * Reverses the elements of a PTPT_ATermElems. Note that separators are reversed with the list, but the order in which each set of separators inbetween two elements occurs does not change
 * \param[in] arg PTPT_ATermElems to be reversed
 * \return #arg reversed
 */
PTPT_ATermElems PTPT_reverseATermElems(PTPT_ATermElems arg) {
  ATermList list = (ATermList) arg;
  ATerm head;
  ATerm sep0;
  ATerm sep1;
  ATerm sep2;
  ATermList result;

 if (ATisEmpty(list) || ATgetLength(list) == 1) {
    return arg;
  }

  result = ATmakeList1(ATgetFirst(list));
      list = ATgetNext(list);
  sep0 = ATgetFirst(list);
  list = ATgetNext(list);
  sep1 = ATgetFirst(list);
  list = ATgetNext(list);
  sep2 = ATgetFirst(list);
  list = ATgetNext(list);

  while (!ATisEmpty(list)) {
    result = ATinsert(result, sep2);
    result = ATinsert(result, sep1);
    result = ATinsert(result, sep0);

   head = ATgetFirst(list);
   result = ATinsert(result, head);
    list = ATgetNext(list);

   if (!ATisEmpty(list)) {
  sep0 = ATgetFirst(list);
  list = ATgetNext(list);
  sep1 = ATgetFirst(list);
  list = ATgetNext(list);
  sep2 = ATgetFirst(list);
  list = ATgetNext(list);
   }
  }

  return (PTPT_ATermElems) result;
}

/**
 * Append a PTPT_ATerm to the end of a PTPT_ATermElems. 
 * \param[in] arg PTPT_ATermElems to append the PTPT_ATerm to
 * \param[in] elem PTPT_ATerm to be appended
 * \return new PTPT_ATermElems with #elem appended after the separators
 */
PTPT_ATermElems PTPT_appendATermElems(PTPT_ATermElems arg0, PTPT_OptLayout wsAfterHead, PTPT_OptLayout wsAfterSep, PTPT_ATerm arg1) {
  return PTPT_concatATermElems(arg0, wsAfterHead, wsAfterSep, PTPT_makeATermElemsSingle(arg1));
}

/**
 * Concatenate two PTPT_ATermElemss. 
 * \param[in] arg0 first PTPT_ATermElems
 * \param[in] arg1 second PTPT_ATermElems
 * \return PTPT_ATermElems with the elements of #arg0 before the elements of #arg1, with the separators in between.
 */
PTPT_ATermElems PTPT_concatATermElems(PTPT_ATermElems arg0, PTPT_OptLayout wsAfterHead, PTPT_OptLayout wsAfterSep, PTPT_ATermElems arg1) {
  if (ATisEmpty((ATermList) arg0)) {
    return arg1;
  }
  arg1 = PTPT_makeATermElemsMany((PTPT_ATerm)ATgetFirst((ATermList) arg0), wsAfterHead, wsAfterSep,  arg1);
  arg1 = (PTPT_ATermElems) ATgetNext((ATermList) arg1);
  return (PTPT_ATermElems) ATconcat((ATermList) arg0, (ATermList) arg1);
}

/**
 * Extract a sublist from a PTPT_ATermElems. 
 * \param[in] arg PTPT_ATermElems to extract a slice from
 * \param[in] start inclusive start index of the sublist
 * \param[in] end exclusive end index of the sublist
 * \return new PTPT_ATermElems with a first element the element at index #start from #arg, and as last element the element at index (#end - 1).
 */
PTPT_ATermElems _PTPT_sliceATermElems(PTPT_ATermElems arg, int start, int end) {
  return (PTPT_ATermElems) ATgetSlice((ATermList) arg, start * 4, end * 4);
}

/**
 * Retrieve the PTPT_ATerm at #index from a PTPT_ATermElems. 
 * \param[in] arg PTPT_ATermElems to retrieve the PTPT_ATerm from
 * \param[in] index index to use to point in the PTPT_ATermElems
 * \return PTPT_ATerm at position #index in #arg
 */
PTPT_ATerm _PTPT_getATermElemsATermAt(PTPT_ATermElems arg, int index) {
 return (PTPT_ATerm)ATelementAt((ATermList) arg,index * 4);
}

/**
 * Replace the PTPT_ATerm at #index from a PTPT_ATermElems by a new one. 
 * \param[in] arg PTPT_ATermElems to retrieve the PTPT_ATerm from
 * \param[in] elem new PTPT_ATerm to replace another
 * \param[in] index index to use to point in the PTPT_ATermElems
 * \return A new PTPT_ATermElemswith #elem replaced in #arg at position #index
 */
PTPT_ATermElems _PTPT_replaceATermElemsATermAt(PTPT_ATermElems arg, PTPT_ATerm elem, int index) {
 return (PTPT_ATermElems) ATreplace((ATermList) arg, (ATerm) ((ATerm) elem), index * 4);
}

/**
 * Builds a PTPT_ATermElems of 2 consecutive elements. The elements are separated.
 * \param[in] elem1 One PTPT_ATerm element of the new PTPT_ATermElems
 * \param[in] elem2 One PTPT_ATerm element of the new PTPT_ATermElems
 * \return A new PTPT_ATermElems consisting of 2 PTPT_ATerms
 */
PTPT_ATermElems PTPT_makeATermElems2(PTPT_OptLayout wsAfterHead, PTPT_OptLayout wsAfterSep, PTPT_ATerm elem1, PTPT_ATerm elem2) {
  return PTPT_makeATermElemsMany(elem1, wsAfterHead, wsAfterSep, PTPT_makeATermElemsSingle(elem2));
}

/**
 * Builds a PTPT_ATermElems of 3 consecutive elements. The elements are separated.
 * \param[in] elem1 One PTPT_ATerm element of the new PTPT_ATermElems
 * \param[in] elem2 One PTPT_ATerm element of the new PTPT_ATermElems
 * \param[in] elem3 One PTPT_ATerm element of the new PTPT_ATermElems
 * \return A new PTPT_ATermElems consisting of 3 PTPT_ATerms
 */
PTPT_ATermElems PTPT_makeATermElems3(PTPT_OptLayout wsAfterHead, PTPT_OptLayout wsAfterSep, PTPT_ATerm elem1, PTPT_ATerm elem2, PTPT_ATerm elem3) {
  return PTPT_makeATermElemsMany(elem1, wsAfterHead, wsAfterSep, PTPT_makeATermElems2(wsAfterHead, wsAfterSep, elem2, elem3));
}

/**
 * Builds a PTPT_ATermElems of 4 consecutive elements. The elements are separated.
 * \param[in] elem1 One PTPT_ATerm element of the new PTPT_ATermElems
 * \param[in] elem2 One PTPT_ATerm element of the new PTPT_ATermElems
 * \param[in] elem3 One PTPT_ATerm element of the new PTPT_ATermElems
 * \param[in] elem4 One PTPT_ATerm element of the new PTPT_ATermElems
 * \return A new PTPT_ATermElems consisting of 4 PTPT_ATerms
 */
PTPT_ATermElems PTPT_makeATermElems4(PTPT_OptLayout wsAfterHead, PTPT_OptLayout wsAfterSep, PTPT_ATerm elem1, PTPT_ATerm elem2, PTPT_ATerm elem3, PTPT_ATerm elem4) {
  return PTPT_makeATermElemsMany(elem1, wsAfterHead, wsAfterSep, PTPT_makeATermElems3(wsAfterHead, wsAfterSep, elem2, elem3, elem4));
}

/**
 * Builds a PTPT_ATermElems of 5 consecutive elements. The elements are separated.
 * \param[in] elem1 One PTPT_ATerm element of the new PTPT_ATermElems
 * \param[in] elem2 One PTPT_ATerm element of the new PTPT_ATermElems
 * \param[in] elem3 One PTPT_ATerm element of the new PTPT_ATermElems
 * \param[in] elem4 One PTPT_ATerm element of the new PTPT_ATermElems
 * \param[in] elem5 One PTPT_ATerm element of the new PTPT_ATermElems
 * \return A new PTPT_ATermElems consisting of 5 PTPT_ATerms
 */
PTPT_ATermElems PTPT_makeATermElems5(PTPT_OptLayout wsAfterHead, PTPT_OptLayout wsAfterSep, PTPT_ATerm elem1, PTPT_ATerm elem2, PTPT_ATerm elem3, PTPT_ATerm elem4, PTPT_ATerm elem5) {
  return PTPT_makeATermElemsMany(elem1, wsAfterHead, wsAfterSep, PTPT_makeATermElems4(wsAfterHead, wsAfterSep, elem2, elem3, elem4, elem5));
}

/**
 * Builds a PTPT_ATermElems of 6 consecutive elements. The elements are separated.
 * \param[in] elem1 One PTPT_ATerm element of the new PTPT_ATermElems
 * \param[in] elem2 One PTPT_ATerm element of the new PTPT_ATermElems
 * \param[in] elem3 One PTPT_ATerm element of the new PTPT_ATermElems
 * \param[in] elem4 One PTPT_ATerm element of the new PTPT_ATermElems
 * \param[in] elem5 One PTPT_ATerm element of the new PTPT_ATermElems
 * \param[in] elem6 One PTPT_ATerm element of the new PTPT_ATermElems
 * \return A new PTPT_ATermElems consisting of 6 PTPT_ATerms
 */
PTPT_ATermElems PTPT_makeATermElems6(PTPT_OptLayout wsAfterHead, PTPT_OptLayout wsAfterSep, PTPT_ATerm elem1, PTPT_ATerm elem2, PTPT_ATerm elem3, PTPT_ATerm elem4, PTPT_ATerm elem5, PTPT_ATerm elem6) {
  return PTPT_makeATermElemsMany(elem1, wsAfterHead, wsAfterSep, PTPT_makeATermElems5(wsAfterHead, wsAfterSep, elem2, elem3, elem4, elem5, elem6));
}

/**
 * Retrieve the number of elements in a PTPT_ATermAnnos. 
 * \param[in] arg input PTPT_ATermAnnos
 * \return The number of elements in #arg, excluding any separators
 */
int _PTPT_getATermAnnosLength(PTPT_ATermAnnos arg) {
  if (ATisEmpty((ATermList) arg)) {
    return 0;
  }
  return (ATgetLength((ATermList) arg) / 4) + 1;
}

/**
 * Reverses the elements of a PTPT_ATermAnnos. Note that separators are reversed with the list, but the order in which each set of separators inbetween two elements occurs does not change
 * \param[in] arg PTPT_ATermAnnos to be reversed
 * \return #arg reversed
 */
PTPT_ATermAnnos PTPT_reverseATermAnnos(PTPT_ATermAnnos arg) {
  ATermList list = (ATermList) arg;
  ATerm head;
  ATerm sep0;
  ATerm sep1;
  ATerm sep2;
  ATermList result;

 if (ATisEmpty(list) || ATgetLength(list) == 1) {
    return arg;
  }

  result = ATmakeList1(ATgetFirst(list));
      list = ATgetNext(list);
  sep0 = ATgetFirst(list);
  list = ATgetNext(list);
  sep1 = ATgetFirst(list);
  list = ATgetNext(list);
  sep2 = ATgetFirst(list);
  list = ATgetNext(list);

  while (!ATisEmpty(list)) {
    result = ATinsert(result, sep2);
    result = ATinsert(result, sep1);
    result = ATinsert(result, sep0);

   head = ATgetFirst(list);
   result = ATinsert(result, head);
    list = ATgetNext(list);

   if (!ATisEmpty(list)) {
  sep0 = ATgetFirst(list);
  list = ATgetNext(list);
  sep1 = ATgetFirst(list);
  list = ATgetNext(list);
  sep2 = ATgetFirst(list);
  list = ATgetNext(list);
   }
  }

  return (PTPT_ATermAnnos) result;
}

/**
 * Append a PTPT_ATerm to the end of a PTPT_ATermAnnos. 
 * \param[in] arg PTPT_ATermAnnos to append the PTPT_ATerm to
 * \param[in] elem PTPT_ATerm to be appended
 * \return new PTPT_ATermAnnos with #elem appended after the separators
 */
PTPT_ATermAnnos PTPT_appendATermAnnos(PTPT_ATermAnnos arg0, PTPT_OptLayout wsAfterHead, PTPT_OptLayout wsAfterSep, PTPT_ATerm arg1) {
  return PTPT_concatATermAnnos(arg0, wsAfterHead, wsAfterSep, PTPT_makeATermAnnosSingle(arg1));
}

/**
 * Concatenate two PTPT_ATermAnnoss. 
 * \param[in] arg0 first PTPT_ATermAnnos
 * \param[in] arg1 second PTPT_ATermAnnos
 * \return PTPT_ATermAnnos with the elements of #arg0 before the elements of #arg1, with the separators in between.
 */
PTPT_ATermAnnos PTPT_concatATermAnnos(PTPT_ATermAnnos arg0, PTPT_OptLayout wsAfterHead, PTPT_OptLayout wsAfterSep, PTPT_ATermAnnos arg1) {
  if (ATisEmpty((ATermList) arg0)) {
    return arg1;
  }
  arg1 = PTPT_makeATermAnnosMany((PTPT_ATerm)ATgetFirst((ATermList) arg0), wsAfterHead, wsAfterSep,  arg1);
  arg1 = (PTPT_ATermAnnos) ATgetNext((ATermList) arg1);
  return (PTPT_ATermAnnos) ATconcat((ATermList) arg0, (ATermList) arg1);
}

/**
 * Extract a sublist from a PTPT_ATermAnnos. 
 * \param[in] arg PTPT_ATermAnnos to extract a slice from
 * \param[in] start inclusive start index of the sublist
 * \param[in] end exclusive end index of the sublist
 * \return new PTPT_ATermAnnos with a first element the element at index #start from #arg, and as last element the element at index (#end - 1).
 */
PTPT_ATermAnnos _PTPT_sliceATermAnnos(PTPT_ATermAnnos arg, int start, int end) {
  return (PTPT_ATermAnnos) ATgetSlice((ATermList) arg, start * 4, end * 4);
}

/**
 * Retrieve the PTPT_ATerm at #index from a PTPT_ATermAnnos. 
 * \param[in] arg PTPT_ATermAnnos to retrieve the PTPT_ATerm from
 * \param[in] index index to use to point in the PTPT_ATermAnnos
 * \return PTPT_ATerm at position #index in #arg
 */
PTPT_ATerm _PTPT_getATermAnnosATermAt(PTPT_ATermAnnos arg, int index) {
 return (PTPT_ATerm)ATelementAt((ATermList) arg,index * 4);
}

/**
 * Replace the PTPT_ATerm at #index from a PTPT_ATermAnnos by a new one. 
 * \param[in] arg PTPT_ATermAnnos to retrieve the PTPT_ATerm from
 * \param[in] elem new PTPT_ATerm to replace another
 * \param[in] index index to use to point in the PTPT_ATermAnnos
 * \return A new PTPT_ATermAnnoswith #elem replaced in #arg at position #index
 */
PTPT_ATermAnnos _PTPT_replaceATermAnnosATermAt(PTPT_ATermAnnos arg, PTPT_ATerm elem, int index) {
 return (PTPT_ATermAnnos) ATreplace((ATermList) arg, (ATerm) ((ATerm) elem), index * 4);
}

/**
 * Builds a PTPT_ATermAnnos of 2 consecutive elements. The elements are separated.
 * \param[in] elem1 One PTPT_ATerm element of the new PTPT_ATermAnnos
 * \param[in] elem2 One PTPT_ATerm element of the new PTPT_ATermAnnos
 * \return A new PTPT_ATermAnnos consisting of 2 PTPT_ATerms
 */
PTPT_ATermAnnos PTPT_makeATermAnnos2(PTPT_OptLayout wsAfterHead, PTPT_OptLayout wsAfterSep, PTPT_ATerm elem1, PTPT_ATerm elem2) {
  return PTPT_makeATermAnnosMany(elem1, wsAfterHead, wsAfterSep, PTPT_makeATermAnnosSingle(elem2));
}

/**
 * Builds a PTPT_ATermAnnos of 3 consecutive elements. The elements are separated.
 * \param[in] elem1 One PTPT_ATerm element of the new PTPT_ATermAnnos
 * \param[in] elem2 One PTPT_ATerm element of the new PTPT_ATermAnnos
 * \param[in] elem3 One PTPT_ATerm element of the new PTPT_ATermAnnos
 * \return A new PTPT_ATermAnnos consisting of 3 PTPT_ATerms
 */
PTPT_ATermAnnos PTPT_makeATermAnnos3(PTPT_OptLayout wsAfterHead, PTPT_OptLayout wsAfterSep, PTPT_ATerm elem1, PTPT_ATerm elem2, PTPT_ATerm elem3) {
  return PTPT_makeATermAnnosMany(elem1, wsAfterHead, wsAfterSep, PTPT_makeATermAnnos2(wsAfterHead, wsAfterSep, elem2, elem3));
}

/**
 * Builds a PTPT_ATermAnnos of 4 consecutive elements. The elements are separated.
 * \param[in] elem1 One PTPT_ATerm element of the new PTPT_ATermAnnos
 * \param[in] elem2 One PTPT_ATerm element of the new PTPT_ATermAnnos
 * \param[in] elem3 One PTPT_ATerm element of the new PTPT_ATermAnnos
 * \param[in] elem4 One PTPT_ATerm element of the new PTPT_ATermAnnos
 * \return A new PTPT_ATermAnnos consisting of 4 PTPT_ATerms
 */
PTPT_ATermAnnos PTPT_makeATermAnnos4(PTPT_OptLayout wsAfterHead, PTPT_OptLayout wsAfterSep, PTPT_ATerm elem1, PTPT_ATerm elem2, PTPT_ATerm elem3, PTPT_ATerm elem4) {
  return PTPT_makeATermAnnosMany(elem1, wsAfterHead, wsAfterSep, PTPT_makeATermAnnos3(wsAfterHead, wsAfterSep, elem2, elem3, elem4));
}

/**
 * Builds a PTPT_ATermAnnos of 5 consecutive elements. The elements are separated.
 * \param[in] elem1 One PTPT_ATerm element of the new PTPT_ATermAnnos
 * \param[in] elem2 One PTPT_ATerm element of the new PTPT_ATermAnnos
 * \param[in] elem3 One PTPT_ATerm element of the new PTPT_ATermAnnos
 * \param[in] elem4 One PTPT_ATerm element of the new PTPT_ATermAnnos
 * \param[in] elem5 One PTPT_ATerm element of the new PTPT_ATermAnnos
 * \return A new PTPT_ATermAnnos consisting of 5 PTPT_ATerms
 */
PTPT_ATermAnnos PTPT_makeATermAnnos5(PTPT_OptLayout wsAfterHead, PTPT_OptLayout wsAfterSep, PTPT_ATerm elem1, PTPT_ATerm elem2, PTPT_ATerm elem3, PTPT_ATerm elem4, PTPT_ATerm elem5) {
  return PTPT_makeATermAnnosMany(elem1, wsAfterHead, wsAfterSep, PTPT_makeATermAnnos4(wsAfterHead, wsAfterSep, elem2, elem3, elem4, elem5));
}

/**
 * Builds a PTPT_ATermAnnos of 6 consecutive elements. The elements are separated.
 * \param[in] elem1 One PTPT_ATerm element of the new PTPT_ATermAnnos
 * \param[in] elem2 One PTPT_ATerm element of the new PTPT_ATermAnnos
 * \param[in] elem3 One PTPT_ATerm element of the new PTPT_ATermAnnos
 * \param[in] elem4 One PTPT_ATerm element of the new PTPT_ATermAnnos
 * \param[in] elem5 One PTPT_ATerm element of the new PTPT_ATermAnnos
 * \param[in] elem6 One PTPT_ATerm element of the new PTPT_ATermAnnos
 * \return A new PTPT_ATermAnnos consisting of 6 PTPT_ATerms
 */
PTPT_ATermAnnos PTPT_makeATermAnnos6(PTPT_OptLayout wsAfterHead, PTPT_OptLayout wsAfterSep, PTPT_ATerm elem1, PTPT_ATerm elem2, PTPT_ATerm elem3, PTPT_ATerm elem4, PTPT_ATerm elem5, PTPT_ATerm elem6) {
  return PTPT_makeATermAnnosMany(elem1, wsAfterHead, wsAfterSep, PTPT_makeATermAnnos5(wsAfterHead, wsAfterSep, elem2, elem3, elem4, elem5, elem6));
}

/**
 * Retrieve the length of a PTPT_LexStrCharChars. 
 * \param[in] arg input PTPT_LexStrCharChars
 * \return The number of elements in the PTPT_LexStrCharChars
 */
int _PTPT_getLexStrCharCharsLength(PTPT_LexStrCharChars arg) {
  return ATgetLength((ATermList) arg);
}

/**
 * Reverse a PTPT_LexStrCharChars. 
 * \param[in] arg PTPT_LexStrCharChars to be reversed
 * \return a reversed #arg
 */
PTPT_LexStrCharChars _PTPT_reverseLexStrCharChars(PTPT_LexStrCharChars arg) {
  return (PTPT_LexStrCharChars) ATreverse((ATermList) arg);
}

/**
 * Append a PTPT_LexStrChar to the end of a PTPT_LexStrCharChars. 
 * \param[in] arg PTPT_LexStrCharChars to append the PTPT_LexStrChar to
 * \param[in] elem PTPT_LexStrChar to be appended
 * \return new PTPT_LexStrCharChars with #elem appended
 */
PTPT_LexStrCharChars _PTPT_appendLexStrCharChars(PTPT_LexStrCharChars arg, PTPT_LexStrChar elem) {
  return (PTPT_LexStrCharChars) ATappend((ATermList) arg, (ATerm) ((ATerm) elem));
}

/**
 * Concatenate two PTPT_LexStrCharCharss. 
 * \param[in] arg0 first PTPT_LexStrCharChars
 * \param[in] arg1 second PTPT_LexStrCharChars
 * \return PTPT_LexStrCharChars with the elements of #arg0 before the elements of #arg1
 */
PTPT_LexStrCharChars _PTPT_concatLexStrCharChars(PTPT_LexStrCharChars arg0, PTPT_LexStrCharChars arg1) {
  return (PTPT_LexStrCharChars) ATconcat((ATermList) arg0, (ATermList) arg1);
}

/**
 * Extract a sublist from a PTPT_LexStrCharChars. 
 * \param[in] arg PTPT_LexStrCharChars to extract a slice from
 * \param[in] start inclusive start index of the sublist
 * \param[in] end exclusive end index of the sublist
 * \return new PTPT_LexStrCharChars with a first element the element at index #start from #arg, and as last element the element at index (#end - 1).
 */
PTPT_LexStrCharChars _PTPT_sliceLexStrCharChars(PTPT_LexStrCharChars arg, int start, int end) {
  return (PTPT_LexStrCharChars) ATgetSlice((ATermList) arg, start, end);
}

/**
 * Retrieve the PTPT_LexStrChar at #index from a PTPT_LexStrCharChars. 
 * \param[in] arg PTPT_LexStrCharChars to retrieve the PTPT_LexStrChar from
 * \param[in] index index to use to point in the PTPT_LexStrCharChars
 * \return PTPT_LexStrChar at position #index in #arg
 */
PTPT_LexStrChar _PTPT_getLexStrCharCharsLexStrCharAt(PTPT_LexStrCharChars arg, int index) {
 return (PTPT_LexStrChar)ATelementAt((ATermList) arg,index);
}

/**
 * Replace the PTPT_LexStrChar at #index from a PTPT_LexStrCharChars by a new one. 
 * \param[in] arg PTPT_LexStrCharChars to retrieve the PTPT_LexStrChar from
 * \param[in] elem new PTPT_LexStrChar to replace another
 * \param[in] index index to use to point in the PTPT_LexStrCharChars
 * \return A new PTPT_LexStrCharCharswith #elem replaced in #arg at position #index
 */
PTPT_LexStrCharChars _PTPT_replaceLexStrCharCharsLexStrCharAt(PTPT_LexStrCharChars arg, PTPT_LexStrChar elem, int index) {
 return (PTPT_LexStrCharChars) ATreplace((ATermList) arg, (ATerm) ((ATerm) elem), index);
}

/**
 * Builds a PTPT_LexStrCharChars of 2 consecutive elements. 
 * \param[in] elem1 One PTPT_LexStrChar element of the new PTPT_LexStrCharChars
 * \param[in] elem2 One PTPT_LexStrChar element of the new PTPT_LexStrCharChars
 * \return A new PTPT_LexStrCharChars consisting of 2 PTPT_LexStrChars
 */
PTPT_LexStrCharChars _PTPT_makeLexStrCharChars2(PTPT_LexStrChar elem1, PTPT_LexStrChar elem2) {
  return (PTPT_LexStrCharChars) ATmakeList2((ATerm) ((ATerm) elem1), (ATerm) ((ATerm) elem2));
}

/**
 * Builds a PTPT_LexStrCharChars of 3 consecutive elements. 
 * \param[in] elem1 One PTPT_LexStrChar element of the new PTPT_LexStrCharChars
 * \param[in] elem2 One PTPT_LexStrChar element of the new PTPT_LexStrCharChars
 * \param[in] elem3 One PTPT_LexStrChar element of the new PTPT_LexStrCharChars
 * \return A new PTPT_LexStrCharChars consisting of 3 PTPT_LexStrChars
 */
PTPT_LexStrCharChars _PTPT_makeLexStrCharChars3(PTPT_LexStrChar elem1, PTPT_LexStrChar elem2, PTPT_LexStrChar elem3) {
  return (PTPT_LexStrCharChars) ATmakeList3((ATerm) ((ATerm) elem1), (ATerm) ((ATerm) elem2), (ATerm) ((ATerm) elem3));
}

/**
 * Builds a PTPT_LexStrCharChars of 4 consecutive elements. 
 * \param[in] elem1 One PTPT_LexStrChar element of the new PTPT_LexStrCharChars
 * \param[in] elem2 One PTPT_LexStrChar element of the new PTPT_LexStrCharChars
 * \param[in] elem3 One PTPT_LexStrChar element of the new PTPT_LexStrCharChars
 * \param[in] elem4 One PTPT_LexStrChar element of the new PTPT_LexStrCharChars
 * \return A new PTPT_LexStrCharChars consisting of 4 PTPT_LexStrChars
 */
PTPT_LexStrCharChars _PTPT_makeLexStrCharChars4(PTPT_LexStrChar elem1, PTPT_LexStrChar elem2, PTPT_LexStrChar elem3, PTPT_LexStrChar elem4) {
  return (PTPT_LexStrCharChars) ATmakeList4((ATerm) ((ATerm) elem1), (ATerm) ((ATerm) elem2), (ATerm) ((ATerm) elem3), (ATerm) ((ATerm) elem4));
}

/**
 * Builds a PTPT_LexStrCharChars of 5 consecutive elements. 
 * \param[in] elem1 One PTPT_LexStrChar element of the new PTPT_LexStrCharChars
 * \param[in] elem2 One PTPT_LexStrChar element of the new PTPT_LexStrCharChars
 * \param[in] elem3 One PTPT_LexStrChar element of the new PTPT_LexStrCharChars
 * \param[in] elem4 One PTPT_LexStrChar element of the new PTPT_LexStrCharChars
 * \param[in] elem5 One PTPT_LexStrChar element of the new PTPT_LexStrCharChars
 * \return A new PTPT_LexStrCharChars consisting of 5 PTPT_LexStrChars
 */
PTPT_LexStrCharChars _PTPT_makeLexStrCharChars5(PTPT_LexStrChar elem1, PTPT_LexStrChar elem2, PTPT_LexStrChar elem3, PTPT_LexStrChar elem4, PTPT_LexStrChar elem5) {
  return (PTPT_LexStrCharChars) ATmakeList5((ATerm) ((ATerm) elem1), (ATerm) ((ATerm) elem2), (ATerm) ((ATerm) elem3), (ATerm) ((ATerm) elem4), (ATerm) ((ATerm) elem5));
}

/**
 * Builds a PTPT_LexStrCharChars of 6 consecutive elements. 
 * \param[in] elem1 One PTPT_LexStrChar element of the new PTPT_LexStrCharChars
 * \param[in] elem2 One PTPT_LexStrChar element of the new PTPT_LexStrCharChars
 * \param[in] elem3 One PTPT_LexStrChar element of the new PTPT_LexStrCharChars
 * \param[in] elem4 One PTPT_LexStrChar element of the new PTPT_LexStrCharChars
 * \param[in] elem5 One PTPT_LexStrChar element of the new PTPT_LexStrCharChars
 * \param[in] elem6 One PTPT_LexStrChar element of the new PTPT_LexStrCharChars
 * \return A new PTPT_LexStrCharChars consisting of 6 PTPT_LexStrChars
 */
PTPT_LexStrCharChars _PTPT_makeLexStrCharChars6(PTPT_LexStrChar elem1, PTPT_LexStrChar elem2, PTPT_LexStrChar elem3, PTPT_LexStrChar elem4, PTPT_LexStrChar elem5, PTPT_LexStrChar elem6) {
  return (PTPT_LexStrCharChars) ATmakeList6((ATerm) ((ATerm) elem1), (ATerm) ((ATerm) elem2), (ATerm) ((ATerm) elem3), (ATerm) ((ATerm) elem4), (ATerm) ((ATerm) elem5), (ATerm) ((ATerm) elem6));
}

/**
 * Constructs a Absent of type PTPT_OptLayout. Like all ATerm types, PTPT_OptLayouts are maximally shared.
 * \return A pointer to a Absent, either newly constructed or shared
 */
PTPT_OptLayout PTPT_makeOptLayoutAbsent(void) {
  return (PTPT_OptLayout)(ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATempty, (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4))), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATempty);
}
/**
 * Constructs a Present of type PTPT_OptLayout. Like all ATerm types, PTPT_OptLayouts are maximally shared.
 * \param[in] layout a child of the new Present
 * \return A pointer to a Present, either newly constructed or shared
 */
PTPT_OptLayout PTPT_makeOptLayoutPresent(PTPT_Layout layout) {
  return (PTPT_OptLayout)(ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl0(PTPT_afun4))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4))), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm) layout));
}
/**
 * Constructs a Lex-to-cf of type PTPT_Layout. Like all ATerm types, PTPT_Layouts are maximally shared.
 * \param[in] list a child of the new Lex-to-cf
 * \return A pointer to a Lex-to-cf, either newly constructed or shared
 */
PTPT_Layout PTPT_makeLayoutLexToCf(PTPT_LexLayoutList list) {
  return (PTPT_Layout)(ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun6, (ATerm)ATmakeAppl1(PTPT_afun7, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl0(PTPT_afun4)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl1(PTPT_afun8, (ATerm)ATmakeAppl1(PTPT_afun6, (ATerm)ATmakeAppl1(PTPT_afun7, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm) list)));
}
/**
 * Constructs a empty of type PTPT_LexLayoutList. Like all ATerm types, PTPT_LexLayoutLists are maximally shared.
 * \return A pointer to a empty, either newly constructed or shared
 */
PTPT_LexLayoutList PTPT_makeLexLayoutListEmpty(void) {
  return (PTPT_LexLayoutList)(ATerm)ATempty;
}
/**
 * Constructs a single of type PTPT_LexLayoutList. Like all ATerm types, PTPT_LexLayoutLists are maximally shared.
 * \param[in] head a child of the new single
 * \return A pointer to a single, either newly constructed or shared
 */
PTPT_LexLayoutList PTPT_makeLexLayoutListSingle(PTPT_LexLayout head) {
  return (PTPT_LexLayoutList)(ATerm)ATmakeList1((ATerm) head);
}
/**
 * Constructs a many of type PTPT_LexLayoutList. Like all ATerm types, PTPT_LexLayoutLists are maximally shared.
 * \param[in] head a child of the new many
 * \param[in] tail a child of the new many
 * \return A pointer to a many, either newly constructed or shared
 */
PTPT_LexLayoutList PTPT_makeLexLayoutListMany(PTPT_LexLayout head, PTPT_LexLayoutList tail) {
  return (PTPT_LexLayoutList)(ATerm)ATinsert((ATermList)tail, (ATerm) head);
}
/**
 * Constructs a annotated of type PTPT_Tree. Like all ATerm types, PTPT_Trees are maximally shared.
 * \param[in] Tree a child of the new annotated
 * \param[in] wsAfterTree a child of the new annotated
 * \param[in] Annotation a child of the new annotated
 * \return A pointer to a annotated, either newly constructed or shared
 */
PTPT_Tree PTPT_makeTreeAnnotated(PTPT_Tree Tree, PTPT_OptLayout wsAfterTree, PTPT_Annotation Annotation) {
  return (PTPT_Tree)(ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun10)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun11)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun11))), (ATerm)ATmakeAppl1(PTPT_afun12, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun13, (ATerm)ATmakeAppl1(PTPT_afun14, (ATerm)ATmakeAppl0(PTPT_afun15)))))), (ATerm)ATinsert(ATinsert(ATmakeList1((ATerm) Annotation), (ATerm) wsAfterTree), (ATerm) Tree));
}
/**
 * Constructs a appl of type PTPT_Tree. Like all ATerm types, PTPT_Trees are maximally shared.
 * \param[in] wsAfterAppl a child of the new appl
 * \param[in] wsAfterParenOpen a child of the new appl
 * \param[in] prod a child of the new appl
 * \param[in] wsAfterProd a child of the new appl
 * \param[in] wsAfterComma a child of the new appl
 * \param[in] args a child of the new appl
 * \param[in] wsAfterArgs a child of the new appl
 * \return A pointer to a appl, either newly constructed or shared
 */
PTPT_Tree PTPT_makeTreeAppl(PTPT_OptLayout wsAfterAppl, PTPT_OptLayout wsAfterParenOpen, PTPT_Production prod, PTPT_OptLayout wsAfterProd, PTPT_OptLayout wsAfterComma, PTPT_Args args, PTPT_OptLayout wsAfterArgs) {
  return (PTPT_Tree)(ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun17))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun18)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun19))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun20)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun21))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun22))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun11))), (ATerm)ATmakeAppl1(PTPT_afun12, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun13, (ATerm)ATmakeAppl1(PTPT_afun14, (ATerm)ATmakeAppl0(PTPT_afun22)))))), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(41)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun17)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(41)))), (ATerm) wsAfterArgs), (ATerm) args), (ATerm) wsAfterComma), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(44)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun19)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(44)))), (ATerm) wsAfterProd), (ATerm) prod), (ATerm) wsAfterParenOpen), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(40)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun21)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(40)))), (ATerm) wsAfterAppl), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(108)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(112)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(112)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(97)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun22)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeInt(108)), (ATerm)ATmakeInt(112)), (ATerm)ATmakeInt(112)), (ATerm)ATmakeInt(97)))));
}
/**
 * Constructs a cycle of type PTPT_Tree. Like all ATerm types, PTPT_Trees are maximally shared.
 * \param[in] wsAfterCycle a child of the new cycle
 * \param[in] wsAfterParenOpen a child of the new cycle
 * \param[in] symbol a child of the new cycle
 * \param[in] wsAfterSymbol a child of the new cycle
 * \param[in] wsAfterComma a child of the new cycle
 * \param[in] length a child of the new cycle
 * \param[in] wsAfterLength a child of the new cycle
 * \return A pointer to a cycle, either newly constructed or shared
 */
PTPT_Tree PTPT_makeTreeCycle(PTPT_OptLayout wsAfterCycle, PTPT_OptLayout wsAfterParenOpen, PTPT_Symbol symbol, PTPT_OptLayout wsAfterSymbol, PTPT_OptLayout wsAfterComma, PTPT_NatCon length, PTPT_OptLayout wsAfterLength) {
  return (PTPT_Tree)(ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun17))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun24)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun19))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun25)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun21))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun26))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun11))), (ATerm)ATmakeAppl1(PTPT_afun12, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun13, (ATerm)ATmakeAppl1(PTPT_afun14, (ATerm)ATmakeAppl0(PTPT_afun26)))))), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(41)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun17)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(41)))), (ATerm) wsAfterLength), (ATerm) length), (ATerm) wsAfterComma), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(44)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun19)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(44)))), (ATerm) wsAfterSymbol), (ATerm) symbol), (ATerm) wsAfterParenOpen), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(40)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun21)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(40)))), (ATerm) wsAfterCycle), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(101)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(108)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(99)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(121)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(99)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun26)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeInt(101)), (ATerm)ATmakeInt(108)), (ATerm)ATmakeInt(99)), (ATerm)ATmakeInt(121)), (ATerm)ATmakeInt(99)))));
}
/**
 * Constructs a amb of type PTPT_Tree. Like all ATerm types, PTPT_Trees are maximally shared.
 * \param[in] wsAfterAmb a child of the new amb
 * \param[in] wsAfterParenOpen a child of the new amb
 * \param[in] args a child of the new amb
 * \param[in] wsAfterArgs a child of the new amb
 * \return A pointer to a amb, either newly constructed or shared
 */
PTPT_Tree PTPT_makeTreeAmb(PTPT_OptLayout wsAfterAmb, PTPT_OptLayout wsAfterParenOpen, PTPT_Args args, PTPT_OptLayout wsAfterArgs) {
  return (PTPT_Tree)(ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun17))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun18)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun21))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun27))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun11))), (ATerm)ATmakeAppl1(PTPT_afun12, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun13, (ATerm)ATmakeAppl1(PTPT_afun14, (ATerm)ATmakeAppl0(PTPT_afun27)))))), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(41)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun17)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(41)))), (ATerm) wsAfterArgs), (ATerm) args), (ATerm) wsAfterParenOpen), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(40)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun21)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(40)))), (ATerm) wsAfterAmb), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(98)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(109)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(97)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun27)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeInt(98)), (ATerm)ATmakeInt(109)), (ATerm)ATmakeInt(97)))));
}
/**
 * Constructs a char of type PTPT_Tree. Like all ATerm types, PTPT_Trees are maximally shared.
 * \param[in] character a child of the new char
 * \return A pointer to a char, either newly constructed or shared
 */
PTPT_Tree PTPT_makeTreeChar(PTPT_NatCon character) {
  return (PTPT_Tree)(ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun24)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun11))), (ATerm)ATmakeAppl1(PTPT_afun12, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun13, (ATerm)ATmakeAppl1(PTPT_afun14, (ATerm)ATmakeAppl0(PTPT_afun28)))))), (ATerm)ATmakeList1((ATerm) character));
}
/**
 * Constructs a no-attrs of type PTPT_Attributes. Like all ATerm types, PTPT_Attributess are maximally shared.
 * \return A pointer to a no-attrs, either newly constructed or shared
 */
PTPT_Attributes PTPT_makeAttributesNoAttrs(void) {
  return (PTPT_Attributes)(ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun29))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun30))), (ATerm)ATmakeAppl1(PTPT_afun12, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun13, (ATerm)ATmakeAppl1(PTPT_afun14, (ATerm)ATmakeAppl0(PTPT_afun29)))))), (ATerm)ATmakeList1((ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(115)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(114)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(116)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(116)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(97)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(45)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(111)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(110)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun29)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeInt(115)), (ATerm)ATmakeInt(114)), (ATerm)ATmakeInt(116)), (ATerm)ATmakeInt(116)), (ATerm)ATmakeInt(97)), (ATerm)ATmakeInt(45)), (ATerm)ATmakeInt(111)), (ATerm)ATmakeInt(110)))));
}
/**
 * Constructs a attrs of type PTPT_Attributes. Like all ATerm types, PTPT_Attributess are maximally shared.
 * \param[in] wsAfterAttrs a child of the new attrs
 * \param[in] wsAfterParenOpen a child of the new attrs
 * \param[in] attributes a child of the new attrs
 * \param[in] wsAfterAttributes a child of the new attrs
 * \return A pointer to a attrs, either newly constructed or shared
 */
PTPT_Attributes PTPT_makeAttributesAttrs(PTPT_OptLayout wsAfterAttrs, PTPT_OptLayout wsAfterParenOpen, PTPT_Attrs attributes, PTPT_OptLayout wsAfterAttributes) {
  return (PTPT_Attributes)(ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun17))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun31)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun21))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun32))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun30))), (ATerm)ATmakeAppl1(PTPT_afun12, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun13, (ATerm)ATmakeAppl1(PTPT_afun14, (ATerm)ATmakeAppl0(PTPT_afun32)))))), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(41)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun17)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(41)))), (ATerm) wsAfterAttributes), (ATerm) attributes), (ATerm) wsAfterParenOpen), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(40)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun21)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(40)))), (ATerm) wsAfterAttrs), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(115)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(114)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(116)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(116)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(97)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun32)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeInt(115)), (ATerm)ATmakeInt(114)), (ATerm)ATmakeInt(116)), (ATerm)ATmakeInt(116)), (ATerm)ATmakeInt(97)))));
}
/**
 * Constructs a many of type PTPT_Attrs. Like all ATerm types, PTPT_Attrss are maximally shared.
 * \param[in] wsAfterBracketOpen a child of the new many
 * \param[in] list a child of the new many
 * \param[in] wsAfterList a child of the new many
 * \return A pointer to a many, either newly constructed or shared
 */
PTPT_Attrs PTPT_makeAttrsMany(PTPT_OptLayout wsAfterBracketOpen, PTPT_AttrList list, PTPT_OptLayout wsAfterList) {
  return (PTPT_Attrs)(ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun33))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl2(PTPT_afun34, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun35)), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun19))))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun36))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun31))), (ATerm)ATmakeAppl1(PTPT_afun12, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun13, (ATerm)ATmakeAppl1(PTPT_afun14, (ATerm)ATmakeAppl0(PTPT_afun37)))))), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(93)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun33)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(93)))), (ATerm) wsAfterList), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl1(PTPT_afun8, (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl2(PTPT_afun34, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun35)), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun19))))), (ATerm) list)), (ATerm) wsAfterBracketOpen), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(91)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun36)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(91)))));
}
/**
 * Constructs a assoc of type PTPT_Attr. Like all ATerm types, PTPT_Attrs are maximally shared.
 * \param[in] wsAfterAssoc a child of the new assoc
 * \param[in] wsAfterParenOpen a child of the new assoc
 * \param[in] associativity a child of the new assoc
 * \param[in] wsAfterAssociativity a child of the new assoc
 * \return A pointer to a assoc, either newly constructed or shared
 */
PTPT_Attr PTPT_makeAttrAssoc(PTPT_OptLayout wsAfterAssoc, PTPT_OptLayout wsAfterParenOpen, PTPT_Associativity associativity, PTPT_OptLayout wsAfterAssociativity) {
  return (PTPT_Attr)(ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun17))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun38)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun21))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun39))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun35))), (ATerm)ATmakeAppl1(PTPT_afun12, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun13, (ATerm)ATmakeAppl1(PTPT_afun14, (ATerm)ATmakeAppl0(PTPT_afun39)))))), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(41)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun17)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(41)))), (ATerm) wsAfterAssociativity), (ATerm) associativity), (ATerm) wsAfterParenOpen), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(40)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun21)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(40)))), (ATerm) wsAfterAssoc), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(99)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(111)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(115)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(115)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(97)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun39)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeInt(99)), (ATerm)ATmakeInt(111)), (ATerm)ATmakeInt(115)), (ATerm)ATmakeInt(115)), (ATerm)ATmakeInt(97)))));
}
/**
 * Constructs a term of type PTPT_Attr. Like all ATerm types, PTPT_Attrs are maximally shared.
 * \param[in] wsAfterTerm a child of the new term
 * \param[in] wsAfterParenOpen a child of the new term
 * \param[in] aterm a child of the new term
 * \param[in] wsAfterAterm a child of the new term
 * \return A pointer to a term, either newly constructed or shared
 */
PTPT_Attr PTPT_makeAttrTerm(PTPT_OptLayout wsAfterTerm, PTPT_OptLayout wsAfterParenOpen, PTPT_ATerm aterm, PTPT_OptLayout wsAfterAterm) {
  return (PTPT_Attr)(ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun17))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun40)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun21))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun41))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun35))), (ATerm)ATmakeAppl1(PTPT_afun12, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun13, (ATerm)ATmakeAppl1(PTPT_afun14, (ATerm)ATmakeAppl0(PTPT_afun41)))))), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(41)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun17)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(41)))), (ATerm) wsAfterAterm), (ATerm) aterm), (ATerm) wsAfterParenOpen), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(40)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun21)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(40)))), (ATerm) wsAfterTerm), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(109)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(114)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(101)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(116)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun41)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeInt(109)), (ATerm)ATmakeInt(114)), (ATerm)ATmakeInt(101)), (ATerm)ATmakeInt(116)))));
}
/**
 * Constructs a id of type PTPT_Attr. Like all ATerm types, PTPT_Attrs are maximally shared.
 * \param[in] wsAfterId a child of the new id
 * \param[in] wsAfterParenOpen a child of the new id
 * \param[in] moduleName a child of the new id
 * \param[in] wsAfterModuleName a child of the new id
 * \return A pointer to a id, either newly constructed or shared
 */
PTPT_Attr PTPT_makeAttrId(PTPT_OptLayout wsAfterId, PTPT_OptLayout wsAfterParenOpen, PTPT_StrCon moduleName, PTPT_OptLayout wsAfterModuleName) {
  return (PTPT_Attr)(ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun17))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun42)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun21))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun43))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun35))), (ATerm)ATmakeAppl1(PTPT_afun12, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun13, (ATerm)ATmakeAppl1(PTPT_afun14, (ATerm)ATmakeAppl0(PTPT_afun43)))))), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(41)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun17)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(41)))), (ATerm) wsAfterModuleName), (ATerm) moduleName), (ATerm) wsAfterParenOpen), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(40)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun21)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(40)))), (ATerm) wsAfterId), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATinsert(ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(100)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(105)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun43)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATinsert(ATmakeList1((ATerm)ATmakeInt(100)), (ATerm)ATmakeInt(105)))));
}
/**
 * Constructs a bracket of type PTPT_Attr. Like all ATerm types, PTPT_Attrs are maximally shared.
 * \return A pointer to a bracket, either newly constructed or shared
 */
PTPT_Attr PTPT_makeAttrBracket(void) {
  return (PTPT_Attr)(ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun44))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun35))), (ATerm)ATmakeAppl1(PTPT_afun12, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun13, (ATerm)ATmakeAppl1(PTPT_afun14, (ATerm)ATmakeAppl0(PTPT_afun44)))))), (ATerm)ATmakeList1((ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(116)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(101)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(107)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(99)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(97)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(114)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(98)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun44)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeInt(116)), (ATerm)ATmakeInt(101)), (ATerm)ATmakeInt(107)), (ATerm)ATmakeInt(99)), (ATerm)ATmakeInt(97)), (ATerm)ATmakeInt(114)), (ATerm)ATmakeInt(98)))));
}
/**
 * Constructs a reject of type PTPT_Attr. Like all ATerm types, PTPT_Attrs are maximally shared.
 * \return A pointer to a reject, either newly constructed or shared
 */
PTPT_Attr PTPT_makeAttrReject(void) {
  return (PTPT_Attr)(ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun45))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun35))), (ATerm)ATmakeAppl1(PTPT_afun12, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun13, (ATerm)ATmakeAppl1(PTPT_afun14, (ATerm)ATmakeAppl0(PTPT_afun45)))))), (ATerm)ATmakeList1((ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(116)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(99)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(101)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(106)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(101)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(114)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun45)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeInt(116)), (ATerm)ATmakeInt(99)), (ATerm)ATmakeInt(101)), (ATerm)ATmakeInt(106)), (ATerm)ATmakeInt(101)), (ATerm)ATmakeInt(114)))));
}
/**
 * Constructs a prefer of type PTPT_Attr. Like all ATerm types, PTPT_Attrs are maximally shared.
 * \return A pointer to a prefer, either newly constructed or shared
 */
PTPT_Attr PTPT_makeAttrPrefer(void) {
  return (PTPT_Attr)(ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun46))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun35))), (ATerm)ATmakeAppl1(PTPT_afun12, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun13, (ATerm)ATmakeAppl1(PTPT_afun14, (ATerm)ATmakeAppl0(PTPT_afun46)))))), (ATerm)ATmakeList1((ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(114)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(101)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(102)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(101)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(114)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(112)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun46)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeInt(114)), (ATerm)ATmakeInt(101)), (ATerm)ATmakeInt(102)), (ATerm)ATmakeInt(101)), (ATerm)ATmakeInt(114)), (ATerm)ATmakeInt(112)))));
}
/**
 * Constructs a avoid of type PTPT_Attr. Like all ATerm types, PTPT_Attrs are maximally shared.
 * \return A pointer to a avoid, either newly constructed or shared
 */
PTPT_Attr PTPT_makeAttrAvoid(void) {
  return (PTPT_Attr)(ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun47))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun35))), (ATerm)ATmakeAppl1(PTPT_afun12, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun13, (ATerm)ATmakeAppl1(PTPT_afun14, (ATerm)ATmakeAppl0(PTPT_afun47)))))), (ATerm)ATmakeList1((ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(100)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(105)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(111)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(118)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(97)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun47)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeInt(100)), (ATerm)ATmakeInt(105)), (ATerm)ATmakeInt(111)), (ATerm)ATmakeInt(118)), (ATerm)ATmakeInt(97)))));
}
/**
 * Constructs a left of type PTPT_Associativity. Like all ATerm types, PTPT_Associativitys are maximally shared.
 * \return A pointer to a left, either newly constructed or shared
 */
PTPT_Associativity PTPT_makeAssociativityLeft(void) {
  return (PTPT_Associativity)(ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun48))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun38))), (ATerm)ATmakeAppl1(PTPT_afun12, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun13, (ATerm)ATmakeAppl1(PTPT_afun14, (ATerm)ATmakeAppl0(PTPT_afun48)))))), (ATerm)ATmakeList1((ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(116)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(102)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(101)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(108)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun48)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeInt(116)), (ATerm)ATmakeInt(102)), (ATerm)ATmakeInt(101)), (ATerm)ATmakeInt(108)))));
}
/**
 * Constructs a right of type PTPT_Associativity. Like all ATerm types, PTPT_Associativitys are maximally shared.
 * \return A pointer to a right, either newly constructed or shared
 */
PTPT_Associativity PTPT_makeAssociativityRight(void) {
  return (PTPT_Associativity)(ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun49))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun38))), (ATerm)ATmakeAppl1(PTPT_afun12, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun13, (ATerm)ATmakeAppl1(PTPT_afun14, (ATerm)ATmakeAppl0(PTPT_afun49)))))), (ATerm)ATmakeList1((ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(116)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(104)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(103)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(105)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(114)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun49)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeInt(116)), (ATerm)ATmakeInt(104)), (ATerm)ATmakeInt(103)), (ATerm)ATmakeInt(105)), (ATerm)ATmakeInt(114)))));
}
/**
 * Constructs a assoc of type PTPT_Associativity. Like all ATerm types, PTPT_Associativitys are maximally shared.
 * \return A pointer to a assoc, either newly constructed or shared
 */
PTPT_Associativity PTPT_makeAssociativityAssoc(void) {
  return (PTPT_Associativity)(ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun39))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun38))), (ATerm)ATmakeAppl1(PTPT_afun12, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun13, (ATerm)ATmakeAppl1(PTPT_afun14, (ATerm)ATmakeAppl0(PTPT_afun39)))))), (ATerm)ATmakeList1((ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(99)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(111)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(115)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(115)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(97)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun39)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeInt(99)), (ATerm)ATmakeInt(111)), (ATerm)ATmakeInt(115)), (ATerm)ATmakeInt(115)), (ATerm)ATmakeInt(97)))));
}
/**
 * Constructs a non-assoc of type PTPT_Associativity. Like all ATerm types, PTPT_Associativitys are maximally shared.
 * \return A pointer to a non-assoc, either newly constructed or shared
 */
PTPT_Associativity PTPT_makeAssociativityNonAssoc(void) {
  return (PTPT_Associativity)(ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun50))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun38))), (ATerm)ATmakeAppl1(PTPT_afun12, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun13, (ATerm)ATmakeAppl1(PTPT_afun14, (ATerm)ATmakeAppl0(PTPT_afun50)))))), (ATerm)ATmakeList1((ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(99)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(111)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(115)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(115)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(97)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(45)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(110)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(111)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(110)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun50)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeInt(99)), (ATerm)ATmakeInt(111)), (ATerm)ATmakeInt(115)), (ATerm)ATmakeInt(115)), (ATerm)ATmakeInt(97)), (ATerm)ATmakeInt(45)), (ATerm)ATmakeInt(110)), (ATerm)ATmakeInt(111)), (ATerm)ATmakeInt(110)))));
}
/**
 * Constructs a empty of type PTPT_AttrList. Like all ATerm types, PTPT_AttrLists are maximally shared.
 * \return A pointer to a empty, either newly constructed or shared
 */
PTPT_AttrList PTPT_makeAttrListEmpty(void) {
  return (PTPT_AttrList)(ATerm)ATempty;
}
/**
 * Constructs a single of type PTPT_AttrList. Like all ATerm types, PTPT_AttrLists are maximally shared.
 * \param[in] head a child of the new single
 * \return A pointer to a single, either newly constructed or shared
 */
PTPT_AttrList PTPT_makeAttrListSingle(PTPT_Attr head) {
  return (PTPT_AttrList)(ATerm)ATmakeList1((ATerm) head);
}
/**
 * Constructs a many of type PTPT_AttrList. Like all ATerm types, PTPT_AttrLists are maximally shared.
 * \param[in] head a child of the new many
 * \param[in] wsAfterHead a child of the new many
 * \param[in] wsAfterSep a child of the new many
 * \param[in] tail a child of the new many
 * \return A pointer to a many, either newly constructed or shared
 */
PTPT_AttrList PTPT_makeAttrListMany(PTPT_Attr head, PTPT_OptLayout wsAfterHead, PTPT_OptLayout wsAfterSep, PTPT_AttrList tail) {
  if (PTPT_isAttrListEmpty(tail)) {
    return PTPT_makeAttrListSingle(head);
  }
  return (PTPT_AttrList)(ATerm)ATinsert(ATinsert(ATinsert(ATinsert((ATermList)tail, (ATerm) wsAfterSep), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(44)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun19)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(44)))), (ATerm) wsAfterHead), (ATerm) head);
}
/**
 * Constructs a top of type PTPT_ParseTree. Like all ATerm types, PTPT_ParseTrees are maximally shared.
 * \param[in] wsAfterParsetree a child of the new top
 * \param[in] wsAfterParenOpen a child of the new top
 * \param[in] top a child of the new top
 * \param[in] wsAfterTop a child of the new top
 * \param[in] wsAfterComma a child of the new top
 * \param[in] ambCnt a child of the new top
 * \param[in] wsAfterAmbCnt a child of the new top
 * \return A pointer to a top, either newly constructed or shared
 */
PTPT_ParseTree PTPT_makeParseTreeTop(PTPT_OptLayout wsAfterParsetree, PTPT_OptLayout wsAfterParenOpen, PTPT_Tree top, PTPT_OptLayout wsAfterTop, PTPT_OptLayout wsAfterComma, PTPT_NatCon ambCnt, PTPT_OptLayout wsAfterAmbCnt) {
  return (PTPT_ParseTree)(ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun17))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun24)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun19))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun11)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun21))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun51))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun52))), (ATerm)ATmakeAppl1(PTPT_afun12, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun13, (ATerm)ATmakeAppl1(PTPT_afun14, (ATerm)ATmakeAppl0(PTPT_afun53)))))), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(41)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun17)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(41)))), (ATerm) wsAfterAmbCnt), (ATerm) ambCnt), (ATerm) wsAfterComma), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(44)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun19)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(44)))), (ATerm) wsAfterTop), (ATerm) top), (ATerm) wsAfterParenOpen), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(40)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun21)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(40)))), (ATerm) wsAfterParsetree), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(101)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(101)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(114)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(116)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(101)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(115)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(114)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(97)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(112)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun51)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeInt(101)), (ATerm)ATmakeInt(101)), (ATerm)ATmakeInt(114)), (ATerm)ATmakeInt(116)), (ATerm)ATmakeInt(101)), (ATerm)ATmakeInt(115)), (ATerm)ATmakeInt(114)), (ATerm)ATmakeInt(97)), (ATerm)ATmakeInt(112)))));
}
/**
 * Constructs a empty of type PTPT_Symbol. Like all ATerm types, PTPT_Symbols are maximally shared.
 * \return A pointer to a empty, either newly constructed or shared
 */
PTPT_Symbol PTPT_makeSymbolEmpty(void) {
  return (PTPT_Symbol)(ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun54))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun25))), (ATerm)ATmakeAppl1(PTPT_afun12, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun13, (ATerm)ATmakeAppl1(PTPT_afun14, (ATerm)ATmakeAppl0(PTPT_afun54)))))), (ATerm)ATmakeList1((ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(121)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(116)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(112)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(109)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(101)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun54)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeInt(121)), (ATerm)ATmakeInt(116)), (ATerm)ATmakeInt(112)), (ATerm)ATmakeInt(109)), (ATerm)ATmakeInt(101)))));
}
/**
 * Constructs a lit of type PTPT_Symbol. Like all ATerm types, PTPT_Symbols are maximally shared.
 * \param[in] wsAfterLit a child of the new lit
 * \param[in] wsAfterParenOpen a child of the new lit
 * \param[in] string a child of the new lit
 * \param[in] wsAfterString a child of the new lit
 * \return A pointer to a lit, either newly constructed or shared
 */
PTPT_Symbol PTPT_makeSymbolLit(PTPT_OptLayout wsAfterLit, PTPT_OptLayout wsAfterParenOpen, PTPT_StrCon string, PTPT_OptLayout wsAfterString) {
  return (PTPT_Symbol)(ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun17))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun42)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun21))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun55))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun25))), (ATerm)ATmakeAppl1(PTPT_afun12, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun13, (ATerm)ATmakeAppl1(PTPT_afun14, (ATerm)ATmakeAppl0(PTPT_afun55)))))), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(41)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun17)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(41)))), (ATerm) wsAfterString), (ATerm) string), (ATerm) wsAfterParenOpen), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(40)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun21)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(40)))), (ATerm) wsAfterLit), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(116)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(105)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(108)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun55)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeInt(116)), (ATerm)ATmakeInt(105)), (ATerm)ATmakeInt(108)))));
}
/**
 * Constructs a cilit of type PTPT_Symbol. Like all ATerm types, PTPT_Symbols are maximally shared.
 * \param[in] wsAfterCilit a child of the new cilit
 * \param[in] wsAfterParenOpen a child of the new cilit
 * \param[in] string a child of the new cilit
 * \param[in] wsAfterString a child of the new cilit
 * \return A pointer to a cilit, either newly constructed or shared
 */
PTPT_Symbol PTPT_makeSymbolCilit(PTPT_OptLayout wsAfterCilit, PTPT_OptLayout wsAfterParenOpen, PTPT_StrCon string, PTPT_OptLayout wsAfterString) {
  return (PTPT_Symbol)(ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun17))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun42)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun21))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun56))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun25))), (ATerm)ATmakeAppl1(PTPT_afun12, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun13, (ATerm)ATmakeAppl1(PTPT_afun14, (ATerm)ATmakeAppl0(PTPT_afun56)))))), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(41)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun17)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(41)))), (ATerm) wsAfterString), (ATerm) string), (ATerm) wsAfterParenOpen), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(40)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun21)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(40)))), (ATerm) wsAfterCilit), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(116)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(105)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(108)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(105)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(99)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun56)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeInt(116)), (ATerm)ATmakeInt(105)), (ATerm)ATmakeInt(108)), (ATerm)ATmakeInt(105)), (ATerm)ATmakeInt(99)))));
}
/**
 * Constructs a cf of type PTPT_Symbol. Like all ATerm types, PTPT_Symbols are maximally shared.
 * \param[in] wsAfterCf a child of the new cf
 * \param[in] wsAfterParenOpen a child of the new cf
 * \param[in] symbol a child of the new cf
 * \param[in] wsAfterSymbol a child of the new cf
 * \return A pointer to a cf, either newly constructed or shared
 */
PTPT_Symbol PTPT_makeSymbolCf(PTPT_OptLayout wsAfterCf, PTPT_OptLayout wsAfterParenOpen, PTPT_Symbol symbol, PTPT_OptLayout wsAfterSymbol) {
  return (PTPT_Symbol)(ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun17))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun25)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun21))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun57))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun25))), (ATerm)ATmakeAppl1(PTPT_afun12, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun13, (ATerm)ATmakeAppl1(PTPT_afun14, (ATerm)ATmakeAppl0(PTPT_afun57)))))), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(41)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun17)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(41)))), (ATerm) wsAfterSymbol), (ATerm) symbol), (ATerm) wsAfterParenOpen), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(40)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun21)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(40)))), (ATerm) wsAfterCf), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATinsert(ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(102)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(99)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun57)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATinsert(ATmakeList1((ATerm)ATmakeInt(102)), (ATerm)ATmakeInt(99)))));
}
/**
 * Constructs a lex of type PTPT_Symbol. Like all ATerm types, PTPT_Symbols are maximally shared.
 * \param[in] wsAfterLex a child of the new lex
 * \param[in] wsAfterParenOpen a child of the new lex
 * \param[in] symbol a child of the new lex
 * \param[in] wsAfterSymbol a child of the new lex
 * \return A pointer to a lex, either newly constructed or shared
 */
PTPT_Symbol PTPT_makeSymbolLex(PTPT_OptLayout wsAfterLex, PTPT_OptLayout wsAfterParenOpen, PTPT_Symbol symbol, PTPT_OptLayout wsAfterSymbol) {
  return (PTPT_Symbol)(ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun17))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun25)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun21))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun58))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun25))), (ATerm)ATmakeAppl1(PTPT_afun12, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun13, (ATerm)ATmakeAppl1(PTPT_afun14, (ATerm)ATmakeAppl0(PTPT_afun58)))))), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(41)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun17)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(41)))), (ATerm) wsAfterSymbol), (ATerm) symbol), (ATerm) wsAfterParenOpen), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(40)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun21)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(40)))), (ATerm) wsAfterLex), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(120)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(101)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(108)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun58)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeInt(120)), (ATerm)ATmakeInt(101)), (ATerm)ATmakeInt(108)))));
}
/**
 * Constructs a opt of type PTPT_Symbol. Like all ATerm types, PTPT_Symbols are maximally shared.
 * \param[in] wsAfterOpt a child of the new opt
 * \param[in] wsAfterParenOpen a child of the new opt
 * \param[in] symbol a child of the new opt
 * \param[in] wsAfterSymbol a child of the new opt
 * \return A pointer to a opt, either newly constructed or shared
 */
PTPT_Symbol PTPT_makeSymbolOpt(PTPT_OptLayout wsAfterOpt, PTPT_OptLayout wsAfterParenOpen, PTPT_Symbol symbol, PTPT_OptLayout wsAfterSymbol) {
  return (PTPT_Symbol)(ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun17))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun25)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun21))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun59))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun25))), (ATerm)ATmakeAppl1(PTPT_afun12, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun13, (ATerm)ATmakeAppl1(PTPT_afun14, (ATerm)ATmakeAppl0(PTPT_afun59)))))), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(41)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun17)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(41)))), (ATerm) wsAfterSymbol), (ATerm) symbol), (ATerm) wsAfterParenOpen), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(40)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun21)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(40)))), (ATerm) wsAfterOpt), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(116)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(112)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(111)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun59)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeInt(116)), (ATerm)ATmakeInt(112)), (ATerm)ATmakeInt(111)))));
}
/**
 * Constructs a alt of type PTPT_Symbol. Like all ATerm types, PTPT_Symbols are maximally shared.
 * \param[in] wsAfterAlt a child of the new alt
 * \param[in] wsAfterParenOpen a child of the new alt
 * \param[in] lhs a child of the new alt
 * \param[in] wsAfterLhs a child of the new alt
 * \param[in] wsAfterComma a child of the new alt
 * \param[in] rhs a child of the new alt
 * \param[in] wsAfterRhs a child of the new alt
 * \return A pointer to a alt, either newly constructed or shared
 */
PTPT_Symbol PTPT_makeSymbolAlt(PTPT_OptLayout wsAfterAlt, PTPT_OptLayout wsAfterParenOpen, PTPT_Symbol lhs, PTPT_OptLayout wsAfterLhs, PTPT_OptLayout wsAfterComma, PTPT_Symbol rhs, PTPT_OptLayout wsAfterRhs) {
  return (PTPT_Symbol)(ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun17))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun25)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun19))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun25)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun21))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun60))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun25))), (ATerm)ATmakeAppl1(PTPT_afun12, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun13, (ATerm)ATmakeAppl1(PTPT_afun14, (ATerm)ATmakeAppl0(PTPT_afun60)))))), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(41)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun17)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(41)))), (ATerm) wsAfterRhs), (ATerm) rhs), (ATerm) wsAfterComma), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(44)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun19)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(44)))), (ATerm) wsAfterLhs), (ATerm) lhs), (ATerm) wsAfterParenOpen), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(40)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun21)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(40)))), (ATerm) wsAfterAlt), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(116)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(108)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(97)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun60)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeInt(116)), (ATerm)ATmakeInt(108)), (ATerm)ATmakeInt(97)))));
}
/**
 * Constructs a seq of type PTPT_Symbol. Like all ATerm types, PTPT_Symbols are maximally shared.
 * \param[in] wsAfterSeq a child of the new seq
 * \param[in] wsAfterParenOpen a child of the new seq
 * \param[in] symbols a child of the new seq
 * \param[in] wsAfterSymbols a child of the new seq
 * \return A pointer to a seq, either newly constructed or shared
 */
PTPT_Symbol PTPT_makeSymbolSeq(PTPT_OptLayout wsAfterSeq, PTPT_OptLayout wsAfterParenOpen, PTPT_Symbols symbols, PTPT_OptLayout wsAfterSymbols) {
  return (PTPT_Symbol)(ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun17))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun61)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun21))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun62))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun25))), (ATerm)ATmakeAppl1(PTPT_afun12, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun13, (ATerm)ATmakeAppl1(PTPT_afun14, (ATerm)ATmakeAppl0(PTPT_afun62)))))), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(41)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun17)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(41)))), (ATerm) wsAfterSymbols), (ATerm) symbols), (ATerm) wsAfterParenOpen), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(40)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun21)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(40)))), (ATerm) wsAfterSeq), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(113)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(101)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(115)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun62)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeInt(113)), (ATerm)ATmakeInt(101)), (ATerm)ATmakeInt(115)))));
}
/**
 * Constructs a tuple of type PTPT_Symbol. Like all ATerm types, PTPT_Symbols are maximally shared.
 * \param[in] wsAfterTuple a child of the new tuple
 * \param[in] wsAfterParenOpen a child of the new tuple
 * \param[in] head a child of the new tuple
 * \param[in] wsAfterHead a child of the new tuple
 * \param[in] wsAfterComma a child of the new tuple
 * \param[in] rest a child of the new tuple
 * \param[in] wsAfterRest a child of the new tuple
 * \return A pointer to a tuple, either newly constructed or shared
 */
PTPT_Symbol PTPT_makeSymbolTuple(PTPT_OptLayout wsAfterTuple, PTPT_OptLayout wsAfterParenOpen, PTPT_Symbol head, PTPT_OptLayout wsAfterHead, PTPT_OptLayout wsAfterComma, PTPT_Symbols rest, PTPT_OptLayout wsAfterRest) {
  return (PTPT_Symbol)(ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun17))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun61)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun19))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun25)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun21))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun63))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun25))), (ATerm)ATmakeAppl1(PTPT_afun12, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun13, (ATerm)ATmakeAppl1(PTPT_afun14, (ATerm)ATmakeAppl0(PTPT_afun63)))))), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(41)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun17)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(41)))), (ATerm) wsAfterRest), (ATerm) rest), (ATerm) wsAfterComma), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(44)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun19)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(44)))), (ATerm) wsAfterHead), (ATerm) head), (ATerm) wsAfterParenOpen), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(40)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun21)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(40)))), (ATerm) wsAfterTuple), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(101)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(108)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(112)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(117)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(116)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun63)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeInt(101)), (ATerm)ATmakeInt(108)), (ATerm)ATmakeInt(112)), (ATerm)ATmakeInt(117)), (ATerm)ATmakeInt(116)))));
}
/**
 * Constructs a sort of type PTPT_Symbol. Like all ATerm types, PTPT_Symbols are maximally shared.
 * \param[in] wsAfterSort a child of the new sort
 * \param[in] wsAfterParenOpen a child of the new sort
 * \param[in] string a child of the new sort
 * \param[in] wsAfterString a child of the new sort
 * \return A pointer to a sort, either newly constructed or shared
 */
PTPT_Symbol PTPT_makeSymbolSort(PTPT_OptLayout wsAfterSort, PTPT_OptLayout wsAfterParenOpen, PTPT_StrCon string, PTPT_OptLayout wsAfterString) {
  return (PTPT_Symbol)(ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun17))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun42)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun21))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun64))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun25))), (ATerm)ATmakeAppl1(PTPT_afun12, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun13, (ATerm)ATmakeAppl1(PTPT_afun14, (ATerm)ATmakeAppl0(PTPT_afun64)))))), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(41)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun17)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(41)))), (ATerm) wsAfterString), (ATerm) string), (ATerm) wsAfterParenOpen), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(40)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun21)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(40)))), (ATerm) wsAfterSort), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(116)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(114)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(111)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(115)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun64)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeInt(116)), (ATerm)ATmakeInt(114)), (ATerm)ATmakeInt(111)), (ATerm)ATmakeInt(115)))));
}
/**
 * Constructs a iter of type PTPT_Symbol. Like all ATerm types, PTPT_Symbols are maximally shared.
 * \param[in] wsAfterIter a child of the new iter
 * \param[in] wsAfterParenOpen a child of the new iter
 * \param[in] symbol a child of the new iter
 * \param[in] wsAfterSymbol a child of the new iter
 * \return A pointer to a iter, either newly constructed or shared
 */
PTPT_Symbol PTPT_makeSymbolIter(PTPT_OptLayout wsAfterIter, PTPT_OptLayout wsAfterParenOpen, PTPT_Symbol symbol, PTPT_OptLayout wsAfterSymbol) {
  return (PTPT_Symbol)(ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun17))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun25)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun21))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun65))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun25))), (ATerm)ATmakeAppl1(PTPT_afun12, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun13, (ATerm)ATmakeAppl1(PTPT_afun14, (ATerm)ATmakeAppl0(PTPT_afun65)))))), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(41)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun17)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(41)))), (ATerm) wsAfterSymbol), (ATerm) symbol), (ATerm) wsAfterParenOpen), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(40)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun21)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(40)))), (ATerm) wsAfterIter), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(114)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(101)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(116)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(105)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun65)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeInt(114)), (ATerm)ATmakeInt(101)), (ATerm)ATmakeInt(116)), (ATerm)ATmakeInt(105)))));
}
/**
 * Constructs a iter-star of type PTPT_Symbol. Like all ATerm types, PTPT_Symbols are maximally shared.
 * \param[in] wsAfterIterStar a child of the new iter-star
 * \param[in] wsAfterParenOpen a child of the new iter-star
 * \param[in] symbol a child of the new iter-star
 * \param[in] wsAfterSymbol a child of the new iter-star
 * \return A pointer to a iter-star, either newly constructed or shared
 */
PTPT_Symbol PTPT_makeSymbolIterStar(PTPT_OptLayout wsAfterIterStar, PTPT_OptLayout wsAfterParenOpen, PTPT_Symbol symbol, PTPT_OptLayout wsAfterSymbol) {
  return (PTPT_Symbol)(ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun17))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun25)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun21))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun66))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun25))), (ATerm)ATmakeAppl1(PTPT_afun12, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun13, (ATerm)ATmakeAppl1(PTPT_afun14, (ATerm)ATmakeAppl0(PTPT_afun66)))))), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(41)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun17)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(41)))), (ATerm) wsAfterSymbol), (ATerm) symbol), (ATerm) wsAfterParenOpen), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(40)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun21)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(40)))), (ATerm) wsAfterIterStar), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(114)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(97)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(116)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(115)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(45)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(114)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(101)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(116)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(105)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun66)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeInt(114)), (ATerm)ATmakeInt(97)), (ATerm)ATmakeInt(116)), (ATerm)ATmakeInt(115)), (ATerm)ATmakeInt(45)), (ATerm)ATmakeInt(114)), (ATerm)ATmakeInt(101)), (ATerm)ATmakeInt(116)), (ATerm)ATmakeInt(105)))));
}
/**
 * Constructs a iter-sep of type PTPT_Symbol. Like all ATerm types, PTPT_Symbols are maximally shared.
 * \param[in] wsAfterIterSep a child of the new iter-sep
 * \param[in] wsAfterParenOpen a child of the new iter-sep
 * \param[in] symbol a child of the new iter-sep
 * \param[in] wsAfterSymbol a child of the new iter-sep
 * \param[in] wsAfterComma a child of the new iter-sep
 * \param[in] separator a child of the new iter-sep
 * \param[in] wsAfterSeparator a child of the new iter-sep
 * \return A pointer to a iter-sep, either newly constructed or shared
 */
PTPT_Symbol PTPT_makeSymbolIterSep(PTPT_OptLayout wsAfterIterSep, PTPT_OptLayout wsAfterParenOpen, PTPT_Symbol symbol, PTPT_OptLayout wsAfterSymbol, PTPT_OptLayout wsAfterComma, PTPT_Symbol separator, PTPT_OptLayout wsAfterSeparator) {
  return (PTPT_Symbol)(ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun17))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun25)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun19))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun25)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun21))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun67))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun25))), (ATerm)ATmakeAppl1(PTPT_afun12, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun13, (ATerm)ATmakeAppl1(PTPT_afun14, (ATerm)ATmakeAppl0(PTPT_afun67)))))), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(41)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun17)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(41)))), (ATerm) wsAfterSeparator), (ATerm) separator), (ATerm) wsAfterComma), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(44)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun19)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(44)))), (ATerm) wsAfterSymbol), (ATerm) symbol), (ATerm) wsAfterParenOpen), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(40)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun21)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(40)))), (ATerm) wsAfterIterSep), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(112)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(101)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(115)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(45)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(114)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(101)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(116)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(105)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun67)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeInt(112)), (ATerm)ATmakeInt(101)), (ATerm)ATmakeInt(115)), (ATerm)ATmakeInt(45)), (ATerm)ATmakeInt(114)), (ATerm)ATmakeInt(101)), (ATerm)ATmakeInt(116)), (ATerm)ATmakeInt(105)))));
}
/**
 * Constructs a iter-star-sep of type PTPT_Symbol. Like all ATerm types, PTPT_Symbols are maximally shared.
 * \param[in] wsAfterIterStarSep a child of the new iter-star-sep
 * \param[in] wsAfterParenOpen a child of the new iter-star-sep
 * \param[in] symbol a child of the new iter-star-sep
 * \param[in] wsAfterSymbol a child of the new iter-star-sep
 * \param[in] wsAfterComma a child of the new iter-star-sep
 * \param[in] separator a child of the new iter-star-sep
 * \param[in] wsAfterSeparator a child of the new iter-star-sep
 * \return A pointer to a iter-star-sep, either newly constructed or shared
 */
PTPT_Symbol PTPT_makeSymbolIterStarSep(PTPT_OptLayout wsAfterIterStarSep, PTPT_OptLayout wsAfterParenOpen, PTPT_Symbol symbol, PTPT_OptLayout wsAfterSymbol, PTPT_OptLayout wsAfterComma, PTPT_Symbol separator, PTPT_OptLayout wsAfterSeparator) {
  return (PTPT_Symbol)(ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun17))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun25)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun19))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun25)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun21))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun68))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun25))), (ATerm)ATmakeAppl1(PTPT_afun12, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun13, (ATerm)ATmakeAppl1(PTPT_afun14, (ATerm)ATmakeAppl0(PTPT_afun68)))))), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(41)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun17)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(41)))), (ATerm) wsAfterSeparator), (ATerm) separator), (ATerm) wsAfterComma), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(44)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun19)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(44)))), (ATerm) wsAfterSymbol), (ATerm) symbol), (ATerm) wsAfterParenOpen), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(40)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun21)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(40)))), (ATerm) wsAfterIterStarSep), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(112)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(101)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(115)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(45)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(114)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(97)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(116)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(115)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(45)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(114)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(101)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(116)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(105)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun68)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeInt(112)), (ATerm)ATmakeInt(101)), (ATerm)ATmakeInt(115)), (ATerm)ATmakeInt(45)), (ATerm)ATmakeInt(114)), (ATerm)ATmakeInt(97)), (ATerm)ATmakeInt(116)), (ATerm)ATmakeInt(115)), (ATerm)ATmakeInt(45)), (ATerm)ATmakeInt(114)), (ATerm)ATmakeInt(101)), (ATerm)ATmakeInt(116)), (ATerm)ATmakeInt(105)))));
}
/**
 * Constructs a iter-n of type PTPT_Symbol. Like all ATerm types, PTPT_Symbols are maximally shared.
 * \param[in] wsAfterIterN a child of the new iter-n
 * \param[in] wsAfterParenOpen a child of the new iter-n
 * \param[in] symbol a child of the new iter-n
 * \param[in] wsAfterSymbol a child of the new iter-n
 * \param[in] wsAfterComma a child of the new iter-n
 * \param[in] number a child of the new iter-n
 * \param[in] wsAfterNumber a child of the new iter-n
 * \return A pointer to a iter-n, either newly constructed or shared
 */
PTPT_Symbol PTPT_makeSymbolIterN(PTPT_OptLayout wsAfterIterN, PTPT_OptLayout wsAfterParenOpen, PTPT_Symbol symbol, PTPT_OptLayout wsAfterSymbol, PTPT_OptLayout wsAfterComma, PTPT_NatCon number, PTPT_OptLayout wsAfterNumber) {
  return (PTPT_Symbol)(ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun17))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun24)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun19))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun25)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun21))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun69))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun25))), (ATerm)ATmakeAppl1(PTPT_afun12, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun13, (ATerm)ATmakeAppl1(PTPT_afun14, (ATerm)ATmakeAppl0(PTPT_afun69)))))), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(41)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun17)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(41)))), (ATerm) wsAfterNumber), (ATerm) number), (ATerm) wsAfterComma), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(44)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun19)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(44)))), (ATerm) wsAfterSymbol), (ATerm) symbol), (ATerm) wsAfterParenOpen), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(40)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun21)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(40)))), (ATerm) wsAfterIterN), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(110)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(45)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(114)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(101)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(116)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(105)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun69)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeInt(110)), (ATerm)ATmakeInt(45)), (ATerm)ATmakeInt(114)), (ATerm)ATmakeInt(101)), (ATerm)ATmakeInt(116)), (ATerm)ATmakeInt(105)))));
}
/**
 * Constructs a iter-sep-n of type PTPT_Symbol. Like all ATerm types, PTPT_Symbols are maximally shared.
 * \param[in] wsAfterIterSepN a child of the new iter-sep-n
 * \param[in] wsAfterParenOpen a child of the new iter-sep-n
 * \param[in] symbol a child of the new iter-sep-n
 * \param[in] wsAfterSymbol a child of the new iter-sep-n
 * \param[in] wsAfterComma1 a child of the new iter-sep-n
 * \param[in] separator a child of the new iter-sep-n
 * \param[in] wsAfterSeparator a child of the new iter-sep-n
 * \param[in] wsAfterComma2 a child of the new iter-sep-n
 * \param[in] number a child of the new iter-sep-n
 * \param[in] wsAfterNumber a child of the new iter-sep-n
 * \return A pointer to a iter-sep-n, either newly constructed or shared
 */
PTPT_Symbol PTPT_makeSymbolIterSepN(PTPT_OptLayout wsAfterIterSepN, PTPT_OptLayout wsAfterParenOpen, PTPT_Symbol symbol, PTPT_OptLayout wsAfterSymbol, PTPT_OptLayout wsAfterComma1, PTPT_Symbol separator, PTPT_OptLayout wsAfterSeparator, PTPT_OptLayout wsAfterComma2, PTPT_NatCon number, PTPT_OptLayout wsAfterNumber) {
  return (PTPT_Symbol)(ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun17))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun24)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun19))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun25)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun19))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun25)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun21))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun70))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun25))), (ATerm)ATmakeAppl1(PTPT_afun12, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun13, (ATerm)ATmakeAppl1(PTPT_afun14, (ATerm)ATmakeAppl0(PTPT_afun70)))))), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(41)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun17)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(41)))), (ATerm) wsAfterNumber), (ATerm) number), (ATerm) wsAfterComma2), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(44)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun19)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(44)))), (ATerm) wsAfterSeparator), (ATerm) separator), (ATerm) wsAfterComma1), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(44)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun19)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(44)))), (ATerm) wsAfterSymbol), (ATerm) symbol), (ATerm) wsAfterParenOpen), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(40)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun21)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(40)))), (ATerm) wsAfterIterSepN), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(110)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(45)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(112)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(101)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(115)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(45)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(114)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(101)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(116)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(105)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun70)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeInt(110)), (ATerm)ATmakeInt(45)), (ATerm)ATmakeInt(112)), (ATerm)ATmakeInt(101)), (ATerm)ATmakeInt(115)), (ATerm)ATmakeInt(45)), (ATerm)ATmakeInt(114)), (ATerm)ATmakeInt(101)), (ATerm)ATmakeInt(116)), (ATerm)ATmakeInt(105)))));
}
/**
 * Constructs a func of type PTPT_Symbol. Like all ATerm types, PTPT_Symbols are maximally shared.
 * \param[in] wsAfterFunc a child of the new func
 * \param[in] wsAfterParenOpen a child of the new func
 * \param[in] symbols a child of the new func
 * \param[in] wsAfterSymbols a child of the new func
 * \param[in] wsAfterComma a child of the new func
 * \param[in] symbol a child of the new func
 * \param[in] wsAfterSymbol a child of the new func
 * \return A pointer to a func, either newly constructed or shared
 */
PTPT_Symbol PTPT_makeSymbolFunc(PTPT_OptLayout wsAfterFunc, PTPT_OptLayout wsAfterParenOpen, PTPT_Symbols symbols, PTPT_OptLayout wsAfterSymbols, PTPT_OptLayout wsAfterComma, PTPT_Symbol symbol, PTPT_OptLayout wsAfterSymbol) {
  return (PTPT_Symbol)(ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun17))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun25)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun19))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun61)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun21))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun71))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun25))), (ATerm)ATmakeAppl1(PTPT_afun12, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun13, (ATerm)ATmakeAppl1(PTPT_afun14, (ATerm)ATmakeAppl0(PTPT_afun71)))))), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(41)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun17)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(41)))), (ATerm) wsAfterSymbol), (ATerm) symbol), (ATerm) wsAfterComma), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(44)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun19)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(44)))), (ATerm) wsAfterSymbols), (ATerm) symbols), (ATerm) wsAfterParenOpen), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(40)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun21)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(40)))), (ATerm) wsAfterFunc), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(99)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(110)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(117)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(102)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun71)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeInt(99)), (ATerm)ATmakeInt(110)), (ATerm)ATmakeInt(117)), (ATerm)ATmakeInt(102)))));
}
/**
 * Constructs a varsym of type PTPT_Symbol. Like all ATerm types, PTPT_Symbols are maximally shared.
 * \param[in] wsAfterVarsym a child of the new varsym
 * \param[in] wsAfterParenOpen a child of the new varsym
 * \param[in] symbol a child of the new varsym
 * \param[in] wsAfterSymbol a child of the new varsym
 * \return A pointer to a varsym, either newly constructed or shared
 */
PTPT_Symbol PTPT_makeSymbolVarsym(PTPT_OptLayout wsAfterVarsym, PTPT_OptLayout wsAfterParenOpen, PTPT_Symbol symbol, PTPT_OptLayout wsAfterSymbol) {
  return (PTPT_Symbol)(ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun17))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun25)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun21))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun72))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun25))), (ATerm)ATmakeAppl1(PTPT_afun12, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun13, (ATerm)ATmakeAppl1(PTPT_afun14, (ATerm)ATmakeAppl0(PTPT_afun72)))))), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(41)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun17)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(41)))), (ATerm) wsAfterSymbol), (ATerm) symbol), (ATerm) wsAfterParenOpen), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(40)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun21)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(40)))), (ATerm) wsAfterVarsym), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(109)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(121)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(115)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(114)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(97)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(118)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun72)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeInt(109)), (ATerm)ATmakeInt(121)), (ATerm)ATmakeInt(115)), (ATerm)ATmakeInt(114)), (ATerm)ATmakeInt(97)), (ATerm)ATmakeInt(118)))));
}
/**
 * Constructs a layout of type PTPT_Symbol. Like all ATerm types, PTPT_Symbols are maximally shared.
 * \return A pointer to a layout, either newly constructed or shared
 */
PTPT_Symbol PTPT_makeSymbolLayout(void) {
  return (PTPT_Symbol)(ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun73))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun25))), (ATerm)ATmakeAppl1(PTPT_afun12, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun13, (ATerm)ATmakeAppl1(PTPT_afun14, (ATerm)ATmakeAppl0(PTPT_afun73)))))), (ATerm)ATmakeList1((ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(116)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(117)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(111)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(121)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(97)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(108)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun73)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeInt(116)), (ATerm)ATmakeInt(117)), (ATerm)ATmakeInt(111)), (ATerm)ATmakeInt(121)), (ATerm)ATmakeInt(97)), (ATerm)ATmakeInt(108)))));
}
/**
 * Constructs a char-class of type PTPT_Symbol. Like all ATerm types, PTPT_Symbols are maximally shared.
 * \param[in] wsAfterCharClass a child of the new char-class
 * \param[in] wsAfterParenOpen a child of the new char-class
 * \param[in] CharRanges a child of the new char-class
 * \param[in] wsAfterCharRanges a child of the new char-class
 * \return A pointer to a char-class, either newly constructed or shared
 */
PTPT_Symbol PTPT_makeSymbolCharClass(PTPT_OptLayout wsAfterCharClass, PTPT_OptLayout wsAfterParenOpen, PTPT_CharRanges CharRanges, PTPT_OptLayout wsAfterCharRanges) {
  return (PTPT_Symbol)(ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun17))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun74)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun21))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun75))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun25))), (ATerm)ATmakeAppl1(PTPT_afun12, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun13, (ATerm)ATmakeAppl1(PTPT_afun14, (ATerm)ATmakeAppl0(PTPT_afun75)))))), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(41)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun17)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(41)))), (ATerm) wsAfterCharRanges), (ATerm) CharRanges), (ATerm) wsAfterParenOpen), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(40)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun21)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(40)))), (ATerm) wsAfterCharClass), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(115)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(115)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(97)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(108)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(99)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(45)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(114)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(97)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(104)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(99)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun75)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeInt(115)), (ATerm)ATmakeInt(115)), (ATerm)ATmakeInt(97)), (ATerm)ATmakeInt(108)), (ATerm)ATmakeInt(99)), (ATerm)ATmakeInt(45)), (ATerm)ATmakeInt(114)), (ATerm)ATmakeInt(97)), (ATerm)ATmakeInt(104)), (ATerm)ATmakeInt(99)))));
}
/**
 * Constructs a strategy of type PTPT_Symbol. Like all ATerm types, PTPT_Symbols are maximally shared.
 * \param[in] wsAfterStrategy a child of the new strategy
 * \param[in] wsAfterParenOpen a child of the new strategy
 * \param[in] lhs a child of the new strategy
 * \param[in] wsAfterLhs a child of the new strategy
 * \param[in] wsAfterComma a child of the new strategy
 * \param[in] rhs a child of the new strategy
 * \param[in] wsAfterRhs a child of the new strategy
 * \return A pointer to a strategy, either newly constructed or shared
 */
PTPT_Symbol PTPT_makeSymbolStrategy(PTPT_OptLayout wsAfterStrategy, PTPT_OptLayout wsAfterParenOpen, PTPT_Symbol lhs, PTPT_OptLayout wsAfterLhs, PTPT_OptLayout wsAfterComma, PTPT_Symbol rhs, PTPT_OptLayout wsAfterRhs) {
  return (PTPT_Symbol)(ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun17))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun25)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun19))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun25)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun21))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun76))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun25))), (ATerm)ATmakeAppl1(PTPT_afun12, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun13, (ATerm)ATmakeAppl1(PTPT_afun14, (ATerm)ATmakeAppl0(PTPT_afun76)))))), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(41)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun17)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(41)))), (ATerm) wsAfterRhs), (ATerm) rhs), (ATerm) wsAfterComma), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(44)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun19)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(44)))), (ATerm) wsAfterLhs), (ATerm) lhs), (ATerm) wsAfterParenOpen), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(40)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun21)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(40)))), (ATerm) wsAfterStrategy), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(121)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(103)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(101)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(116)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(97)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(114)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(116)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(115)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun76)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeInt(121)), (ATerm)ATmakeInt(103)), (ATerm)ATmakeInt(101)), (ATerm)ATmakeInt(116)), (ATerm)ATmakeInt(97)), (ATerm)ATmakeInt(114)), (ATerm)ATmakeInt(116)), (ATerm)ATmakeInt(115)))));
}
/**
 * Constructs a parameterized-sort of type PTPT_Symbol. Like all ATerm types, PTPT_Symbols are maximally shared.
 * \param[in] wsAfterParameterizedSort a child of the new parameterized-sort
 * \param[in] wsAfterParenOpen a child of the new parameterized-sort
 * \param[in] sort a child of the new parameterized-sort
 * \param[in] wsAfterSort a child of the new parameterized-sort
 * \param[in] wsAfterComma a child of the new parameterized-sort
 * \param[in] parameters a child of the new parameterized-sort
 * \param[in] wsAfterParameters a child of the new parameterized-sort
 * \return A pointer to a parameterized-sort, either newly constructed or shared
 */
PTPT_Symbol PTPT_makeSymbolParameterizedSort(PTPT_OptLayout wsAfterParameterizedSort, PTPT_OptLayout wsAfterParenOpen, PTPT_StrCon sort, PTPT_OptLayout wsAfterSort, PTPT_OptLayout wsAfterComma, PTPT_Symbols parameters, PTPT_OptLayout wsAfterParameters) {
  return (PTPT_Symbol)(ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun17))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun61)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun19))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun42)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun21))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun77))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun25))), (ATerm)ATmakeAppl1(PTPT_afun12, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun13, (ATerm)ATmakeAppl1(PTPT_afun14, (ATerm)ATmakeAppl0(PTPT_afun77)))))), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(41)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun17)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(41)))), (ATerm) wsAfterParameters), (ATerm) parameters), (ATerm) wsAfterComma), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(44)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun19)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(44)))), (ATerm) wsAfterSort), (ATerm) sort), (ATerm) wsAfterParenOpen), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(40)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun21)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(40)))), (ATerm) wsAfterParameterizedSort), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(116)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(114)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(111)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(115)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(45)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(100)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(101)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(122)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(105)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(114)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(101)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(116)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(101)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(109)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(97)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(114)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(97)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(112)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun77)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeInt(116)), (ATerm)ATmakeInt(114)), (ATerm)ATmakeInt(111)), (ATerm)ATmakeInt(115)), (ATerm)ATmakeInt(45)), (ATerm)ATmakeInt(100)), (ATerm)ATmakeInt(101)), (ATerm)ATmakeInt(122)), (ATerm)ATmakeInt(105)), (ATerm)ATmakeInt(114)), (ATerm)ATmakeInt(101)), (ATerm)ATmakeInt(116)), (ATerm)ATmakeInt(101)), (ATerm)ATmakeInt(109)), (ATerm)ATmakeInt(97)), (ATerm)ATmakeInt(114)), (ATerm)ATmakeInt(97)), (ATerm)ATmakeInt(112)))));
}
/**
 * Constructs a list of type PTPT_Symbols. Like all ATerm types, PTPT_Symbolss are maximally shared.
 * \param[in] wsAfterBracketOpen a child of the new list
 * \param[in] list a child of the new list
 * \param[in] wsAfterList a child of the new list
 * \return A pointer to a list, either newly constructed or shared
 */
PTPT_Symbols PTPT_makeSymbolsList(PTPT_OptLayout wsAfterBracketOpen, PTPT_SymbolList list, PTPT_OptLayout wsAfterList) {
  return (PTPT_Symbols)(ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun33))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl2(PTPT_afun78, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun25)), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun19))))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun36))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun61))), (ATerm)ATmakeAppl1(PTPT_afun12, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun13, (ATerm)ATmakeAppl1(PTPT_afun14, (ATerm)ATmakeAppl0(PTPT_afun79)))))), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(93)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun33)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(93)))), (ATerm) wsAfterList), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl1(PTPT_afun8, (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl2(PTPT_afun78, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun25)), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun19))))), (ATerm) list)), (ATerm) wsAfterBracketOpen), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(91)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun36)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(91)))));
}
/**
 * Constructs a list of type PTPT_CharRanges. Like all ATerm types, PTPT_CharRangess are maximally shared.
 * \param[in] wsAfterBracketOpen a child of the new list
 * \param[in] list a child of the new list
 * \param[in] wsAfterList a child of the new list
 * \return A pointer to a list, either newly constructed or shared
 */
PTPT_CharRanges PTPT_makeCharRangesList(PTPT_OptLayout wsAfterBracketOpen, PTPT_CharRangeList list, PTPT_OptLayout wsAfterList) {
  return (PTPT_CharRanges)(ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun33))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl2(PTPT_afun78, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun80)), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun19))))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun36))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun74))), (ATerm)ATmakeAppl1(PTPT_afun12, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun13, (ATerm)ATmakeAppl1(PTPT_afun14, (ATerm)ATmakeAppl0(PTPT_afun79)))))), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(93)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun33)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(93)))), (ATerm) wsAfterList), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl1(PTPT_afun8, (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl2(PTPT_afun78, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun80)), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun19))))), (ATerm) list)), (ATerm) wsAfterBracketOpen), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(91)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun36)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(91)))));
}
/**
 * Constructs a character of type PTPT_CharRange. Like all ATerm types, PTPT_CharRanges are maximally shared.
 * \param[in] integer a child of the new character
 * \return A pointer to a character, either newly constructed or shared
 */
PTPT_CharRange PTPT_makeCharRangeCharacter(PTPT_NatCon integer) {
  return (PTPT_CharRange)(ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun24)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun80))), (ATerm)ATmakeAppl1(PTPT_afun12, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun13, (ATerm)ATmakeAppl1(PTPT_afun14, (ATerm)ATmakeAppl0(PTPT_afun81)))))), (ATerm)ATmakeList1((ATerm) integer));
}
/**
 * Constructs a range of type PTPT_CharRange. Like all ATerm types, PTPT_CharRanges are maximally shared.
 * \param[in] wsAfterRange a child of the new range
 * \param[in] wsAfterParenOpen a child of the new range
 * \param[in] start a child of the new range
 * \param[in] wsAfterStart a child of the new range
 * \param[in] wsAfterComma a child of the new range
 * \param[in] end a child of the new range
 * \param[in] wsAfterEnd a child of the new range
 * \return A pointer to a range, either newly constructed or shared
 */
PTPT_CharRange PTPT_makeCharRangeRange(PTPT_OptLayout wsAfterRange, PTPT_OptLayout wsAfterParenOpen, PTPT_NatCon start, PTPT_OptLayout wsAfterStart, PTPT_OptLayout wsAfterComma, PTPT_NatCon end, PTPT_OptLayout wsAfterEnd) {
  return (PTPT_CharRange)(ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun17))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun24)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun19))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun24)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun21))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun82))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun80))), (ATerm)ATmakeAppl1(PTPT_afun12, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun13, (ATerm)ATmakeAppl1(PTPT_afun14, (ATerm)ATmakeAppl0(PTPT_afun82)))))), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(41)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun17)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(41)))), (ATerm) wsAfterEnd), (ATerm) end), (ATerm) wsAfterComma), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(44)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun19)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(44)))), (ATerm) wsAfterStart), (ATerm) start), (ATerm) wsAfterParenOpen), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(40)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun21)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(40)))), (ATerm) wsAfterRange), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(101)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(103)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(110)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(97)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(114)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun82)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeInt(101)), (ATerm)ATmakeInt(103)), (ATerm)ATmakeInt(110)), (ATerm)ATmakeInt(97)), (ATerm)ATmakeInt(114)))));
}
/**
 * Constructs a Symbol of type PTPT_Start. Like all ATerm types, PTPT_Starts are maximally shared.
 * \param[in] wsBefore a child of the new Symbol
 * \param[in] topSymbol a child of the new Symbol
 * \param[in] wsAfter a child of the new Symbol
 * \param[in] ambCnt a child of the new Symbol
 * \return A pointer to a Symbol, either newly constructed or shared
 */
PTPT_Start PTPT_makeStartSymbol(PTPT_OptLayout wsBefore, PTPT_Symbol topSymbol, PTPT_OptLayout wsAfter, int ambCnt) {
  return (PTPT_Start)(ATerm)ATmakeAppl2(PTPT_afun83, (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun25)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun84)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATinsert(ATinsert(ATmakeList1((ATerm) wsAfter), (ATerm) topSymbol), (ATerm) wsBefore)), (ATerm) (ATerm) ATmakeInt(ambCnt));
}
/**
 * Constructs a Tree of type PTPT_Start. Like all ATerm types, PTPT_Starts are maximally shared.
 * \param[in] wsBefore a child of the new Tree
 * \param[in] topTree a child of the new Tree
 * \param[in] wsAfter a child of the new Tree
 * \param[in] ambCnt a child of the new Tree
 * \return A pointer to a Tree, either newly constructed or shared
 */
PTPT_Start PTPT_makeStartTree(PTPT_OptLayout wsBefore, PTPT_Tree topTree, PTPT_OptLayout wsAfter, int ambCnt) {
  return (PTPT_Start)(ATerm)ATmakeAppl2(PTPT_afun83, (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun11)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun84)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATinsert(ATinsert(ATmakeList1((ATerm) wsAfter), (ATerm) topTree), (ATerm) wsBefore)), (ATerm) (ATerm) ATmakeInt(ambCnt));
}
/**
 * Constructs a ATerm of type PTPT_Start. Like all ATerm types, PTPT_Starts are maximally shared.
 * \param[in] wsBefore a child of the new ATerm
 * \param[in] topATerm a child of the new ATerm
 * \param[in] wsAfter a child of the new ATerm
 * \param[in] ambCnt a child of the new ATerm
 * \return A pointer to a ATerm, either newly constructed or shared
 */
PTPT_Start PTPT_makeStartATerm(PTPT_OptLayout wsBefore, PTPT_ATerm topATerm, PTPT_OptLayout wsAfter, int ambCnt) {
  return (PTPT_Start)(ATerm)ATmakeAppl2(PTPT_afun83, (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun40)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun84)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATinsert(ATinsert(ATmakeList1((ATerm) wsAfter), (ATerm) topATerm), (ATerm) wsBefore)), (ATerm) (ATerm) ATmakeInt(ambCnt));
}
/**
 * Constructs a IntCon of type PTPT_Start. Like all ATerm types, PTPT_Starts are maximally shared.
 * \param[in] wsBefore a child of the new IntCon
 * \param[in] topIntCon a child of the new IntCon
 * \param[in] wsAfter a child of the new IntCon
 * \param[in] ambCnt a child of the new IntCon
 * \return A pointer to a IntCon, either newly constructed or shared
 */
PTPT_Start PTPT_makeStartIntCon(PTPT_OptLayout wsBefore, PTPT_IntCon topIntCon, PTPT_OptLayout wsAfter, int ambCnt) {
  return (PTPT_Start)(ATerm)ATmakeAppl2(PTPT_afun83, (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun85)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun84)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATinsert(ATinsert(ATmakeList1((ATerm) wsAfter), (ATerm) topIntCon), (ATerm) wsBefore)), (ATerm) (ATerm) ATmakeInt(ambCnt));
}
/**
 * Constructs a RealCon of type PTPT_Start. Like all ATerm types, PTPT_Starts are maximally shared.
 * \param[in] wsBefore a child of the new RealCon
 * \param[in] topRealCon a child of the new RealCon
 * \param[in] wsAfter a child of the new RealCon
 * \param[in] ambCnt a child of the new RealCon
 * \return A pointer to a RealCon, either newly constructed or shared
 */
PTPT_Start PTPT_makeStartRealCon(PTPT_OptLayout wsBefore, PTPT_RealCon topRealCon, PTPT_OptLayout wsAfter, int ambCnt) {
  return (PTPT_Start)(ATerm)ATmakeAppl2(PTPT_afun83, (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun86)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun84)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATinsert(ATinsert(ATmakeList1((ATerm) wsAfter), (ATerm) topRealCon), (ATerm) wsBefore)), (ATerm) (ATerm) ATmakeInt(ambCnt));
}
/**
 * Constructs a empty of type PTPT_SymbolList. Like all ATerm types, PTPT_SymbolLists are maximally shared.
 * \return A pointer to a empty, either newly constructed or shared
 */
PTPT_SymbolList PTPT_makeSymbolListEmpty(void) {
  return (PTPT_SymbolList)(ATerm)ATempty;
}
/**
 * Constructs a single of type PTPT_SymbolList. Like all ATerm types, PTPT_SymbolLists are maximally shared.
 * \param[in] head a child of the new single
 * \return A pointer to a single, either newly constructed or shared
 */
PTPT_SymbolList PTPT_makeSymbolListSingle(PTPT_Symbol head) {
  return (PTPT_SymbolList)(ATerm)ATmakeList1((ATerm) head);
}
/**
 * Constructs a many of type PTPT_SymbolList. Like all ATerm types, PTPT_SymbolLists are maximally shared.
 * \param[in] head a child of the new many
 * \param[in] wsAfterHead a child of the new many
 * \param[in] wsAfterSep a child of the new many
 * \param[in] tail a child of the new many
 * \return A pointer to a many, either newly constructed or shared
 */
PTPT_SymbolList PTPT_makeSymbolListMany(PTPT_Symbol head, PTPT_OptLayout wsAfterHead, PTPT_OptLayout wsAfterSep, PTPT_SymbolList tail) {
  if (PTPT_isSymbolListEmpty(tail)) {
    return PTPT_makeSymbolListSingle(head);
  }
  return (PTPT_SymbolList)(ATerm)ATinsert(ATinsert(ATinsert(ATinsert((ATermList)tail, (ATerm) wsAfterSep), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(44)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun19)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(44)))), (ATerm) wsAfterHead), (ATerm) head);
}
/**
 * Constructs a empty of type PTPT_CharRangeList. Like all ATerm types, PTPT_CharRangeLists are maximally shared.
 * \return A pointer to a empty, either newly constructed or shared
 */
PTPT_CharRangeList PTPT_makeCharRangeListEmpty(void) {
  return (PTPT_CharRangeList)(ATerm)ATempty;
}
/**
 * Constructs a single of type PTPT_CharRangeList. Like all ATerm types, PTPT_CharRangeLists are maximally shared.
 * \param[in] head a child of the new single
 * \return A pointer to a single, either newly constructed or shared
 */
PTPT_CharRangeList PTPT_makeCharRangeListSingle(PTPT_CharRange head) {
  return (PTPT_CharRangeList)(ATerm)ATmakeList1((ATerm) head);
}
/**
 * Constructs a many of type PTPT_CharRangeList. Like all ATerm types, PTPT_CharRangeLists are maximally shared.
 * \param[in] head a child of the new many
 * \param[in] wsAfterHead a child of the new many
 * \param[in] wsAfterSep a child of the new many
 * \param[in] tail a child of the new many
 * \return A pointer to a many, either newly constructed or shared
 */
PTPT_CharRangeList PTPT_makeCharRangeListMany(PTPT_CharRange head, PTPT_OptLayout wsAfterHead, PTPT_OptLayout wsAfterSep, PTPT_CharRangeList tail) {
  if (PTPT_isCharRangeListEmpty(tail)) {
    return PTPT_makeCharRangeListSingle(head);
  }
  return (PTPT_CharRangeList)(ATerm)ATinsert(ATinsert(ATinsert(ATinsert((ATermList)tail, (ATerm) wsAfterSep), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(44)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun19)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(44)))), (ATerm) wsAfterHead), (ATerm) head);
}
/**
 * Constructs a list of type PTPT_Args. Like all ATerm types, PTPT_Argss are maximally shared.
 * \param[in] wsAfterBracketOpen a child of the new list
 * \param[in] list a child of the new list
 * \param[in] wsAfterList a child of the new list
 * \return A pointer to a list, either newly constructed or shared
 */
PTPT_Args PTPT_makeArgsList(PTPT_OptLayout wsAfterBracketOpen, PTPT_TreeList list, PTPT_OptLayout wsAfterList) {
  return (PTPT_Args)(ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun33))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl2(PTPT_afun78, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun11)), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun19))))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun36))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun18))), (ATerm)ATmakeAppl1(PTPT_afun12, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun13, (ATerm)ATmakeAppl1(PTPT_afun14, (ATerm)ATmakeAppl0(PTPT_afun79)))))), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(93)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun33)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(93)))), (ATerm) wsAfterList), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl1(PTPT_afun8, (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl2(PTPT_afun78, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun11)), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun19))))), (ATerm) list)), (ATerm) wsAfterBracketOpen), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(91)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun36)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(91)))));
}
/**
 * Constructs a default of type PTPT_Production. Like all ATerm types, PTPT_Productions are maximally shared.
 * \param[in] wsAfterProd a child of the new default
 * \param[in] wsAfterParenOpen a child of the new default
 * \param[in] lhs a child of the new default
 * \param[in] wsAfterLhs a child of the new default
 * \param[in] wsAfterComma1 a child of the new default
 * \param[in] rhs a child of the new default
 * \param[in] wsAfterRhs a child of the new default
 * \param[in] wsAfterComma2 a child of the new default
 * \param[in] attributes a child of the new default
 * \param[in] wsAfterAttributes a child of the new default
 * \return A pointer to a default, either newly constructed or shared
 */
PTPT_Production PTPT_makeProductionDefault(PTPT_OptLayout wsAfterProd, PTPT_OptLayout wsAfterParenOpen, PTPT_Symbols lhs, PTPT_OptLayout wsAfterLhs, PTPT_OptLayout wsAfterComma1, PTPT_Symbol rhs, PTPT_OptLayout wsAfterRhs, PTPT_OptLayout wsAfterComma2, PTPT_Attributes attributes, PTPT_OptLayout wsAfterAttributes) {
  return (PTPT_Production)(ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun17))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun30)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun19))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun25)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun19))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun61)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun21))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun87))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun20))), (ATerm)ATmakeAppl1(PTPT_afun12, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun13, (ATerm)ATmakeAppl1(PTPT_afun14, (ATerm)ATmakeAppl0(PTPT_afun88)))))), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(41)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun17)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(41)))), (ATerm) wsAfterAttributes), (ATerm) attributes), (ATerm) wsAfterComma2), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(44)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun19)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(44)))), (ATerm) wsAfterRhs), (ATerm) rhs), (ATerm) wsAfterComma1), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(44)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun19)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(44)))), (ATerm) wsAfterLhs), (ATerm) lhs), (ATerm) wsAfterParenOpen), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(40)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun21)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(40)))), (ATerm) wsAfterProd), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(100)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(111)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(114)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(112)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun87)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeInt(100)), (ATerm)ATmakeInt(111)), (ATerm)ATmakeInt(114)), (ATerm)ATmakeInt(112)))));
}
/**
 * Constructs a list of type PTPT_Production. Like all ATerm types, PTPT_Productions are maximally shared.
 * \param[in] wsAfterList a child of the new list
 * \param[in] wsAfterParenOpen a child of the new list
 * \param[in] rhs a child of the new list
 * \param[in] wsAfterRhs a child of the new list
 * \return A pointer to a list, either newly constructed or shared
 */
PTPT_Production PTPT_makeProductionList(PTPT_OptLayout wsAfterList, PTPT_OptLayout wsAfterParenOpen, PTPT_Symbol rhs, PTPT_OptLayout wsAfterRhs) {
  return (PTPT_Production)(ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun17))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun25)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun21))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun79))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun20))), (ATerm)ATmakeAppl1(PTPT_afun12, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun13, (ATerm)ATmakeAppl1(PTPT_afun14, (ATerm)ATmakeAppl0(PTPT_afun79)))))), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(41)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun17)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(41)))), (ATerm) wsAfterRhs), (ATerm) rhs), (ATerm) wsAfterParenOpen), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(40)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun21)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(40)))), (ATerm) wsAfterList), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(116)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(115)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(105)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(108)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun79)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeInt(116)), (ATerm)ATmakeInt(115)), (ATerm)ATmakeInt(105)), (ATerm)ATmakeInt(108)))));
}
/**
 * Constructs a empty of type PTPT_TreeList. Like all ATerm types, PTPT_TreeLists are maximally shared.
 * \return A pointer to a empty, either newly constructed or shared
 */
PTPT_TreeList PTPT_makeTreeListEmpty(void) {
  return (PTPT_TreeList)(ATerm)ATempty;
}
/**
 * Constructs a single of type PTPT_TreeList. Like all ATerm types, PTPT_TreeLists are maximally shared.
 * \param[in] head a child of the new single
 * \return A pointer to a single, either newly constructed or shared
 */
PTPT_TreeList PTPT_makeTreeListSingle(PTPT_Tree head) {
  return (PTPT_TreeList)(ATerm)ATmakeList1((ATerm) head);
}
/**
 * Constructs a many of type PTPT_TreeList. Like all ATerm types, PTPT_TreeLists are maximally shared.
 * \param[in] head a child of the new many
 * \param[in] wsAfterHead a child of the new many
 * \param[in] wsAfterSep a child of the new many
 * \param[in] tail a child of the new many
 * \return A pointer to a many, either newly constructed or shared
 */
PTPT_TreeList PTPT_makeTreeListMany(PTPT_Tree head, PTPT_OptLayout wsAfterHead, PTPT_OptLayout wsAfterSep, PTPT_TreeList tail) {
  if (PTPT_isTreeListEmpty(tail)) {
    return PTPT_makeTreeListSingle(head);
  }
  return (PTPT_TreeList)(ATerm)ATinsert(ATinsert(ATinsert(ATinsert((ATermList)tail, (ATerm) wsAfterSep), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(44)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun19)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(44)))), (ATerm) wsAfterHead), (ATerm) head);
}
/**
 * Constructs a quoted of type PTPT_AFun. Like all ATerm types, PTPT_AFuns are maximally shared.
 * \param[in] StrCon a child of the new quoted
 * \return A pointer to a quoted, either newly constructed or shared
 */
PTPT_AFun PTPT_makeAFunQuoted(PTPT_StrCon StrCon) {
  return (PTPT_AFun)(ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun42)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun89))), (ATerm)ATmakeAppl1(PTPT_afun12, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun13, (ATerm)ATmakeAppl1(PTPT_afun14, (ATerm)ATmakeAppl0(PTPT_afun90)))))), (ATerm)ATmakeList1((ATerm) StrCon));
}
/**
 * Constructs a unquoted of type PTPT_AFun. Like all ATerm types, PTPT_AFuns are maximally shared.
 * \param[in] IdCon a child of the new unquoted
 * \return A pointer to a unquoted, either newly constructed or shared
 */
PTPT_AFun PTPT_makeAFunUnquoted(PTPT_IdCon IdCon) {
  return (PTPT_AFun)(ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun91)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun89))), (ATerm)ATmakeAppl1(PTPT_afun12, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun13, (ATerm)ATmakeAppl1(PTPT_afun14, (ATerm)ATmakeAppl0(PTPT_afun92)))))), (ATerm)ATmakeList1((ATerm) IdCon));
}
/**
 * Constructs a int of type PTPT_ATerm. Like all ATerm types, PTPT_ATerms are maximally shared.
 * \param[in] IntCon a child of the new int
 * \return A pointer to a int, either newly constructed or shared
 */
PTPT_ATerm PTPT_makeATermInt(PTPT_IntCon IntCon) {
  return (PTPT_ATerm)(ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun85)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun40))), (ATerm)ATmakeAppl1(PTPT_afun12, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun13, (ATerm)ATmakeAppl1(PTPT_afun14, (ATerm)ATmakeAppl0(PTPT_afun93)))))), (ATerm)ATmakeList1((ATerm) IntCon));
}
/**
 * Constructs a real of type PTPT_ATerm. Like all ATerm types, PTPT_ATerms are maximally shared.
 * \param[in] RealCon a child of the new real
 * \return A pointer to a real, either newly constructed or shared
 */
PTPT_ATerm PTPT_makeATermReal(PTPT_RealCon RealCon) {
  return (PTPT_ATerm)(ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun86)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun40))), (ATerm)ATmakeAppl1(PTPT_afun12, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun13, (ATerm)ATmakeAppl1(PTPT_afun14, (ATerm)ATmakeAppl0(PTPT_afun94)))))), (ATerm)ATmakeList1((ATerm) RealCon));
}
/**
 * Constructs a fun of type PTPT_ATerm. Like all ATerm types, PTPT_ATerms are maximally shared.
 * \param[in] fun a child of the new fun
 * \return A pointer to a fun, either newly constructed or shared
 */
PTPT_ATerm PTPT_makeATermFun(PTPT_AFun fun) {
  return (PTPT_ATerm)(ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun89)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun40))), (ATerm)ATmakeAppl1(PTPT_afun12, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun13, (ATerm)ATmakeAppl1(PTPT_afun14, (ATerm)ATmakeAppl0(PTPT_afun95)))))), (ATerm)ATmakeList1((ATerm) fun));
}
/**
 * Constructs a appl of type PTPT_ATerm. Like all ATerm types, PTPT_ATerms are maximally shared.
 * \param[in] fun a child of the new appl
 * \param[in] wsAfterFun a child of the new appl
 * \param[in] wsAfterParenOpen a child of the new appl
 * \param[in] args a child of the new appl
 * \param[in] wsAfterArgs a child of the new appl
 * \return A pointer to a appl, either newly constructed or shared
 */
PTPT_ATerm PTPT_makeATermAppl(PTPT_AFun fun, PTPT_OptLayout wsAfterFun, PTPT_OptLayout wsAfterParenOpen, PTPT_ATermArgs args, PTPT_OptLayout wsAfterArgs) {
  return (PTPT_ATerm)(ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun17))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl2(PTPT_afun34, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun40)), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun19))))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun21))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun89)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun40))), (ATerm)ATmakeAppl1(PTPT_afun12, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun13, (ATerm)ATmakeAppl1(PTPT_afun14, (ATerm)ATmakeAppl0(PTPT_afun22)))))), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(41)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun17)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(41)))), (ATerm) wsAfterArgs), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl1(PTPT_afun8, (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl2(PTPT_afun34, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun40)), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun19))))), (ATerm) args)), (ATerm) wsAfterParenOpen), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(40)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun21)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(40)))), (ATerm) wsAfterFun), (ATerm) fun));
}
/**
 * Constructs a placeholder of type PTPT_ATerm. Like all ATerm types, PTPT_ATerms are maximally shared.
 * \param[in] wsAfterLessThan a child of the new placeholder
 * \param[in] type a child of the new placeholder
 * \param[in] wsAfterType a child of the new placeholder
 * \return A pointer to a placeholder, either newly constructed or shared
 */
PTPT_ATerm PTPT_makeATermPlaceholder(PTPT_OptLayout wsAfterLessThan, PTPT_ATerm type, PTPT_OptLayout wsAfterType) {
  return (PTPT_ATerm)(ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun96))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun40)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun97))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun40))), (ATerm)ATmakeAppl1(PTPT_afun12, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun13, (ATerm)ATmakeAppl1(PTPT_afun14, (ATerm)ATmakeAppl0(PTPT_afun98)))))), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(62)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun96)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(62)))), (ATerm) wsAfterType), (ATerm) type), (ATerm) wsAfterLessThan), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(60)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun97)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(60)))));
}
/**
 * Constructs a list of type PTPT_ATerm. Like all ATerm types, PTPT_ATerms are maximally shared.
 * \param[in] wsAfterBracketOpen a child of the new list
 * \param[in] elems a child of the new list
 * \param[in] wsAfterElems a child of the new list
 * \return A pointer to a list, either newly constructed or shared
 */
PTPT_ATerm PTPT_makeATermList(PTPT_OptLayout wsAfterBracketOpen, PTPT_ATermElems elems, PTPT_OptLayout wsAfterElems) {
  return (PTPT_ATerm)(ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun33))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl2(PTPT_afun78, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun40)), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun19))))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun36))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun40))), (ATerm)ATmakeAppl1(PTPT_afun12, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun13, (ATerm)ATmakeAppl1(PTPT_afun14, (ATerm)ATmakeAppl0(PTPT_afun79)))))), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(93)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun33)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(93)))), (ATerm) wsAfterElems), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl1(PTPT_afun8, (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl2(PTPT_afun78, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun40)), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun19))))), (ATerm) elems)), (ATerm) wsAfterBracketOpen), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(91)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun36)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(91)))));
}
/**
 * Constructs a annotated of type PTPT_ATerm. Like all ATerm types, PTPT_ATerms are maximally shared.
 * \param[in] trm a child of the new annotated
 * \param[in] wsAfterTrm a child of the new annotated
 * \param[in] Annotation a child of the new annotated
 * \return A pointer to a annotated, either newly constructed or shared
 */
PTPT_ATerm PTPT_makeATermAnnotated(PTPT_ATerm trm, PTPT_OptLayout wsAfterTrm, PTPT_Annotation Annotation) {
  return (PTPT_ATerm)(ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun10)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun40)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun40))), (ATerm)ATmakeAppl1(PTPT_afun12, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun13, (ATerm)ATmakeAppl1(PTPT_afun14, (ATerm)ATmakeAppl0(PTPT_afun15)))))), (ATerm)ATinsert(ATinsert(ATmakeList1((ATerm) Annotation), (ATerm) wsAfterTrm), (ATerm) trm));
}
/**
 * Constructs a default of type PTPT_Annotation. Like all ATerm types, PTPT_Annotations are maximally shared.
 * \param[in] wsAfterBraceOpen a child of the new default
 * \param[in] annos a child of the new default
 * \param[in] wsAfterAnnos a child of the new default
 * \return A pointer to a default, either newly constructed or shared
 */
PTPT_Annotation PTPT_makeAnnotationDefault(PTPT_OptLayout wsAfterBraceOpen, PTPT_ATermAnnos annos, PTPT_OptLayout wsAfterAnnos) {
  return (PTPT_Annotation)(ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun99))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl2(PTPT_afun34, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun40)), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun19))))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun100))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun10))), (ATerm)ATmakeAppl1(PTPT_afun12, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun13, (ATerm)ATmakeAppl1(PTPT_afun14, (ATerm)ATmakeAppl0(PTPT_afun88)))))), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(125)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun99)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(125)))), (ATerm) wsAfterAnnos), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl1(PTPT_afun8, (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl2(PTPT_afun34, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun40)), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun19))))), (ATerm) annos)), (ATerm) wsAfterBraceOpen), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(123)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun100)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(123)))));
}
/**
 * Constructs a empty of type PTPT_ATermArgs. Like all ATerm types, PTPT_ATermArgss are maximally shared.
 * \return A pointer to a empty, either newly constructed or shared
 */
PTPT_ATermArgs PTPT_makeATermArgsEmpty(void) {
  return (PTPT_ATermArgs)(ATerm)ATempty;
}
/**
 * Constructs a single of type PTPT_ATermArgs. Like all ATerm types, PTPT_ATermArgss are maximally shared.
 * \param[in] head a child of the new single
 * \return A pointer to a single, either newly constructed or shared
 */
PTPT_ATermArgs PTPT_makeATermArgsSingle(PTPT_ATerm head) {
  return (PTPT_ATermArgs)(ATerm)ATmakeList1((ATerm) head);
}
/**
 * Constructs a many of type PTPT_ATermArgs. Like all ATerm types, PTPT_ATermArgss are maximally shared.
 * \param[in] head a child of the new many
 * \param[in] wsAfterHead a child of the new many
 * \param[in] wsAfterSep a child of the new many
 * \param[in] tail a child of the new many
 * \return A pointer to a many, either newly constructed or shared
 */
PTPT_ATermArgs PTPT_makeATermArgsMany(PTPT_ATerm head, PTPT_OptLayout wsAfterHead, PTPT_OptLayout wsAfterSep, PTPT_ATermArgs tail) {
  if (PTPT_isATermArgsEmpty(tail)) {
    return PTPT_makeATermArgsSingle(head);
  }
  return (PTPT_ATermArgs)(ATerm)ATinsert(ATinsert(ATinsert(ATinsert((ATermList)tail, (ATerm) wsAfterSep), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(44)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun19)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(44)))), (ATerm) wsAfterHead), (ATerm) head);
}
/**
 * Constructs a empty of type PTPT_ATermElems. Like all ATerm types, PTPT_ATermElemss are maximally shared.
 * \return A pointer to a empty, either newly constructed or shared
 */
PTPT_ATermElems PTPT_makeATermElemsEmpty(void) {
  return (PTPT_ATermElems)(ATerm)ATempty;
}
/**
 * Constructs a single of type PTPT_ATermElems. Like all ATerm types, PTPT_ATermElemss are maximally shared.
 * \param[in] head a child of the new single
 * \return A pointer to a single, either newly constructed or shared
 */
PTPT_ATermElems PTPT_makeATermElemsSingle(PTPT_ATerm head) {
  return (PTPT_ATermElems)(ATerm)ATmakeList1((ATerm) head);
}
/**
 * Constructs a many of type PTPT_ATermElems. Like all ATerm types, PTPT_ATermElemss are maximally shared.
 * \param[in] head a child of the new many
 * \param[in] wsAfterHead a child of the new many
 * \param[in] wsAfterSep a child of the new many
 * \param[in] tail a child of the new many
 * \return A pointer to a many, either newly constructed or shared
 */
PTPT_ATermElems PTPT_makeATermElemsMany(PTPT_ATerm head, PTPT_OptLayout wsAfterHead, PTPT_OptLayout wsAfterSep, PTPT_ATermElems tail) {
  if (PTPT_isATermElemsEmpty(tail)) {
    return PTPT_makeATermElemsSingle(head);
  }
  return (PTPT_ATermElems)(ATerm)ATinsert(ATinsert(ATinsert(ATinsert((ATermList)tail, (ATerm) wsAfterSep), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(44)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun19)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(44)))), (ATerm) wsAfterHead), (ATerm) head);
}
/**
 * Constructs a empty of type PTPT_ATermAnnos. Like all ATerm types, PTPT_ATermAnnoss are maximally shared.
 * \return A pointer to a empty, either newly constructed or shared
 */
PTPT_ATermAnnos PTPT_makeATermAnnosEmpty(void) {
  return (PTPT_ATermAnnos)(ATerm)ATempty;
}
/**
 * Constructs a single of type PTPT_ATermAnnos. Like all ATerm types, PTPT_ATermAnnoss are maximally shared.
 * \param[in] head a child of the new single
 * \return A pointer to a single, either newly constructed or shared
 */
PTPT_ATermAnnos PTPT_makeATermAnnosSingle(PTPT_ATerm head) {
  return (PTPT_ATermAnnos)(ATerm)ATmakeList1((ATerm) head);
}
/**
 * Constructs a many of type PTPT_ATermAnnos. Like all ATerm types, PTPT_ATermAnnoss are maximally shared.
 * \param[in] head a child of the new many
 * \param[in] wsAfterHead a child of the new many
 * \param[in] wsAfterSep a child of the new many
 * \param[in] tail a child of the new many
 * \return A pointer to a many, either newly constructed or shared
 */
PTPT_ATermAnnos PTPT_makeATermAnnosMany(PTPT_ATerm head, PTPT_OptLayout wsAfterHead, PTPT_OptLayout wsAfterSep, PTPT_ATermAnnos tail) {
  if (PTPT_isATermAnnosEmpty(tail)) {
    return PTPT_makeATermAnnosSingle(head);
  }
  return (PTPT_ATermAnnos)(ATerm)ATinsert(ATinsert(ATinsert(ATinsert((ATermList)tail, (ATerm) wsAfterSep), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(44)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun19)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(44)))), (ATerm) wsAfterHead), (ATerm) head);
}
/**
 * Constructs a natural of type PTPT_IntCon. Like all ATerm types, PTPT_IntCons are maximally shared.
 * \param[in] NatCon a child of the new natural
 * \return A pointer to a natural, either newly constructed or shared
 */
PTPT_IntCon PTPT_makeIntConNatural(PTPT_NatCon NatCon) {
  return (PTPT_IntCon)(ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun24)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun85))), (ATerm)ATmakeAppl1(PTPT_afun12, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun13, (ATerm)ATmakeAppl1(PTPT_afun14, (ATerm)ATmakeAppl0(PTPT_afun101)))))), (ATerm)ATmakeList1((ATerm) NatCon));
}
/**
 * Constructs a positive of type PTPT_IntCon. Like all ATerm types, PTPT_IntCons are maximally shared.
 * \param[in] wsAfterPos a child of the new positive
 * \param[in] NatCon a child of the new positive
 * \return A pointer to a positive, either newly constructed or shared
 */
PTPT_IntCon PTPT_makeIntConPositive(PTPT_OptLayout wsAfterPos, PTPT_NatCon NatCon) {
  return (PTPT_IntCon)(ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun24)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun102))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun85))), (ATerm)ATmakeAppl1(PTPT_afun12, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun13, (ATerm)ATmakeAppl1(PTPT_afun14, (ATerm)ATmakeAppl0(PTPT_afun103)))))), (ATerm)ATinsert(ATinsert(ATmakeList1((ATerm) NatCon), (ATerm) wsAfterPos), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(43)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun102)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(43)))));
}
/**
 * Constructs a negative of type PTPT_IntCon. Like all ATerm types, PTPT_IntCons are maximally shared.
 * \param[in] wsAfterNeg a child of the new negative
 * \param[in] NatCon a child of the new negative
 * \return A pointer to a negative, either newly constructed or shared
 */
PTPT_IntCon PTPT_makeIntConNegative(PTPT_OptLayout wsAfterNeg, PTPT_NatCon NatCon) {
  return (PTPT_IntCon)(ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun24)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun104))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun85))), (ATerm)ATmakeAppl1(PTPT_afun12, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun13, (ATerm)ATmakeAppl1(PTPT_afun14, (ATerm)ATmakeAppl0(PTPT_afun105)))))), (ATerm)ATinsert(ATinsert(ATmakeList1((ATerm) NatCon), (ATerm) wsAfterNeg), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(45)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun104)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(45)))));
}
/**
 * Constructs a present of type PTPT_OptExp. Like all ATerm types, PTPT_OptExps are maximally shared.
 * \param[in] wsAfterE a child of the new present
 * \param[in] IntCon a child of the new present
 * \return A pointer to a present, either newly constructed or shared
 */
PTPT_OptExp PTPT_makeOptExpPresent(PTPT_OptLayout wsAfterE, PTPT_IntCon IntCon) {
  return (PTPT_OptExp)(ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun85)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun106))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun107))), (ATerm)ATmakeAppl1(PTPT_afun12, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun13, (ATerm)ATmakeAppl1(PTPT_afun14, (ATerm)ATmakeAppl0(PTPT_afun108)))))), (ATerm)ATinsert(ATinsert(ATmakeList1((ATerm) IntCon), (ATerm) wsAfterE), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(101)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun106)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(101)))));
}
/**
 * Constructs a absent of type PTPT_OptExp. Like all ATerm types, PTPT_OptExps are maximally shared.
 * \return A pointer to a absent, either newly constructed or shared
 */
PTPT_OptExp PTPT_makeOptExpAbsent(void) {
  return (PTPT_OptExp)(ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATempty, (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun107))), (ATerm)ATmakeAppl1(PTPT_afun12, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun13, (ATerm)ATmakeAppl1(PTPT_afun14, (ATerm)ATmakeAppl0(PTPT_afun109)))))), (ATerm)ATempty);
}
/**
 * Constructs a real-con of type PTPT_RealCon. Like all ATerm types, PTPT_RealCons are maximally shared.
 * \param[in] base a child of the new real-con
 * \param[in] wsAfterBase a child of the new real-con
 * \param[in] wsAfterPeriod a child of the new real-con
 * \param[in] decimal a child of the new real-con
 * \param[in] wsAfterDecimal a child of the new real-con
 * \param[in] exp a child of the new real-con
 * \return A pointer to a real-con, either newly constructed or shared
 */
PTPT_RealCon PTPT_makeRealConRealCon(PTPT_IntCon base, PTPT_OptLayout wsAfterBase, PTPT_OptLayout wsAfterPeriod, PTPT_NatCon decimal, PTPT_OptLayout wsAfterDecimal, PTPT_OptExp exp) {
  return (PTPT_RealCon)(ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun107)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun24)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun110))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun3, (ATerm)ATmakeAppl0(PTPT_afun4)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun85)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun86))), (ATerm)ATmakeAppl1(PTPT_afun12, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun13, (ATerm)ATmakeAppl1(PTPT_afun14, (ATerm)ATmakeAppl0(PTPT_afun111)))))), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm) exp), (ATerm) wsAfterDecimal), (ATerm) decimal), (ATerm) wsAfterPeriod), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(46)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun110)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(46)))), (ATerm) wsAfterBase), (ATerm) base));
}
/**
 * Constructs a newline of type PTPT_LexStrChar. Like all ATerm types, PTPT_LexStrChars are maximally shared.
 * \return A pointer to a newline, either newly constructed or shared
 */
PTPT_LexStrChar PTPT_makeLexStrCharNewline(void) {
  return (PTPT_LexStrChar)(ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun112))), (ATerm)ATmakeAppl1(PTPT_afun6, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun113))), (ATerm)ATmakeAppl1(PTPT_afun12, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun13, (ATerm)ATmakeAppl1(PTPT_afun14, (ATerm)ATmakeAppl0(PTPT_afun114)))))), (ATerm)ATmakeList1((ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATinsert(ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(110)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(92)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun112)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATinsert(ATmakeList1((ATerm)ATmakeInt(110)), (ATerm)ATmakeInt(92)))));
}
/**
 * Constructs a tab of type PTPT_LexStrChar. Like all ATerm types, PTPT_LexStrChars are maximally shared.
 * \return A pointer to a tab, either newly constructed or shared
 */
PTPT_LexStrChar PTPT_makeLexStrCharTab(void) {
  return (PTPT_LexStrChar)(ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun115))), (ATerm)ATmakeAppl1(PTPT_afun6, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun113))), (ATerm)ATmakeAppl1(PTPT_afun12, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun13, (ATerm)ATmakeAppl1(PTPT_afun14, (ATerm)ATmakeAppl0(PTPT_afun116)))))), (ATerm)ATmakeList1((ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATinsert(ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(116)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(92)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun115)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATinsert(ATmakeList1((ATerm)ATmakeInt(116)), (ATerm)ATmakeInt(92)))));
}
/**
 * Constructs a quote of type PTPT_LexStrChar. Like all ATerm types, PTPT_LexStrChars are maximally shared.
 * \return A pointer to a quote, either newly constructed or shared
 */
PTPT_LexStrChar PTPT_makeLexStrCharQuote(void) {
  return (PTPT_LexStrChar)(ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun117))), (ATerm)ATmakeAppl1(PTPT_afun6, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun113))), (ATerm)ATmakeAppl1(PTPT_afun12, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun13, (ATerm)ATmakeAppl1(PTPT_afun14, (ATerm)ATmakeAppl0(PTPT_afun118)))))), (ATerm)ATmakeList1((ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATinsert(ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(34)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(92)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun117)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATinsert(ATmakeList1((ATerm)ATmakeInt(34)), (ATerm)ATmakeInt(92)))));
}
/**
 * Constructs a backslash of type PTPT_LexStrChar. Like all ATerm types, PTPT_LexStrChars are maximally shared.
 * \return A pointer to a backslash, either newly constructed or shared
 */
PTPT_LexStrChar PTPT_makeLexStrCharBackslash(void) {
  return (PTPT_LexStrChar)(ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun119))), (ATerm)ATmakeAppl1(PTPT_afun6, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun113))), (ATerm)ATmakeAppl1(PTPT_afun12, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun13, (ATerm)ATmakeAppl1(PTPT_afun14, (ATerm)ATmakeAppl0(PTPT_afun120)))))), (ATerm)ATmakeList1((ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATinsert(ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(92)))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(92)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun119)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATinsert(ATmakeList1((ATerm)ATmakeInt(92)), (ATerm)ATmakeInt(92)))));
}
/**
 * Constructs a decimal of type PTPT_LexStrChar. Like all ATerm types, PTPT_LexStrChars are maximally shared.
 * \param[in] a a child of the new decimal
 * \param[in] b a child of the new decimal
 * \param[in] c a child of the new decimal
 * \return A pointer to a decimal, either newly constructed or shared
 */
PTPT_LexStrChar PTPT_makeLexStrCharDecimal(char a, char b, char c) {
  return (PTPT_LexStrChar)(ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeAppl2(PTPT_afun121, (ATerm)ATmakeInt(48), (ATerm)ATmakeInt(57))))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeAppl2(PTPT_afun121, (ATerm)ATmakeInt(48), (ATerm)ATmakeInt(57))))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeAppl2(PTPT_afun121, (ATerm)ATmakeInt(48), (ATerm)ATmakeInt(57))))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun122))), (ATerm)ATmakeAppl1(PTPT_afun6, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun113))), (ATerm)ATmakeAppl1(PTPT_afun12, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun13, (ATerm)ATmakeAppl1(PTPT_afun14, (ATerm)ATmakeAppl0(PTPT_afun123)))))), (ATerm)ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm) ((ATerm) PTPT_byteToChar(c))), (ATerm) ((ATerm) PTPT_byteToChar(b))), (ATerm) ((ATerm) PTPT_byteToChar(a))), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(92)))), (ATerm)ATmakeAppl1(PTPT_afun16, (ATerm)ATmakeAppl0(PTPT_afun122)), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(92)))));
}
/**
 * Constructs a normal of type PTPT_LexStrChar. Like all ATerm types, PTPT_LexStrChars are maximally shared.
 * \param[in] ch a child of the new normal
 * \return A pointer to a normal, either newly constructed or shared
 */
PTPT_LexStrChar PTPT_makeLexStrCharNormal(char ch) {
  return (PTPT_LexStrChar)(ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl2(PTPT_afun121, (ATerm)ATmakeInt(93), (ATerm)ATmakeInt(255))), (ATerm)ATmakeAppl2(PTPT_afun121, (ATerm)ATmakeInt(35), (ATerm)ATmakeInt(91))), (ATerm)ATmakeAppl2(PTPT_afun121, (ATerm)ATmakeInt(32), (ATerm)ATmakeInt(33))))), (ATerm)ATmakeAppl1(PTPT_afun6, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun113))), (ATerm)ATmakeAppl1(PTPT_afun12, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun13, (ATerm)ATmakeAppl1(PTPT_afun14, (ATerm)ATmakeAppl0(PTPT_afun124)))))), (ATerm)ATmakeList1((ATerm) ((ATerm) PTPT_byteToChar(ch))));
}
/**
 * Constructs a Lex-to-cf of type PTPT_StrChar. Like all ATerm types, PTPT_StrChars are maximally shared.
 * \param[in] StrChar a child of the new Lex-to-cf
 * \return A pointer to a Lex-to-cf, either newly constructed or shared
 */
PTPT_StrChar PTPT_makeStrCharLexToCf(PTPT_LexStrChar StrChar) {
  return (PTPT_StrChar)(ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun6, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun113)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun113))), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm) StrChar));
}
/**
 * Constructs a default of type PTPT_LexStrCon. Like all ATerm types, PTPT_LexStrCons are maximally shared.
 * \param[in] chars a child of the new default
 * \return A pointer to a default, either newly constructed or shared
 */
PTPT_LexStrCon PTPT_makeLexStrConDefault(PTPT_LexStrCharChars chars) {
  return (PTPT_LexStrCon)(ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(34)))), (ATerm)ATmakeAppl1(PTPT_afun6, (ATerm)ATmakeAppl1(PTPT_afun125, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun113))))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeInt(34)))), (ATerm)ATmakeAppl1(PTPT_afun6, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun42))), (ATerm)ATmakeAppl1(PTPT_afun12, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun13, (ATerm)ATmakeAppl1(PTPT_afun14, (ATerm)ATmakeAppl0(PTPT_afun88)))))), (ATerm)ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeInt(34)), (ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl1(PTPT_afun8, (ATerm)ATmakeAppl1(PTPT_afun6, (ATerm)ATmakeAppl1(PTPT_afun125, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun113))))), (ATerm) chars)), (ATerm)ATmakeInt(34)));
}
/**
 * Constructs a Lex-to-cf of type PTPT_StrCon. Like all ATerm types, PTPT_StrCons are maximally shared.
 * \param[in] StrCon a child of the new Lex-to-cf
 * \return A pointer to a Lex-to-cf, either newly constructed or shared
 */
PTPT_StrCon PTPT_makeStrConLexToCf(PTPT_LexStrCon StrCon) {
  return (PTPT_StrCon)(ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun6, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun42)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun42))), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm) StrCon));
}
/**
 * Constructs a empty of type PTPT_LexStrCharChars. Like all ATerm types, PTPT_LexStrCharCharss are maximally shared.
 * \return A pointer to a empty, either newly constructed or shared
 */
PTPT_LexStrCharChars PTPT_makeLexStrCharCharsEmpty(void) {
  return (PTPT_LexStrCharChars)(ATerm)ATempty;
}
/**
 * Constructs a single of type PTPT_LexStrCharChars. Like all ATerm types, PTPT_LexStrCharCharss are maximally shared.
 * \param[in] head a child of the new single
 * \return A pointer to a single, either newly constructed or shared
 */
PTPT_LexStrCharChars PTPT_makeLexStrCharCharsSingle(PTPT_LexStrChar head) {
  return (PTPT_LexStrCharChars)(ATerm)ATmakeList1((ATerm) head);
}
/**
 * Constructs a many of type PTPT_LexStrCharChars. Like all ATerm types, PTPT_LexStrCharCharss are maximally shared.
 * \param[in] head a child of the new many
 * \param[in] tail a child of the new many
 * \return A pointer to a many, either newly constructed or shared
 */
PTPT_LexStrCharChars PTPT_makeLexStrCharCharsMany(PTPT_LexStrChar head, PTPT_LexStrCharChars tail) {
  return (PTPT_LexStrCharChars)(ATerm)ATinsert((ATermList)tail, (ATerm) head);
}
/**
 * Constructs a digits of type PTPT_LexNatCon. Like all ATerm types, PTPT_LexNatCons are maximally shared.
 * \param[in] list a child of the new digits
 * \return A pointer to a digits, either newly constructed or shared
 */
PTPT_LexNatCon PTPT_makeLexNatConDigits(const char* list) {
  return (PTPT_LexNatCon)(ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun6, (ATerm)ATmakeAppl1(PTPT_afun7, (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeAppl2(PTPT_afun121, (ATerm)ATmakeInt(48), (ATerm)ATmakeInt(57))))))), (ATerm)ATmakeAppl1(PTPT_afun6, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun24))), (ATerm)ATmakeAppl1(PTPT_afun12, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun13, (ATerm)ATmakeAppl1(PTPT_afun14, (ATerm)ATmakeAppl0(PTPT_afun126)))))), (ATerm)ATmakeList1((ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl1(PTPT_afun8, (ATerm)ATmakeAppl1(PTPT_afun6, (ATerm)ATmakeAppl1(PTPT_afun7, (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATmakeList1((ATerm)ATmakeAppl2(PTPT_afun121, (ATerm)ATmakeInt(48), (ATerm)ATmakeInt(57))))))), (ATerm) ((ATerm) PTPT_stringToChars(list)))));
}
/**
 * Constructs a Lex-to-cf of type PTPT_NatCon. Like all ATerm types, PTPT_NatCons are maximally shared.
 * \param[in] NatCon a child of the new Lex-to-cf
 * \return A pointer to a Lex-to-cf, either newly constructed or shared
 */
PTPT_NatCon PTPT_makeNatConLexToCf(PTPT_LexNatCon NatCon) {
  return (PTPT_NatCon)(ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun6, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun24)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun24))), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm) NatCon));
}
/**
 * Constructs a default of type PTPT_LexIdCon. Like all ATerm types, PTPT_LexIdCons are maximally shared.
 * \param[in] head a child of the new default
 * \param[in] tail a child of the new default
 * \return A pointer to a default, either newly constructed or shared
 */
PTPT_LexIdCon PTPT_makeLexIdConDefault(char head, const char* tail) {
  return (PTPT_LexIdCon)(ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATinsert(ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun6, (ATerm)ATmakeAppl1(PTPT_afun125, (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl2(PTPT_afun121, (ATerm)ATmakeInt(97), (ATerm)ATmakeInt(122))), (ATerm)ATmakeAppl2(PTPT_afun121, (ATerm)ATmakeInt(65), (ATerm)ATmakeInt(90))), (ATerm)ATmakeAppl2(PTPT_afun121, (ATerm)ATmakeInt(48), (ATerm)ATmakeInt(57))), (ATerm)ATmakeInt(45)))))), (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATinsert(ATmakeList1((ATerm)ATmakeAppl2(PTPT_afun121, (ATerm)ATmakeInt(97), (ATerm)ATmakeInt(122))), (ATerm)ATmakeAppl2(PTPT_afun121, (ATerm)ATmakeInt(65), (ATerm)ATmakeInt(90))))), (ATerm)ATmakeAppl1(PTPT_afun6, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun91))), (ATerm)ATmakeAppl1(PTPT_afun12, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun13, (ATerm)ATmakeAppl1(PTPT_afun14, (ATerm)ATmakeAppl0(PTPT_afun88)))))), (ATerm)ATinsert(ATmakeList1((ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl1(PTPT_afun8, (ATerm)ATmakeAppl1(PTPT_afun6, (ATerm)ATmakeAppl1(PTPT_afun125, (ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl2(PTPT_afun121, (ATerm)ATmakeInt(97), (ATerm)ATmakeInt(122))), (ATerm)ATmakeAppl2(PTPT_afun121, (ATerm)ATmakeInt(65), (ATerm)ATmakeInt(90))), (ATerm)ATmakeAppl2(PTPT_afun121, (ATerm)ATmakeInt(48), (ATerm)ATmakeInt(57))), (ATerm)ATmakeInt(45)))))), (ATerm) ((ATerm) PTPT_stringToChars(tail)))), (ATerm) ((ATerm) PTPT_byteToChar(head))));
}
/**
 * Constructs a Lex-to-cf of type PTPT_IdCon. Like all ATerm types, PTPT_IdCons are maximally shared.
 * \param[in] IdCon a child of the new Lex-to-cf
 * \return A pointer to a Lex-to-cf, either newly constructed or shared
 */
PTPT_IdCon PTPT_makeIdConLexToCf(PTPT_LexIdCon IdCon) {
  return (PTPT_IdCon)(ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun6, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun91)))), (ATerm)ATmakeAppl1(PTPT_afun2, (ATerm)ATmakeAppl1(PTPT_afun9, (ATerm)ATmakeAppl0(PTPT_afun91))), (ATerm)ATmakeAppl0(PTPT_afun5)), (ATerm)ATmakeList1((ATerm) IdCon));
}
/**
 * Constructs a whitespace of type PTPT_LexLayout. Like all ATerm types, PTPT_LexLayouts are maximally shared.
 * \param[in] ch a child of the new whitespace
 * \return A pointer to a whitespace, either newly constructed or shared
 */
PTPT_LexLayout PTPT_makeLexLayoutWhitespace(char ch) {
  return (PTPT_LexLayout)(ATerm)ATmakeAppl2(PTPT_afun0, (ATerm)ATmakeAppl3(PTPT_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun23, (ATerm)ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeInt(32)), (ATerm)ATmakeInt(13)), (ATerm)ATmakeAppl2(PTPT_afun121, (ATerm)ATmakeInt(9), (ATerm)ATmakeInt(10))))), (ATerm)ATmakeAppl1(PTPT_afun6, (ATerm)ATmakeAppl0(PTPT_afun4)), (ATerm)ATmakeAppl1(PTPT_afun12, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(PTPT_afun13, (ATerm)ATmakeAppl1(PTPT_afun14, (ATerm)ATmakeAppl0(PTPT_afun127)))))), (ATerm)ATmakeList1((ATerm) ((ATerm) PTPT_byteToChar(ch))));
}

/**
 * Tests equality of two PTPT_OptLayouts. A constant time operation.
 * \param[in] arg0 first PTPT_OptLayout to be compared
 * \param[in] arg1 second PTPT_OptLayout to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _PTPT_isEqualOptLayout(PTPT_OptLayout arg0, PTPT_OptLayout arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two PTPT_Layouts. A constant time operation.
 * \param[in] arg0 first PTPT_Layout to be compared
 * \param[in] arg1 second PTPT_Layout to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _PTPT_isEqualLayout(PTPT_Layout arg0, PTPT_Layout arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two PTPT_LexLayoutLists. A constant time operation.
 * \param[in] arg0 first PTPT_LexLayoutList to be compared
 * \param[in] arg1 second PTPT_LexLayoutList to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _PTPT_isEqualLexLayoutList(PTPT_LexLayoutList arg0, PTPT_LexLayoutList arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two PTPT_Trees. A constant time operation.
 * \param[in] arg0 first PTPT_Tree to be compared
 * \param[in] arg1 second PTPT_Tree to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _PTPT_isEqualTree(PTPT_Tree arg0, PTPT_Tree arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two PTPT_Attributess. A constant time operation.
 * \param[in] arg0 first PTPT_Attributes to be compared
 * \param[in] arg1 second PTPT_Attributes to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _PTPT_isEqualAttributes(PTPT_Attributes arg0, PTPT_Attributes arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two PTPT_Attrss. A constant time operation.
 * \param[in] arg0 first PTPT_Attrs to be compared
 * \param[in] arg1 second PTPT_Attrs to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _PTPT_isEqualAttrs(PTPT_Attrs arg0, PTPT_Attrs arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two PTPT_Attrs. A constant time operation.
 * \param[in] arg0 first PTPT_Attr to be compared
 * \param[in] arg1 second PTPT_Attr to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _PTPT_isEqualAttr(PTPT_Attr arg0, PTPT_Attr arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two PTPT_Associativitys. A constant time operation.
 * \param[in] arg0 first PTPT_Associativity to be compared
 * \param[in] arg1 second PTPT_Associativity to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _PTPT_isEqualAssociativity(PTPT_Associativity arg0, PTPT_Associativity arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two PTPT_AttrLists. A constant time operation.
 * \param[in] arg0 first PTPT_AttrList to be compared
 * \param[in] arg1 second PTPT_AttrList to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _PTPT_isEqualAttrList(PTPT_AttrList arg0, PTPT_AttrList arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two PTPT_ParseTrees. A constant time operation.
 * \param[in] arg0 first PTPT_ParseTree to be compared
 * \param[in] arg1 second PTPT_ParseTree to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _PTPT_isEqualParseTree(PTPT_ParseTree arg0, PTPT_ParseTree arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two PTPT_Symbols. A constant time operation.
 * \param[in] arg0 first PTPT_Symbol to be compared
 * \param[in] arg1 second PTPT_Symbol to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _PTPT_isEqualSymbol(PTPT_Symbol arg0, PTPT_Symbol arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two PTPT_Symbolss. A constant time operation.
 * \param[in] arg0 first PTPT_Symbols to be compared
 * \param[in] arg1 second PTPT_Symbols to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _PTPT_isEqualSymbols(PTPT_Symbols arg0, PTPT_Symbols arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two PTPT_CharRangess. A constant time operation.
 * \param[in] arg0 first PTPT_CharRanges to be compared
 * \param[in] arg1 second PTPT_CharRanges to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _PTPT_isEqualCharRanges(PTPT_CharRanges arg0, PTPT_CharRanges arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two PTPT_CharRanges. A constant time operation.
 * \param[in] arg0 first PTPT_CharRange to be compared
 * \param[in] arg1 second PTPT_CharRange to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _PTPT_isEqualCharRange(PTPT_CharRange arg0, PTPT_CharRange arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two PTPT_Starts. A constant time operation.
 * \param[in] arg0 first PTPT_Start to be compared
 * \param[in] arg1 second PTPT_Start to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _PTPT_isEqualStart(PTPT_Start arg0, PTPT_Start arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two PTPT_SymbolLists. A constant time operation.
 * \param[in] arg0 first PTPT_SymbolList to be compared
 * \param[in] arg1 second PTPT_SymbolList to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _PTPT_isEqualSymbolList(PTPT_SymbolList arg0, PTPT_SymbolList arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two PTPT_CharRangeLists. A constant time operation.
 * \param[in] arg0 first PTPT_CharRangeList to be compared
 * \param[in] arg1 second PTPT_CharRangeList to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _PTPT_isEqualCharRangeList(PTPT_CharRangeList arg0, PTPT_CharRangeList arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two PTPT_Argss. A constant time operation.
 * \param[in] arg0 first PTPT_Args to be compared
 * \param[in] arg1 second PTPT_Args to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _PTPT_isEqualArgs(PTPT_Args arg0, PTPT_Args arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two PTPT_Productions. A constant time operation.
 * \param[in] arg0 first PTPT_Production to be compared
 * \param[in] arg1 second PTPT_Production to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _PTPT_isEqualProduction(PTPT_Production arg0, PTPT_Production arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two PTPT_TreeLists. A constant time operation.
 * \param[in] arg0 first PTPT_TreeList to be compared
 * \param[in] arg1 second PTPT_TreeList to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _PTPT_isEqualTreeList(PTPT_TreeList arg0, PTPT_TreeList arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two PTPT_AFuns. A constant time operation.
 * \param[in] arg0 first PTPT_AFun to be compared
 * \param[in] arg1 second PTPT_AFun to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _PTPT_isEqualAFun(PTPT_AFun arg0, PTPT_AFun arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two PTPT_ATerms. A constant time operation.
 * \param[in] arg0 first PTPT_ATerm to be compared
 * \param[in] arg1 second PTPT_ATerm to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _PTPT_isEqualATerm(PTPT_ATerm arg0, PTPT_ATerm arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two PTPT_Annotations. A constant time operation.
 * \param[in] arg0 first PTPT_Annotation to be compared
 * \param[in] arg1 second PTPT_Annotation to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _PTPT_isEqualAnnotation(PTPT_Annotation arg0, PTPT_Annotation arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two PTPT_ATermArgss. A constant time operation.
 * \param[in] arg0 first PTPT_ATermArgs to be compared
 * \param[in] arg1 second PTPT_ATermArgs to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _PTPT_isEqualATermArgs(PTPT_ATermArgs arg0, PTPT_ATermArgs arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two PTPT_ATermElemss. A constant time operation.
 * \param[in] arg0 first PTPT_ATermElems to be compared
 * \param[in] arg1 second PTPT_ATermElems to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _PTPT_isEqualATermElems(PTPT_ATermElems arg0, PTPT_ATermElems arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two PTPT_ATermAnnoss. A constant time operation.
 * \param[in] arg0 first PTPT_ATermAnnos to be compared
 * \param[in] arg1 second PTPT_ATermAnnos to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _PTPT_isEqualATermAnnos(PTPT_ATermAnnos arg0, PTPT_ATermAnnos arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two PTPT_IntCons. A constant time operation.
 * \param[in] arg0 first PTPT_IntCon to be compared
 * \param[in] arg1 second PTPT_IntCon to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _PTPT_isEqualIntCon(PTPT_IntCon arg0, PTPT_IntCon arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two PTPT_OptExps. A constant time operation.
 * \param[in] arg0 first PTPT_OptExp to be compared
 * \param[in] arg1 second PTPT_OptExp to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _PTPT_isEqualOptExp(PTPT_OptExp arg0, PTPT_OptExp arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two PTPT_RealCons. A constant time operation.
 * \param[in] arg0 first PTPT_RealCon to be compared
 * \param[in] arg1 second PTPT_RealCon to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _PTPT_isEqualRealCon(PTPT_RealCon arg0, PTPT_RealCon arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two PTPT_LexStrChars. A constant time operation.
 * \param[in] arg0 first PTPT_LexStrChar to be compared
 * \param[in] arg1 second PTPT_LexStrChar to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _PTPT_isEqualLexStrChar(PTPT_LexStrChar arg0, PTPT_LexStrChar arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two PTPT_StrChars. A constant time operation.
 * \param[in] arg0 first PTPT_StrChar to be compared
 * \param[in] arg1 second PTPT_StrChar to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _PTPT_isEqualStrChar(PTPT_StrChar arg0, PTPT_StrChar arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two PTPT_LexStrCons. A constant time operation.
 * \param[in] arg0 first PTPT_LexStrCon to be compared
 * \param[in] arg1 second PTPT_LexStrCon to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _PTPT_isEqualLexStrCon(PTPT_LexStrCon arg0, PTPT_LexStrCon arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two PTPT_StrCons. A constant time operation.
 * \param[in] arg0 first PTPT_StrCon to be compared
 * \param[in] arg1 second PTPT_StrCon to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _PTPT_isEqualStrCon(PTPT_StrCon arg0, PTPT_StrCon arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two PTPT_LexStrCharCharss. A constant time operation.
 * \param[in] arg0 first PTPT_LexStrCharChars to be compared
 * \param[in] arg1 second PTPT_LexStrCharChars to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _PTPT_isEqualLexStrCharChars(PTPT_LexStrCharChars arg0, PTPT_LexStrCharChars arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two PTPT_LexNatCons. A constant time operation.
 * \param[in] arg0 first PTPT_LexNatCon to be compared
 * \param[in] arg1 second PTPT_LexNatCon to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _PTPT_isEqualLexNatCon(PTPT_LexNatCon arg0, PTPT_LexNatCon arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two PTPT_NatCons. A constant time operation.
 * \param[in] arg0 first PTPT_NatCon to be compared
 * \param[in] arg1 second PTPT_NatCon to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _PTPT_isEqualNatCon(PTPT_NatCon arg0, PTPT_NatCon arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two PTPT_LexIdCons. A constant time operation.
 * \param[in] arg0 first PTPT_LexIdCon to be compared
 * \param[in] arg1 second PTPT_LexIdCon to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _PTPT_isEqualLexIdCon(PTPT_LexIdCon arg0, PTPT_LexIdCon arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two PTPT_IdCons. A constant time operation.
 * \param[in] arg0 first PTPT_IdCon to be compared
 * \param[in] arg1 second PTPT_IdCon to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _PTPT_isEqualIdCon(PTPT_IdCon arg0, PTPT_IdCon arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two PTPT_LexLayouts. A constant time operation.
 * \param[in] arg0 first PTPT_LexLayout to be compared
 * \param[in] arg1 second PTPT_LexLayout to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _PTPT_isEqualLexLayout(PTPT_LexLayout arg0, PTPT_LexLayout arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Assert whether a PTPT_OptLayout is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input PTPT_OptLayout
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool PTPT_isValidOptLayout(PTPT_OptLayout arg) {
  if (PTPT_isOptLayoutAbsent(arg)) {
    return ATtrue;
  }
  else if (PTPT_isOptLayoutPresent(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_OptLayout is a Absent by checking against the following ATerm pattern: appl(prod([],cf(opt(layout)),no-attrs),[]). May not be used to assert correctness of the PTPT_OptLayout
 * \param[in] arg input PTPT_OptLayout
 * \return ATtrue if #arg corresponds to the signature of a Absent, or ATfalse otherwise
 */
inline ATbool PTPT_isOptLayoutAbsent(PTPT_OptLayout arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == PTPT_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == PTPT_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATisEmpty((ATermList)arg_arg0_arg0)) {
        ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
        /* checking for: cf */
        if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == PTPT_afun2) {
          ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
          /* checking for: opt */
          if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == PTPT_afun3) {
            ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
            /* checking for: layout */
            if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == PTPT_afun4) {
              ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
              /* checking for: no-attrs */
              if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == PTPT_afun5) {
                ATerm arg_arg1 = ATgetArgument(arg, 1);
                if (ATisEmpty((ATermList)arg_arg1)) {
                  return ATtrue;
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_OptLayout is a Present by checking against the following ATerm pattern: appl(prod([cf(layout)],cf(opt(layout)),no-attrs),[<"layout"("Layout")>]). May not be used to assert correctness of the PTPT_OptLayout
 * \param[in] arg input PTPT_OptLayout
 * \return ATtrue if #arg corresponds to the signature of a Present, or ATfalse otherwise
 */
inline ATbool PTPT_isOptLayoutPresent(PTPT_OptLayout arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == PTPT_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == PTPT_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: cf */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: layout */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun4) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
              ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
              /* checking for: cf */
              if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == PTPT_afun2) {
                ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                /* checking for: opt */
                if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == PTPT_afun3) {
                  ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                  /* checking for: layout */
                  if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == PTPT_afun4) {
                    ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                    /* checking for: no-attrs */
                    if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == PTPT_afun5) {
                      ATerm arg_arg1 = ATgetArgument(arg, 1);
                      if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                        ATermList arg_arg1_list = (ATermList)arg_arg1;
                        arg_arg1_list = ATgetNext(arg_arg1_list);
                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                          return ATtrue;
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_OptLayout has a layout. 
 * \param[in] arg input PTPT_OptLayout
 * \return ATtrue if the PTPT_OptLayout had a layout, or ATfalse otherwise
 */
ATbool PTPT_hasOptLayoutLayout(PTPT_OptLayout arg) {
  if (PTPT_isOptLayoutPresent(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Get the layout PTPT_Layout of a PTPT_OptLayout. Note that the precondition is that this PTPT_OptLayout actually has a layout
 * \param[in] arg input PTPT_OptLayout
 * \return the layout of #arg, if it exist or an undefined value if it does not
 */
PTPT_Layout PTPT_getOptLayoutLayout(PTPT_OptLayout arg) {
  
    return (PTPT_Layout)ATgetFirst((ATermList)ATgetArgument((ATermAppl)arg, 1));
}

/**
 * Set the layout of a PTPT_OptLayout. The precondition being that this PTPT_OptLayout actually has a layout
 * \param[in] arg input PTPT_OptLayout
 * \param[in] layout new PTPT_Layout to set in #arg
 * \return A new PTPT_OptLayout with layout at the right place, or a core dump if #arg did not have a layout
 */
PTPT_OptLayout PTPT_setOptLayoutLayout(PTPT_OptLayout arg, PTPT_Layout layout) {
  if (PTPT_isOptLayoutPresent(arg)) {
    return (PTPT_OptLayout)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) layout), 0), 1);
  }

  ATabort("OptLayout has no Layout: %t\n", arg);
  return (PTPT_OptLayout)NULL;
}

/**
 * Assert whether a PTPT_Layout is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input PTPT_Layout
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool PTPT_isValidLayout(PTPT_Layout arg) {
  if (PTPT_isLayoutLexToCf(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Layout is a Lex-to-cf by checking against the following ATerm pattern: appl(prod([lex(iter(layout))],cf(layout),no-attrs),[appl(list(lex(iter(layout))),<"list"("Lex-Layout-list")>)]). Always returns ATtrue
 * \param[in] arg input PTPT_Layout
 * \return ATtrue if #arg corresponds to the signature of a Lex-to-cf, or ATfalse otherwise
 */
inline ATbool PTPT_isLayoutLexToCf(PTPT_Layout arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == PTPT_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == PTPT_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lex */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun6) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: iter */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun7) {
            ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
            /* checking for: layout */
            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
              if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                /* checking for: cf */
                if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == PTPT_afun2) {
                  ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                  /* checking for: layout */
                  if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == PTPT_afun4) {
                    ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                    /* checking for: no-attrs */
                    if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == PTPT_afun5) {
                      ATerm arg_arg1 = ATgetArgument(arg, 1);
                      if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                        ATerm arg_arg1_head;
                        ATermList arg_arg1_list = (ATermList)arg_arg1;
                        arg_arg1_head = ATgetFirst(arg_arg1_list);
                        arg_arg1_list = ATgetNext(arg_arg1_list);
                        /* checking for: appl */
                        if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                          ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                          /* checking for: list */
                          if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun8) {
                            ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                            /* checking for: lex */
                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0) == PTPT_afun6) {
                              ATerm arg_arg1_head_arg0_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0, 0);
                              /* checking for: iter */
                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0) == PTPT_afun7) {
                                ATerm arg_arg1_head_arg0_arg0_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0, 0);
                                /* checking for: layout */
                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg0) == PTPT_afun4) {
                                  if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                    return ATtrue;
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Layout has a list. 
 * \param[in] arg input PTPT_Layout
 * \return ATtrue if the PTPT_Layout had a list, or ATfalse otherwise
 */
ATbool PTPT_hasLayoutList(PTPT_Layout arg) {
  if (PTPT_isLayoutLexToCf(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Get the list PTPT_LexLayoutList of a PTPT_Layout. Note that the precondition is that this PTPT_Layout actually has a list
 * \param[in] arg input PTPT_Layout
 * \return the list of #arg, if it exist or an undefined value if it does not
 */
PTPT_LexLayoutList PTPT_getLayoutList(PTPT_Layout arg) {
  
    return (PTPT_LexLayoutList)ATgetArgument((ATermAppl)ATgetFirst((ATermList)ATgetArgument((ATermAppl)arg, 1)), 1);
}

/**
 * Set the list of a PTPT_Layout. The precondition being that this PTPT_Layout actually has a list
 * \param[in] arg input PTPT_Layout
 * \param[in] list new PTPT_LexLayoutList to set in #arg
 * \return A new PTPT_Layout with list at the right place, or a core dump if #arg did not have a list
 */
PTPT_Layout PTPT_setLayoutList(PTPT_Layout arg, PTPT_LexLayoutList list) {
  if (PTPT_isLayoutLexToCf(arg)) {
    return (PTPT_Layout)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)ATsetArgument((ATermAppl)ATgetFirst((ATermList)ATgetArgument((ATermAppl)arg, 1)), (ATerm)((ATerm) list), 1), 0), 1);
  }

  ATabort("Layout has no List: %t\n", arg);
  return (PTPT_Layout)NULL;
}

/**
 * Assert whether a PTPT_LexLayoutList is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input PTPT_LexLayoutList
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool PTPT_isValidLexLayoutList(PTPT_LexLayoutList arg) {
  if (PTPT_isLexLayoutListEmpty(arg)) {
    return ATtrue;
  }
  else if (PTPT_isLexLayoutListSingle(arg)) {
    return ATtrue;
  }
  else if (PTPT_isLexLayoutListMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_LexLayoutList is a empty by checking against the following ATerm pattern: []. May not be used to assert correctness of the PTPT_LexLayoutList
 * \param[in] arg input PTPT_LexLayoutList
 * \return ATtrue if #arg corresponds to the signature of a empty, or ATfalse otherwise
 */
inline ATbool PTPT_isLexLayoutListEmpty(PTPT_LexLayoutList arg){
  if (ATisEmpty((ATermList)arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_LexLayoutList is a single by checking against the following ATerm pattern: [<head(Lex-Layout)>]. May not be used to assert correctness of the PTPT_LexLayoutList
 * \param[in] arg input PTPT_LexLayoutList
 * \return ATtrue if #arg corresponds to the signature of a single, or ATfalse otherwise
 */
inline ATbool PTPT_isLexLayoutListSingle(PTPT_LexLayoutList arg){
  if (ATgetType((ATerm)arg) == AT_LIST && ATisEmpty((ATermList)arg) == ATfalse) {
    ATermList arg_list = (ATermList)arg;
    arg_list = ATgetNext(arg_list);
    if (ATgetType((ATerm)arg_list) == AT_LIST && ATisEmpty((ATermList)arg_list) == ATtrue) {
      return ATtrue;
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_LexLayoutList is a many by checking against the following ATerm pattern: [<head(Lex-Layout)>,<[tail(Lex-Layout-list)]>]. May not be used to assert correctness of the PTPT_LexLayoutList
 * \param[in] arg input PTPT_LexLayoutList
 * \return ATtrue if #arg corresponds to the signature of a many, or ATfalse otherwise
 */
inline ATbool PTPT_isLexLayoutListMany(PTPT_LexLayoutList arg){
  if (ATgetType((ATerm)arg) == AT_LIST && ATisEmpty((ATermList)arg) == ATfalse) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_LexLayoutList has a head. 
 * \param[in] arg input PTPT_LexLayoutList
 * \return ATtrue if the PTPT_LexLayoutList had a head, or ATfalse otherwise
 */
ATbool PTPT_hasLexLayoutListHead(PTPT_LexLayoutList arg) {
  if (PTPT_isLexLayoutListSingle(arg)) {
    return ATtrue;
  }
  else if (PTPT_isLexLayoutListMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_LexLayoutList has a tail. 
 * \param[in] arg input PTPT_LexLayoutList
 * \return ATtrue if the PTPT_LexLayoutList had a tail, or ATfalse otherwise
 */
ATbool PTPT_hasLexLayoutListTail(PTPT_LexLayoutList arg) {
  if (PTPT_isLexLayoutListMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Get the head PTPT_LexLayout of a PTPT_LexLayoutList. Note that the precondition is that this PTPT_LexLayoutList actually has a head
 * \param[in] arg input PTPT_LexLayoutList
 * \return the head of #arg, if it exist or an undefined value if it does not
 */
PTPT_LexLayout PTPT_getLexLayoutListHead(PTPT_LexLayoutList arg) {
  if (PTPT_isLexLayoutListSingle(arg)) {
    return (PTPT_LexLayout)ATgetFirst((ATermList)arg);
  }
  else 
    return (PTPT_LexLayout)ATgetFirst((ATermList)arg);
}

/**
 * Get the tail PTPT_LexLayoutList of a PTPT_LexLayoutList. Note that the precondition is that this PTPT_LexLayoutList actually has a tail
 * \param[in] arg input PTPT_LexLayoutList
 * \return the tail of #arg, if it exist or an undefined value if it does not
 */
PTPT_LexLayoutList PTPT_getLexLayoutListTail(PTPT_LexLayoutList arg) {
  
    return (PTPT_LexLayoutList)ATgetNext((ATermList)arg);
}

/**
 * Set the head of a PTPT_LexLayoutList. The precondition being that this PTPT_LexLayoutList actually has a head
 * \param[in] arg input PTPT_LexLayoutList
 * \param[in] head new PTPT_LexLayout to set in #arg
 * \return A new PTPT_LexLayoutList with head at the right place, or a core dump if #arg did not have a head
 */
PTPT_LexLayoutList PTPT_setLexLayoutListHead(PTPT_LexLayoutList arg, PTPT_LexLayout head) {
  if (PTPT_isLexLayoutListSingle(arg)) {
    return (PTPT_LexLayoutList)ATreplace((ATermList)arg, (ATerm)((ATerm) head), 0);
  }
  else if (PTPT_isLexLayoutListMany(arg)) {
    return (PTPT_LexLayoutList)ATreplace((ATermList)arg, (ATerm)((ATerm) head), 0);
  }

  ATabort("LexLayoutList has no Head: %t\n", arg);
  return (PTPT_LexLayoutList)NULL;
}

/**
 * Set the tail of a PTPT_LexLayoutList. The precondition being that this PTPT_LexLayoutList actually has a tail
 * \param[in] arg input PTPT_LexLayoutList
 * \param[in] tail new PTPT_LexLayoutList to set in #arg
 * \return A new PTPT_LexLayoutList with tail at the right place, or a core dump if #arg did not have a tail
 */
PTPT_LexLayoutList PTPT_setLexLayoutListTail(PTPT_LexLayoutList arg, PTPT_LexLayoutList tail) {
  if (PTPT_isLexLayoutListMany(arg)) {
    return (PTPT_LexLayoutList)ATreplaceTail((ATermList)arg, (ATermList)((ATerm) tail), 1);
  }

  ATabort("LexLayoutList has no Tail: %t\n", arg);
  return (PTPT_LexLayoutList)NULL;
}

/**
 * Assert whether a PTPT_Tree is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input PTPT_Tree
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool PTPT_isValidTree(PTPT_Tree arg) {
  if (PTPT_isTreeAnnotated(arg)) {
    return ATtrue;
  }
  else if (PTPT_isTreeAppl(arg)) {
    return ATtrue;
  }
  else if (PTPT_isTreeCycle(arg)) {
    return ATtrue;
  }
  else if (PTPT_isTreeAmb(arg)) {
    return ATtrue;
  }
  else if (PTPT_isTreeChar(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Tree is a annotated by checking against the following ATerm pattern: appl(prod([cf(sort("Tree")),cf(opt(layout)),cf(sort("Annotation"))],cf(sort("Tree")),attrs([term(cons("annotated"))])),[<"Tree"("Tree")>,<"ws-after-Tree"("OptLayout")>,<"Annotation"("Annotation")>]). May not be used to assert correctness of the PTPT_Tree
 * \param[in] arg input PTPT_Tree
 * \return ATtrue if #arg corresponds to the signature of a annotated, or ATfalse otherwise
 */
inline ATbool PTPT_isTreeAnnotated(PTPT_Tree arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == PTPT_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == PTPT_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: cf */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: sort */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun9) {
            ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
            /* checking for: Tree */
            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun11) {
              if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                /* checking for: cf */
                if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                  ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                  /* checking for: opt */
                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                    ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                    /* checking for: layout */
                    if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                      if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                        /* checking for: cf */
                        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                          /* checking for: sort */
                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun9) {
                            ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                            /* checking for: Annotation */
                            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun10) {
                              if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                                ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                /* checking for: cf */
                                if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == PTPT_afun2) {
                                  ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                  /* checking for: sort */
                                  if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == PTPT_afun9) {
                                    ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                    /* checking for: Tree */
                                    if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == PTPT_afun11) {
                                      ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                      /* checking for: attrs */
                                      if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == PTPT_afun12) {
                                        ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                        if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                          ATerm arg_arg0_arg2_arg0_head;
                                          ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                          arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                          arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                          /* checking for: term */
                                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == PTPT_afun13) {
                                            ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                            /* checking for: cons */
                                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == PTPT_afun14) {
                                              ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                              /* checking for: annotated */
                                              if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == PTPT_afun15) {
                                                if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                  ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                  if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                    ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                    arg_arg1_list = ATgetNext(arg_arg1_list);
                                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                      arg_arg1_list = ATgetNext(arg_arg1_list);
                                                      if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                        arg_arg1_list = ATgetNext(arg_arg1_list);
                                                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                          return ATtrue;
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Tree is a appl by checking against the following ATerm pattern: appl(prod([lit("appl"),cf(opt(layout)),lit("("),cf(opt(layout)),cf(sort("Production")),cf(opt(layout)),lit(","),cf(opt(layout)),cf(sort("Args")),cf(opt(layout)),lit(")")],cf(sort("Tree")),attrs([term(cons("appl"))])),[appl(prod([char-class([97]),char-class([112]),char-class([112]),char-class([108])],lit("appl"),no-attrs),[97,112,112,108]),<"ws-after-appl"("OptLayout")>,appl(prod([char-class([40])],lit("("),no-attrs),[40]),<"ws-after-("("OptLayout")>,<"prod"("Production")>,<"ws-after-prod"("OptLayout")>,appl(prod([char-class([44])],lit(","),no-attrs),[44]),<"ws-after-,"("OptLayout")>,<"args"("Args")>,<"ws-after-args"("OptLayout")>,appl(prod([char-class([41])],lit(")"),no-attrs),[41])]). May not be used to assert correctness of the PTPT_Tree
 * \param[in] arg input PTPT_Tree
 * \return ATtrue if #arg corresponds to the signature of a appl, or ATfalse otherwise
 */
inline ATbool PTPT_isTreeAppl(PTPT_Tree arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == PTPT_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == PTPT_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lit */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: appl */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun22) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
              /* checking for: cf */
              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                /* checking for: opt */
                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                  /* checking for: layout */
                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                      arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                      arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                      /* checking for: lit */
                      if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
                        ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                        /* checking for: ( */
                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun21) {
                          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                            arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                            arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                            /* checking for: cf */
                            if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                              ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                              /* checking for: opt */
                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                /* checking for: layout */
                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                  if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                    arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                    arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                    /* checking for: cf */
                                    if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                      ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                      /* checking for: sort */
                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun9) {
                                        ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                        /* checking for: Production */
                                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun20) {
                                          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                            arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                            arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                            /* checking for: cf */
                                            if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                              ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                              /* checking for: opt */
                                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                                ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                /* checking for: layout */
                                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                                  if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                    arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                    arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                    /* checking for: lit */
                                                    if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
                                                      ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                      /* checking for: , */
                                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun19) {
                                                        if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                          arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                          arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                          /* checking for: cf */
                                                          if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                                            ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                            /* checking for: opt */
                                                            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                                              ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                              /* checking for: layout */
                                                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                                                if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                                  arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                                  arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                                  /* checking for: cf */
                                                                  if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                                                    ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                                    /* checking for: sort */
                                                                    if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun9) {
                                                                      ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                                      /* checking for: Args */
                                                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun18) {
                                                                        if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                                          arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                                          arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                                          /* checking for: cf */
                                                                          if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                                                            ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                                            /* checking for: opt */
                                                                            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                                                              ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                                              /* checking for: layout */
                                                                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                                                                if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                                                  arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                                                  arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                                                  /* checking for: lit */
                                                                                  if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
                                                                                    ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                                                    /* checking for: ) */
                                                                                    if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun17) {
                                                                                      if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                                                                                        ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                                                                        /* checking for: cf */
                                                                                        if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == PTPT_afun2) {
                                                                                          ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                                                                          /* checking for: sort */
                                                                                          if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == PTPT_afun9) {
                                                                                            ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                                                                            /* checking for: Tree */
                                                                                            if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == PTPT_afun11) {
                                                                                              ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                                                                              /* checking for: attrs */
                                                                                              if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == PTPT_afun12) {
                                                                                                ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                                                                                if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                                                                                  ATerm arg_arg0_arg2_arg0_head;
                                                                                                  ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                                                                                  arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                                                                                  arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                                                                                  /* checking for: term */
                                                                                                  if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == PTPT_afun13) {
                                                                                                    ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                                                                                    /* checking for: cons */
                                                                                                    if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == PTPT_afun14) {
                                                                                                      ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                                                                                      /* checking for: appl */
                                                                                                      if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == PTPT_afun22) {
                                                                                                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                                                                          ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                                                                          if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                                                                            ATerm arg_arg1_head;
                                                                                                            ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                                                                            arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                            arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                            /* checking for: appl */
                                                                                                            if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                              ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                              /* checking for: prod */
                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                                                ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                  ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                  arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                  arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                  /* checking for: char-class */
                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                      ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 97) {

                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                            arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                            arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                            /* checking for: char-class */
                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 112) {

                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                      arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                      arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                      /* checking for: char-class */
                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                          ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                          arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                          arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 112) {

                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                                arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                /* checking for: char-class */
                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                    ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                    arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                    arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 108) {

                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                          ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                          /* checking for: lit */
                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                                            ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                            /* checking for: appl */
                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun22) {
                                                                                                                                                              ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                              /* checking for: no-attrs */
                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                                ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                  ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                  ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                  arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                  arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 97) {

                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                      arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                      arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 112) {

                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                          arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                          arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 112) {

                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                              arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                              arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 108) {

                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                    arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                      arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                                                                      arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                      /* checking for: appl */
                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                                                                                                        ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                                                                                        /* checking for: prod */
                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                                                                                                                          ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                                                                            ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                                                                            ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                                                                            arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                            arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                            /* checking for: char-class */
                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                                ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                                arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 40) {

                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                                                      ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                                                                      /* checking for: lit */
                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                                                        /* checking for: ( */
                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun21) {
                                                                                                                                                                                                          ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                                                          /* checking for: no-attrs */
                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                                                                            ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                                                              ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                                                              ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                                                              arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                              arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 40) {

                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                    arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                      arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                        arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                          arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                                                                                                          arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                          /* checking for: appl */
                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                                                                                                                                            ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                                                                                                                            /* checking for: prod */
                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                                                                                                                                                              ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                                                                                                                ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                                                                                                                ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                                                                                                                arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                /* checking for: char-class */
                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                                                                    ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                                                                    arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                    arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 44) {

                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                          ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                                                                                                          /* checking for: lit */
                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                                                                                                                            ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                                                                                            /* checking for: , */
                                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun19) {
                                                                                                                                                                                                                                              ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                                                                                              /* checking for: no-attrs */
                                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                                                                                                                ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                                                                                                  ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                                                                                                  ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                                                                                                  arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                  arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 44) {

                                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                        arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                          arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                            arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                              arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                                                                                                                                              arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                              /* checking for: appl */
                                                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                                                                                                                                                                                ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                                                                                                                                                                /* checking for: prod */
                                                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                                                                                                                                                                                                  ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                                                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                                                                                                                                                    ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                                                                                                                                                    arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                                                    arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                                                    /* checking for: char-class */
                                                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                                                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                                                                                                        ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                                                                                                        arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                                                        arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 41) {

                                                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                                                              ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                                                                                                                                              /* checking for: lit */
                                                                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                                                                                                                                                                ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                                                                                                                                /* checking for: ) */
                                                                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun17) {
                                                                                                                                                                                                                                                                                  ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                                                                                                                                  /* checking for: no-attrs */
                                                                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                                                                                                                                                    ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                                                                                                                                      ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                                                                                                                                      ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                                                                                                                                      arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                      arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 41) {

                                                                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                                                                                                                                                                                                            return ATtrue;
                                                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                }
                                                                                                                                                                                                                              }
                                                                                                                                                                                                                            }
                                                                                                                                                                                                                          }
                                                                                                                                                                                                                        }
                                                                                                                                                                                                                      }
                                                                                                                                                                                                                    }
                                                                                                                                                                                                                  }
                                                                                                                                                                                                                }
                                                                                                                                                                                                              }
                                                                                                                                                                                                            }
                                                                                                                                                                                                          }
                                                                                                                                                                                                        }
                                                                                                                                                                                                      }
                                                                                                                                                                                                    }
                                                                                                                                                                                                  }
                                                                                                                                                                                                }
                                                                                                                                                                                              }
                                                                                                                                                                                            }
                                                                                                                                                                                          }
                                                                                                                                                                                        }
                                                                                                                                                                                      }
                                                                                                                                                                                    }
                                                                                                                                                                                  }
                                                                                                                                                                                }
                                                                                                                                                                              }
                                                                                                                                                                            }
                                                                                                                                                                          }
                                                                                                                                                                        }
                                                                                                                                                                      }
                                                                                                                                                                    }
                                                                                                                                                                  }
                                                                                                                                                                }
                                                                                                                                                              }
                                                                                                                                                            }
                                                                                                                                                          }
                                                                                                                                                        }
                                                                                                                                                      }
                                                                                                                                                    }
                                                                                                                                                  }
                                                                                                                                                }
                                                                                                                                              }
                                                                                                                                            }
                                                                                                                                          }
                                                                                                                                        }
                                                                                                                                      }
                                                                                                                                    }
                                                                                                                                  }
                                                                                                                                }
                                                                                                                              }
                                                                                                                            }
                                                                                                                          }
                                                                                                                        }
                                                                                                                      }
                                                                                                                    }
                                                                                                                  }
                                                                                                                }
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Tree is a cycle by checking against the following ATerm pattern: appl(prod([lit("cycle"),cf(opt(layout)),lit("("),cf(opt(layout)),cf(sort("Symbol")),cf(opt(layout)),lit(","),cf(opt(layout)),cf(sort("NatCon")),cf(opt(layout)),lit(")")],cf(sort("Tree")),attrs([term(cons("cycle"))])),[appl(prod([char-class([99]),char-class([121]),char-class([99]),char-class([108]),char-class([101])],lit("cycle"),no-attrs),[99,121,99,108,101]),<"ws-after-cycle"("OptLayout")>,appl(prod([char-class([40])],lit("("),no-attrs),[40]),<"ws-after-("("OptLayout")>,<"symbol"("Symbol")>,<"ws-after-symbol"("OptLayout")>,appl(prod([char-class([44])],lit(","),no-attrs),[44]),<"ws-after-,"("OptLayout")>,<"length"("NatCon")>,<"ws-after-length"("OptLayout")>,appl(prod([char-class([41])],lit(")"),no-attrs),[41])]). May not be used to assert correctness of the PTPT_Tree
 * \param[in] arg input PTPT_Tree
 * \return ATtrue if #arg corresponds to the signature of a cycle, or ATfalse otherwise
 */
inline ATbool PTPT_isTreeCycle(PTPT_Tree arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == PTPT_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == PTPT_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lit */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: cycle */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun26) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
              /* checking for: cf */
              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                /* checking for: opt */
                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                  /* checking for: layout */
                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                      arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                      arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                      /* checking for: lit */
                      if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
                        ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                        /* checking for: ( */
                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun21) {
                          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                            arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                            arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                            /* checking for: cf */
                            if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                              ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                              /* checking for: opt */
                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                /* checking for: layout */
                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                  if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                    arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                    arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                    /* checking for: cf */
                                    if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                      ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                      /* checking for: sort */
                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun9) {
                                        ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                        /* checking for: Symbol */
                                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun25) {
                                          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                            arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                            arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                            /* checking for: cf */
                                            if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                              ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                              /* checking for: opt */
                                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                                ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                /* checking for: layout */
                                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                                  if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                    arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                    arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                    /* checking for: lit */
                                                    if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
                                                      ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                      /* checking for: , */
                                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun19) {
                                                        if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                          arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                          arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                          /* checking for: cf */
                                                          if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                                            ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                            /* checking for: opt */
                                                            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                                              ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                              /* checking for: layout */
                                                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                                                if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                                  arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                                  arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                                  /* checking for: cf */
                                                                  if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                                                    ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                                    /* checking for: sort */
                                                                    if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun9) {
                                                                      ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                                      /* checking for: NatCon */
                                                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun24) {
                                                                        if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                                          arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                                          arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                                          /* checking for: cf */
                                                                          if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                                                            ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                                            /* checking for: opt */
                                                                            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                                                              ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                                              /* checking for: layout */
                                                                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                                                                if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                                                  arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                                                  arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                                                  /* checking for: lit */
                                                                                  if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
                                                                                    ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                                                    /* checking for: ) */
                                                                                    if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun17) {
                                                                                      if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                                                                                        ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                                                                        /* checking for: cf */
                                                                                        if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == PTPT_afun2) {
                                                                                          ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                                                                          /* checking for: sort */
                                                                                          if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == PTPT_afun9) {
                                                                                            ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                                                                            /* checking for: Tree */
                                                                                            if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == PTPT_afun11) {
                                                                                              ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                                                                              /* checking for: attrs */
                                                                                              if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == PTPT_afun12) {
                                                                                                ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                                                                                if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                                                                                  ATerm arg_arg0_arg2_arg0_head;
                                                                                                  ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                                                                                  arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                                                                                  arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                                                                                  /* checking for: term */
                                                                                                  if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == PTPT_afun13) {
                                                                                                    ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                                                                                    /* checking for: cons */
                                                                                                    if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == PTPT_afun14) {
                                                                                                      ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                                                                                      /* checking for: cycle */
                                                                                                      if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == PTPT_afun26) {
                                                                                                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                                                                          ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                                                                          if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                                                                            ATerm arg_arg1_head;
                                                                                                            ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                                                                            arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                            arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                            /* checking for: appl */
                                                                                                            if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                              ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                              /* checking for: prod */
                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                                                ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                  ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                  arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                  arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                  /* checking for: char-class */
                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                      ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 99) {

                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                            arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                            arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                            /* checking for: char-class */
                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 121) {

                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                      arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                      arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                      /* checking for: char-class */
                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                          ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                          arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                          arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 99) {

                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                                arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                /* checking for: char-class */
                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                    ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                    arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                    arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 108) {

                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                                          arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                          arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                          /* checking for: char-class */
                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                              ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                              arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                              arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 101) {

                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                    ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                                    /* checking for: lit */
                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                                                      ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                      /* checking for: cycle */
                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun26) {
                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                        /* checking for: no-attrs */
                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                                          ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                            ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                            ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                            arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                            arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 99) {

                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 121) {

                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                    arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                    arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 99) {

                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                        arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                        arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 108) {

                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                            arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                            arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 101) {

                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                    arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                                                                                    arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                    /* checking for: appl */
                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                                                                                                                      ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                                                                                                      /* checking for: prod */
                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                                                                                          ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                                                                                          ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                                                                                          arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                          arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                          /* checking for: char-class */
                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                                              ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                                              arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                              arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 40) {

                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                                                                    ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                                                                                    /* checking for: lit */
                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                                                                                                      ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                                                                      /* checking for: ( */
                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun21) {
                                                                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                                                                        /* checking for: no-attrs */
                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                                                                                          ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                                                                            ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                                                                            ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                                                                            arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                            arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 40) {

                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                    arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                      arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                        arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                                                                                                                        arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                        /* checking for: appl */
                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                                                                                                                                                          ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                                                                                                                                          /* checking for: prod */
                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                                                                                                                                                                            ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                                                                                                                              ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                                                                                                                              ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                                                                                                                              arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                              arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                              /* checking for: char-class */
                                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                                                                                  ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 44) {

                                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                                                                                                                        /* checking for: lit */
                                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                                                                                                                                          ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                                                                                                          /* checking for: , */
                                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun19) {
                                                                                                                                                                                                                                                            ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                                                                                                            /* checking for: no-attrs */
                                                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                                                                                                                              ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                                                                                                                ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                                                                                                                ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                                                                                                                arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 44) {

                                                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                      arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                        arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                          arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                            arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                                                                                                                                                            arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                                            /* checking for: appl */
                                                                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                                                                                                                                                                                              ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                                                                                                                                                                              /* checking for: prod */
                                                                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                                                                                                                                                                                                                ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                                                                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                                                                                                                                                                  ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                                                                                                                                                                  arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                                                                  arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                                                                  /* checking for: char-class */
                                                                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                                                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                                                                                                                      ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 41) {

                                                                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                                                                            ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                                                                                                                                                            /* checking for: lit */
                                                                                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                                                                                                                                                                              ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                                                                                                                                              /* checking for: ) */
                                                                                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun17) {
                                                                                                                                                                                                                                                                                                ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                                                                                                                                                /* checking for: no-attrs */
                                                                                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                                                                                                                                                                  ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                                                                                                                                                    ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                                                                                                                                                    ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                                                                                                                                                    arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                                    arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 41) {

                                                                                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                                                                                                                                                                                                                          return ATtrue;
                                                                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                }
                                                                                                                                                                                                                              }
                                                                                                                                                                                                                            }
                                                                                                                                                                                                                          }
                                                                                                                                                                                                                        }
                                                                                                                                                                                                                      }
                                                                                                                                                                                                                    }
                                                                                                                                                                                                                  }
                                                                                                                                                                                                                }
                                                                                                                                                                                                              }
                                                                                                                                                                                                            }
                                                                                                                                                                                                          }
                                                                                                                                                                                                        }
                                                                                                                                                                                                      }
                                                                                                                                                                                                    }
                                                                                                                                                                                                  }
                                                                                                                                                                                                }
                                                                                                                                                                                              }
                                                                                                                                                                                            }
                                                                                                                                                                                          }
                                                                                                                                                                                        }
                                                                                                                                                                                      }
                                                                                                                                                                                    }
                                                                                                                                                                                  }
                                                                                                                                                                                }
                                                                                                                                                                              }
                                                                                                                                                                            }
                                                                                                                                                                          }
                                                                                                                                                                        }
                                                                                                                                                                      }
                                                                                                                                                                    }
                                                                                                                                                                  }
                                                                                                                                                                }
                                                                                                                                                              }
                                                                                                                                                            }
                                                                                                                                                          }
                                                                                                                                                        }
                                                                                                                                                      }
                                                                                                                                                    }
                                                                                                                                                  }
                                                                                                                                                }
                                                                                                                                              }
                                                                                                                                            }
                                                                                                                                          }
                                                                                                                                        }
                                                                                                                                      }
                                                                                                                                    }
                                                                                                                                  }
                                                                                                                                }
                                                                                                                              }
                                                                                                                            }
                                                                                                                          }
                                                                                                                        }
                                                                                                                      }
                                                                                                                    }
                                                                                                                  }
                                                                                                                }
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Tree is a amb by checking against the following ATerm pattern: appl(prod([lit("amb"),cf(opt(layout)),lit("("),cf(opt(layout)),cf(sort("Args")),cf(opt(layout)),lit(")")],cf(sort("Tree")),attrs([term(cons("amb"))])),[appl(prod([char-class([97]),char-class([109]),char-class([98])],lit("amb"),no-attrs),[97,109,98]),<"ws-after-amb"("OptLayout")>,appl(prod([char-class([40])],lit("("),no-attrs),[40]),<"ws-after-("("OptLayout")>,<"args"("Args")>,<"ws-after-args"("OptLayout")>,appl(prod([char-class([41])],lit(")"),no-attrs),[41])]). May not be used to assert correctness of the PTPT_Tree
 * \param[in] arg input PTPT_Tree
 * \return ATtrue if #arg corresponds to the signature of a amb, or ATfalse otherwise
 */
inline ATbool PTPT_isTreeAmb(PTPT_Tree arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == PTPT_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == PTPT_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lit */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: amb */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun27) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
              /* checking for: cf */
              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                /* checking for: opt */
                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                  /* checking for: layout */
                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                      arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                      arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                      /* checking for: lit */
                      if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
                        ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                        /* checking for: ( */
                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun21) {
                          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                            arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                            arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                            /* checking for: cf */
                            if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                              ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                              /* checking for: opt */
                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                /* checking for: layout */
                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                  if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                    arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                    arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                    /* checking for: cf */
                                    if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                      ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                      /* checking for: sort */
                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun9) {
                                        ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                        /* checking for: Args */
                                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun18) {
                                          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                            arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                            arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                            /* checking for: cf */
                                            if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                              ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                              /* checking for: opt */
                                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                                ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                /* checking for: layout */
                                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                                  if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                    arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                    arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                    /* checking for: lit */
                                                    if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
                                                      ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                      /* checking for: ) */
                                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun17) {
                                                        if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                                                          ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                                          /* checking for: cf */
                                                          if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == PTPT_afun2) {
                                                            ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                                            /* checking for: sort */
                                                            if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == PTPT_afun9) {
                                                              ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                                              /* checking for: Tree */
                                                              if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == PTPT_afun11) {
                                                                ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                                                /* checking for: attrs */
                                                                if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == PTPT_afun12) {
                                                                  ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                                                  if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                                                    ATerm arg_arg0_arg2_arg0_head;
                                                                    ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                                                    arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                                                    arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                                                    /* checking for: term */
                                                                    if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == PTPT_afun13) {
                                                                      ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                                                      /* checking for: cons */
                                                                      if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == PTPT_afun14) {
                                                                        ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                                                        /* checking for: amb */
                                                                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == PTPT_afun27) {
                                                                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                                            ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                                            if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                                              ATerm arg_arg1_head;
                                                                              ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                                              arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                              arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                              /* checking for: appl */
                                                                              if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                /* checking for: prod */
                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                  ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                    ATerm arg_arg1_head_arg0_arg0_head;
                                                                                    ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                    arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                    arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                    /* checking for: char-class */
                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                        ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                        arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                        arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 97) {

                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                              arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                              arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                              /* checking for: char-class */
                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                  ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 109) {

                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                        arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                        arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                        /* checking for: char-class */
                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                            ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                            arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                            arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 98) {

                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                  ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                  /* checking for: lit */
                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                    ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                    /* checking for: amb */
                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun27) {
                                                                                                                      ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                      /* checking for: no-attrs */
                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                        ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                          ATerm arg_arg1_head_arg1_head;
                                                                                                                          ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                          arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                          arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 97) {

                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                              arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                              arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 109) {

                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                  arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                  arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 98) {

                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                      if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                        arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                          arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                          arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                          /* checking for: appl */
                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                                                            ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                                            /* checking for: prod */
                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                                                                              ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                                ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                                ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                                arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                /* checking for: char-class */
                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                    ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                    arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                    arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 40) {

                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                          ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                          /* checking for: lit */
                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                                            ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                            /* checking for: ( */
                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun21) {
                                                                                                                                                              ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                              /* checking for: no-attrs */
                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                                ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                  ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                  ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                  arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                  arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 40) {

                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                        arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                          arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                            arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                              arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                                                              arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                              /* checking for: appl */
                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                                                                                                ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                                                                                /* checking for: prod */
                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                                                                                                                  ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                                                                    ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                                                                    arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                    arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                    /* checking for: char-class */
                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                        ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                        arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                        arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 41) {

                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                                              ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                                                              /* checking for: lit */
                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                                                                                ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                                                /* checking for: ) */
                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun17) {
                                                                                                                                                                                                  ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                                                  /* checking for: no-attrs */
                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                                                                    ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                                                      ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                                                      ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                                                      arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                      arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 41) {

                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                                                                                                                            return ATtrue;
                                                                                                                                                                                                          }
                                                                                                                                                                                                        }
                                                                                                                                                                                                      }
                                                                                                                                                                                                    }
                                                                                                                                                                                                  }
                                                                                                                                                                                                }
                                                                                                                                                                                              }
                                                                                                                                                                                            }
                                                                                                                                                                                          }
                                                                                                                                                                                        }
                                                                                                                                                                                      }
                                                                                                                                                                                    }
                                                                                                                                                                                  }
                                                                                                                                                                                }
                                                                                                                                                                              }
                                                                                                                                                                            }
                                                                                                                                                                          }
                                                                                                                                                                        }
                                                                                                                                                                      }
                                                                                                                                                                    }
                                                                                                                                                                  }
                                                                                                                                                                }
                                                                                                                                                              }
                                                                                                                                                            }
                                                                                                                                                          }
                                                                                                                                                        }
                                                                                                                                                      }
                                                                                                                                                    }
                                                                                                                                                  }
                                                                                                                                                }
                                                                                                                                              }
                                                                                                                                            }
                                                                                                                                          }
                                                                                                                                        }
                                                                                                                                      }
                                                                                                                                    }
                                                                                                                                  }
                                                                                                                                }
                                                                                                                              }
                                                                                                                            }
                                                                                                                          }
                                                                                                                        }
                                                                                                                      }
                                                                                                                    }
                                                                                                                  }
                                                                                                                }
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Tree is a char by checking against the following ATerm pattern: appl(prod([cf(sort("NatCon"))],cf(sort("Tree")),attrs([term(cons("char"))])),[<"character"("NatCon")>]). May not be used to assert correctness of the PTPT_Tree
 * \param[in] arg input PTPT_Tree
 * \return ATtrue if #arg corresponds to the signature of a char, or ATfalse otherwise
 */
inline ATbool PTPT_isTreeChar(PTPT_Tree arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == PTPT_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == PTPT_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: cf */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: sort */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun9) {
            ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
            /* checking for: NatCon */
            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun24) {
              if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                /* checking for: cf */
                if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == PTPT_afun2) {
                  ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                  /* checking for: sort */
                  if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == PTPT_afun9) {
                    ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                    /* checking for: Tree */
                    if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == PTPT_afun11) {
                      ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                      /* checking for: attrs */
                      if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == PTPT_afun12) {
                        ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                        if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                          ATerm arg_arg0_arg2_arg0_head;
                          ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                          arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                          arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                          /* checking for: term */
                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == PTPT_afun13) {
                            ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                            /* checking for: cons */
                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == PTPT_afun14) {
                              ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                              /* checking for: char */
                              if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == PTPT_afun28) {
                                if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                  ATerm arg_arg1 = ATgetArgument(arg, 1);
                                  if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                    ATermList arg_arg1_list = (ATermList)arg_arg1;
                                    arg_arg1_list = ATgetNext(arg_arg1_list);
                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                      return ATtrue;
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Tree has a Tree. 
 * \param[in] arg input PTPT_Tree
 * \return ATtrue if the PTPT_Tree had a Tree, or ATfalse otherwise
 */
ATbool PTPT_hasTreeTree(PTPT_Tree arg) {
  if (PTPT_isTreeAnnotated(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Tree has a ws-after-Tree. 
 * \param[in] arg input PTPT_Tree
 * \return ATtrue if the PTPT_Tree had a ws-after-Tree, or ATfalse otherwise
 */
ATbool PTPT_hasTreeWsAfterTree(PTPT_Tree arg) {
  if (PTPT_isTreeAnnotated(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Tree has a Annotation. 
 * \param[in] arg input PTPT_Tree
 * \return ATtrue if the PTPT_Tree had a Annotation, or ATfalse otherwise
 */
ATbool PTPT_hasTreeAnnotation(PTPT_Tree arg) {
  if (PTPT_isTreeAnnotated(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Tree has a ws-after-appl. 
 * \param[in] arg input PTPT_Tree
 * \return ATtrue if the PTPT_Tree had a ws-after-appl, or ATfalse otherwise
 */
ATbool PTPT_hasTreeWsAfterAppl(PTPT_Tree arg) {
  if (PTPT_isTreeAppl(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Tree has a ws-after-(. 
 * \param[in] arg input PTPT_Tree
 * \return ATtrue if the PTPT_Tree had a ws-after-(, or ATfalse otherwise
 */
ATbool PTPT_hasTreeWsAfterParenOpen(PTPT_Tree arg) {
  if (PTPT_isTreeAppl(arg)) {
    return ATtrue;
  }
  else if (PTPT_isTreeCycle(arg)) {
    return ATtrue;
  }
  else if (PTPT_isTreeAmb(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Tree has a prod. 
 * \param[in] arg input PTPT_Tree
 * \return ATtrue if the PTPT_Tree had a prod, or ATfalse otherwise
 */
ATbool PTPT_hasTreeProd(PTPT_Tree arg) {
  if (PTPT_isTreeAppl(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Tree has a ws-after-prod. 
 * \param[in] arg input PTPT_Tree
 * \return ATtrue if the PTPT_Tree had a ws-after-prod, or ATfalse otherwise
 */
ATbool PTPT_hasTreeWsAfterProd(PTPT_Tree arg) {
  if (PTPT_isTreeAppl(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Tree has a ws-after-,. 
 * \param[in] arg input PTPT_Tree
 * \return ATtrue if the PTPT_Tree had a ws-after-,, or ATfalse otherwise
 */
ATbool PTPT_hasTreeWsAfterComma(PTPT_Tree arg) {
  if (PTPT_isTreeAppl(arg)) {
    return ATtrue;
  }
  else if (PTPT_isTreeCycle(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Tree has a args. 
 * \param[in] arg input PTPT_Tree
 * \return ATtrue if the PTPT_Tree had a args, or ATfalse otherwise
 */
ATbool PTPT_hasTreeArgs(PTPT_Tree arg) {
  if (PTPT_isTreeAppl(arg)) {
    return ATtrue;
  }
  else if (PTPT_isTreeAmb(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Tree has a ws-after-args. 
 * \param[in] arg input PTPT_Tree
 * \return ATtrue if the PTPT_Tree had a ws-after-args, or ATfalse otherwise
 */
ATbool PTPT_hasTreeWsAfterArgs(PTPT_Tree arg) {
  if (PTPT_isTreeAppl(arg)) {
    return ATtrue;
  }
  else if (PTPT_isTreeAmb(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Tree has a ws-after-cycle. 
 * \param[in] arg input PTPT_Tree
 * \return ATtrue if the PTPT_Tree had a ws-after-cycle, or ATfalse otherwise
 */
ATbool PTPT_hasTreeWsAfterCycle(PTPT_Tree arg) {
  if (PTPT_isTreeCycle(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Tree has a symbol. 
 * \param[in] arg input PTPT_Tree
 * \return ATtrue if the PTPT_Tree had a symbol, or ATfalse otherwise
 */
ATbool PTPT_hasTreeSymbol(PTPT_Tree arg) {
  if (PTPT_isTreeCycle(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Tree has a ws-after-symbol. 
 * \param[in] arg input PTPT_Tree
 * \return ATtrue if the PTPT_Tree had a ws-after-symbol, or ATfalse otherwise
 */
ATbool PTPT_hasTreeWsAfterSymbol(PTPT_Tree arg) {
  if (PTPT_isTreeCycle(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Tree has a length. 
 * \param[in] arg input PTPT_Tree
 * \return ATtrue if the PTPT_Tree had a length, or ATfalse otherwise
 */
ATbool PTPT_hasTreeLength(PTPT_Tree arg) {
  if (PTPT_isTreeCycle(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Tree has a ws-after-length. 
 * \param[in] arg input PTPT_Tree
 * \return ATtrue if the PTPT_Tree had a ws-after-length, or ATfalse otherwise
 */
ATbool PTPT_hasTreeWsAfterLength(PTPT_Tree arg) {
  if (PTPT_isTreeCycle(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Tree has a ws-after-amb. 
 * \param[in] arg input PTPT_Tree
 * \return ATtrue if the PTPT_Tree had a ws-after-amb, or ATfalse otherwise
 */
ATbool PTPT_hasTreeWsAfterAmb(PTPT_Tree arg) {
  if (PTPT_isTreeAmb(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Tree has a character. 
 * \param[in] arg input PTPT_Tree
 * \return ATtrue if the PTPT_Tree had a character, or ATfalse otherwise
 */
ATbool PTPT_hasTreeCharacter(PTPT_Tree arg) {
  if (PTPT_isTreeChar(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Get the Tree PTPT_Tree of a PTPT_Tree. Note that the precondition is that this PTPT_Tree actually has a Tree
 * \param[in] arg input PTPT_Tree
 * \return the Tree of #arg, if it exist or an undefined value if it does not
 */
PTPT_Tree PTPT_getTreeTree(PTPT_Tree arg) {
  
    return (PTPT_Tree)ATgetFirst((ATermList)ATgetArgument((ATermAppl)arg, 1));
}

/**
 * Get the ws-after-Tree PTPT_OptLayout of a PTPT_Tree. Note that the precondition is that this PTPT_Tree actually has a ws-after-Tree
 * \param[in] arg input PTPT_Tree
 * \return the ws-after-Tree of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getTreeWsAfterTree(PTPT_Tree arg) {
  
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1);
}

/**
 * Get the Annotation PTPT_Annotation of a PTPT_Tree. Note that the precondition is that this PTPT_Tree actually has a Annotation
 * \param[in] arg input PTPT_Tree
 * \return the Annotation of #arg, if it exist or an undefined value if it does not
 */
PTPT_Annotation PTPT_getTreeAnnotation(PTPT_Tree arg) {
  
    return (PTPT_Annotation)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 2);
}

/**
 * Get the ws-after-appl PTPT_OptLayout of a PTPT_Tree. Note that the precondition is that this PTPT_Tree actually has a ws-after-appl
 * \param[in] arg input PTPT_Tree
 * \return the ws-after-appl of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getTreeWsAfterAppl(PTPT_Tree arg) {
  
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1);
}

/**
 * Get the ws-after-( PTPT_OptLayout of a PTPT_Tree. Note that the precondition is that this PTPT_Tree actually has a ws-after-(
 * \param[in] arg input PTPT_Tree
 * \return the ws-after-( of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getTreeWsAfterParenOpen(PTPT_Tree arg) {
  if (PTPT_isTreeAppl(arg)) {
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 3);
  }
  else if (PTPT_isTreeCycle(arg)) {
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 3);
  }
  else 
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 3);
}

/**
 * Get the prod PTPT_Production of a PTPT_Tree. Note that the precondition is that this PTPT_Tree actually has a prod
 * \param[in] arg input PTPT_Tree
 * \return the prod of #arg, if it exist or an undefined value if it does not
 */
PTPT_Production PTPT_getTreeProd(PTPT_Tree arg) {
  
    return (PTPT_Production)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 4);
}

/**
 * Get the ws-after-prod PTPT_OptLayout of a PTPT_Tree. Note that the precondition is that this PTPT_Tree actually has a ws-after-prod
 * \param[in] arg input PTPT_Tree
 * \return the ws-after-prod of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getTreeWsAfterProd(PTPT_Tree arg) {
  
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 5);
}

/**
 * Get the ws-after-, PTPT_OptLayout of a PTPT_Tree. Note that the precondition is that this PTPT_Tree actually has a ws-after-,
 * \param[in] arg input PTPT_Tree
 * \return the ws-after-, of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getTreeWsAfterComma(PTPT_Tree arg) {
  if (PTPT_isTreeAppl(arg)) {
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 7);
  }
  else 
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 7);
}

/**
 * Get the args PTPT_Args of a PTPT_Tree. Note that the precondition is that this PTPT_Tree actually has a args
 * \param[in] arg input PTPT_Tree
 * \return the args of #arg, if it exist or an undefined value if it does not
 */
PTPT_Args PTPT_getTreeArgs(PTPT_Tree arg) {
  if (PTPT_isTreeAppl(arg)) {
    return (PTPT_Args)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 8);
  }
  else 
    return (PTPT_Args)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 4);
}

/**
 * Get the ws-after-args PTPT_OptLayout of a PTPT_Tree. Note that the precondition is that this PTPT_Tree actually has a ws-after-args
 * \param[in] arg input PTPT_Tree
 * \return the ws-after-args of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getTreeWsAfterArgs(PTPT_Tree arg) {
  if (PTPT_isTreeAppl(arg)) {
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 9);
  }
  else 
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 5);
}

/**
 * Get the ws-after-cycle PTPT_OptLayout of a PTPT_Tree. Note that the precondition is that this PTPT_Tree actually has a ws-after-cycle
 * \param[in] arg input PTPT_Tree
 * \return the ws-after-cycle of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getTreeWsAfterCycle(PTPT_Tree arg) {
  
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1);
}

/**
 * Get the symbol PTPT_Symbol of a PTPT_Tree. Note that the precondition is that this PTPT_Tree actually has a symbol
 * \param[in] arg input PTPT_Tree
 * \return the symbol of #arg, if it exist or an undefined value if it does not
 */
PTPT_Symbol PTPT_getTreeSymbol(PTPT_Tree arg) {
  
    return (PTPT_Symbol)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 4);
}

/**
 * Get the ws-after-symbol PTPT_OptLayout of a PTPT_Tree. Note that the precondition is that this PTPT_Tree actually has a ws-after-symbol
 * \param[in] arg input PTPT_Tree
 * \return the ws-after-symbol of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getTreeWsAfterSymbol(PTPT_Tree arg) {
  
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 5);
}

/**
 * Get the length PTPT_NatCon of a PTPT_Tree. Note that the precondition is that this PTPT_Tree actually has a length
 * \param[in] arg input PTPT_Tree
 * \return the length of #arg, if it exist or an undefined value if it does not
 */
PTPT_NatCon PTPT_getTreeLength(PTPT_Tree arg) {
  
    return (PTPT_NatCon)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 8);
}

/**
 * Get the ws-after-length PTPT_OptLayout of a PTPT_Tree. Note that the precondition is that this PTPT_Tree actually has a ws-after-length
 * \param[in] arg input PTPT_Tree
 * \return the ws-after-length of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getTreeWsAfterLength(PTPT_Tree arg) {
  
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 9);
}

/**
 * Get the ws-after-amb PTPT_OptLayout of a PTPT_Tree. Note that the precondition is that this PTPT_Tree actually has a ws-after-amb
 * \param[in] arg input PTPT_Tree
 * \return the ws-after-amb of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getTreeWsAfterAmb(PTPT_Tree arg) {
  
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1);
}

/**
 * Get the character PTPT_NatCon of a PTPT_Tree. Note that the precondition is that this PTPT_Tree actually has a character
 * \param[in] arg input PTPT_Tree
 * \return the character of #arg, if it exist or an undefined value if it does not
 */
PTPT_NatCon PTPT_getTreeCharacter(PTPT_Tree arg) {
  
    return (PTPT_NatCon)ATgetFirst((ATermList)ATgetArgument((ATermAppl)arg, 1));
}

/**
 * Set the Tree of a PTPT_Tree. The precondition being that this PTPT_Tree actually has a Tree
 * \param[in] arg input PTPT_Tree
 * \param[in] Tree new PTPT_Tree to set in #arg
 * \return A new PTPT_Tree with Tree at the right place, or a core dump if #arg did not have a Tree
 */
PTPT_Tree PTPT_setTreeTree(PTPT_Tree arg, PTPT_Tree Tree) {
  if (PTPT_isTreeAnnotated(arg)) {
    return (PTPT_Tree)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) Tree), 0), 1);
  }

  ATabort("Tree has no Tree: %t\n", arg);
  return (PTPT_Tree)NULL;
}

/**
 * Set the ws-after-Tree of a PTPT_Tree. The precondition being that this PTPT_Tree actually has a ws-after-Tree
 * \param[in] arg input PTPT_Tree
 * \param[in] wsAfterTree new PTPT_OptLayout to set in #arg
 * \return A new PTPT_Tree with wsAfterTree at the right place, or a core dump if #arg did not have a wsAfterTree
 */
PTPT_Tree PTPT_setTreeWsAfterTree(PTPT_Tree arg, PTPT_OptLayout wsAfterTree) {
  if (PTPT_isTreeAnnotated(arg)) {
    return (PTPT_Tree)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterTree), 1), 1);
  }

  ATabort("Tree has no WsAfterTree: %t\n", arg);
  return (PTPT_Tree)NULL;
}

/**
 * Set the Annotation of a PTPT_Tree. The precondition being that this PTPT_Tree actually has a Annotation
 * \param[in] arg input PTPT_Tree
 * \param[in] Annotation new PTPT_Annotation to set in #arg
 * \return A new PTPT_Tree with Annotation at the right place, or a core dump if #arg did not have a Annotation
 */
PTPT_Tree PTPT_setTreeAnnotation(PTPT_Tree arg, PTPT_Annotation Annotation) {
  if (PTPT_isTreeAnnotated(arg)) {
    return (PTPT_Tree)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) Annotation), 2), 1);
  }

  ATabort("Tree has no Annotation: %t\n", arg);
  return (PTPT_Tree)NULL;
}

/**
 * Set the ws-after-appl of a PTPT_Tree. The precondition being that this PTPT_Tree actually has a ws-after-appl
 * \param[in] arg input PTPT_Tree
 * \param[in] wsAfterAppl new PTPT_OptLayout to set in #arg
 * \return A new PTPT_Tree with wsAfterAppl at the right place, or a core dump if #arg did not have a wsAfterAppl
 */
PTPT_Tree PTPT_setTreeWsAfterAppl(PTPT_Tree arg, PTPT_OptLayout wsAfterAppl) {
  if (PTPT_isTreeAppl(arg)) {
    return (PTPT_Tree)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterAppl), 1), 1);
  }

  ATabort("Tree has no WsAfterAppl: %t\n", arg);
  return (PTPT_Tree)NULL;
}

/**
 * Set the ws-after-( of a PTPT_Tree. The precondition being that this PTPT_Tree actually has a ws-after-(
 * \param[in] arg input PTPT_Tree
 * \param[in] wsAfterParenOpen new PTPT_OptLayout to set in #arg
 * \return A new PTPT_Tree with wsAfterParenOpen at the right place, or a core dump if #arg did not have a wsAfterParenOpen
 */
PTPT_Tree PTPT_setTreeWsAfterParenOpen(PTPT_Tree arg, PTPT_OptLayout wsAfterParenOpen) {
  if (PTPT_isTreeAppl(arg)) {
    return (PTPT_Tree)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterParenOpen), 3), 1);
  }
  else if (PTPT_isTreeCycle(arg)) {
    return (PTPT_Tree)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterParenOpen), 3), 1);
  }
  else if (PTPT_isTreeAmb(arg)) {
    return (PTPT_Tree)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterParenOpen), 3), 1);
  }

  ATabort("Tree has no WsAfterParenOpen: %t\n", arg);
  return (PTPT_Tree)NULL;
}

/**
 * Set the prod of a PTPT_Tree. The precondition being that this PTPT_Tree actually has a prod
 * \param[in] arg input PTPT_Tree
 * \param[in] prod new PTPT_Production to set in #arg
 * \return A new PTPT_Tree with prod at the right place, or a core dump if #arg did not have a prod
 */
PTPT_Tree PTPT_setTreeProd(PTPT_Tree arg, PTPT_Production prod) {
  if (PTPT_isTreeAppl(arg)) {
    return (PTPT_Tree)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) prod), 4), 1);
  }

  ATabort("Tree has no Prod: %t\n", arg);
  return (PTPT_Tree)NULL;
}

/**
 * Set the ws-after-prod of a PTPT_Tree. The precondition being that this PTPT_Tree actually has a ws-after-prod
 * \param[in] arg input PTPT_Tree
 * \param[in] wsAfterProd new PTPT_OptLayout to set in #arg
 * \return A new PTPT_Tree with wsAfterProd at the right place, or a core dump if #arg did not have a wsAfterProd
 */
PTPT_Tree PTPT_setTreeWsAfterProd(PTPT_Tree arg, PTPT_OptLayout wsAfterProd) {
  if (PTPT_isTreeAppl(arg)) {
    return (PTPT_Tree)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterProd), 5), 1);
  }

  ATabort("Tree has no WsAfterProd: %t\n", arg);
  return (PTPT_Tree)NULL;
}

/**
 * Set the ws-after-, of a PTPT_Tree. The precondition being that this PTPT_Tree actually has a ws-after-,
 * \param[in] arg input PTPT_Tree
 * \param[in] wsAfterComma new PTPT_OptLayout to set in #arg
 * \return A new PTPT_Tree with wsAfterComma at the right place, or a core dump if #arg did not have a wsAfterComma
 */
PTPT_Tree PTPT_setTreeWsAfterComma(PTPT_Tree arg, PTPT_OptLayout wsAfterComma) {
  if (PTPT_isTreeAppl(arg)) {
    return (PTPT_Tree)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterComma), 7), 1);
  }
  else if (PTPT_isTreeCycle(arg)) {
    return (PTPT_Tree)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterComma), 7), 1);
  }

  ATabort("Tree has no WsAfterComma: %t\n", arg);
  return (PTPT_Tree)NULL;
}

/**
 * Set the args of a PTPT_Tree. The precondition being that this PTPT_Tree actually has a args
 * \param[in] arg input PTPT_Tree
 * \param[in] args new PTPT_Args to set in #arg
 * \return A new PTPT_Tree with args at the right place, or a core dump if #arg did not have a args
 */
PTPT_Tree PTPT_setTreeArgs(PTPT_Tree arg, PTPT_Args args) {
  if (PTPT_isTreeAppl(arg)) {
    return (PTPT_Tree)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) args), 8), 1);
  }
  else if (PTPT_isTreeAmb(arg)) {
    return (PTPT_Tree)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) args), 4), 1);
  }

  ATabort("Tree has no Args: %t\n", arg);
  return (PTPT_Tree)NULL;
}

/**
 * Set the ws-after-args of a PTPT_Tree. The precondition being that this PTPT_Tree actually has a ws-after-args
 * \param[in] arg input PTPT_Tree
 * \param[in] wsAfterArgs new PTPT_OptLayout to set in #arg
 * \return A new PTPT_Tree with wsAfterArgs at the right place, or a core dump if #arg did not have a wsAfterArgs
 */
PTPT_Tree PTPT_setTreeWsAfterArgs(PTPT_Tree arg, PTPT_OptLayout wsAfterArgs) {
  if (PTPT_isTreeAppl(arg)) {
    return (PTPT_Tree)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterArgs), 9), 1);
  }
  else if (PTPT_isTreeAmb(arg)) {
    return (PTPT_Tree)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterArgs), 5), 1);
  }

  ATabort("Tree has no WsAfterArgs: %t\n", arg);
  return (PTPT_Tree)NULL;
}

/**
 * Set the ws-after-cycle of a PTPT_Tree. The precondition being that this PTPT_Tree actually has a ws-after-cycle
 * \param[in] arg input PTPT_Tree
 * \param[in] wsAfterCycle new PTPT_OptLayout to set in #arg
 * \return A new PTPT_Tree with wsAfterCycle at the right place, or a core dump if #arg did not have a wsAfterCycle
 */
PTPT_Tree PTPT_setTreeWsAfterCycle(PTPT_Tree arg, PTPT_OptLayout wsAfterCycle) {
  if (PTPT_isTreeCycle(arg)) {
    return (PTPT_Tree)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterCycle), 1), 1);
  }

  ATabort("Tree has no WsAfterCycle: %t\n", arg);
  return (PTPT_Tree)NULL;
}

/**
 * Set the symbol of a PTPT_Tree. The precondition being that this PTPT_Tree actually has a symbol
 * \param[in] arg input PTPT_Tree
 * \param[in] symbol new PTPT_Symbol to set in #arg
 * \return A new PTPT_Tree with symbol at the right place, or a core dump if #arg did not have a symbol
 */
PTPT_Tree PTPT_setTreeSymbol(PTPT_Tree arg, PTPT_Symbol symbol) {
  if (PTPT_isTreeCycle(arg)) {
    return (PTPT_Tree)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) symbol), 4), 1);
  }

  ATabort("Tree has no Symbol: %t\n", arg);
  return (PTPT_Tree)NULL;
}

/**
 * Set the ws-after-symbol of a PTPT_Tree. The precondition being that this PTPT_Tree actually has a ws-after-symbol
 * \param[in] arg input PTPT_Tree
 * \param[in] wsAfterSymbol new PTPT_OptLayout to set in #arg
 * \return A new PTPT_Tree with wsAfterSymbol at the right place, or a core dump if #arg did not have a wsAfterSymbol
 */
PTPT_Tree PTPT_setTreeWsAfterSymbol(PTPT_Tree arg, PTPT_OptLayout wsAfterSymbol) {
  if (PTPT_isTreeCycle(arg)) {
    return (PTPT_Tree)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterSymbol), 5), 1);
  }

  ATabort("Tree has no WsAfterSymbol: %t\n", arg);
  return (PTPT_Tree)NULL;
}

/**
 * Set the length of a PTPT_Tree. The precondition being that this PTPT_Tree actually has a length
 * \param[in] arg input PTPT_Tree
 * \param[in] length new PTPT_NatCon to set in #arg
 * \return A new PTPT_Tree with length at the right place, or a core dump if #arg did not have a length
 */
PTPT_Tree PTPT_setTreeLength(PTPT_Tree arg, PTPT_NatCon length) {
  if (PTPT_isTreeCycle(arg)) {
    return (PTPT_Tree)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) length), 8), 1);
  }

  ATabort("Tree has no Length: %t\n", arg);
  return (PTPT_Tree)NULL;
}

/**
 * Set the ws-after-length of a PTPT_Tree. The precondition being that this PTPT_Tree actually has a ws-after-length
 * \param[in] arg input PTPT_Tree
 * \param[in] wsAfterLength new PTPT_OptLayout to set in #arg
 * \return A new PTPT_Tree with wsAfterLength at the right place, or a core dump if #arg did not have a wsAfterLength
 */
PTPT_Tree PTPT_setTreeWsAfterLength(PTPT_Tree arg, PTPT_OptLayout wsAfterLength) {
  if (PTPT_isTreeCycle(arg)) {
    return (PTPT_Tree)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterLength), 9), 1);
  }

  ATabort("Tree has no WsAfterLength: %t\n", arg);
  return (PTPT_Tree)NULL;
}

/**
 * Set the ws-after-amb of a PTPT_Tree. The precondition being that this PTPT_Tree actually has a ws-after-amb
 * \param[in] arg input PTPT_Tree
 * \param[in] wsAfterAmb new PTPT_OptLayout to set in #arg
 * \return A new PTPT_Tree with wsAfterAmb at the right place, or a core dump if #arg did not have a wsAfterAmb
 */
PTPT_Tree PTPT_setTreeWsAfterAmb(PTPT_Tree arg, PTPT_OptLayout wsAfterAmb) {
  if (PTPT_isTreeAmb(arg)) {
    return (PTPT_Tree)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterAmb), 1), 1);
  }

  ATabort("Tree has no WsAfterAmb: %t\n", arg);
  return (PTPT_Tree)NULL;
}

/**
 * Set the character of a PTPT_Tree. The precondition being that this PTPT_Tree actually has a character
 * \param[in] arg input PTPT_Tree
 * \param[in] character new PTPT_NatCon to set in #arg
 * \return A new PTPT_Tree with character at the right place, or a core dump if #arg did not have a character
 */
PTPT_Tree PTPT_setTreeCharacter(PTPT_Tree arg, PTPT_NatCon character) {
  if (PTPT_isTreeChar(arg)) {
    return (PTPT_Tree)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) character), 0), 1);
  }

  ATabort("Tree has no Character: %t\n", arg);
  return (PTPT_Tree)NULL;
}

/**
 * Assert whether a PTPT_Attributes is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input PTPT_Attributes
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool PTPT_isValidAttributes(PTPT_Attributes arg) {
  if (PTPT_isAttributesNoAttrs(arg)) {
    return ATtrue;
  }
  else if (PTPT_isAttributesAttrs(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Attributes is a no-attrs by checking against the following ATerm pattern: appl(prod([lit("no-attrs")],cf(sort("Attributes")),attrs([term(cons("no-attrs"))])),[appl(prod([char-class([110]),char-class([111]),char-class([45]),char-class([97]),char-class([116]),char-class([116]),char-class([114]),char-class([115])],lit("no-attrs"),no-attrs),[110,111,45,97,116,116,114,115])]). May not be used to assert correctness of the PTPT_Attributes
 * \param[in] arg input PTPT_Attributes
 * \return ATtrue if #arg corresponds to the signature of a no-attrs, or ATfalse otherwise
 */
inline ATbool PTPT_isAttributesNoAttrs(PTPT_Attributes arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == PTPT_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == PTPT_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lit */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: no-attrs */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun29) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
              ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
              /* checking for: cf */
              if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == PTPT_afun2) {
                ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                /* checking for: sort */
                if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == PTPT_afun9) {
                  ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                  /* checking for: Attributes */
                  if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == PTPT_afun30) {
                    ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                    /* checking for: attrs */
                    if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == PTPT_afun12) {
                      ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                      if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                        ATerm arg_arg0_arg2_arg0_head;
                        ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                        arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                        arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                        /* checking for: term */
                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == PTPT_afun13) {
                          ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                          /* checking for: cons */
                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == PTPT_afun14) {
                            ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                            /* checking for: no-attrs */
                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == PTPT_afun29) {
                              if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                ATerm arg_arg1 = ATgetArgument(arg, 1);
                                if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                  ATerm arg_arg1_head;
                                  ATermList arg_arg1_list = (ATermList)arg_arg1;
                                  arg_arg1_head = ATgetFirst(arg_arg1_list);
                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                  /* checking for: appl */
                                  if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                    ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                    /* checking for: prod */
                                    if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                      ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                        ATerm arg_arg1_head_arg0_arg0_head;
                                        ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                        arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                        arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                        /* checking for: char-class */
                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                          ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                            ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                            ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                            arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                            arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                            if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 110) {

                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                  arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                  arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                  /* checking for: char-class */
                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                      ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                      arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                      arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 111) {

                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                            arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                            arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                            /* checking for: char-class */
                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 45) {

                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                      arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                      arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                      /* checking for: char-class */
                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                          ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                          arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                          arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 97) {

                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                /* checking for: char-class */
                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                    ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                    arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                    arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 116) {

                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                          arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                          arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                          /* checking for: char-class */
                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                              ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                              arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                              arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 116) {

                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                    arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                    arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                    /* checking for: char-class */
                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                        ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                        arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                        arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 114) {

                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                              arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                              arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                              /* checking for: char-class */
                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                  ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 115) {

                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                        ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                        /* checking for: lit */
                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                          ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                          /* checking for: no-attrs */
                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun29) {
                                                                                                                            ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                            /* checking for: no-attrs */
                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                              ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                ATerm arg_arg1_head_arg1_head;
                                                                                                                                ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 110) {

                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                    arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                    arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 111) {

                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                        arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                        arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 45) {

                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                            arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                            arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 97) {

                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 116) {

                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                    arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                    arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 116) {

                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                        arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                        arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 114) {

                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                            arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                            arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 115) {

                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                                                                                  return ATtrue;
                                                                                                                                                                }
                                                                                                                                                              }
                                                                                                                                                            }
                                                                                                                                                          }
                                                                                                                                                        }
                                                                                                                                                      }
                                                                                                                                                    }
                                                                                                                                                  }
                                                                                                                                                }
                                                                                                                                              }
                                                                                                                                            }
                                                                                                                                          }
                                                                                                                                        }
                                                                                                                                      }
                                                                                                                                    }
                                                                                                                                  }
                                                                                                                                }
                                                                                                                              }
                                                                                                                            }
                                                                                                                          }
                                                                                                                        }
                                                                                                                      }
                                                                                                                    }
                                                                                                                  }
                                                                                                                }
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Attributes is a attrs by checking against the following ATerm pattern: appl(prod([lit("attrs"),cf(opt(layout)),lit("("),cf(opt(layout)),cf(sort("Attrs")),cf(opt(layout)),lit(")")],cf(sort("Attributes")),attrs([term(cons("attrs"))])),[appl(prod([char-class([97]),char-class([116]),char-class([116]),char-class([114]),char-class([115])],lit("attrs"),no-attrs),[97,116,116,114,115]),<"ws-after-attrs"("OptLayout")>,appl(prod([char-class([40])],lit("("),no-attrs),[40]),<"ws-after-("("OptLayout")>,<"attributes"("Attrs")>,<"ws-after-attributes"("OptLayout")>,appl(prod([char-class([41])],lit(")"),no-attrs),[41])]). May not be used to assert correctness of the PTPT_Attributes
 * \param[in] arg input PTPT_Attributes
 * \return ATtrue if #arg corresponds to the signature of a attrs, or ATfalse otherwise
 */
inline ATbool PTPT_isAttributesAttrs(PTPT_Attributes arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == PTPT_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == PTPT_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lit */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: attrs */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun32) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
              /* checking for: cf */
              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                /* checking for: opt */
                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                  /* checking for: layout */
                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                      arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                      arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                      /* checking for: lit */
                      if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
                        ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                        /* checking for: ( */
                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun21) {
                          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                            arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                            arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                            /* checking for: cf */
                            if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                              ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                              /* checking for: opt */
                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                /* checking for: layout */
                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                  if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                    arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                    arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                    /* checking for: cf */
                                    if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                      ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                      /* checking for: sort */
                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun9) {
                                        ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                        /* checking for: Attrs */
                                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun31) {
                                          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                            arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                            arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                            /* checking for: cf */
                                            if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                              ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                              /* checking for: opt */
                                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                                ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                /* checking for: layout */
                                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                                  if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                    arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                    arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                    /* checking for: lit */
                                                    if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
                                                      ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                      /* checking for: ) */
                                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun17) {
                                                        if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                                                          ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                                          /* checking for: cf */
                                                          if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == PTPT_afun2) {
                                                            ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                                            /* checking for: sort */
                                                            if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == PTPT_afun9) {
                                                              ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                                              /* checking for: Attributes */
                                                              if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == PTPT_afun30) {
                                                                ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                                                /* checking for: attrs */
                                                                if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == PTPT_afun12) {
                                                                  ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                                                  if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                                                    ATerm arg_arg0_arg2_arg0_head;
                                                                    ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                                                    arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                                                    arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                                                    /* checking for: term */
                                                                    if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == PTPT_afun13) {
                                                                      ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                                                      /* checking for: cons */
                                                                      if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == PTPT_afun14) {
                                                                        ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                                                        /* checking for: attrs */
                                                                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == PTPT_afun32) {
                                                                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                                            ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                                            if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                                              ATerm arg_arg1_head;
                                                                              ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                                              arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                              arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                              /* checking for: appl */
                                                                              if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                /* checking for: prod */
                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                  ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                    ATerm arg_arg1_head_arg0_arg0_head;
                                                                                    ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                    arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                    arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                    /* checking for: char-class */
                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                        ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                        arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                        arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 97) {

                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                              arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                              arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                              /* checking for: char-class */
                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                  ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 116) {

                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                        arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                        arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                        /* checking for: char-class */
                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                            ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                            arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                            arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 116) {

                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                  arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                  arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                  /* checking for: char-class */
                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                      ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 114) {

                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                            arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                            arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                            /* checking for: char-class */
                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 115) {

                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                      ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                      /* checking for: lit */
                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                        ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                        /* checking for: attrs */
                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun32) {
                                                                                                                                          ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                          /* checking for: no-attrs */
                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                            ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                              ATerm arg_arg1_head_arg1_head;
                                                                                                                                              ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                              arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                              arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 97) {

                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                  arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                  arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 116) {

                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                      arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                      arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 116) {

                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                          arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                          arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 114) {

                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                              arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                              arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 115) {

                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                    arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                      arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                                                      arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                      /* checking for: appl */
                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                                                                                        ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                                                                        /* checking for: prod */
                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                                                                                                          ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                                                            ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                                                            ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                                                            arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                            arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                            /* checking for: char-class */
                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 40) {

                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                                      ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                                                      /* checking for: lit */
                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                                        /* checking for: ( */
                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun21) {
                                                                                                                                                                                          ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                                          /* checking for: no-attrs */
                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                                                            ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                                              ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                                              ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                                              arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                              arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 40) {

                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                    arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                      arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                        arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                          arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                                                                                          arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                          /* checking for: appl */
                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                                                                                                                            ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                                                                                                            /* checking for: prod */
                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                                                                                                                                              ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                                                                                                ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                                                                                                ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                                                                                                arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                /* checking for: char-class */
                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                                                    ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                                                    arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                    arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 41) {

                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                                                                          ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                                                                                          /* checking for: lit */
                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                                                                                                            ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                                                                            /* checking for: ) */
                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun17) {
                                                                                                                                                                                                                              ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                                                                              /* checking for: no-attrs */
                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                                                                                                ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                                                                                  ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                                                                                  ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                                                                                  arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                  arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 41) {

                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                                                                                                                                                        return ATtrue;
                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                }
                                                                                                                                                                                                                              }
                                                                                                                                                                                                                            }
                                                                                                                                                                                                                          }
                                                                                                                                                                                                                        }
                                                                                                                                                                                                                      }
                                                                                                                                                                                                                    }
                                                                                                                                                                                                                  }
                                                                                                                                                                                                                }
                                                                                                                                                                                                              }
                                                                                                                                                                                                            }
                                                                                                                                                                                                          }
                                                                                                                                                                                                        }
                                                                                                                                                                                                      }
                                                                                                                                                                                                    }
                                                                                                                                                                                                  }
                                                                                                                                                                                                }
                                                                                                                                                                                              }
                                                                                                                                                                                            }
                                                                                                                                                                                          }
                                                                                                                                                                                        }
                                                                                                                                                                                      }
                                                                                                                                                                                    }
                                                                                                                                                                                  }
                                                                                                                                                                                }
                                                                                                                                                                              }
                                                                                                                                                                            }
                                                                                                                                                                          }
                                                                                                                                                                        }
                                                                                                                                                                      }
                                                                                                                                                                    }
                                                                                                                                                                  }
                                                                                                                                                                }
                                                                                                                                                              }
                                                                                                                                                            }
                                                                                                                                                          }
                                                                                                                                                        }
                                                                                                                                                      }
                                                                                                                                                    }
                                                                                                                                                  }
                                                                                                                                                }
                                                                                                                                              }
                                                                                                                                            }
                                                                                                                                          }
                                                                                                                                        }
                                                                                                                                      }
                                                                                                                                    }
                                                                                                                                  }
                                                                                                                                }
                                                                                                                              }
                                                                                                                            }
                                                                                                                          }
                                                                                                                        }
                                                                                                                      }
                                                                                                                    }
                                                                                                                  }
                                                                                                                }
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Attributes has a ws-after-attrs. 
 * \param[in] arg input PTPT_Attributes
 * \return ATtrue if the PTPT_Attributes had a ws-after-attrs, or ATfalse otherwise
 */
ATbool PTPT_hasAttributesWsAfterAttrs(PTPT_Attributes arg) {
  if (PTPT_isAttributesAttrs(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Attributes has a ws-after-(. 
 * \param[in] arg input PTPT_Attributes
 * \return ATtrue if the PTPT_Attributes had a ws-after-(, or ATfalse otherwise
 */
ATbool PTPT_hasAttributesWsAfterParenOpen(PTPT_Attributes arg) {
  if (PTPT_isAttributesAttrs(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Attributes has a attributes. 
 * \param[in] arg input PTPT_Attributes
 * \return ATtrue if the PTPT_Attributes had a attributes, or ATfalse otherwise
 */
ATbool PTPT_hasAttributesAttributes(PTPT_Attributes arg) {
  if (PTPT_isAttributesAttrs(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Attributes has a ws-after-attributes. 
 * \param[in] arg input PTPT_Attributes
 * \return ATtrue if the PTPT_Attributes had a ws-after-attributes, or ATfalse otherwise
 */
ATbool PTPT_hasAttributesWsAfterAttributes(PTPT_Attributes arg) {
  if (PTPT_isAttributesAttrs(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Get the ws-after-attrs PTPT_OptLayout of a PTPT_Attributes. Note that the precondition is that this PTPT_Attributes actually has a ws-after-attrs
 * \param[in] arg input PTPT_Attributes
 * \return the ws-after-attrs of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getAttributesWsAfterAttrs(PTPT_Attributes arg) {
  
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1);
}

/**
 * Get the ws-after-( PTPT_OptLayout of a PTPT_Attributes. Note that the precondition is that this PTPT_Attributes actually has a ws-after-(
 * \param[in] arg input PTPT_Attributes
 * \return the ws-after-( of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getAttributesWsAfterParenOpen(PTPT_Attributes arg) {
  
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 3);
}

/**
 * Get the attributes PTPT_Attrs of a PTPT_Attributes. Note that the precondition is that this PTPT_Attributes actually has a attributes
 * \param[in] arg input PTPT_Attributes
 * \return the attributes of #arg, if it exist or an undefined value if it does not
 */
PTPT_Attrs PTPT_getAttributesAttributes(PTPT_Attributes arg) {
  
    return (PTPT_Attrs)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 4);
}

/**
 * Get the ws-after-attributes PTPT_OptLayout of a PTPT_Attributes. Note that the precondition is that this PTPT_Attributes actually has a ws-after-attributes
 * \param[in] arg input PTPT_Attributes
 * \return the ws-after-attributes of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getAttributesWsAfterAttributes(PTPT_Attributes arg) {
  
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 5);
}

/**
 * Set the ws-after-attrs of a PTPT_Attributes. The precondition being that this PTPT_Attributes actually has a ws-after-attrs
 * \param[in] arg input PTPT_Attributes
 * \param[in] wsAfterAttrs new PTPT_OptLayout to set in #arg
 * \return A new PTPT_Attributes with wsAfterAttrs at the right place, or a core dump if #arg did not have a wsAfterAttrs
 */
PTPT_Attributes PTPT_setAttributesWsAfterAttrs(PTPT_Attributes arg, PTPT_OptLayout wsAfterAttrs) {
  if (PTPT_isAttributesAttrs(arg)) {
    return (PTPT_Attributes)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterAttrs), 1), 1);
  }

  ATabort("Attributes has no WsAfterAttrs: %t\n", arg);
  return (PTPT_Attributes)NULL;
}

/**
 * Set the ws-after-( of a PTPT_Attributes. The precondition being that this PTPT_Attributes actually has a ws-after-(
 * \param[in] arg input PTPT_Attributes
 * \param[in] wsAfterParenOpen new PTPT_OptLayout to set in #arg
 * \return A new PTPT_Attributes with wsAfterParenOpen at the right place, or a core dump if #arg did not have a wsAfterParenOpen
 */
PTPT_Attributes PTPT_setAttributesWsAfterParenOpen(PTPT_Attributes arg, PTPT_OptLayout wsAfterParenOpen) {
  if (PTPT_isAttributesAttrs(arg)) {
    return (PTPT_Attributes)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterParenOpen), 3), 1);
  }

  ATabort("Attributes has no WsAfterParenOpen: %t\n", arg);
  return (PTPT_Attributes)NULL;
}

/**
 * Set the attributes of a PTPT_Attributes. The precondition being that this PTPT_Attributes actually has a attributes
 * \param[in] arg input PTPT_Attributes
 * \param[in] attributes new PTPT_Attrs to set in #arg
 * \return A new PTPT_Attributes with attributes at the right place, or a core dump if #arg did not have a attributes
 */
PTPT_Attributes PTPT_setAttributesAttributes(PTPT_Attributes arg, PTPT_Attrs attributes) {
  if (PTPT_isAttributesAttrs(arg)) {
    return (PTPT_Attributes)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) attributes), 4), 1);
  }

  ATabort("Attributes has no Attributes: %t\n", arg);
  return (PTPT_Attributes)NULL;
}

/**
 * Set the ws-after-attributes of a PTPT_Attributes. The precondition being that this PTPT_Attributes actually has a ws-after-attributes
 * \param[in] arg input PTPT_Attributes
 * \param[in] wsAfterAttributes new PTPT_OptLayout to set in #arg
 * \return A new PTPT_Attributes with wsAfterAttributes at the right place, or a core dump if #arg did not have a wsAfterAttributes
 */
PTPT_Attributes PTPT_setAttributesWsAfterAttributes(PTPT_Attributes arg, PTPT_OptLayout wsAfterAttributes) {
  if (PTPT_isAttributesAttrs(arg)) {
    return (PTPT_Attributes)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterAttributes), 5), 1);
  }

  ATabort("Attributes has no WsAfterAttributes: %t\n", arg);
  return (PTPT_Attributes)NULL;
}

/**
 * Assert whether a PTPT_Attrs is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input PTPT_Attrs
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool PTPT_isValidAttrs(PTPT_Attrs arg) {
  if (PTPT_isAttrsMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Attrs is a many by checking against the following ATerm pattern: appl(prod([lit("["),cf(opt(layout)),cf(iter-sep(sort("Attr"),lit(","))),cf(opt(layout)),lit("]")],cf(sort("Attrs")),attrs([term(cons("many"))])),[appl(prod([char-class([91])],lit("["),no-attrs),[91]),<"ws-after-["("OptLayout")>,appl(list(cf(iter-sep(sort("Attr"),lit(",")))),<"list"("Attr-list")>),<"ws-after-list"("OptLayout")>,appl(prod([char-class([93])],lit("]"),no-attrs),[93])]). Always returns ATtrue
 * \param[in] arg input PTPT_Attrs
 * \return ATtrue if #arg corresponds to the signature of a many, or ATfalse otherwise
 */
inline ATbool PTPT_isAttrsMany(PTPT_Attrs arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == PTPT_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == PTPT_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lit */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: [ */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun36) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
              /* checking for: cf */
              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                /* checking for: opt */
                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                  /* checking for: layout */
                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                      arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                      arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                      /* checking for: cf */
                      if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                        ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                        /* checking for: iter-sep */
                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun34) {
                          ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                          /* checking for: sort */
                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun9) {
                            ATerm arg_arg0_arg0_head_arg0_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0_arg0, 0);
                            /* checking for: Attr */
                            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0_arg0) == PTPT_afun35) {
                              ATerm arg_arg0_arg0_head_arg0_arg1 = ATgetArgument(arg_arg0_arg0_head_arg0, 1);
                              /* checking for: lit */
                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg1) == PTPT_afun16) {
                                ATerm arg_arg0_arg0_head_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0_arg1, 0);
                                /* checking for: , */
                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg1_arg0) == PTPT_afun19) {
                                  if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                    arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                    arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                    /* checking for: cf */
                                    if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                      ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                      /* checking for: opt */
                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                        ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                        /* checking for: layout */
                                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                            arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                            arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                            /* checking for: lit */
                                            if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
                                              ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                              /* checking for: ] */
                                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun33) {
                                                if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                                                  ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                                  /* checking for: cf */
                                                  if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == PTPT_afun2) {
                                                    ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                                    /* checking for: sort */
                                                    if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == PTPT_afun9) {
                                                      ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                                      /* checking for: Attrs */
                                                      if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == PTPT_afun31) {
                                                        ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                                        /* checking for: attrs */
                                                        if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == PTPT_afun12) {
                                                          ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                                          if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                                            ATerm arg_arg0_arg2_arg0_head;
                                                            ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                                            arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                                            arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                                            /* checking for: term */
                                                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == PTPT_afun13) {
                                                              ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                                              /* checking for: cons */
                                                              if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == PTPT_afun14) {
                                                                ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                                                /* checking for: many */
                                                                if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == PTPT_afun37) {
                                                                  if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                                    ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                                    if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                                      ATerm arg_arg1_head;
                                                                      ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                                      arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                      arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                      /* checking for: appl */
                                                                      if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                        ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                        /* checking for: prod */
                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                          ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                            ATerm arg_arg1_head_arg0_arg0_head;
                                                                            ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                            arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                            arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                            /* checking for: char-class */
                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 91) {

                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                      ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                      /* checking for: lit */
                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                        ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                        /* checking for: [ */
                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun36) {
                                                                                          ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                          /* checking for: no-attrs */
                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                            ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                              ATerm arg_arg1_head_arg1_head;
                                                                                              ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                              arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                              arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 91) {

                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                  if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                    arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                      arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                      arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                      /* checking for: appl */
                                                                                                      if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                        ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                        /* checking for: list */
                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun8) {
                                                                                                          ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                          /* checking for: cf */
                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0) == PTPT_afun2) {
                                                                                                            ATerm arg_arg1_head_arg0_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0, 0);
                                                                                                            /* checking for: iter-sep */
                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0) == PTPT_afun34) {
                                                                                                              ATerm arg_arg1_head_arg0_arg0_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0, 0);
                                                                                                              /* checking for: sort */
                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg0) == PTPT_afun9) {
                                                                                                                ATerm arg_arg1_head_arg0_arg0_arg0_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0_arg0, 0);
                                                                                                                /* checking for: Attr */
                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg0_arg0) == PTPT_afun35) {
                                                                                                                  ATerm arg_arg1_head_arg0_arg0_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0, 1);
                                                                                                                  /* checking for: lit */
                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg1) == PTPT_afun16) {
                                                                                                                    ATerm arg_arg1_head_arg0_arg0_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0_arg1, 0);
                                                                                                                    /* checking for: , */
                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg1_arg0) == PTPT_afun19) {
                                                                                                                      if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                        arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                          arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                          arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                          /* checking for: appl */
                                                                                                                          if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                                            ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                            /* checking for: prod */
                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                                                              ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                /* checking for: char-class */
                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                    ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                    arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                    arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 93) {

                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                          ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                          /* checking for: lit */
                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                            ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                            /* checking for: ] */
                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun33) {
                                                                                                                                              ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                              /* checking for: no-attrs */
                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                  ATerm arg_arg1_head_arg1_head;
                                                                                                                                                  ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                  arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                  arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 93) {

                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                                                                        return ATtrue;
                                                                                                                                                      }
                                                                                                                                                    }
                                                                                                                                                  }
                                                                                                                                                }
                                                                                                                                              }
                                                                                                                                            }
                                                                                                                                          }
                                                                                                                                        }
                                                                                                                                      }
                                                                                                                                    }
                                                                                                                                  }
                                                                                                                                }
                                                                                                                              }
                                                                                                                            }
                                                                                                                          }
                                                                                                                        }
                                                                                                                      }
                                                                                                                    }
                                                                                                                  }
                                                                                                                }
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Attrs has a ws-after-[. 
 * \param[in] arg input PTPT_Attrs
 * \return ATtrue if the PTPT_Attrs had a ws-after-[, or ATfalse otherwise
 */
ATbool PTPT_hasAttrsWsAfterBracketOpen(PTPT_Attrs arg) {
  if (PTPT_isAttrsMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Attrs has a list. 
 * \param[in] arg input PTPT_Attrs
 * \return ATtrue if the PTPT_Attrs had a list, or ATfalse otherwise
 */
ATbool PTPT_hasAttrsList(PTPT_Attrs arg) {
  if (PTPT_isAttrsMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Attrs has a ws-after-list. 
 * \param[in] arg input PTPT_Attrs
 * \return ATtrue if the PTPT_Attrs had a ws-after-list, or ATfalse otherwise
 */
ATbool PTPT_hasAttrsWsAfterList(PTPT_Attrs arg) {
  if (PTPT_isAttrsMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Get the ws-after-[ PTPT_OptLayout of a PTPT_Attrs. Note that the precondition is that this PTPT_Attrs actually has a ws-after-[
 * \param[in] arg input PTPT_Attrs
 * \return the ws-after-[ of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getAttrsWsAfterBracketOpen(PTPT_Attrs arg) {
  
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1);
}

/**
 * Get the list PTPT_AttrList of a PTPT_Attrs. Note that the precondition is that this PTPT_Attrs actually has a list
 * \param[in] arg input PTPT_Attrs
 * \return the list of #arg, if it exist or an undefined value if it does not
 */
PTPT_AttrList PTPT_getAttrsList(PTPT_Attrs arg) {
  
    return (PTPT_AttrList)ATgetArgument((ATermAppl)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 2), 1);
}

/**
 * Get the ws-after-list PTPT_OptLayout of a PTPT_Attrs. Note that the precondition is that this PTPT_Attrs actually has a ws-after-list
 * \param[in] arg input PTPT_Attrs
 * \return the ws-after-list of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getAttrsWsAfterList(PTPT_Attrs arg) {
  
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 3);
}

/**
 * Set the ws-after-[ of a PTPT_Attrs. The precondition being that this PTPT_Attrs actually has a ws-after-[
 * \param[in] arg input PTPT_Attrs
 * \param[in] wsAfterBracketOpen new PTPT_OptLayout to set in #arg
 * \return A new PTPT_Attrs with wsAfterBracketOpen at the right place, or a core dump if #arg did not have a wsAfterBracketOpen
 */
PTPT_Attrs PTPT_setAttrsWsAfterBracketOpen(PTPT_Attrs arg, PTPT_OptLayout wsAfterBracketOpen) {
  if (PTPT_isAttrsMany(arg)) {
    return (PTPT_Attrs)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterBracketOpen), 1), 1);
  }

  ATabort("Attrs has no WsAfterBracketOpen: %t\n", arg);
  return (PTPT_Attrs)NULL;
}

/**
 * Set the list of a PTPT_Attrs. The precondition being that this PTPT_Attrs actually has a list
 * \param[in] arg input PTPT_Attrs
 * \param[in] list new PTPT_AttrList to set in #arg
 * \return A new PTPT_Attrs with list at the right place, or a core dump if #arg did not have a list
 */
PTPT_Attrs PTPT_setAttrsList(PTPT_Attrs arg, PTPT_AttrList list) {
  if (PTPT_isAttrsMany(arg)) {
    return (PTPT_Attrs)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)ATsetArgument((ATermAppl)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 2), (ATerm)((ATerm) list), 1), 2), 1);
  }

  ATabort("Attrs has no List: %t\n", arg);
  return (PTPT_Attrs)NULL;
}

/**
 * Set the ws-after-list of a PTPT_Attrs. The precondition being that this PTPT_Attrs actually has a ws-after-list
 * \param[in] arg input PTPT_Attrs
 * \param[in] wsAfterList new PTPT_OptLayout to set in #arg
 * \return A new PTPT_Attrs with wsAfterList at the right place, or a core dump if #arg did not have a wsAfterList
 */
PTPT_Attrs PTPT_setAttrsWsAfterList(PTPT_Attrs arg, PTPT_OptLayout wsAfterList) {
  if (PTPT_isAttrsMany(arg)) {
    return (PTPT_Attrs)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterList), 3), 1);
  }

  ATabort("Attrs has no WsAfterList: %t\n", arg);
  return (PTPT_Attrs)NULL;
}

/**
 * Assert whether a PTPT_Attr is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input PTPT_Attr
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool PTPT_isValidAttr(PTPT_Attr arg) {
  if (PTPT_isAttrAssoc(arg)) {
    return ATtrue;
  }
  else if (PTPT_isAttrTerm(arg)) {
    return ATtrue;
  }
  else if (PTPT_isAttrId(arg)) {
    return ATtrue;
  }
  else if (PTPT_isAttrBracket(arg)) {
    return ATtrue;
  }
  else if (PTPT_isAttrReject(arg)) {
    return ATtrue;
  }
  else if (PTPT_isAttrPrefer(arg)) {
    return ATtrue;
  }
  else if (PTPT_isAttrAvoid(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Attr is a assoc by checking against the following ATerm pattern: appl(prod([lit("assoc"),cf(opt(layout)),lit("("),cf(opt(layout)),cf(sort("Associativity")),cf(opt(layout)),lit(")")],cf(sort("Attr")),attrs([term(cons("assoc"))])),[appl(prod([char-class([97]),char-class([115]),char-class([115]),char-class([111]),char-class([99])],lit("assoc"),no-attrs),[97,115,115,111,99]),<"ws-after-assoc"("OptLayout")>,appl(prod([char-class([40])],lit("("),no-attrs),[40]),<"ws-after-("("OptLayout")>,<"associativity"("Associativity")>,<"ws-after-associativity"("OptLayout")>,appl(prod([char-class([41])],lit(")"),no-attrs),[41])]). May not be used to assert correctness of the PTPT_Attr
 * \param[in] arg input PTPT_Attr
 * \return ATtrue if #arg corresponds to the signature of a assoc, or ATfalse otherwise
 */
inline ATbool PTPT_isAttrAssoc(PTPT_Attr arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == PTPT_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == PTPT_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lit */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: assoc */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun39) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
              /* checking for: cf */
              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                /* checking for: opt */
                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                  /* checking for: layout */
                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                      arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                      arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                      /* checking for: lit */
                      if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
                        ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                        /* checking for: ( */
                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun21) {
                          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                            arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                            arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                            /* checking for: cf */
                            if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                              ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                              /* checking for: opt */
                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                /* checking for: layout */
                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                  if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                    arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                    arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                    /* checking for: cf */
                                    if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                      ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                      /* checking for: sort */
                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun9) {
                                        ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                        /* checking for: Associativity */
                                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun38) {
                                          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                            arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                            arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                            /* checking for: cf */
                                            if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                              ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                              /* checking for: opt */
                                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                                ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                /* checking for: layout */
                                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                                  if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                    arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                    arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                    /* checking for: lit */
                                                    if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
                                                      ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                      /* checking for: ) */
                                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun17) {
                                                        if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                                                          ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                                          /* checking for: cf */
                                                          if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == PTPT_afun2) {
                                                            ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                                            /* checking for: sort */
                                                            if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == PTPT_afun9) {
                                                              ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                                              /* checking for: Attr */
                                                              if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == PTPT_afun35) {
                                                                ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                                                /* checking for: attrs */
                                                                if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == PTPT_afun12) {
                                                                  ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                                                  if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                                                    ATerm arg_arg0_arg2_arg0_head;
                                                                    ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                                                    arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                                                    arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                                                    /* checking for: term */
                                                                    if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == PTPT_afun13) {
                                                                      ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                                                      /* checking for: cons */
                                                                      if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == PTPT_afun14) {
                                                                        ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                                                        /* checking for: assoc */
                                                                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == PTPT_afun39) {
                                                                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                                            ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                                            if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                                              ATerm arg_arg1_head;
                                                                              ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                                              arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                              arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                              /* checking for: appl */
                                                                              if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                /* checking for: prod */
                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                  ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                    ATerm arg_arg1_head_arg0_arg0_head;
                                                                                    ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                    arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                    arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                    /* checking for: char-class */
                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                        ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                        arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                        arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 97) {

                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                              arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                              arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                              /* checking for: char-class */
                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                  ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 115) {

                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                        arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                        arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                        /* checking for: char-class */
                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                            ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                            arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                            arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 115) {

                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                  arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                  arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                  /* checking for: char-class */
                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                      ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 111) {

                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                            arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                            arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                            /* checking for: char-class */
                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 99) {

                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                      ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                      /* checking for: lit */
                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                        ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                        /* checking for: assoc */
                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun39) {
                                                                                                                                          ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                          /* checking for: no-attrs */
                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                            ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                              ATerm arg_arg1_head_arg1_head;
                                                                                                                                              ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                              arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                              arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 97) {

                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                  arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                  arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 115) {

                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                      arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                      arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 115) {

                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                          arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                          arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 111) {

                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                              arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                              arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 99) {

                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                    arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                      arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                                                      arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                      /* checking for: appl */
                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                                                                                        ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                                                                        /* checking for: prod */
                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                                                                                                          ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                                                            ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                                                            ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                                                            arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                            arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                            /* checking for: char-class */
                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 40) {

                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                                      ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                                                      /* checking for: lit */
                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                                        /* checking for: ( */
                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun21) {
                                                                                                                                                                                          ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                                          /* checking for: no-attrs */
                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                                                            ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                                              ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                                              ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                                              arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                              arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 40) {

                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                    arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                      arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                        arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                          arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                                                                                          arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                          /* checking for: appl */
                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                                                                                                                            ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                                                                                                            /* checking for: prod */
                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                                                                                                                                              ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                                                                                                ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                                                                                                ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                                                                                                arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                /* checking for: char-class */
                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                                                    ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                                                    arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                    arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 41) {

                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                                                                          ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                                                                                          /* checking for: lit */
                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                                                                                                            ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                                                                            /* checking for: ) */
                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun17) {
                                                                                                                                                                                                                              ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                                                                              /* checking for: no-attrs */
                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                                                                                                ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                                                                                  ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                                                                                  ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                                                                                  arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                  arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 41) {

                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                                                                                                                                                        return ATtrue;
                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                }
                                                                                                                                                                                                                              }
                                                                                                                                                                                                                            }
                                                                                                                                                                                                                          }
                                                                                                                                                                                                                        }
                                                                                                                                                                                                                      }
                                                                                                                                                                                                                    }
                                                                                                                                                                                                                  }
                                                                                                                                                                                                                }
                                                                                                                                                                                                              }
                                                                                                                                                                                                            }
                                                                                                                                                                                                          }
                                                                                                                                                                                                        }
                                                                                                                                                                                                      }
                                                                                                                                                                                                    }
                                                                                                                                                                                                  }
                                                                                                                                                                                                }
                                                                                                                                                                                              }
                                                                                                                                                                                            }
                                                                                                                                                                                          }
                                                                                                                                                                                        }
                                                                                                                                                                                      }
                                                                                                                                                                                    }
                                                                                                                                                                                  }
                                                                                                                                                                                }
                                                                                                                                                                              }
                                                                                                                                                                            }
                                                                                                                                                                          }
                                                                                                                                                                        }
                                                                                                                                                                      }
                                                                                                                                                                    }
                                                                                                                                                                  }
                                                                                                                                                                }
                                                                                                                                                              }
                                                                                                                                                            }
                                                                                                                                                          }
                                                                                                                                                        }
                                                                                                                                                      }
                                                                                                                                                    }
                                                                                                                                                  }
                                                                                                                                                }
                                                                                                                                              }
                                                                                                                                            }
                                                                                                                                          }
                                                                                                                                        }
                                                                                                                                      }
                                                                                                                                    }
                                                                                                                                  }
                                                                                                                                }
                                                                                                                              }
                                                                                                                            }
                                                                                                                          }
                                                                                                                        }
                                                                                                                      }
                                                                                                                    }
                                                                                                                  }
                                                                                                                }
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Attr is a term by checking against the following ATerm pattern: appl(prod([lit("term"),cf(opt(layout)),lit("("),cf(opt(layout)),cf(sort("ATerm")),cf(opt(layout)),lit(")")],cf(sort("Attr")),attrs([term(cons("term"))])),[appl(prod([char-class([116]),char-class([101]),char-class([114]),char-class([109])],lit("term"),no-attrs),[116,101,114,109]),<"ws-after-term"("OptLayout")>,appl(prod([char-class([40])],lit("("),no-attrs),[40]),<"ws-after-("("OptLayout")>,<"aterm"("ATerm")>,<"ws-after-aterm"("OptLayout")>,appl(prod([char-class([41])],lit(")"),no-attrs),[41])]). May not be used to assert correctness of the PTPT_Attr
 * \param[in] arg input PTPT_Attr
 * \return ATtrue if #arg corresponds to the signature of a term, or ATfalse otherwise
 */
inline ATbool PTPT_isAttrTerm(PTPT_Attr arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == PTPT_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == PTPT_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lit */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: term */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun41) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
              /* checking for: cf */
              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                /* checking for: opt */
                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                  /* checking for: layout */
                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                      arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                      arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                      /* checking for: lit */
                      if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
                        ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                        /* checking for: ( */
                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun21) {
                          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                            arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                            arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                            /* checking for: cf */
                            if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                              ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                              /* checking for: opt */
                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                /* checking for: layout */
                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                  if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                    arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                    arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                    /* checking for: cf */
                                    if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                      ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                      /* checking for: sort */
                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun9) {
                                        ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                        /* checking for: ATerm */
                                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun40) {
                                          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                            arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                            arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                            /* checking for: cf */
                                            if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                              ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                              /* checking for: opt */
                                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                                ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                /* checking for: layout */
                                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                                  if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                    arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                    arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                    /* checking for: lit */
                                                    if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
                                                      ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                      /* checking for: ) */
                                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun17) {
                                                        if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                                                          ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                                          /* checking for: cf */
                                                          if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == PTPT_afun2) {
                                                            ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                                            /* checking for: sort */
                                                            if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == PTPT_afun9) {
                                                              ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                                              /* checking for: Attr */
                                                              if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == PTPT_afun35) {
                                                                ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                                                /* checking for: attrs */
                                                                if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == PTPT_afun12) {
                                                                  ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                                                  if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                                                    ATerm arg_arg0_arg2_arg0_head;
                                                                    ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                                                    arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                                                    arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                                                    /* checking for: term */
                                                                    if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == PTPT_afun13) {
                                                                      ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                                                      /* checking for: cons */
                                                                      if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == PTPT_afun14) {
                                                                        ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                                                        /* checking for: term */
                                                                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == PTPT_afun41) {
                                                                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                                            ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                                            if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                                              ATerm arg_arg1_head;
                                                                              ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                                              arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                              arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                              /* checking for: appl */
                                                                              if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                /* checking for: prod */
                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                  ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                    ATerm arg_arg1_head_arg0_arg0_head;
                                                                                    ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                    arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                    arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                    /* checking for: char-class */
                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                        ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                        arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                        arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 116) {

                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                              arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                              arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                              /* checking for: char-class */
                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                  ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 101) {

                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                        arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                        arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                        /* checking for: char-class */
                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                            ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                            arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                            arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 114) {

                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                  arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                  arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                  /* checking for: char-class */
                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                      ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 109) {

                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                            ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                            /* checking for: lit */
                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                              ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                              /* checking for: term */
                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun41) {
                                                                                                                                ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                /* checking for: no-attrs */
                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                  ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                    ATerm arg_arg1_head_arg1_head;
                                                                                                                                    ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                    arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                    arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 116) {

                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                        arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                        arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 101) {

                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                            arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                            arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 114) {

                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 109) {

                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                      arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                        arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                                        arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                        /* checking for: appl */
                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                                                                          ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                                                          /* checking for: prod */
                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                                                                                            ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                                              ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                                              ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                                              arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                              arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                              /* checking for: char-class */
                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                  ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 40) {

                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                                        /* checking for: lit */
                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                                                          ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                          /* checking for: ( */
                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun21) {
                                                                                                                                                                            ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                            /* checking for: no-attrs */
                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                                              ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                                ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                                ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                                arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 40) {

                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                      arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                        arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                          arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                            arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                                                                            arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                            /* checking for: appl */
                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                                                                                                              ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                                                                                              /* checking for: prod */
                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                                                                                                                                ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                                                                                  ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                                                                                  arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                  arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                  /* checking for: char-class */
                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                                      ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 41) {

                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                                                            ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                                                                            /* checking for: lit */
                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                                                                                              ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                                                              /* checking for: ) */
                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun17) {
                                                                                                                                                                                                                ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                                                                /* checking for: no-attrs */
                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                                                                                  ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                                                                    ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                                                                    ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                                                                    arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                    arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 41) {

                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                                                                                                                                          return ATtrue;
                                                                                                                                                                                                                        }
                                                                                                                                                                                                                      }
                                                                                                                                                                                                                    }
                                                                                                                                                                                                                  }
                                                                                                                                                                                                                }
                                                                                                                                                                                                              }
                                                                                                                                                                                                            }
                                                                                                                                                                                                          }
                                                                                                                                                                                                        }
                                                                                                                                                                                                      }
                                                                                                                                                                                                    }
                                                                                                                                                                                                  }
                                                                                                                                                                                                }
                                                                                                                                                                                              }
                                                                                                                                                                                            }
                                                                                                                                                                                          }
                                                                                                                                                                                        }
                                                                                                                                                                                      }
                                                                                                                                                                                    }
                                                                                                                                                                                  }
                                                                                                                                                                                }
                                                                                                                                                                              }
                                                                                                                                                                            }
                                                                                                                                                                          }
                                                                                                                                                                        }
                                                                                                                                                                      }
                                                                                                                                                                    }
                                                                                                                                                                  }
                                                                                                                                                                }
                                                                                                                                                              }
                                                                                                                                                            }
                                                                                                                                                          }
                                                                                                                                                        }
                                                                                                                                                      }
                                                                                                                                                    }
                                                                                                                                                  }
                                                                                                                                                }
                                                                                                                                              }
                                                                                                                                            }
                                                                                                                                          }
                                                                                                                                        }
                                                                                                                                      }
                                                                                                                                    }
                                                                                                                                  }
                                                                                                                                }
                                                                                                                              }
                                                                                                                            }
                                                                                                                          }
                                                                                                                        }
                                                                                                                      }
                                                                                                                    }
                                                                                                                  }
                                                                                                                }
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Attr is a id by checking against the following ATerm pattern: appl(prod([lit("id"),cf(opt(layout)),lit("("),cf(opt(layout)),cf(sort("StrCon")),cf(opt(layout)),lit(")")],cf(sort("Attr")),attrs([term(cons("id"))])),[appl(prod([char-class([105]),char-class([100])],lit("id"),no-attrs),[105,100]),<"ws-after-id"("OptLayout")>,appl(prod([char-class([40])],lit("("),no-attrs),[40]),<"ws-after-("("OptLayout")>,<"module-name"("StrCon")>,<"ws-after-module-name"("OptLayout")>,appl(prod([char-class([41])],lit(")"),no-attrs),[41])]). May not be used to assert correctness of the PTPT_Attr
 * \param[in] arg input PTPT_Attr
 * \return ATtrue if #arg corresponds to the signature of a id, or ATfalse otherwise
 */
inline ATbool PTPT_isAttrId(PTPT_Attr arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == PTPT_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == PTPT_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lit */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: id */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun43) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
              /* checking for: cf */
              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                /* checking for: opt */
                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                  /* checking for: layout */
                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                      arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                      arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                      /* checking for: lit */
                      if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
                        ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                        /* checking for: ( */
                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun21) {
                          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                            arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                            arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                            /* checking for: cf */
                            if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                              ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                              /* checking for: opt */
                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                /* checking for: layout */
                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                  if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                    arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                    arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                    /* checking for: cf */
                                    if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                      ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                      /* checking for: sort */
                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun9) {
                                        ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                        /* checking for: StrCon */
                                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun42) {
                                          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                            arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                            arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                            /* checking for: cf */
                                            if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                              ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                              /* checking for: opt */
                                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                                ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                /* checking for: layout */
                                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                                  if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                    arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                    arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                    /* checking for: lit */
                                                    if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
                                                      ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                      /* checking for: ) */
                                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun17) {
                                                        if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                                                          ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                                          /* checking for: cf */
                                                          if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == PTPT_afun2) {
                                                            ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                                            /* checking for: sort */
                                                            if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == PTPT_afun9) {
                                                              ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                                              /* checking for: Attr */
                                                              if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == PTPT_afun35) {
                                                                ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                                                /* checking for: attrs */
                                                                if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == PTPT_afun12) {
                                                                  ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                                                  if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                                                    ATerm arg_arg0_arg2_arg0_head;
                                                                    ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                                                    arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                                                    arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                                                    /* checking for: term */
                                                                    if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == PTPT_afun13) {
                                                                      ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                                                      /* checking for: cons */
                                                                      if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == PTPT_afun14) {
                                                                        ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                                                        /* checking for: id */
                                                                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == PTPT_afun43) {
                                                                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                                            ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                                            if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                                              ATerm arg_arg1_head;
                                                                              ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                                              arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                              arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                              /* checking for: appl */
                                                                              if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                /* checking for: prod */
                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                  ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                    ATerm arg_arg1_head_arg0_arg0_head;
                                                                                    ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                    arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                    arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                    /* checking for: char-class */
                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                        ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                        arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                        arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 105) {

                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                              arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                              arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                              /* checking for: char-class */
                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                  ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 100) {

                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                        ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                        /* checking for: lit */
                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                          ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                          /* checking for: id */
                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun43) {
                                                                                                            ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                            /* checking for: no-attrs */
                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                              ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                ATerm arg_arg1_head_arg1_head;
                                                                                                                ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 105) {

                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                    arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                    arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 100) {

                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                          arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                          if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                            arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                            arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                            /* checking for: appl */
                                                                                                                            if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                                              ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                              /* checking for: prod */
                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                                                                ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                  ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                  arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                  arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                  /* checking for: char-class */
                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                      ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 40) {

                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                            ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                            /* checking for: lit */
                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                              ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                              /* checking for: ( */
                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun21) {
                                                                                                                                                ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                /* checking for: no-attrs */
                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                  ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                    ATerm arg_arg1_head_arg1_head;
                                                                                                                                                    ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                    arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                    arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 40) {

                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                          arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                            arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                              arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                                                arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                /* checking for: appl */
                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                                                                                  ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                                                                  /* checking for: prod */
                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                                                                                                    ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                                                      ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                                                      ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                                                      arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                      arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                      /* checking for: char-class */
                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                          ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                          arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                          arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 41) {

                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                                ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                                                /* checking for: lit */
                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                                                                  ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                                  /* checking for: ) */
                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun17) {
                                                                                                                                                                                    ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                                    /* checking for: no-attrs */
                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                                                      ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                                        ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                                        ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                                        arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                        arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 41) {

                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                                                                                                              return ATtrue;
                                                                                                                                                                                            }
                                                                                                                                                                                          }
                                                                                                                                                                                        }
                                                                                                                                                                                      }
                                                                                                                                                                                    }
                                                                                                                                                                                  }
                                                                                                                                                                                }
                                                                                                                                                                              }
                                                                                                                                                                            }
                                                                                                                                                                          }
                                                                                                                                                                        }
                                                                                                                                                                      }
                                                                                                                                                                    }
                                                                                                                                                                  }
                                                                                                                                                                }
                                                                                                                                                              }
                                                                                                                                                            }
                                                                                                                                                          }
                                                                                                                                                        }
                                                                                                                                                      }
                                                                                                                                                    }
                                                                                                                                                  }
                                                                                                                                                }
                                                                                                                                              }
                                                                                                                                            }
                                                                                                                                          }
                                                                                                                                        }
                                                                                                                                      }
                                                                                                                                    }
                                                                                                                                  }
                                                                                                                                }
                                                                                                                              }
                                                                                                                            }
                                                                                                                          }
                                                                                                                        }
                                                                                                                      }
                                                                                                                    }
                                                                                                                  }
                                                                                                                }
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Attr is a bracket by checking against the following ATerm pattern: appl(prod([lit("bracket")],cf(sort("Attr")),attrs([term(cons("bracket"))])),[appl(prod([char-class([98]),char-class([114]),char-class([97]),char-class([99]),char-class([107]),char-class([101]),char-class([116])],lit("bracket"),no-attrs),[98,114,97,99,107,101,116])]). May not be used to assert correctness of the PTPT_Attr
 * \param[in] arg input PTPT_Attr
 * \return ATtrue if #arg corresponds to the signature of a bracket, or ATfalse otherwise
 */
inline ATbool PTPT_isAttrBracket(PTPT_Attr arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == PTPT_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == PTPT_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lit */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: bracket */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun44) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
              ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
              /* checking for: cf */
              if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == PTPT_afun2) {
                ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                /* checking for: sort */
                if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == PTPT_afun9) {
                  ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                  /* checking for: Attr */
                  if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == PTPT_afun35) {
                    ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                    /* checking for: attrs */
                    if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == PTPT_afun12) {
                      ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                      if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                        ATerm arg_arg0_arg2_arg0_head;
                        ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                        arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                        arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                        /* checking for: term */
                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == PTPT_afun13) {
                          ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                          /* checking for: cons */
                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == PTPT_afun14) {
                            ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                            /* checking for: bracket */
                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == PTPT_afun44) {
                              if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                ATerm arg_arg1 = ATgetArgument(arg, 1);
                                if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                  ATerm arg_arg1_head;
                                  ATermList arg_arg1_list = (ATermList)arg_arg1;
                                  arg_arg1_head = ATgetFirst(arg_arg1_list);
                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                  /* checking for: appl */
                                  if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                    ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                    /* checking for: prod */
                                    if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                      ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                        ATerm arg_arg1_head_arg0_arg0_head;
                                        ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                        arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                        arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                        /* checking for: char-class */
                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                          ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                            ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                            ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                            arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                            arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                            if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 98) {

                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                  arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                  arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                  /* checking for: char-class */
                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                      ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                      arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                      arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 114) {

                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                            arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                            arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                            /* checking for: char-class */
                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 97) {

                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                      arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                      arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                      /* checking for: char-class */
                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                          ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                          arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                          arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 99) {

                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                /* checking for: char-class */
                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                    ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                    arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                    arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 107) {

                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                          arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                          arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                          /* checking for: char-class */
                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                              ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                              arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                              arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 101) {

                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                    arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                    arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                    /* checking for: char-class */
                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                        ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                        arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                        arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 116) {

                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                              ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                              /* checking for: lit */
                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                /* checking for: bracket */
                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun44) {
                                                                                                                  ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                  /* checking for: no-attrs */
                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                    ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                      ATerm arg_arg1_head_arg1_head;
                                                                                                                      ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                      arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                      arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 98) {

                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                          arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                          arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 114) {

                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                              arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                              arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 97) {

                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                  arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                  arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 99) {

                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                      arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                      arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 107) {

                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                          arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                          arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 101) {

                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                              arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                              arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 116) {

                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                                                                    return ATtrue;
                                                                                                                                                  }
                                                                                                                                                }
                                                                                                                                              }
                                                                                                                                            }
                                                                                                                                          }
                                                                                                                                        }
                                                                                                                                      }
                                                                                                                                    }
                                                                                                                                  }
                                                                                                                                }
                                                                                                                              }
                                                                                                                            }
                                                                                                                          }
                                                                                                                        }
                                                                                                                      }
                                                                                                                    }
                                                                                                                  }
                                                                                                                }
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Attr is a reject by checking against the following ATerm pattern: appl(prod([lit("reject")],cf(sort("Attr")),attrs([term(cons("reject"))])),[appl(prod([char-class([114]),char-class([101]),char-class([106]),char-class([101]),char-class([99]),char-class([116])],lit("reject"),no-attrs),[114,101,106,101,99,116])]). May not be used to assert correctness of the PTPT_Attr
 * \param[in] arg input PTPT_Attr
 * \return ATtrue if #arg corresponds to the signature of a reject, or ATfalse otherwise
 */
inline ATbool PTPT_isAttrReject(PTPT_Attr arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == PTPT_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == PTPT_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lit */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: reject */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun45) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
              ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
              /* checking for: cf */
              if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == PTPT_afun2) {
                ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                /* checking for: sort */
                if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == PTPT_afun9) {
                  ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                  /* checking for: Attr */
                  if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == PTPT_afun35) {
                    ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                    /* checking for: attrs */
                    if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == PTPT_afun12) {
                      ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                      if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                        ATerm arg_arg0_arg2_arg0_head;
                        ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                        arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                        arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                        /* checking for: term */
                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == PTPT_afun13) {
                          ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                          /* checking for: cons */
                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == PTPT_afun14) {
                            ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                            /* checking for: reject */
                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == PTPT_afun45) {
                              if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                ATerm arg_arg1 = ATgetArgument(arg, 1);
                                if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                  ATerm arg_arg1_head;
                                  ATermList arg_arg1_list = (ATermList)arg_arg1;
                                  arg_arg1_head = ATgetFirst(arg_arg1_list);
                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                  /* checking for: appl */
                                  if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                    ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                    /* checking for: prod */
                                    if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                      ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                        ATerm arg_arg1_head_arg0_arg0_head;
                                        ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                        arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                        arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                        /* checking for: char-class */
                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                          ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                            ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                            ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                            arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                            arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                            if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 114) {

                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                  arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                  arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                  /* checking for: char-class */
                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                      ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                      arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                      arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 101) {

                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                            arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                            arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                            /* checking for: char-class */
                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 106) {

                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                      arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                      arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                      /* checking for: char-class */
                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                          ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                          arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                          arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 101) {

                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                /* checking for: char-class */
                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                    ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                    arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                    arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 99) {

                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                          arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                          arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                          /* checking for: char-class */
                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                              ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                              arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                              arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 116) {

                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                    ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                    /* checking for: lit */
                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                      ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                      /* checking for: reject */
                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun45) {
                                                                                                        ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                        /* checking for: no-attrs */
                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                          ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                            ATerm arg_arg1_head_arg1_head;
                                                                                                            ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                            arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                            arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 114) {

                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 101) {

                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                    arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                    arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 106) {

                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                        arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                        arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 101) {

                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                            arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                            arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 99) {

                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 116) {

                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                                                      return ATtrue;
                                                                                                                                    }
                                                                                                                                  }
                                                                                                                                }
                                                                                                                              }
                                                                                                                            }
                                                                                                                          }
                                                                                                                        }
                                                                                                                      }
                                                                                                                    }
                                                                                                                  }
                                                                                                                }
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Attr is a prefer by checking against the following ATerm pattern: appl(prod([lit("prefer")],cf(sort("Attr")),attrs([term(cons("prefer"))])),[appl(prod([char-class([112]),char-class([114]),char-class([101]),char-class([102]),char-class([101]),char-class([114])],lit("prefer"),no-attrs),[112,114,101,102,101,114])]). May not be used to assert correctness of the PTPT_Attr
 * \param[in] arg input PTPT_Attr
 * \return ATtrue if #arg corresponds to the signature of a prefer, or ATfalse otherwise
 */
inline ATbool PTPT_isAttrPrefer(PTPT_Attr arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == PTPT_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == PTPT_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lit */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: prefer */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun46) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
              ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
              /* checking for: cf */
              if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == PTPT_afun2) {
                ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                /* checking for: sort */
                if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == PTPT_afun9) {
                  ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                  /* checking for: Attr */
                  if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == PTPT_afun35) {
                    ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                    /* checking for: attrs */
                    if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == PTPT_afun12) {
                      ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                      if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                        ATerm arg_arg0_arg2_arg0_head;
                        ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                        arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                        arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                        /* checking for: term */
                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == PTPT_afun13) {
                          ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                          /* checking for: cons */
                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == PTPT_afun14) {
                            ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                            /* checking for: prefer */
                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == PTPT_afun46) {
                              if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                ATerm arg_arg1 = ATgetArgument(arg, 1);
                                if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                  ATerm arg_arg1_head;
                                  ATermList arg_arg1_list = (ATermList)arg_arg1;
                                  arg_arg1_head = ATgetFirst(arg_arg1_list);
                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                  /* checking for: appl */
                                  if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                    ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                    /* checking for: prod */
                                    if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                      ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                        ATerm arg_arg1_head_arg0_arg0_head;
                                        ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                        arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                        arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                        /* checking for: char-class */
                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                          ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                            ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                            ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                            arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                            arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                            if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 112) {

                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                  arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                  arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                  /* checking for: char-class */
                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                      ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                      arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                      arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 114) {

                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                            arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                            arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                            /* checking for: char-class */
                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 101) {

                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                      arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                      arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                      /* checking for: char-class */
                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                          ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                          arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                          arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 102) {

                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                /* checking for: char-class */
                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                    ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                    arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                    arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 101) {

                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                          arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                          arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                          /* checking for: char-class */
                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                              ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                              arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                              arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 114) {

                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                    ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                    /* checking for: lit */
                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                      ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                      /* checking for: prefer */
                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun46) {
                                                                                                        ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                        /* checking for: no-attrs */
                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                          ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                            ATerm arg_arg1_head_arg1_head;
                                                                                                            ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                            arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                            arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 112) {

                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 114) {

                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                    arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                    arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 101) {

                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                        arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                        arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 102) {

                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                            arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                            arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 101) {

                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 114) {

                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                                                      return ATtrue;
                                                                                                                                    }
                                                                                                                                  }
                                                                                                                                }
                                                                                                                              }
                                                                                                                            }
                                                                                                                          }
                                                                                                                        }
                                                                                                                      }
                                                                                                                    }
                                                                                                                  }
                                                                                                                }
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Attr is a avoid by checking against the following ATerm pattern: appl(prod([lit("avoid")],cf(sort("Attr")),attrs([term(cons("avoid"))])),[appl(prod([char-class([97]),char-class([118]),char-class([111]),char-class([105]),char-class([100])],lit("avoid"),no-attrs),[97,118,111,105,100])]). May not be used to assert correctness of the PTPT_Attr
 * \param[in] arg input PTPT_Attr
 * \return ATtrue if #arg corresponds to the signature of a avoid, or ATfalse otherwise
 */
inline ATbool PTPT_isAttrAvoid(PTPT_Attr arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == PTPT_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == PTPT_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lit */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: avoid */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun47) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
              ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
              /* checking for: cf */
              if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == PTPT_afun2) {
                ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                /* checking for: sort */
                if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == PTPT_afun9) {
                  ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                  /* checking for: Attr */
                  if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == PTPT_afun35) {
                    ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                    /* checking for: attrs */
                    if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == PTPT_afun12) {
                      ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                      if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                        ATerm arg_arg0_arg2_arg0_head;
                        ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                        arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                        arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                        /* checking for: term */
                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == PTPT_afun13) {
                          ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                          /* checking for: cons */
                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == PTPT_afun14) {
                            ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                            /* checking for: avoid */
                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == PTPT_afun47) {
                              if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                ATerm arg_arg1 = ATgetArgument(arg, 1);
                                if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                  ATerm arg_arg1_head;
                                  ATermList arg_arg1_list = (ATermList)arg_arg1;
                                  arg_arg1_head = ATgetFirst(arg_arg1_list);
                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                  /* checking for: appl */
                                  if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                    ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                    /* checking for: prod */
                                    if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                      ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                        ATerm arg_arg1_head_arg0_arg0_head;
                                        ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                        arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                        arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                        /* checking for: char-class */
                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                          ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                            ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                            ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                            arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                            arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                            if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 97) {

                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                  arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                  arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                  /* checking for: char-class */
                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                      ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                      arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                      arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 118) {

                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                            arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                            arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                            /* checking for: char-class */
                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 111) {

                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                      arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                      arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                      /* checking for: char-class */
                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                          ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                          arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                          arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 105) {

                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                /* checking for: char-class */
                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                    ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                    arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                    arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 100) {

                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                          ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                          /* checking for: lit */
                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                            ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                            /* checking for: avoid */
                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun47) {
                                                                                              ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                              /* checking for: no-attrs */
                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                  ATerm arg_arg1_head_arg1_head;
                                                                                                  ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                  arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                  arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 97) {

                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                      arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                      arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 118) {

                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                          arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                          arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 111) {

                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                              arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                              arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 105) {

                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                  arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                  arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 100) {

                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                      if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                                        return ATtrue;
                                                                                                                      }
                                                                                                                    }
                                                                                                                  }
                                                                                                                }
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Attr has a ws-after-assoc. 
 * \param[in] arg input PTPT_Attr
 * \return ATtrue if the PTPT_Attr had a ws-after-assoc, or ATfalse otherwise
 */
ATbool PTPT_hasAttrWsAfterAssoc(PTPT_Attr arg) {
  if (PTPT_isAttrAssoc(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Attr has a ws-after-(. 
 * \param[in] arg input PTPT_Attr
 * \return ATtrue if the PTPT_Attr had a ws-after-(, or ATfalse otherwise
 */
ATbool PTPT_hasAttrWsAfterParenOpen(PTPT_Attr arg) {
  if (PTPT_isAttrAssoc(arg)) {
    return ATtrue;
  }
  else if (PTPT_isAttrTerm(arg)) {
    return ATtrue;
  }
  else if (PTPT_isAttrId(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Attr has a associativity. 
 * \param[in] arg input PTPT_Attr
 * \return ATtrue if the PTPT_Attr had a associativity, or ATfalse otherwise
 */
ATbool PTPT_hasAttrAssociativity(PTPT_Attr arg) {
  if (PTPT_isAttrAssoc(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Attr has a ws-after-associativity. 
 * \param[in] arg input PTPT_Attr
 * \return ATtrue if the PTPT_Attr had a ws-after-associativity, or ATfalse otherwise
 */
ATbool PTPT_hasAttrWsAfterAssociativity(PTPT_Attr arg) {
  if (PTPT_isAttrAssoc(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Attr has a ws-after-term. 
 * \param[in] arg input PTPT_Attr
 * \return ATtrue if the PTPT_Attr had a ws-after-term, or ATfalse otherwise
 */
ATbool PTPT_hasAttrWsAfterTerm(PTPT_Attr arg) {
  if (PTPT_isAttrTerm(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Attr has a aterm. 
 * \param[in] arg input PTPT_Attr
 * \return ATtrue if the PTPT_Attr had a aterm, or ATfalse otherwise
 */
ATbool PTPT_hasAttrAterm(PTPT_Attr arg) {
  if (PTPT_isAttrTerm(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Attr has a ws-after-aterm. 
 * \param[in] arg input PTPT_Attr
 * \return ATtrue if the PTPT_Attr had a ws-after-aterm, or ATfalse otherwise
 */
ATbool PTPT_hasAttrWsAfterAterm(PTPT_Attr arg) {
  if (PTPT_isAttrTerm(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Attr has a ws-after-id. 
 * \param[in] arg input PTPT_Attr
 * \return ATtrue if the PTPT_Attr had a ws-after-id, or ATfalse otherwise
 */
ATbool PTPT_hasAttrWsAfterId(PTPT_Attr arg) {
  if (PTPT_isAttrId(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Attr has a module-name. 
 * \param[in] arg input PTPT_Attr
 * \return ATtrue if the PTPT_Attr had a module-name, or ATfalse otherwise
 */
ATbool PTPT_hasAttrModuleName(PTPT_Attr arg) {
  if (PTPT_isAttrId(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Attr has a ws-after-module-name. 
 * \param[in] arg input PTPT_Attr
 * \return ATtrue if the PTPT_Attr had a ws-after-module-name, or ATfalse otherwise
 */
ATbool PTPT_hasAttrWsAfterModuleName(PTPT_Attr arg) {
  if (PTPT_isAttrId(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Get the ws-after-assoc PTPT_OptLayout of a PTPT_Attr. Note that the precondition is that this PTPT_Attr actually has a ws-after-assoc
 * \param[in] arg input PTPT_Attr
 * \return the ws-after-assoc of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getAttrWsAfterAssoc(PTPT_Attr arg) {
  
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1);
}

/**
 * Get the ws-after-( PTPT_OptLayout of a PTPT_Attr. Note that the precondition is that this PTPT_Attr actually has a ws-after-(
 * \param[in] arg input PTPT_Attr
 * \return the ws-after-( of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getAttrWsAfterParenOpen(PTPT_Attr arg) {
  if (PTPT_isAttrAssoc(arg)) {
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 3);
  }
  else if (PTPT_isAttrTerm(arg)) {
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 3);
  }
  else 
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 3);
}

/**
 * Get the associativity PTPT_Associativity of a PTPT_Attr. Note that the precondition is that this PTPT_Attr actually has a associativity
 * \param[in] arg input PTPT_Attr
 * \return the associativity of #arg, if it exist or an undefined value if it does not
 */
PTPT_Associativity PTPT_getAttrAssociativity(PTPT_Attr arg) {
  
    return (PTPT_Associativity)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 4);
}

/**
 * Get the ws-after-associativity PTPT_OptLayout of a PTPT_Attr. Note that the precondition is that this PTPT_Attr actually has a ws-after-associativity
 * \param[in] arg input PTPT_Attr
 * \return the ws-after-associativity of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getAttrWsAfterAssociativity(PTPT_Attr arg) {
  
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 5);
}

/**
 * Get the ws-after-term PTPT_OptLayout of a PTPT_Attr. Note that the precondition is that this PTPT_Attr actually has a ws-after-term
 * \param[in] arg input PTPT_Attr
 * \return the ws-after-term of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getAttrWsAfterTerm(PTPT_Attr arg) {
  
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1);
}

/**
 * Get the aterm PTPT_ATerm of a PTPT_Attr. Note that the precondition is that this PTPT_Attr actually has a aterm
 * \param[in] arg input PTPT_Attr
 * \return the aterm of #arg, if it exist or an undefined value if it does not
 */
PTPT_ATerm PTPT_getAttrAterm(PTPT_Attr arg) {
  
    return (PTPT_ATerm)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 4);
}

/**
 * Get the ws-after-aterm PTPT_OptLayout of a PTPT_Attr. Note that the precondition is that this PTPT_Attr actually has a ws-after-aterm
 * \param[in] arg input PTPT_Attr
 * \return the ws-after-aterm of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getAttrWsAfterAterm(PTPT_Attr arg) {
  
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 5);
}

/**
 * Get the ws-after-id PTPT_OptLayout of a PTPT_Attr. Note that the precondition is that this PTPT_Attr actually has a ws-after-id
 * \param[in] arg input PTPT_Attr
 * \return the ws-after-id of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getAttrWsAfterId(PTPT_Attr arg) {
  
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1);
}

/**
 * Get the module-name PTPT_StrCon of a PTPT_Attr. Note that the precondition is that this PTPT_Attr actually has a module-name
 * \param[in] arg input PTPT_Attr
 * \return the module-name of #arg, if it exist or an undefined value if it does not
 */
PTPT_StrCon PTPT_getAttrModuleName(PTPT_Attr arg) {
  
    return (PTPT_StrCon)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 4);
}

/**
 * Get the ws-after-module-name PTPT_OptLayout of a PTPT_Attr. Note that the precondition is that this PTPT_Attr actually has a ws-after-module-name
 * \param[in] arg input PTPT_Attr
 * \return the ws-after-module-name of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getAttrWsAfterModuleName(PTPT_Attr arg) {
  
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 5);
}

/**
 * Set the ws-after-assoc of a PTPT_Attr. The precondition being that this PTPT_Attr actually has a ws-after-assoc
 * \param[in] arg input PTPT_Attr
 * \param[in] wsAfterAssoc new PTPT_OptLayout to set in #arg
 * \return A new PTPT_Attr with wsAfterAssoc at the right place, or a core dump if #arg did not have a wsAfterAssoc
 */
PTPT_Attr PTPT_setAttrWsAfterAssoc(PTPT_Attr arg, PTPT_OptLayout wsAfterAssoc) {
  if (PTPT_isAttrAssoc(arg)) {
    return (PTPT_Attr)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterAssoc), 1), 1);
  }

  ATabort("Attr has no WsAfterAssoc: %t\n", arg);
  return (PTPT_Attr)NULL;
}

/**
 * Set the ws-after-( of a PTPT_Attr. The precondition being that this PTPT_Attr actually has a ws-after-(
 * \param[in] arg input PTPT_Attr
 * \param[in] wsAfterParenOpen new PTPT_OptLayout to set in #arg
 * \return A new PTPT_Attr with wsAfterParenOpen at the right place, or a core dump if #arg did not have a wsAfterParenOpen
 */
PTPT_Attr PTPT_setAttrWsAfterParenOpen(PTPT_Attr arg, PTPT_OptLayout wsAfterParenOpen) {
  if (PTPT_isAttrAssoc(arg)) {
    return (PTPT_Attr)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterParenOpen), 3), 1);
  }
  else if (PTPT_isAttrTerm(arg)) {
    return (PTPT_Attr)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterParenOpen), 3), 1);
  }
  else if (PTPT_isAttrId(arg)) {
    return (PTPT_Attr)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterParenOpen), 3), 1);
  }

  ATabort("Attr has no WsAfterParenOpen: %t\n", arg);
  return (PTPT_Attr)NULL;
}

/**
 * Set the associativity of a PTPT_Attr. The precondition being that this PTPT_Attr actually has a associativity
 * \param[in] arg input PTPT_Attr
 * \param[in] associativity new PTPT_Associativity to set in #arg
 * \return A new PTPT_Attr with associativity at the right place, or a core dump if #arg did not have a associativity
 */
PTPT_Attr PTPT_setAttrAssociativity(PTPT_Attr arg, PTPT_Associativity associativity) {
  if (PTPT_isAttrAssoc(arg)) {
    return (PTPT_Attr)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) associativity), 4), 1);
  }

  ATabort("Attr has no Associativity: %t\n", arg);
  return (PTPT_Attr)NULL;
}

/**
 * Set the ws-after-associativity of a PTPT_Attr. The precondition being that this PTPT_Attr actually has a ws-after-associativity
 * \param[in] arg input PTPT_Attr
 * \param[in] wsAfterAssociativity new PTPT_OptLayout to set in #arg
 * \return A new PTPT_Attr with wsAfterAssociativity at the right place, or a core dump if #arg did not have a wsAfterAssociativity
 */
PTPT_Attr PTPT_setAttrWsAfterAssociativity(PTPT_Attr arg, PTPT_OptLayout wsAfterAssociativity) {
  if (PTPT_isAttrAssoc(arg)) {
    return (PTPT_Attr)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterAssociativity), 5), 1);
  }

  ATabort("Attr has no WsAfterAssociativity: %t\n", arg);
  return (PTPT_Attr)NULL;
}

/**
 * Set the ws-after-term of a PTPT_Attr. The precondition being that this PTPT_Attr actually has a ws-after-term
 * \param[in] arg input PTPT_Attr
 * \param[in] wsAfterTerm new PTPT_OptLayout to set in #arg
 * \return A new PTPT_Attr with wsAfterTerm at the right place, or a core dump if #arg did not have a wsAfterTerm
 */
PTPT_Attr PTPT_setAttrWsAfterTerm(PTPT_Attr arg, PTPT_OptLayout wsAfterTerm) {
  if (PTPT_isAttrTerm(arg)) {
    return (PTPT_Attr)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterTerm), 1), 1);
  }

  ATabort("Attr has no WsAfterTerm: %t\n", arg);
  return (PTPT_Attr)NULL;
}

/**
 * Set the aterm of a PTPT_Attr. The precondition being that this PTPT_Attr actually has a aterm
 * \param[in] arg input PTPT_Attr
 * \param[in] aterm new PTPT_ATerm to set in #arg
 * \return A new PTPT_Attr with aterm at the right place, or a core dump if #arg did not have a aterm
 */
PTPT_Attr PTPT_setAttrAterm(PTPT_Attr arg, PTPT_ATerm aterm) {
  if (PTPT_isAttrTerm(arg)) {
    return (PTPT_Attr)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) aterm), 4), 1);
  }

  ATabort("Attr has no Aterm: %t\n", arg);
  return (PTPT_Attr)NULL;
}

/**
 * Set the ws-after-aterm of a PTPT_Attr. The precondition being that this PTPT_Attr actually has a ws-after-aterm
 * \param[in] arg input PTPT_Attr
 * \param[in] wsAfterAterm new PTPT_OptLayout to set in #arg
 * \return A new PTPT_Attr with wsAfterAterm at the right place, or a core dump if #arg did not have a wsAfterAterm
 */
PTPT_Attr PTPT_setAttrWsAfterAterm(PTPT_Attr arg, PTPT_OptLayout wsAfterAterm) {
  if (PTPT_isAttrTerm(arg)) {
    return (PTPT_Attr)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterAterm), 5), 1);
  }

  ATabort("Attr has no WsAfterAterm: %t\n", arg);
  return (PTPT_Attr)NULL;
}

/**
 * Set the ws-after-id of a PTPT_Attr. The precondition being that this PTPT_Attr actually has a ws-after-id
 * \param[in] arg input PTPT_Attr
 * \param[in] wsAfterId new PTPT_OptLayout to set in #arg
 * \return A new PTPT_Attr with wsAfterId at the right place, or a core dump if #arg did not have a wsAfterId
 */
PTPT_Attr PTPT_setAttrWsAfterId(PTPT_Attr arg, PTPT_OptLayout wsAfterId) {
  if (PTPT_isAttrId(arg)) {
    return (PTPT_Attr)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterId), 1), 1);
  }

  ATabort("Attr has no WsAfterId: %t\n", arg);
  return (PTPT_Attr)NULL;
}

/**
 * Set the module-name of a PTPT_Attr. The precondition being that this PTPT_Attr actually has a module-name
 * \param[in] arg input PTPT_Attr
 * \param[in] moduleName new PTPT_StrCon to set in #arg
 * \return A new PTPT_Attr with moduleName at the right place, or a core dump if #arg did not have a moduleName
 */
PTPT_Attr PTPT_setAttrModuleName(PTPT_Attr arg, PTPT_StrCon moduleName) {
  if (PTPT_isAttrId(arg)) {
    return (PTPT_Attr)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) moduleName), 4), 1);
  }

  ATabort("Attr has no ModuleName: %t\n", arg);
  return (PTPT_Attr)NULL;
}

/**
 * Set the ws-after-module-name of a PTPT_Attr. The precondition being that this PTPT_Attr actually has a ws-after-module-name
 * \param[in] arg input PTPT_Attr
 * \param[in] wsAfterModuleName new PTPT_OptLayout to set in #arg
 * \return A new PTPT_Attr with wsAfterModuleName at the right place, or a core dump if #arg did not have a wsAfterModuleName
 */
PTPT_Attr PTPT_setAttrWsAfterModuleName(PTPT_Attr arg, PTPT_OptLayout wsAfterModuleName) {
  if (PTPT_isAttrId(arg)) {
    return (PTPT_Attr)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterModuleName), 5), 1);
  }

  ATabort("Attr has no WsAfterModuleName: %t\n", arg);
  return (PTPT_Attr)NULL;
}

/**
 * Assert whether a PTPT_Associativity is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input PTPT_Associativity
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool PTPT_isValidAssociativity(PTPT_Associativity arg) {
  if (PTPT_isAssociativityLeft(arg)) {
    return ATtrue;
  }
  else if (PTPT_isAssociativityRight(arg)) {
    return ATtrue;
  }
  else if (PTPT_isAssociativityAssoc(arg)) {
    return ATtrue;
  }
  else if (PTPT_isAssociativityNonAssoc(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Associativity is a left by checking against the following ATerm pattern: appl(prod([lit("left")],cf(sort("Associativity")),attrs([term(cons("left"))])),[appl(prod([char-class([108]),char-class([101]),char-class([102]),char-class([116])],lit("left"),no-attrs),[108,101,102,116])]). May not be used to assert correctness of the PTPT_Associativity
 * \param[in] arg input PTPT_Associativity
 * \return ATtrue if #arg corresponds to the signature of a left, or ATfalse otherwise
 */
inline ATbool PTPT_isAssociativityLeft(PTPT_Associativity arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == PTPT_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == PTPT_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lit */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: left */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun48) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
              ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
              /* checking for: cf */
              if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == PTPT_afun2) {
                ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                /* checking for: sort */
                if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == PTPT_afun9) {
                  ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                  /* checking for: Associativity */
                  if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == PTPT_afun38) {
                    ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                    /* checking for: attrs */
                    if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == PTPT_afun12) {
                      ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                      if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                        ATerm arg_arg0_arg2_arg0_head;
                        ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                        arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                        arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                        /* checking for: term */
                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == PTPT_afun13) {
                          ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                          /* checking for: cons */
                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == PTPT_afun14) {
                            ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                            /* checking for: left */
                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == PTPT_afun48) {
                              if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                ATerm arg_arg1 = ATgetArgument(arg, 1);
                                if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                  ATerm arg_arg1_head;
                                  ATermList arg_arg1_list = (ATermList)arg_arg1;
                                  arg_arg1_head = ATgetFirst(arg_arg1_list);
                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                  /* checking for: appl */
                                  if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                    ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                    /* checking for: prod */
                                    if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                      ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                        ATerm arg_arg1_head_arg0_arg0_head;
                                        ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                        arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                        arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                        /* checking for: char-class */
                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                          ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                            ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                            ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                            arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                            arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                            if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 108) {

                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                  arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                  arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                  /* checking for: char-class */
                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                      ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                      arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                      arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 101) {

                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                            arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                            arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                            /* checking for: char-class */
                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 102) {

                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                      arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                      arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                      /* checking for: char-class */
                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                          ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                          arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                          arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 116) {

                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                /* checking for: lit */
                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                  ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                  /* checking for: left */
                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun48) {
                                                                                    ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                    /* checking for: no-attrs */
                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                      ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                        ATerm arg_arg1_head_arg1_head;
                                                                                        ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                        arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                        arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 108) {

                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                            arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                            arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 101) {

                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 102) {

                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                    arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                    arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 116) {

                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                          return ATtrue;
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Associativity is a right by checking against the following ATerm pattern: appl(prod([lit("right")],cf(sort("Associativity")),attrs([term(cons("right"))])),[appl(prod([char-class([114]),char-class([105]),char-class([103]),char-class([104]),char-class([116])],lit("right"),no-attrs),[114,105,103,104,116])]). May not be used to assert correctness of the PTPT_Associativity
 * \param[in] arg input PTPT_Associativity
 * \return ATtrue if #arg corresponds to the signature of a right, or ATfalse otherwise
 */
inline ATbool PTPT_isAssociativityRight(PTPT_Associativity arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == PTPT_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == PTPT_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lit */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: right */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun49) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
              ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
              /* checking for: cf */
              if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == PTPT_afun2) {
                ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                /* checking for: sort */
                if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == PTPT_afun9) {
                  ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                  /* checking for: Associativity */
                  if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == PTPT_afun38) {
                    ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                    /* checking for: attrs */
                    if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == PTPT_afun12) {
                      ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                      if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                        ATerm arg_arg0_arg2_arg0_head;
                        ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                        arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                        arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                        /* checking for: term */
                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == PTPT_afun13) {
                          ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                          /* checking for: cons */
                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == PTPT_afun14) {
                            ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                            /* checking for: right */
                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == PTPT_afun49) {
                              if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                ATerm arg_arg1 = ATgetArgument(arg, 1);
                                if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                  ATerm arg_arg1_head;
                                  ATermList arg_arg1_list = (ATermList)arg_arg1;
                                  arg_arg1_head = ATgetFirst(arg_arg1_list);
                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                  /* checking for: appl */
                                  if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                    ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                    /* checking for: prod */
                                    if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                      ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                        ATerm arg_arg1_head_arg0_arg0_head;
                                        ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                        arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                        arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                        /* checking for: char-class */
                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                          ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                            ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                            ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                            arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                            arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                            if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 114) {

                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                  arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                  arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                  /* checking for: char-class */
                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                      ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                      arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                      arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 105) {

                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                            arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                            arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                            /* checking for: char-class */
                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 103) {

                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                      arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                      arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                      /* checking for: char-class */
                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                          ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                          arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                          arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 104) {

                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                /* checking for: char-class */
                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                    ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                    arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                    arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 116) {

                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                          ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                          /* checking for: lit */
                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                            ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                            /* checking for: right */
                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun49) {
                                                                                              ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                              /* checking for: no-attrs */
                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                  ATerm arg_arg1_head_arg1_head;
                                                                                                  ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                  arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                  arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 114) {

                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                      arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                      arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 105) {

                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                          arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                          arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 103) {

                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                              arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                              arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 104) {

                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                  arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                  arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 116) {

                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                      if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                                        return ATtrue;
                                                                                                                      }
                                                                                                                    }
                                                                                                                  }
                                                                                                                }
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Associativity is a assoc by checking against the following ATerm pattern: appl(prod([lit("assoc")],cf(sort("Associativity")),attrs([term(cons("assoc"))])),[appl(prod([char-class([97]),char-class([115]),char-class([115]),char-class([111]),char-class([99])],lit("assoc"),no-attrs),[97,115,115,111,99])]). May not be used to assert correctness of the PTPT_Associativity
 * \param[in] arg input PTPT_Associativity
 * \return ATtrue if #arg corresponds to the signature of a assoc, or ATfalse otherwise
 */
inline ATbool PTPT_isAssociativityAssoc(PTPT_Associativity arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == PTPT_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == PTPT_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lit */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: assoc */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun39) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
              ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
              /* checking for: cf */
              if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == PTPT_afun2) {
                ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                /* checking for: sort */
                if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == PTPT_afun9) {
                  ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                  /* checking for: Associativity */
                  if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == PTPT_afun38) {
                    ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                    /* checking for: attrs */
                    if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == PTPT_afun12) {
                      ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                      if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                        ATerm arg_arg0_arg2_arg0_head;
                        ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                        arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                        arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                        /* checking for: term */
                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == PTPT_afun13) {
                          ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                          /* checking for: cons */
                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == PTPT_afun14) {
                            ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                            /* checking for: assoc */
                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == PTPT_afun39) {
                              if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                ATerm arg_arg1 = ATgetArgument(arg, 1);
                                if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                  ATerm arg_arg1_head;
                                  ATermList arg_arg1_list = (ATermList)arg_arg1;
                                  arg_arg1_head = ATgetFirst(arg_arg1_list);
                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                  /* checking for: appl */
                                  if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                    ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                    /* checking for: prod */
                                    if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                      ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                        ATerm arg_arg1_head_arg0_arg0_head;
                                        ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                        arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                        arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                        /* checking for: char-class */
                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                          ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                            ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                            ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                            arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                            arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                            if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 97) {

                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                  arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                  arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                  /* checking for: char-class */
                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                      ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                      arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                      arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 115) {

                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                            arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                            arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                            /* checking for: char-class */
                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 115) {

                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                      arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                      arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                      /* checking for: char-class */
                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                          ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                          arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                          arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 111) {

                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                /* checking for: char-class */
                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                    ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                    arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                    arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 99) {

                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                          ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                          /* checking for: lit */
                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                            ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                            /* checking for: assoc */
                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun39) {
                                                                                              ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                              /* checking for: no-attrs */
                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                  ATerm arg_arg1_head_arg1_head;
                                                                                                  ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                  arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                  arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 97) {

                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                      arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                      arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 115) {

                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                          arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                          arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 115) {

                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                              arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                              arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 111) {

                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                  arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                  arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 99) {

                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                      if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                                        return ATtrue;
                                                                                                                      }
                                                                                                                    }
                                                                                                                  }
                                                                                                                }
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Associativity is a non-assoc by checking against the following ATerm pattern: appl(prod([lit("non-assoc")],cf(sort("Associativity")),attrs([term(cons("non-assoc"))])),[appl(prod([char-class([110]),char-class([111]),char-class([110]),char-class([45]),char-class([97]),char-class([115]),char-class([115]),char-class([111]),char-class([99])],lit("non-assoc"),no-attrs),[110,111,110,45,97,115,115,111,99])]). May not be used to assert correctness of the PTPT_Associativity
 * \param[in] arg input PTPT_Associativity
 * \return ATtrue if #arg corresponds to the signature of a non-assoc, or ATfalse otherwise
 */
inline ATbool PTPT_isAssociativityNonAssoc(PTPT_Associativity arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == PTPT_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == PTPT_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lit */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: non-assoc */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun50) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
              ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
              /* checking for: cf */
              if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == PTPT_afun2) {
                ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                /* checking for: sort */
                if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == PTPT_afun9) {
                  ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                  /* checking for: Associativity */
                  if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == PTPT_afun38) {
                    ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                    /* checking for: attrs */
                    if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == PTPT_afun12) {
                      ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                      if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                        ATerm arg_arg0_arg2_arg0_head;
                        ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                        arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                        arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                        /* checking for: term */
                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == PTPT_afun13) {
                          ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                          /* checking for: cons */
                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == PTPT_afun14) {
                            ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                            /* checking for: non-assoc */
                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == PTPT_afun50) {
                              if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                ATerm arg_arg1 = ATgetArgument(arg, 1);
                                if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                  ATerm arg_arg1_head;
                                  ATermList arg_arg1_list = (ATermList)arg_arg1;
                                  arg_arg1_head = ATgetFirst(arg_arg1_list);
                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                  /* checking for: appl */
                                  if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                    ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                    /* checking for: prod */
                                    if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                      ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                        ATerm arg_arg1_head_arg0_arg0_head;
                                        ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                        arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                        arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                        /* checking for: char-class */
                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                          ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                            ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                            ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                            arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                            arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                            if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 110) {

                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                  arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                  arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                  /* checking for: char-class */
                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                      ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                      arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                      arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 111) {

                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                            arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                            arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                            /* checking for: char-class */
                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 110) {

                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                      arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                      arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                      /* checking for: char-class */
                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                          ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                          arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                          arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 45) {

                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                /* checking for: char-class */
                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                    ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                    arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                    arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 97) {

                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                          arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                          arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                          /* checking for: char-class */
                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                              ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                              arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                              arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 115) {

                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                    arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                    arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                    /* checking for: char-class */
                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                        ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                        arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                        arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 115) {

                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                              arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                              arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                              /* checking for: char-class */
                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                  ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 111) {

                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                        arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                        arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                        /* checking for: char-class */
                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                            ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                            arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                            arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 99) {

                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                  ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                  /* checking for: lit */
                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                    ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                    /* checking for: non-assoc */
                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun50) {
                                                                                                                                      ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                      /* checking for: no-attrs */
                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                        ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                          ATerm arg_arg1_head_arg1_head;
                                                                                                                                          ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                          arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                          arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 110) {

                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                              arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                              arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 111) {

                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                  arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                  arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 110) {

                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                      arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                      arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 45) {

                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                          arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                          arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 97) {

                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                              arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                              arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 115) {

                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                  arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                  arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 115) {

                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                      arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                      arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 111) {

                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                          arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                          arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 99) {

                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                                                                                                return ATtrue;
                                                                                                                                                                              }
                                                                                                                                                                            }
                                                                                                                                                                          }
                                                                                                                                                                        }
                                                                                                                                                                      }
                                                                                                                                                                    }
                                                                                                                                                                  }
                                                                                                                                                                }
                                                                                                                                                              }
                                                                                                                                                            }
                                                                                                                                                          }
                                                                                                                                                        }
                                                                                                                                                      }
                                                                                                                                                    }
                                                                                                                                                  }
                                                                                                                                                }
                                                                                                                                              }
                                                                                                                                            }
                                                                                                                                          }
                                                                                                                                        }
                                                                                                                                      }
                                                                                                                                    }
                                                                                                                                  }
                                                                                                                                }
                                                                                                                              }
                                                                                                                            }
                                                                                                                          }
                                                                                                                        }
                                                                                                                      }
                                                                                                                    }
                                                                                                                  }
                                                                                                                }
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_AttrList is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input PTPT_AttrList
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool PTPT_isValidAttrList(PTPT_AttrList arg) {
  if (PTPT_isAttrListEmpty(arg)) {
    return ATtrue;
  }
  else if (PTPT_isAttrListSingle(arg)) {
    return ATtrue;
  }
  else if (PTPT_isAttrListMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_AttrList is a empty by checking against the following ATerm pattern: []. May not be used to assert correctness of the PTPT_AttrList
 * \param[in] arg input PTPT_AttrList
 * \return ATtrue if #arg corresponds to the signature of a empty, or ATfalse otherwise
 */
inline ATbool PTPT_isAttrListEmpty(PTPT_AttrList arg){
  if (ATisEmpty((ATermList)arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_AttrList is a single by checking against the following ATerm pattern: [<head(Attr)>]. May not be used to assert correctness of the PTPT_AttrList
 * \param[in] arg input PTPT_AttrList
 * \return ATtrue if #arg corresponds to the signature of a single, or ATfalse otherwise
 */
inline ATbool PTPT_isAttrListSingle(PTPT_AttrList arg){
  if (ATgetType((ATerm)arg) == AT_LIST && ATisEmpty((ATermList)arg) == ATfalse) {
    ATermList arg_list = (ATermList)arg;
    arg_list = ATgetNext(arg_list);
    if (ATgetType((ATerm)arg_list) == AT_LIST && ATisEmpty((ATermList)arg_list) == ATtrue) {
      return ATtrue;
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_AttrList is a many by checking against the following ATerm pattern: [<head(Attr)>,<ws-after-head("OptLayout")>,appl(prod([char-class([44])],lit(","),no-attrs),[44]),<ws-after-sep("OptLayout")>,<[tail(Attr-list)]>]. May not be used to assert correctness of the PTPT_AttrList
 * \param[in] arg input PTPT_AttrList
 * \return ATtrue if #arg corresponds to the signature of a many, or ATfalse otherwise
 */
inline ATbool PTPT_isAttrListMany(PTPT_AttrList arg){
  if (ATgetType((ATerm)arg) == AT_LIST && ATisEmpty((ATermList)arg) == ATfalse) {
    ATerm arg_head;
    ATermList arg_list = (ATermList)arg;
    arg_list = ATgetNext(arg_list);
    if (ATgetType((ATerm)arg_list) == AT_LIST && ATisEmpty((ATermList)arg_list) == ATfalse) {
      arg_list = ATgetNext(arg_list);
      if (ATgetType((ATerm)arg_list) == AT_LIST && ATisEmpty((ATermList)arg_list) == ATfalse) {
        arg_head = ATgetFirst(arg_list);
        arg_list = ATgetNext(arg_list);
        /* checking for: appl */
        if (ATgetType((ATerm)arg_head) == AT_APPL && ATgetAFun((ATermAppl)arg_head) == PTPT_afun0) {
          ATerm arg_head_arg0 = ATgetArgument(arg_head, 0);
          /* checking for: prod */
          if (ATgetType((ATerm)arg_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_head_arg0) == PTPT_afun1) {
            ATerm arg_head_arg0_arg0 = ATgetArgument(arg_head_arg0, 0);
            if (ATgetType((ATerm)arg_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_head_arg0_arg0) == ATfalse) {
              ATerm arg_head_arg0_arg0_head;
              ATermList arg_head_arg0_arg0_list = (ATermList)arg_head_arg0_arg0;
              arg_head_arg0_arg0_head = ATgetFirst(arg_head_arg0_arg0_list);
              arg_head_arg0_arg0_list = ATgetNext(arg_head_arg0_arg0_list);
              /* checking for: char-class */
              if (ATgetType((ATerm)arg_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_head_arg0_arg0_head) == PTPT_afun23) {
                ATerm arg_head_arg0_arg0_head_arg0 = ATgetArgument(arg_head_arg0_arg0_head, 0);
                if (ATgetType((ATerm)arg_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_head_arg0_arg0_head_arg0) == ATfalse) {
                  ATerm arg_head_arg0_arg0_head_arg0_head;
                  ATermList arg_head_arg0_arg0_head_arg0_list = (ATermList)arg_head_arg0_arg0_head_arg0;
                  arg_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_head_arg0_arg0_head_arg0_list);
                  arg_head_arg0_arg0_head_arg0_list = ATgetNext(arg_head_arg0_arg0_head_arg0_list);
                  if (ATgetInt((ATermInt)arg_head_arg0_arg0_head_arg0_head) == 44) {

                    if (ATgetType((ATerm)arg_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_head_arg0_arg0_head_arg0_list) == ATtrue) {
                      if (ATgetType((ATerm)arg_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_head_arg0_arg0_list) == ATtrue) {
                        ATerm arg_head_arg0_arg1 = ATgetArgument(arg_head_arg0, 1);
                        /* checking for: lit */
                        if (ATgetType((ATerm)arg_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_head_arg0_arg1) == PTPT_afun16) {
                          ATerm arg_head_arg0_arg1_arg0 = ATgetArgument(arg_head_arg0_arg1, 0);
                          /* checking for: , */
                          if (ATgetType((ATerm)arg_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_head_arg0_arg1_arg0) == PTPT_afun19) {
                            ATerm arg_head_arg0_arg2 = ATgetArgument(arg_head_arg0, 2);
                            /* checking for: no-attrs */
                            if (ATgetType((ATerm)arg_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_head_arg0_arg2) == PTPT_afun5) {
                              ATerm arg_head_arg1 = ATgetArgument(arg_head, 1);
                              if (ATgetType((ATerm)arg_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_head_arg1) == ATfalse) {
                                ATerm arg_head_arg1_head;
                                ATermList arg_head_arg1_list = (ATermList)arg_head_arg1;
                                arg_head_arg1_head = ATgetFirst(arg_head_arg1_list);
                                arg_head_arg1_list = ATgetNext(arg_head_arg1_list);
                                if (ATgetInt((ATermInt)arg_head_arg1_head) == 44) {

                                  if (ATgetType((ATerm)arg_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_head_arg1_list) == ATtrue) {
                                    if (ATgetType((ATerm)arg_list) == AT_LIST && ATisEmpty((ATermList)arg_list) == ATfalse) {
                                      return ATtrue;
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_AttrList has a head. 
 * \param[in] arg input PTPT_AttrList
 * \return ATtrue if the PTPT_AttrList had a head, or ATfalse otherwise
 */
ATbool PTPT_hasAttrListHead(PTPT_AttrList arg) {
  if (PTPT_isAttrListSingle(arg)) {
    return ATtrue;
  }
  else if (PTPT_isAttrListMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_AttrList has a ws-after-head. 
 * \param[in] arg input PTPT_AttrList
 * \return ATtrue if the PTPT_AttrList had a ws-after-head, or ATfalse otherwise
 */
ATbool PTPT_hasAttrListWsAfterHead(PTPT_AttrList arg) {
  if (PTPT_isAttrListMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_AttrList has a ws-after-sep. 
 * \param[in] arg input PTPT_AttrList
 * \return ATtrue if the PTPT_AttrList had a ws-after-sep, or ATfalse otherwise
 */
ATbool PTPT_hasAttrListWsAfterSep(PTPT_AttrList arg) {
  if (PTPT_isAttrListMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_AttrList has a tail. 
 * \param[in] arg input PTPT_AttrList
 * \return ATtrue if the PTPT_AttrList had a tail, or ATfalse otherwise
 */
ATbool PTPT_hasAttrListTail(PTPT_AttrList arg) {
  if (PTPT_isAttrListMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Returns a list of all but the first element of a PTPT_AttrList. 
 * \param[in] arg input PTPT_AttrList
 * \return A new PTPT_AttrList, without the first element and the separator(s) just after it.)
 */
PTPT_AttrList PTPT_getAttrListTail(PTPT_AttrList arg) {
  assert(!PTPT_isAttrListEmpty(arg) && "getTail on an empty list");
  if (PTPT_isAttrListSingle(arg)) {
    return (PTPT_AttrList) PTPT_makeAttrListEmpty();
  }
  else {
  
    return (PTPT_AttrList)ATgetTail((ATermList)arg, 4);
  }
}

/**
 * Get the head PTPT_Attr of a PTPT_AttrList. Note that the precondition is that this PTPT_AttrList actually has a head
 * \param[in] arg input PTPT_AttrList
 * \return the head of #arg, if it exist or an undefined value if it does not
 */
PTPT_Attr PTPT_getAttrListHead(PTPT_AttrList arg) {
  if (PTPT_isAttrListSingle(arg)) {
    return (PTPT_Attr)ATgetFirst((ATermList)arg);
  }
  else 
    return (PTPT_Attr)ATgetFirst((ATermList)arg);
}

/**
 * Get the ws-after-head PTPT_OptLayout of a PTPT_AttrList. Note that the precondition is that this PTPT_AttrList actually has a ws-after-head
 * \param[in] arg input PTPT_AttrList
 * \return the ws-after-head of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getAttrListWsAfterHead(PTPT_AttrList arg) {
  
    return (PTPT_OptLayout)ATelementAt((ATermList)arg, 1);
}

/**
 * Get the ws-after-sep PTPT_OptLayout of a PTPT_AttrList. Note that the precondition is that this PTPT_AttrList actually has a ws-after-sep
 * \param[in] arg input PTPT_AttrList
 * \return the ws-after-sep of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getAttrListWsAfterSep(PTPT_AttrList arg) {
  
    return (PTPT_OptLayout)ATelementAt((ATermList)arg, 3);
}

/**
 * Set the head of a PTPT_AttrList. The precondition being that this PTPT_AttrList actually has a head
 * \param[in] arg input PTPT_AttrList
 * \param[in] head new PTPT_Attr to set in #arg
 * \return A new PTPT_AttrList with head at the right place, or a core dump if #arg did not have a head
 */
PTPT_AttrList PTPT_setAttrListHead(PTPT_AttrList arg, PTPT_Attr head) {
  if (PTPT_isAttrListSingle(arg)) {
    return (PTPT_AttrList)ATreplace((ATermList)arg, (ATerm)((ATerm) head), 0);
  }
  else if (PTPT_isAttrListMany(arg)) {
    return (PTPT_AttrList)ATreplace((ATermList)arg, (ATerm)((ATerm) head), 0);
  }

  ATabort("AttrList has no Head: %t\n", arg);
  return (PTPT_AttrList)NULL;
}

/**
 * Set the ws-after-head of a PTPT_AttrList. The precondition being that this PTPT_AttrList actually has a ws-after-head
 * \param[in] arg input PTPT_AttrList
 * \param[in] wsAfterHead new PTPT_OptLayout to set in #arg
 * \return A new PTPT_AttrList with wsAfterHead at the right place, or a core dump if #arg did not have a wsAfterHead
 */
PTPT_AttrList PTPT_setAttrListWsAfterHead(PTPT_AttrList arg, PTPT_OptLayout wsAfterHead) {
  if (PTPT_isAttrListMany(arg)) {
    return (PTPT_AttrList)ATreplace((ATermList)arg, (ATerm)((ATerm) wsAfterHead), 1);
  }

  ATabort("AttrList has no WsAfterHead: %t\n", arg);
  return (PTPT_AttrList)NULL;
}

/**
 * Set the ws-after-sep of a PTPT_AttrList. The precondition being that this PTPT_AttrList actually has a ws-after-sep
 * \param[in] arg input PTPT_AttrList
 * \param[in] wsAfterSep new PTPT_OptLayout to set in #arg
 * \return A new PTPT_AttrList with wsAfterSep at the right place, or a core dump if #arg did not have a wsAfterSep
 */
PTPT_AttrList PTPT_setAttrListWsAfterSep(PTPT_AttrList arg, PTPT_OptLayout wsAfterSep) {
  if (PTPT_isAttrListMany(arg)) {
    return (PTPT_AttrList)ATreplace((ATermList)arg, (ATerm)((ATerm) wsAfterSep), 3);
  }

  ATabort("AttrList has no WsAfterSep: %t\n", arg);
  return (PTPT_AttrList)NULL;
}

/**
 * Set the tail of a PTPT_AttrList. The precondition being that this PTPT_AttrList actually has a tail
 * \param[in] arg input PTPT_AttrList
 * \param[in] tail new PTPT_AttrList to set in #arg
 * \return A new PTPT_AttrList with tail at the right place, or a core dump if #arg did not have a tail
 */
PTPT_AttrList PTPT_setAttrListTail(PTPT_AttrList arg, PTPT_AttrList tail) {
  if (PTPT_isAttrListMany(arg)) {
    return (PTPT_AttrList)ATreplaceTail((ATermList)arg, (ATermList)((ATerm) tail), 4);
  }

  ATabort("AttrList has no Tail: %t\n", arg);
  return (PTPT_AttrList)NULL;
}

/**
 * Assert whether a PTPT_ParseTree is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input PTPT_ParseTree
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool PTPT_isValidParseTree(PTPT_ParseTree arg) {
  if (PTPT_isParseTreeTop(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_ParseTree is a top by checking against the following ATerm pattern: appl(prod([lit("parsetree"),cf(opt(layout)),lit("("),cf(opt(layout)),cf(sort("Tree")),cf(opt(layout)),lit(","),cf(opt(layout)),cf(sort("NatCon")),cf(opt(layout)),lit(")")],cf(sort("ParseTree")),attrs([term(cons("top"))])),[appl(prod([char-class([112]),char-class([97]),char-class([114]),char-class([115]),char-class([101]),char-class([116]),char-class([114]),char-class([101]),char-class([101])],lit("parsetree"),no-attrs),[112,97,114,115,101,116,114,101,101]),<"ws-after-parsetree"("OptLayout")>,appl(prod([char-class([40])],lit("("),no-attrs),[40]),<"ws-after-("("OptLayout")>,<"top"("Tree")>,<"ws-after-top"("OptLayout")>,appl(prod([char-class([44])],lit(","),no-attrs),[44]),<"ws-after-,"("OptLayout")>,<"amb-cnt"("NatCon")>,<"ws-after-amb-cnt"("OptLayout")>,appl(prod([char-class([41])],lit(")"),no-attrs),[41])]). Always returns ATtrue
 * \param[in] arg input PTPT_ParseTree
 * \return ATtrue if #arg corresponds to the signature of a top, or ATfalse otherwise
 */
inline ATbool PTPT_isParseTreeTop(PTPT_ParseTree arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == PTPT_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == PTPT_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lit */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: parsetree */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun51) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
              /* checking for: cf */
              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                /* checking for: opt */
                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                  /* checking for: layout */
                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                      arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                      arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                      /* checking for: lit */
                      if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
                        ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                        /* checking for: ( */
                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun21) {
                          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                            arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                            arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                            /* checking for: cf */
                            if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                              ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                              /* checking for: opt */
                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                /* checking for: layout */
                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                  if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                    arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                    arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                    /* checking for: cf */
                                    if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                      ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                      /* checking for: sort */
                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun9) {
                                        ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                        /* checking for: Tree */
                                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun11) {
                                          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                            arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                            arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                            /* checking for: cf */
                                            if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                              ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                              /* checking for: opt */
                                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                                ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                /* checking for: layout */
                                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                                  if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                    arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                    arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                    /* checking for: lit */
                                                    if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
                                                      ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                      /* checking for: , */
                                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun19) {
                                                        if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                          arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                          arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                          /* checking for: cf */
                                                          if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                                            ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                            /* checking for: opt */
                                                            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                                              ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                              /* checking for: layout */
                                                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                                                if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                                  arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                                  arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                                  /* checking for: cf */
                                                                  if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                                                    ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                                    /* checking for: sort */
                                                                    if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun9) {
                                                                      ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                                      /* checking for: NatCon */
                                                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun24) {
                                                                        if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                                          arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                                          arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                                          /* checking for: cf */
                                                                          if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                                                            ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                                            /* checking for: opt */
                                                                            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                                                              ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                                              /* checking for: layout */
                                                                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                                                                if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                                                  arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                                                  arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                                                  /* checking for: lit */
                                                                                  if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
                                                                                    ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                                                    /* checking for: ) */
                                                                                    if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun17) {
                                                                                      if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                                                                                        ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                                                                        /* checking for: cf */
                                                                                        if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == PTPT_afun2) {
                                                                                          ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                                                                          /* checking for: sort */
                                                                                          if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == PTPT_afun9) {
                                                                                            ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                                                                            /* checking for: ParseTree */
                                                                                            if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == PTPT_afun52) {
                                                                                              ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                                                                              /* checking for: attrs */
                                                                                              if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == PTPT_afun12) {
                                                                                                ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                                                                                if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                                                                                  ATerm arg_arg0_arg2_arg0_head;
                                                                                                  ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                                                                                  arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                                                                                  arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                                                                                  /* checking for: term */
                                                                                                  if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == PTPT_afun13) {
                                                                                                    ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                                                                                    /* checking for: cons */
                                                                                                    if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == PTPT_afun14) {
                                                                                                      ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                                                                                      /* checking for: top */
                                                                                                      if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == PTPT_afun53) {
                                                                                                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                                                                          ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                                                                          if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                                                                            ATerm arg_arg1_head;
                                                                                                            ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                                                                            arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                            arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                            /* checking for: appl */
                                                                                                            if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                              ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                              /* checking for: prod */
                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                                                ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                  ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                  arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                  arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                  /* checking for: char-class */
                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                      ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 112) {

                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                            arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                            arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                            /* checking for: char-class */
                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 97) {

                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                      arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                      arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                      /* checking for: char-class */
                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                          ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                          arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                          arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 114) {

                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                                arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                /* checking for: char-class */
                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                    ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                    arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                    arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 115) {

                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                                          arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                          arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                          /* checking for: char-class */
                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                              ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                              arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                              arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 101) {

                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                                                    arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                    arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                    /* checking for: char-class */
                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                        ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                        arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                        arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 116) {

                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                                                              arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                              arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                              /* checking for: char-class */
                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                  ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 114) {

                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                                                                        arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                        arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                        /* checking for: char-class */
                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                            ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                            arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                            arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 101) {

                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                                                                                  arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                  arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                  /* checking for: char-class */
                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                                      ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 101) {

                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                                                            ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                                                                            /* checking for: lit */
                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                                                                                              ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                                                              /* checking for: parsetree */
                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun51) {
                                                                                                                                                                                                                ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                                                                /* checking for: no-attrs */
                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                                                                                  ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                                                                    ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                                                                    ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                                                                    arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                    arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 112) {

                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                                        arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                        arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 97) {

                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                                            arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                            arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 114) {

                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 115) {

                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                    arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                    arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 101) {

                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                        arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                        arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 116) {

                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                            arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                            arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 114) {

                                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 101) {

                                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                    arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                    arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 101) {

                                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                          arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                            arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                                                                                                                                            arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                            /* checking for: appl */
                                                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                                                                                                                                                                              ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                                                                                                                                                              /* checking for: prod */
                                                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                                                                                                                                                                                                ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                                                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                                                                                                                                                  ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                                                                                                                                                  arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                                                  arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                                                  /* checking for: char-class */
                                                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                                                                                                      ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 40) {

                                                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                                                            ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                                                                                                                                            /* checking for: lit */
                                                                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                                                                                                                                                              ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                                                                                                                              /* checking for: ( */
                                                                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun21) {
                                                                                                                                                                                                                                                                                ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                                                                                                                                /* checking for: no-attrs */
                                                                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                                                                                                                                                  ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                                                                                                                                    ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                                                                                                                                    ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                                                                                                                                    arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                    arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 40) {

                                                                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                          arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                            arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                              arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                                arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                                                                                                                                                                                arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                                                                /* checking for: appl */
                                                                                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                                                                                                                                                                                                                  ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                                                                                                                                                                                                  /* checking for: prod */
                                                                                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                                                                                                                                                                                                                                    ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                                                                                                                                                                                      ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                                                                                                                                                                                      ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                                                                                                                                                                                      arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                                                                                      arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                                                                                      /* checking for: char-class */
                                                                                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                                                                                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                                                                                                                                          ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                                                                                                                                          arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                                                                                          arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 44) {

                                                                                                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                                                                                                ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                                                                                                                                                                                /* checking for: lit */
                                                                                                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                                                                                                                                                                                                  ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                                                                                                                                                                  /* checking for: , */
                                                                                                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun19) {
                                                                                                                                                                                                                                                                                                                    ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                                                                                                                                                                    /* checking for: no-attrs */
                                                                                                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                                                                                                                                                                                      ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                                                                                                                                                                        ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                                                                                                                                                                        ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                                                                                                                                                                        arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                                                        arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 44) {

                                                                                                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                                                              arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                                                                arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                                                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                                                                    arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                                                                                                                                                                                                                    arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                                                                                                    /* checking for: appl */
                                                                                                                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                                                                                                                                                                                                                                                      ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                                                                                                                                                                                                                                      /* checking for: prod */
                                                                                                                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                                                                                                                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                                                                                                                                                                                                                          ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                                                                                                                                                                                                                          ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                                                                                                                                                                                                                          arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                                                                                                                          arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                                                                                                                          /* checking for: char-class */
                                                                                                                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                                                                                                                                                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                                                                                                                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                                                                                                                                                                              ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                                                                                                                                                                              arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                                                                                                                              arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 41) {

                                                                                                                                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                                                                                                                                    ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                                                                                                                                                                                                                    /* checking for: lit */
                                                                                                                                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                                                                                                                                                                                                                                      ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                                                                                                                                                                                                      /* checking for: ) */
                                                                                                                                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun17) {
                                                                                                                                                                                                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                                                                                                                                                                                                        /* checking for: no-attrs */
                                                                                                                                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                                                                                                                                                                                                                          ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                                                                                                                                                                                                            ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                                                                                                                                                                                                            ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                                                                                                                                                                                                            arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                                                                                            arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 41) {

                                                                                                                                                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                                                                                                                                                                                                                                                                                  return ATtrue;
                                                                                                                                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                }
                                                                                                                                                                                                                              }
                                                                                                                                                                                                                            }
                                                                                                                                                                                                                          }
                                                                                                                                                                                                                        }
                                                                                                                                                                                                                      }
                                                                                                                                                                                                                    }
                                                                                                                                                                                                                  }
                                                                                                                                                                                                                }
                                                                                                                                                                                                              }
                                                                                                                                                                                                            }
                                                                                                                                                                                                          }
                                                                                                                                                                                                        }
                                                                                                                                                                                                      }
                                                                                                                                                                                                    }
                                                                                                                                                                                                  }
                                                                                                                                                                                                }
                                                                                                                                                                                              }
                                                                                                                                                                                            }
                                                                                                                                                                                          }
                                                                                                                                                                                        }
                                                                                                                                                                                      }
                                                                                                                                                                                    }
                                                                                                                                                                                  }
                                                                                                                                                                                }
                                                                                                                                                                              }
                                                                                                                                                                            }
                                                                                                                                                                          }
                                                                                                                                                                        }
                                                                                                                                                                      }
                                                                                                                                                                    }
                                                                                                                                                                  }
                                                                                                                                                                }
                                                                                                                                                              }
                                                                                                                                                            }
                                                                                                                                                          }
                                                                                                                                                        }
                                                                                                                                                      }
                                                                                                                                                    }
                                                                                                                                                  }
                                                                                                                                                }
                                                                                                                                              }
                                                                                                                                            }
                                                                                                                                          }
                                                                                                                                        }
                                                                                                                                      }
                                                                                                                                    }
                                                                                                                                  }
                                                                                                                                }
                                                                                                                              }
                                                                                                                            }
                                                                                                                          }
                                                                                                                        }
                                                                                                                      }
                                                                                                                    }
                                                                                                                  }
                                                                                                                }
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_ParseTree has a ws-after-parsetree. 
 * \param[in] arg input PTPT_ParseTree
 * \return ATtrue if the PTPT_ParseTree had a ws-after-parsetree, or ATfalse otherwise
 */
ATbool PTPT_hasParseTreeWsAfterParsetree(PTPT_ParseTree arg) {
  if (PTPT_isParseTreeTop(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_ParseTree has a ws-after-(. 
 * \param[in] arg input PTPT_ParseTree
 * \return ATtrue if the PTPT_ParseTree had a ws-after-(, or ATfalse otherwise
 */
ATbool PTPT_hasParseTreeWsAfterParenOpen(PTPT_ParseTree arg) {
  if (PTPT_isParseTreeTop(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_ParseTree has a top. 
 * \param[in] arg input PTPT_ParseTree
 * \return ATtrue if the PTPT_ParseTree had a top, or ATfalse otherwise
 */
ATbool PTPT_hasParseTreeTop(PTPT_ParseTree arg) {
  if (PTPT_isParseTreeTop(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_ParseTree has a ws-after-top. 
 * \param[in] arg input PTPT_ParseTree
 * \return ATtrue if the PTPT_ParseTree had a ws-after-top, or ATfalse otherwise
 */
ATbool PTPT_hasParseTreeWsAfterTop(PTPT_ParseTree arg) {
  if (PTPT_isParseTreeTop(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_ParseTree has a ws-after-,. 
 * \param[in] arg input PTPT_ParseTree
 * \return ATtrue if the PTPT_ParseTree had a ws-after-,, or ATfalse otherwise
 */
ATbool PTPT_hasParseTreeWsAfterComma(PTPT_ParseTree arg) {
  if (PTPT_isParseTreeTop(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_ParseTree has a amb-cnt. 
 * \param[in] arg input PTPT_ParseTree
 * \return ATtrue if the PTPT_ParseTree had a amb-cnt, or ATfalse otherwise
 */
ATbool PTPT_hasParseTreeAmbCnt(PTPT_ParseTree arg) {
  if (PTPT_isParseTreeTop(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_ParseTree has a ws-after-amb-cnt. 
 * \param[in] arg input PTPT_ParseTree
 * \return ATtrue if the PTPT_ParseTree had a ws-after-amb-cnt, or ATfalse otherwise
 */
ATbool PTPT_hasParseTreeWsAfterAmbCnt(PTPT_ParseTree arg) {
  if (PTPT_isParseTreeTop(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Get the ws-after-parsetree PTPT_OptLayout of a PTPT_ParseTree. Note that the precondition is that this PTPT_ParseTree actually has a ws-after-parsetree
 * \param[in] arg input PTPT_ParseTree
 * \return the ws-after-parsetree of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getParseTreeWsAfterParsetree(PTPT_ParseTree arg) {
  
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1);
}

/**
 * Get the ws-after-( PTPT_OptLayout of a PTPT_ParseTree. Note that the precondition is that this PTPT_ParseTree actually has a ws-after-(
 * \param[in] arg input PTPT_ParseTree
 * \return the ws-after-( of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getParseTreeWsAfterParenOpen(PTPT_ParseTree arg) {
  
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 3);
}

/**
 * Get the top PTPT_Tree of a PTPT_ParseTree. Note that the precondition is that this PTPT_ParseTree actually has a top
 * \param[in] arg input PTPT_ParseTree
 * \return the top of #arg, if it exist or an undefined value if it does not
 */
PTPT_Tree PTPT_getParseTreeTop(PTPT_ParseTree arg) {
  
    return (PTPT_Tree)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 4);
}

/**
 * Get the ws-after-top PTPT_OptLayout of a PTPT_ParseTree. Note that the precondition is that this PTPT_ParseTree actually has a ws-after-top
 * \param[in] arg input PTPT_ParseTree
 * \return the ws-after-top of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getParseTreeWsAfterTop(PTPT_ParseTree arg) {
  
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 5);
}

/**
 * Get the ws-after-, PTPT_OptLayout of a PTPT_ParseTree. Note that the precondition is that this PTPT_ParseTree actually has a ws-after-,
 * \param[in] arg input PTPT_ParseTree
 * \return the ws-after-, of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getParseTreeWsAfterComma(PTPT_ParseTree arg) {
  
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 7);
}

/**
 * Get the amb-cnt PTPT_NatCon of a PTPT_ParseTree. Note that the precondition is that this PTPT_ParseTree actually has a amb-cnt
 * \param[in] arg input PTPT_ParseTree
 * \return the amb-cnt of #arg, if it exist or an undefined value if it does not
 */
PTPT_NatCon PTPT_getParseTreeAmbCnt(PTPT_ParseTree arg) {
  
    return (PTPT_NatCon)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 8);
}

/**
 * Get the ws-after-amb-cnt PTPT_OptLayout of a PTPT_ParseTree. Note that the precondition is that this PTPT_ParseTree actually has a ws-after-amb-cnt
 * \param[in] arg input PTPT_ParseTree
 * \return the ws-after-amb-cnt of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getParseTreeWsAfterAmbCnt(PTPT_ParseTree arg) {
  
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 9);
}

/**
 * Set the ws-after-parsetree of a PTPT_ParseTree. The precondition being that this PTPT_ParseTree actually has a ws-after-parsetree
 * \param[in] arg input PTPT_ParseTree
 * \param[in] wsAfterParsetree new PTPT_OptLayout to set in #arg
 * \return A new PTPT_ParseTree with wsAfterParsetree at the right place, or a core dump if #arg did not have a wsAfterParsetree
 */
PTPT_ParseTree PTPT_setParseTreeWsAfterParsetree(PTPT_ParseTree arg, PTPT_OptLayout wsAfterParsetree) {
  if (PTPT_isParseTreeTop(arg)) {
    return (PTPT_ParseTree)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterParsetree), 1), 1);
  }

  ATabort("ParseTree has no WsAfterParsetree: %t\n", arg);
  return (PTPT_ParseTree)NULL;
}

/**
 * Set the ws-after-( of a PTPT_ParseTree. The precondition being that this PTPT_ParseTree actually has a ws-after-(
 * \param[in] arg input PTPT_ParseTree
 * \param[in] wsAfterParenOpen new PTPT_OptLayout to set in #arg
 * \return A new PTPT_ParseTree with wsAfterParenOpen at the right place, or a core dump if #arg did not have a wsAfterParenOpen
 */
PTPT_ParseTree PTPT_setParseTreeWsAfterParenOpen(PTPT_ParseTree arg, PTPT_OptLayout wsAfterParenOpen) {
  if (PTPT_isParseTreeTop(arg)) {
    return (PTPT_ParseTree)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterParenOpen), 3), 1);
  }

  ATabort("ParseTree has no WsAfterParenOpen: %t\n", arg);
  return (PTPT_ParseTree)NULL;
}

/**
 * Set the top of a PTPT_ParseTree. The precondition being that this PTPT_ParseTree actually has a top
 * \param[in] arg input PTPT_ParseTree
 * \param[in] top new PTPT_Tree to set in #arg
 * \return A new PTPT_ParseTree with top at the right place, or a core dump if #arg did not have a top
 */
PTPT_ParseTree PTPT_setParseTreeTop(PTPT_ParseTree arg, PTPT_Tree top) {
  if (PTPT_isParseTreeTop(arg)) {
    return (PTPT_ParseTree)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) top), 4), 1);
  }

  ATabort("ParseTree has no Top: %t\n", arg);
  return (PTPT_ParseTree)NULL;
}

/**
 * Set the ws-after-top of a PTPT_ParseTree. The precondition being that this PTPT_ParseTree actually has a ws-after-top
 * \param[in] arg input PTPT_ParseTree
 * \param[in] wsAfterTop new PTPT_OptLayout to set in #arg
 * \return A new PTPT_ParseTree with wsAfterTop at the right place, or a core dump if #arg did not have a wsAfterTop
 */
PTPT_ParseTree PTPT_setParseTreeWsAfterTop(PTPT_ParseTree arg, PTPT_OptLayout wsAfterTop) {
  if (PTPT_isParseTreeTop(arg)) {
    return (PTPT_ParseTree)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterTop), 5), 1);
  }

  ATabort("ParseTree has no WsAfterTop: %t\n", arg);
  return (PTPT_ParseTree)NULL;
}

/**
 * Set the ws-after-, of a PTPT_ParseTree. The precondition being that this PTPT_ParseTree actually has a ws-after-,
 * \param[in] arg input PTPT_ParseTree
 * \param[in] wsAfterComma new PTPT_OptLayout to set in #arg
 * \return A new PTPT_ParseTree with wsAfterComma at the right place, or a core dump if #arg did not have a wsAfterComma
 */
PTPT_ParseTree PTPT_setParseTreeWsAfterComma(PTPT_ParseTree arg, PTPT_OptLayout wsAfterComma) {
  if (PTPT_isParseTreeTop(arg)) {
    return (PTPT_ParseTree)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterComma), 7), 1);
  }

  ATabort("ParseTree has no WsAfterComma: %t\n", arg);
  return (PTPT_ParseTree)NULL;
}

/**
 * Set the amb-cnt of a PTPT_ParseTree. The precondition being that this PTPT_ParseTree actually has a amb-cnt
 * \param[in] arg input PTPT_ParseTree
 * \param[in] ambCnt new PTPT_NatCon to set in #arg
 * \return A new PTPT_ParseTree with ambCnt at the right place, or a core dump if #arg did not have a ambCnt
 */
PTPT_ParseTree PTPT_setParseTreeAmbCnt(PTPT_ParseTree arg, PTPT_NatCon ambCnt) {
  if (PTPT_isParseTreeTop(arg)) {
    return (PTPT_ParseTree)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) ambCnt), 8), 1);
  }

  ATabort("ParseTree has no AmbCnt: %t\n", arg);
  return (PTPT_ParseTree)NULL;
}

/**
 * Set the ws-after-amb-cnt of a PTPT_ParseTree. The precondition being that this PTPT_ParseTree actually has a ws-after-amb-cnt
 * \param[in] arg input PTPT_ParseTree
 * \param[in] wsAfterAmbCnt new PTPT_OptLayout to set in #arg
 * \return A new PTPT_ParseTree with wsAfterAmbCnt at the right place, or a core dump if #arg did not have a wsAfterAmbCnt
 */
PTPT_ParseTree PTPT_setParseTreeWsAfterAmbCnt(PTPT_ParseTree arg, PTPT_OptLayout wsAfterAmbCnt) {
  if (PTPT_isParseTreeTop(arg)) {
    return (PTPT_ParseTree)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterAmbCnt), 9), 1);
  }

  ATabort("ParseTree has no WsAfterAmbCnt: %t\n", arg);
  return (PTPT_ParseTree)NULL;
}

/**
 * Assert whether a PTPT_Symbol is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input PTPT_Symbol
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool PTPT_isValidSymbol(PTPT_Symbol arg) {
  if (PTPT_isSymbolEmpty(arg)) {
    return ATtrue;
  }
  else if (PTPT_isSymbolLit(arg)) {
    return ATtrue;
  }
  else if (PTPT_isSymbolCilit(arg)) {
    return ATtrue;
  }
  else if (PTPT_isSymbolCf(arg)) {
    return ATtrue;
  }
  else if (PTPT_isSymbolLex(arg)) {
    return ATtrue;
  }
  else if (PTPT_isSymbolOpt(arg)) {
    return ATtrue;
  }
  else if (PTPT_isSymbolAlt(arg)) {
    return ATtrue;
  }
  else if (PTPT_isSymbolSeq(arg)) {
    return ATtrue;
  }
  else if (PTPT_isSymbolTuple(arg)) {
    return ATtrue;
  }
  else if (PTPT_isSymbolSort(arg)) {
    return ATtrue;
  }
  else if (PTPT_isSymbolIter(arg)) {
    return ATtrue;
  }
  else if (PTPT_isSymbolIterStar(arg)) {
    return ATtrue;
  }
  else if (PTPT_isSymbolIterSep(arg)) {
    return ATtrue;
  }
  else if (PTPT_isSymbolIterStarSep(arg)) {
    return ATtrue;
  }
  else if (PTPT_isSymbolIterN(arg)) {
    return ATtrue;
  }
  else if (PTPT_isSymbolIterSepN(arg)) {
    return ATtrue;
  }
  else if (PTPT_isSymbolFunc(arg)) {
    return ATtrue;
  }
  else if (PTPT_isSymbolVarsym(arg)) {
    return ATtrue;
  }
  else if (PTPT_isSymbolLayout(arg)) {
    return ATtrue;
  }
  else if (PTPT_isSymbolCharClass(arg)) {
    return ATtrue;
  }
  else if (PTPT_isSymbolStrategy(arg)) {
    return ATtrue;
  }
  else if (PTPT_isSymbolParameterizedSort(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Symbol is a empty by checking against the following ATerm pattern: appl(prod([lit("empty")],cf(sort("Symbol")),attrs([term(cons("empty"))])),[appl(prod([char-class([101]),char-class([109]),char-class([112]),char-class([116]),char-class([121])],lit("empty"),no-attrs),[101,109,112,116,121])]). May not be used to assert correctness of the PTPT_Symbol
 * \param[in] arg input PTPT_Symbol
 * \return ATtrue if #arg corresponds to the signature of a empty, or ATfalse otherwise
 */
inline ATbool PTPT_isSymbolEmpty(PTPT_Symbol arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == PTPT_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == PTPT_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lit */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: empty */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun54) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
              ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
              /* checking for: cf */
              if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == PTPT_afun2) {
                ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                /* checking for: sort */
                if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == PTPT_afun9) {
                  ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                  /* checking for: Symbol */
                  if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == PTPT_afun25) {
                    ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                    /* checking for: attrs */
                    if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == PTPT_afun12) {
                      ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                      if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                        ATerm arg_arg0_arg2_arg0_head;
                        ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                        arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                        arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                        /* checking for: term */
                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == PTPT_afun13) {
                          ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                          /* checking for: cons */
                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == PTPT_afun14) {
                            ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                            /* checking for: empty */
                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == PTPT_afun54) {
                              if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                ATerm arg_arg1 = ATgetArgument(arg, 1);
                                if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                  ATerm arg_arg1_head;
                                  ATermList arg_arg1_list = (ATermList)arg_arg1;
                                  arg_arg1_head = ATgetFirst(arg_arg1_list);
                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                  /* checking for: appl */
                                  if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                    ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                    /* checking for: prod */
                                    if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                      ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                        ATerm arg_arg1_head_arg0_arg0_head;
                                        ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                        arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                        arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                        /* checking for: char-class */
                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                          ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                            ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                            ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                            arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                            arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                            if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 101) {

                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                  arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                  arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                  /* checking for: char-class */
                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                      ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                      arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                      arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 109) {

                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                            arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                            arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                            /* checking for: char-class */
                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 112) {

                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                      arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                      arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                      /* checking for: char-class */
                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                          ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                          arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                          arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 116) {

                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                /* checking for: char-class */
                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                    ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                    arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                    arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 121) {

                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                          ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                          /* checking for: lit */
                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                            ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                            /* checking for: empty */
                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun54) {
                                                                                              ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                              /* checking for: no-attrs */
                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                  ATerm arg_arg1_head_arg1_head;
                                                                                                  ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                  arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                  arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 101) {

                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                      arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                      arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 109) {

                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                          arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                          arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 112) {

                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                              arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                              arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 116) {

                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                  arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                  arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 121) {

                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                      if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                                        return ATtrue;
                                                                                                                      }
                                                                                                                    }
                                                                                                                  }
                                                                                                                }
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Symbol is a lit by checking against the following ATerm pattern: appl(prod([lit("lit"),cf(opt(layout)),lit("("),cf(opt(layout)),cf(sort("StrCon")),cf(opt(layout)),lit(")")],cf(sort("Symbol")),attrs([term(cons("lit"))])),[appl(prod([char-class([108]),char-class([105]),char-class([116])],lit("lit"),no-attrs),[108,105,116]),<"ws-after-lit"("OptLayout")>,appl(prod([char-class([40])],lit("("),no-attrs),[40]),<"ws-after-("("OptLayout")>,<"string"("StrCon")>,<"ws-after-string"("OptLayout")>,appl(prod([char-class([41])],lit(")"),no-attrs),[41])]). May not be used to assert correctness of the PTPT_Symbol
 * \param[in] arg input PTPT_Symbol
 * \return ATtrue if #arg corresponds to the signature of a lit, or ATfalse otherwise
 */
inline ATbool PTPT_isSymbolLit(PTPT_Symbol arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == PTPT_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == PTPT_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lit */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: lit */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun55) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
              /* checking for: cf */
              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                /* checking for: opt */
                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                  /* checking for: layout */
                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                      arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                      arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                      /* checking for: lit */
                      if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
                        ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                        /* checking for: ( */
                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun21) {
                          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                            arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                            arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                            /* checking for: cf */
                            if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                              ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                              /* checking for: opt */
                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                /* checking for: layout */
                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                  if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                    arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                    arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                    /* checking for: cf */
                                    if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                      ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                      /* checking for: sort */
                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun9) {
                                        ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                        /* checking for: StrCon */
                                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun42) {
                                          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                            arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                            arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                            /* checking for: cf */
                                            if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                              ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                              /* checking for: opt */
                                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                                ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                /* checking for: layout */
                                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                                  if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                    arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                    arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                    /* checking for: lit */
                                                    if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
                                                      ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                      /* checking for: ) */
                                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun17) {
                                                        if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                                                          ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                                          /* checking for: cf */
                                                          if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == PTPT_afun2) {
                                                            ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                                            /* checking for: sort */
                                                            if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == PTPT_afun9) {
                                                              ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                                              /* checking for: Symbol */
                                                              if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == PTPT_afun25) {
                                                                ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                                                /* checking for: attrs */
                                                                if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == PTPT_afun12) {
                                                                  ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                                                  if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                                                    ATerm arg_arg0_arg2_arg0_head;
                                                                    ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                                                    arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                                                    arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                                                    /* checking for: term */
                                                                    if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == PTPT_afun13) {
                                                                      ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                                                      /* checking for: cons */
                                                                      if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == PTPT_afun14) {
                                                                        ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                                                        /* checking for: lit */
                                                                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == PTPT_afun55) {
                                                                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                                            ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                                            if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                                              ATerm arg_arg1_head;
                                                                              ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                                              arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                              arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                              /* checking for: appl */
                                                                              if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                /* checking for: prod */
                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                  ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                    ATerm arg_arg1_head_arg0_arg0_head;
                                                                                    ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                    arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                    arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                    /* checking for: char-class */
                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                        ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                        arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                        arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 108) {

                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                              arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                              arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                              /* checking for: char-class */
                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                  ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 105) {

                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                        arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                        arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                        /* checking for: char-class */
                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                            ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                            arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                            arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 116) {

                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                  ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                  /* checking for: lit */
                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                    ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                    /* checking for: lit */
                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun55) {
                                                                                                                      ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                      /* checking for: no-attrs */
                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                        ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                          ATerm arg_arg1_head_arg1_head;
                                                                                                                          ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                          arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                          arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 108) {

                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                              arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                              arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 105) {

                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                  arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                  arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 116) {

                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                      if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                        arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                          arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                          arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                          /* checking for: appl */
                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                                                            ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                                            /* checking for: prod */
                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                                                                              ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                                ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                                ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                                arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                /* checking for: char-class */
                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                    ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                    arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                    arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 40) {

                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                          ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                          /* checking for: lit */
                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                                            ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                            /* checking for: ( */
                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun21) {
                                                                                                                                                              ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                              /* checking for: no-attrs */
                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                                ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                  ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                  ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                  arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                  arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 40) {

                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                        arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                          arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                            arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                              arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                                                              arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                              /* checking for: appl */
                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                                                                                                ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                                                                                /* checking for: prod */
                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                                                                                                                  ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                                                                    ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                                                                    arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                    arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                    /* checking for: char-class */
                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                        ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                        arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                        arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 41) {

                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                                              ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                                                              /* checking for: lit */
                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                                                                                ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                                                /* checking for: ) */
                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun17) {
                                                                                                                                                                                                  ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                                                  /* checking for: no-attrs */
                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                                                                    ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                                                      ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                                                      ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                                                      arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                      arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 41) {

                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                                                                                                                            return ATtrue;
                                                                                                                                                                                                          }
                                                                                                                                                                                                        }
                                                                                                                                                                                                      }
                                                                                                                                                                                                    }
                                                                                                                                                                                                  }
                                                                                                                                                                                                }
                                                                                                                                                                                              }
                                                                                                                                                                                            }
                                                                                                                                                                                          }
                                                                                                                                                                                        }
                                                                                                                                                                                      }
                                                                                                                                                                                    }
                                                                                                                                                                                  }
                                                                                                                                                                                }
                                                                                                                                                                              }
                                                                                                                                                                            }
                                                                                                                                                                          }
                                                                                                                                                                        }
                                                                                                                                                                      }
                                                                                                                                                                    }
                                                                                                                                                                  }
                                                                                                                                                                }
                                                                                                                                                              }
                                                                                                                                                            }
                                                                                                                                                          }
                                                                                                                                                        }
                                                                                                                                                      }
                                                                                                                                                    }
                                                                                                                                                  }
                                                                                                                                                }
                                                                                                                                              }
                                                                                                                                            }
                                                                                                                                          }
                                                                                                                                        }
                                                                                                                                      }
                                                                                                                                    }
                                                                                                                                  }
                                                                                                                                }
                                                                                                                              }
                                                                                                                            }
                                                                                                                          }
                                                                                                                        }
                                                                                                                      }
                                                                                                                    }
                                                                                                                  }
                                                                                                                }
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Symbol is a cilit by checking against the following ATerm pattern: appl(prod([lit("cilit"),cf(opt(layout)),lit("("),cf(opt(layout)),cf(sort("StrCon")),cf(opt(layout)),lit(")")],cf(sort("Symbol")),attrs([term(cons("cilit"))])),[appl(prod([char-class([99]),char-class([105]),char-class([108]),char-class([105]),char-class([116])],lit("cilit"),no-attrs),[99,105,108,105,116]),<"ws-after-cilit"("OptLayout")>,appl(prod([char-class([40])],lit("("),no-attrs),[40]),<"ws-after-("("OptLayout")>,<"string"("StrCon")>,<"ws-after-string"("OptLayout")>,appl(prod([char-class([41])],lit(")"),no-attrs),[41])]). May not be used to assert correctness of the PTPT_Symbol
 * \param[in] arg input PTPT_Symbol
 * \return ATtrue if #arg corresponds to the signature of a cilit, or ATfalse otherwise
 */
inline ATbool PTPT_isSymbolCilit(PTPT_Symbol arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == PTPT_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == PTPT_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lit */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: cilit */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun56) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
              /* checking for: cf */
              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                /* checking for: opt */
                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                  /* checking for: layout */
                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                      arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                      arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                      /* checking for: lit */
                      if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
                        ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                        /* checking for: ( */
                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun21) {
                          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                            arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                            arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                            /* checking for: cf */
                            if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                              ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                              /* checking for: opt */
                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                /* checking for: layout */
                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                  if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                    arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                    arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                    /* checking for: cf */
                                    if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                      ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                      /* checking for: sort */
                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun9) {
                                        ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                        /* checking for: StrCon */
                                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun42) {
                                          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                            arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                            arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                            /* checking for: cf */
                                            if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                              ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                              /* checking for: opt */
                                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                                ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                /* checking for: layout */
                                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                                  if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                    arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                    arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                    /* checking for: lit */
                                                    if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
                                                      ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                      /* checking for: ) */
                                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun17) {
                                                        if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                                                          ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                                          /* checking for: cf */
                                                          if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == PTPT_afun2) {
                                                            ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                                            /* checking for: sort */
                                                            if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == PTPT_afun9) {
                                                              ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                                              /* checking for: Symbol */
                                                              if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == PTPT_afun25) {
                                                                ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                                                /* checking for: attrs */
                                                                if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == PTPT_afun12) {
                                                                  ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                                                  if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                                                    ATerm arg_arg0_arg2_arg0_head;
                                                                    ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                                                    arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                                                    arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                                                    /* checking for: term */
                                                                    if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == PTPT_afun13) {
                                                                      ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                                                      /* checking for: cons */
                                                                      if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == PTPT_afun14) {
                                                                        ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                                                        /* checking for: cilit */
                                                                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == PTPT_afun56) {
                                                                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                                            ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                                            if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                                              ATerm arg_arg1_head;
                                                                              ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                                              arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                              arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                              /* checking for: appl */
                                                                              if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                /* checking for: prod */
                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                  ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                    ATerm arg_arg1_head_arg0_arg0_head;
                                                                                    ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                    arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                    arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                    /* checking for: char-class */
                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                        ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                        arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                        arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 99) {

                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                              arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                              arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                              /* checking for: char-class */
                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                  ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 105) {

                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                        arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                        arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                        /* checking for: char-class */
                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                            ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                            arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                            arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 108) {

                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                  arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                  arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                  /* checking for: char-class */
                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                      ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 105) {

                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                            arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                            arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                            /* checking for: char-class */
                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 116) {

                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                      ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                      /* checking for: lit */
                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                        ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                        /* checking for: cilit */
                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun56) {
                                                                                                                                          ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                          /* checking for: no-attrs */
                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                            ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                              ATerm arg_arg1_head_arg1_head;
                                                                                                                                              ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                              arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                              arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 99) {

                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                  arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                  arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 105) {

                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                      arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                      arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 108) {

                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                          arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                          arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 105) {

                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                              arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                              arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 116) {

                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                    arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                      arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                                                      arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                      /* checking for: appl */
                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                                                                                        ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                                                                        /* checking for: prod */
                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                                                                                                          ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                                                            ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                                                            ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                                                            arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                            arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                            /* checking for: char-class */
                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 40) {

                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                                      ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                                                      /* checking for: lit */
                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                                        /* checking for: ( */
                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun21) {
                                                                                                                                                                                          ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                                          /* checking for: no-attrs */
                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                                                            ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                                              ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                                              ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                                              arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                              arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 40) {

                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                    arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                      arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                        arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                          arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                                                                                          arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                          /* checking for: appl */
                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                                                                                                                            ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                                                                                                            /* checking for: prod */
                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                                                                                                                                              ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                                                                                                ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                                                                                                ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                                                                                                arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                /* checking for: char-class */
                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                                                    ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                                                    arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                    arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 41) {

                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                                                                          ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                                                                                          /* checking for: lit */
                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                                                                                                            ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                                                                            /* checking for: ) */
                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun17) {
                                                                                                                                                                                                                              ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                                                                              /* checking for: no-attrs */
                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                                                                                                ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                                                                                  ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                                                                                  ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                                                                                  arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                  arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 41) {

                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                                                                                                                                                        return ATtrue;
                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                }
                                                                                                                                                                                                                              }
                                                                                                                                                                                                                            }
                                                                                                                                                                                                                          }
                                                                                                                                                                                                                        }
                                                                                                                                                                                                                      }
                                                                                                                                                                                                                    }
                                                                                                                                                                                                                  }
                                                                                                                                                                                                                }
                                                                                                                                                                                                              }
                                                                                                                                                                                                            }
                                                                                                                                                                                                          }
                                                                                                                                                                                                        }
                                                                                                                                                                                                      }
                                                                                                                                                                                                    }
                                                                                                                                                                                                  }
                                                                                                                                                                                                }
                                                                                                                                                                                              }
                                                                                                                                                                                            }
                                                                                                                                                                                          }
                                                                                                                                                                                        }
                                                                                                                                                                                      }
                                                                                                                                                                                    }
                                                                                                                                                                                  }
                                                                                                                                                                                }
                                                                                                                                                                              }
                                                                                                                                                                            }
                                                                                                                                                                          }
                                                                                                                                                                        }
                                                                                                                                                                      }
                                                                                                                                                                    }
                                                                                                                                                                  }
                                                                                                                                                                }
                                                                                                                                                              }
                                                                                                                                                            }
                                                                                                                                                          }
                                                                                                                                                        }
                                                                                                                                                      }
                                                                                                                                                    }
                                                                                                                                                  }
                                                                                                                                                }
                                                                                                                                              }
                                                                                                                                            }
                                                                                                                                          }
                                                                                                                                        }
                                                                                                                                      }
                                                                                                                                    }
                                                                                                                                  }
                                                                                                                                }
                                                                                                                              }
                                                                                                                            }
                                                                                                                          }
                                                                                                                        }
                                                                                                                      }
                                                                                                                    }
                                                                                                                  }
                                                                                                                }
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Symbol is a cf by checking against the following ATerm pattern: appl(prod([lit("cf"),cf(opt(layout)),lit("("),cf(opt(layout)),cf(sort("Symbol")),cf(opt(layout)),lit(")")],cf(sort("Symbol")),attrs([term(cons("cf"))])),[appl(prod([char-class([99]),char-class([102])],lit("cf"),no-attrs),[99,102]),<"ws-after-cf"("OptLayout")>,appl(prod([char-class([40])],lit("("),no-attrs),[40]),<"ws-after-("("OptLayout")>,<"symbol"("Symbol")>,<"ws-after-symbol"("OptLayout")>,appl(prod([char-class([41])],lit(")"),no-attrs),[41])]). May not be used to assert correctness of the PTPT_Symbol
 * \param[in] arg input PTPT_Symbol
 * \return ATtrue if #arg corresponds to the signature of a cf, or ATfalse otherwise
 */
inline ATbool PTPT_isSymbolCf(PTPT_Symbol arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == PTPT_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == PTPT_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lit */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: cf */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun57) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
              /* checking for: cf */
              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                /* checking for: opt */
                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                  /* checking for: layout */
                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                      arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                      arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                      /* checking for: lit */
                      if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
                        ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                        /* checking for: ( */
                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun21) {
                          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                            arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                            arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                            /* checking for: cf */
                            if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                              ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                              /* checking for: opt */
                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                /* checking for: layout */
                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                  if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                    arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                    arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                    /* checking for: cf */
                                    if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                      ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                      /* checking for: sort */
                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun9) {
                                        ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                        /* checking for: Symbol */
                                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun25) {
                                          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                            arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                            arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                            /* checking for: cf */
                                            if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                              ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                              /* checking for: opt */
                                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                                ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                /* checking for: layout */
                                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                                  if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                    arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                    arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                    /* checking for: lit */
                                                    if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
                                                      ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                      /* checking for: ) */
                                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun17) {
                                                        if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                                                          ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                                          /* checking for: cf */
                                                          if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == PTPT_afun2) {
                                                            ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                                            /* checking for: sort */
                                                            if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == PTPT_afun9) {
                                                              ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                                              /* checking for: Symbol */
                                                              if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == PTPT_afun25) {
                                                                ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                                                /* checking for: attrs */
                                                                if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == PTPT_afun12) {
                                                                  ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                                                  if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                                                    ATerm arg_arg0_arg2_arg0_head;
                                                                    ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                                                    arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                                                    arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                                                    /* checking for: term */
                                                                    if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == PTPT_afun13) {
                                                                      ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                                                      /* checking for: cons */
                                                                      if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == PTPT_afun14) {
                                                                        ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                                                        /* checking for: cf */
                                                                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == PTPT_afun57) {
                                                                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                                            ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                                            if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                                              ATerm arg_arg1_head;
                                                                              ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                                              arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                              arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                              /* checking for: appl */
                                                                              if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                /* checking for: prod */
                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                  ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                    ATerm arg_arg1_head_arg0_arg0_head;
                                                                                    ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                    arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                    arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                    /* checking for: char-class */
                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                        ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                        arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                        arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 99) {

                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                              arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                              arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                              /* checking for: char-class */
                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                  ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 102) {

                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                        ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                        /* checking for: lit */
                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                          ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                          /* checking for: cf */
                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun57) {
                                                                                                            ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                            /* checking for: no-attrs */
                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                              ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                ATerm arg_arg1_head_arg1_head;
                                                                                                                ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 99) {

                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                    arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                    arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 102) {

                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                          arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                          if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                            arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                            arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                            /* checking for: appl */
                                                                                                                            if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                                              ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                              /* checking for: prod */
                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                                                                ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                  ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                  arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                  arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                  /* checking for: char-class */
                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                      ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 40) {

                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                            ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                            /* checking for: lit */
                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                              ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                              /* checking for: ( */
                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun21) {
                                                                                                                                                ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                /* checking for: no-attrs */
                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                  ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                    ATerm arg_arg1_head_arg1_head;
                                                                                                                                                    ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                    arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                    arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 40) {

                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                          arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                            arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                              arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                                                arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                /* checking for: appl */
                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                                                                                  ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                                                                  /* checking for: prod */
                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                                                                                                    ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                                                      ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                                                      ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                                                      arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                      arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                      /* checking for: char-class */
                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                          ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                          arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                          arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 41) {

                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                                ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                                                /* checking for: lit */
                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                                                                  ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                                  /* checking for: ) */
                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun17) {
                                                                                                                                                                                    ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                                    /* checking for: no-attrs */
                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                                                      ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                                        ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                                        ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                                        arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                        arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 41) {

                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                                                                                                              return ATtrue;
                                                                                                                                                                                            }
                                                                                                                                                                                          }
                                                                                                                                                                                        }
                                                                                                                                                                                      }
                                                                                                                                                                                    }
                                                                                                                                                                                  }
                                                                                                                                                                                }
                                                                                                                                                                              }
                                                                                                                                                                            }
                                                                                                                                                                          }
                                                                                                                                                                        }
                                                                                                                                                                      }
                                                                                                                                                                    }
                                                                                                                                                                  }
                                                                                                                                                                }
                                                                                                                                                              }
                                                                                                                                                            }
                                                                                                                                                          }
                                                                                                                                                        }
                                                                                                                                                      }
                                                                                                                                                    }
                                                                                                                                                  }
                                                                                                                                                }
                                                                                                                                              }
                                                                                                                                            }
                                                                                                                                          }
                                                                                                                                        }
                                                                                                                                      }
                                                                                                                                    }
                                                                                                                                  }
                                                                                                                                }
                                                                                                                              }
                                                                                                                            }
                                                                                                                          }
                                                                                                                        }
                                                                                                                      }
                                                                                                                    }
                                                                                                                  }
                                                                                                                }
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Symbol is a lex by checking against the following ATerm pattern: appl(prod([lit("lex"),cf(opt(layout)),lit("("),cf(opt(layout)),cf(sort("Symbol")),cf(opt(layout)),lit(")")],cf(sort("Symbol")),attrs([term(cons("lex"))])),[appl(prod([char-class([108]),char-class([101]),char-class([120])],lit("lex"),no-attrs),[108,101,120]),<"ws-after-lex"("OptLayout")>,appl(prod([char-class([40])],lit("("),no-attrs),[40]),<"ws-after-("("OptLayout")>,<"symbol"("Symbol")>,<"ws-after-symbol"("OptLayout")>,appl(prod([char-class([41])],lit(")"),no-attrs),[41])]). May not be used to assert correctness of the PTPT_Symbol
 * \param[in] arg input PTPT_Symbol
 * \return ATtrue if #arg corresponds to the signature of a lex, or ATfalse otherwise
 */
inline ATbool PTPT_isSymbolLex(PTPT_Symbol arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == PTPT_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == PTPT_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lit */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: lex */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun58) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
              /* checking for: cf */
              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                /* checking for: opt */
                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                  /* checking for: layout */
                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                      arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                      arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                      /* checking for: lit */
                      if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
                        ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                        /* checking for: ( */
                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun21) {
                          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                            arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                            arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                            /* checking for: cf */
                            if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                              ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                              /* checking for: opt */
                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                /* checking for: layout */
                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                  if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                    arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                    arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                    /* checking for: cf */
                                    if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                      ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                      /* checking for: sort */
                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun9) {
                                        ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                        /* checking for: Symbol */
                                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun25) {
                                          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                            arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                            arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                            /* checking for: cf */
                                            if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                              ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                              /* checking for: opt */
                                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                                ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                /* checking for: layout */
                                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                                  if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                    arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                    arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                    /* checking for: lit */
                                                    if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
                                                      ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                      /* checking for: ) */
                                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun17) {
                                                        if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                                                          ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                                          /* checking for: cf */
                                                          if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == PTPT_afun2) {
                                                            ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                                            /* checking for: sort */
                                                            if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == PTPT_afun9) {
                                                              ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                                              /* checking for: Symbol */
                                                              if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == PTPT_afun25) {
                                                                ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                                                /* checking for: attrs */
                                                                if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == PTPT_afun12) {
                                                                  ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                                                  if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                                                    ATerm arg_arg0_arg2_arg0_head;
                                                                    ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                                                    arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                                                    arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                                                    /* checking for: term */
                                                                    if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == PTPT_afun13) {
                                                                      ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                                                      /* checking for: cons */
                                                                      if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == PTPT_afun14) {
                                                                        ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                                                        /* checking for: lex */
                                                                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == PTPT_afun58) {
                                                                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                                            ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                                            if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                                              ATerm arg_arg1_head;
                                                                              ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                                              arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                              arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                              /* checking for: appl */
                                                                              if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                /* checking for: prod */
                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                  ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                    ATerm arg_arg1_head_arg0_arg0_head;
                                                                                    ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                    arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                    arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                    /* checking for: char-class */
                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                        ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                        arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                        arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 108) {

                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                              arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                              arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                              /* checking for: char-class */
                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                  ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 101) {

                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                        arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                        arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                        /* checking for: char-class */
                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                            ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                            arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                            arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 120) {

                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                  ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                  /* checking for: lit */
                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                    ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                    /* checking for: lex */
                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun58) {
                                                                                                                      ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                      /* checking for: no-attrs */
                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                        ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                          ATerm arg_arg1_head_arg1_head;
                                                                                                                          ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                          arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                          arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 108) {

                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                              arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                              arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 101) {

                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                  arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                  arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 120) {

                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                      if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                        arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                          arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                          arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                          /* checking for: appl */
                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                                                            ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                                            /* checking for: prod */
                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                                                                              ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                                ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                                ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                                arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                /* checking for: char-class */
                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                    ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                    arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                    arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 40) {

                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                          ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                          /* checking for: lit */
                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                                            ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                            /* checking for: ( */
                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun21) {
                                                                                                                                                              ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                              /* checking for: no-attrs */
                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                                ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                  ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                  ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                  arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                  arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 40) {

                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                        arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                          arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                            arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                              arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                                                              arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                              /* checking for: appl */
                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                                                                                                ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                                                                                /* checking for: prod */
                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                                                                                                                  ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                                                                    ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                                                                    arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                    arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                    /* checking for: char-class */
                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                        ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                        arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                        arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 41) {

                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                                              ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                                                              /* checking for: lit */
                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                                                                                ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                                                /* checking for: ) */
                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun17) {
                                                                                                                                                                                                  ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                                                  /* checking for: no-attrs */
                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                                                                    ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                                                      ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                                                      ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                                                      arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                      arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 41) {

                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                                                                                                                            return ATtrue;
                                                                                                                                                                                                          }
                                                                                                                                                                                                        }
                                                                                                                                                                                                      }
                                                                                                                                                                                                    }
                                                                                                                                                                                                  }
                                                                                                                                                                                                }
                                                                                                                                                                                              }
                                                                                                                                                                                            }
                                                                                                                                                                                          }
                                                                                                                                                                                        }
                                                                                                                                                                                      }
                                                                                                                                                                                    }
                                                                                                                                                                                  }
                                                                                                                                                                                }
                                                                                                                                                                              }
                                                                                                                                                                            }
                                                                                                                                                                          }
                                                                                                                                                                        }
                                                                                                                                                                      }
                                                                                                                                                                    }
                                                                                                                                                                  }
                                                                                                                                                                }
                                                                                                                                                              }
                                                                                                                                                            }
                                                                                                                                                          }
                                                                                                                                                        }
                                                                                                                                                      }
                                                                                                                                                    }
                                                                                                                                                  }
                                                                                                                                                }
                                                                                                                                              }
                                                                                                                                            }
                                                                                                                                          }
                                                                                                                                        }
                                                                                                                                      }
                                                                                                                                    }
                                                                                                                                  }
                                                                                                                                }
                                                                                                                              }
                                                                                                                            }
                                                                                                                          }
                                                                                                                        }
                                                                                                                      }
                                                                                                                    }
                                                                                                                  }
                                                                                                                }
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Symbol is a opt by checking against the following ATerm pattern: appl(prod([lit("opt"),cf(opt(layout)),lit("("),cf(opt(layout)),cf(sort("Symbol")),cf(opt(layout)),lit(")")],cf(sort("Symbol")),attrs([term(cons("opt"))])),[appl(prod([char-class([111]),char-class([112]),char-class([116])],lit("opt"),no-attrs),[111,112,116]),<"ws-after-opt"("OptLayout")>,appl(prod([char-class([40])],lit("("),no-attrs),[40]),<"ws-after-("("OptLayout")>,<"symbol"("Symbol")>,<"ws-after-symbol"("OptLayout")>,appl(prod([char-class([41])],lit(")"),no-attrs),[41])]). May not be used to assert correctness of the PTPT_Symbol
 * \param[in] arg input PTPT_Symbol
 * \return ATtrue if #arg corresponds to the signature of a opt, or ATfalse otherwise
 */
inline ATbool PTPT_isSymbolOpt(PTPT_Symbol arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == PTPT_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == PTPT_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lit */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: opt */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun59) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
              /* checking for: cf */
              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                /* checking for: opt */
                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                  /* checking for: layout */
                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                      arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                      arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                      /* checking for: lit */
                      if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
                        ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                        /* checking for: ( */
                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun21) {
                          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                            arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                            arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                            /* checking for: cf */
                            if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                              ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                              /* checking for: opt */
                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                /* checking for: layout */
                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                  if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                    arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                    arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                    /* checking for: cf */
                                    if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                      ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                      /* checking for: sort */
                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun9) {
                                        ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                        /* checking for: Symbol */
                                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun25) {
                                          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                            arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                            arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                            /* checking for: cf */
                                            if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                              ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                              /* checking for: opt */
                                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                                ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                /* checking for: layout */
                                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                                  if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                    arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                    arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                    /* checking for: lit */
                                                    if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
                                                      ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                      /* checking for: ) */
                                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun17) {
                                                        if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                                                          ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                                          /* checking for: cf */
                                                          if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == PTPT_afun2) {
                                                            ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                                            /* checking for: sort */
                                                            if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == PTPT_afun9) {
                                                              ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                                              /* checking for: Symbol */
                                                              if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == PTPT_afun25) {
                                                                ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                                                /* checking for: attrs */
                                                                if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == PTPT_afun12) {
                                                                  ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                                                  if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                                                    ATerm arg_arg0_arg2_arg0_head;
                                                                    ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                                                    arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                                                    arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                                                    /* checking for: term */
                                                                    if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == PTPT_afun13) {
                                                                      ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                                                      /* checking for: cons */
                                                                      if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == PTPT_afun14) {
                                                                        ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                                                        /* checking for: opt */
                                                                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == PTPT_afun59) {
                                                                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                                            ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                                            if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                                              ATerm arg_arg1_head;
                                                                              ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                                              arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                              arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                              /* checking for: appl */
                                                                              if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                /* checking for: prod */
                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                  ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                    ATerm arg_arg1_head_arg0_arg0_head;
                                                                                    ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                    arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                    arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                    /* checking for: char-class */
                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                        ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                        arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                        arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 111) {

                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                              arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                              arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                              /* checking for: char-class */
                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                  ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 112) {

                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                        arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                        arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                        /* checking for: char-class */
                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                            ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                            arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                            arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 116) {

                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                  ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                  /* checking for: lit */
                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                    ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                    /* checking for: opt */
                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun59) {
                                                                                                                      ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                      /* checking for: no-attrs */
                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                        ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                          ATerm arg_arg1_head_arg1_head;
                                                                                                                          ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                          arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                          arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 111) {

                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                              arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                              arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 112) {

                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                  arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                  arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 116) {

                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                      if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                        arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                          arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                          arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                          /* checking for: appl */
                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                                                            ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                                            /* checking for: prod */
                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                                                                              ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                                ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                                ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                                arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                /* checking for: char-class */
                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                    ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                    arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                    arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 40) {

                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                          ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                          /* checking for: lit */
                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                                            ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                            /* checking for: ( */
                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun21) {
                                                                                                                                                              ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                              /* checking for: no-attrs */
                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                                ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                  ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                  ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                  arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                  arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 40) {

                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                        arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                          arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                            arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                              arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                                                              arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                              /* checking for: appl */
                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                                                                                                ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                                                                                /* checking for: prod */
                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                                                                                                                  ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                                                                    ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                                                                    arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                    arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                    /* checking for: char-class */
                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                        ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                        arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                        arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 41) {

                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                                              ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                                                              /* checking for: lit */
                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                                                                                ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                                                /* checking for: ) */
                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun17) {
                                                                                                                                                                                                  ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                                                  /* checking for: no-attrs */
                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                                                                    ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                                                      ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                                                      ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                                                      arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                      arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 41) {

                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                                                                                                                            return ATtrue;
                                                                                                                                                                                                          }
                                                                                                                                                                                                        }
                                                                                                                                                                                                      }
                                                                                                                                                                                                    }
                                                                                                                                                                                                  }
                                                                                                                                                                                                }
                                                                                                                                                                                              }
                                                                                                                                                                                            }
                                                                                                                                                                                          }
                                                                                                                                                                                        }
                                                                                                                                                                                      }
                                                                                                                                                                                    }
                                                                                                                                                                                  }
                                                                                                                                                                                }
                                                                                                                                                                              }
                                                                                                                                                                            }
                                                                                                                                                                          }
                                                                                                                                                                        }
                                                                                                                                                                      }
                                                                                                                                                                    }
                                                                                                                                                                  }
                                                                                                                                                                }
                                                                                                                                                              }
                                                                                                                                                            }
                                                                                                                                                          }
                                                                                                                                                        }
                                                                                                                                                      }
                                                                                                                                                    }
                                                                                                                                                  }
                                                                                                                                                }
                                                                                                                                              }
                                                                                                                                            }
                                                                                                                                          }
                                                                                                                                        }
                                                                                                                                      }
                                                                                                                                    }
                                                                                                                                  }
                                                                                                                                }
                                                                                                                              }
                                                                                                                            }
                                                                                                                          }
                                                                                                                        }
                                                                                                                      }
                                                                                                                    }
                                                                                                                  }
                                                                                                                }
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Symbol is a alt by checking against the following ATerm pattern: appl(prod([lit("alt"),cf(opt(layout)),lit("("),cf(opt(layout)),cf(sort("Symbol")),cf(opt(layout)),lit(","),cf(opt(layout)),cf(sort("Symbol")),cf(opt(layout)),lit(")")],cf(sort("Symbol")),attrs([term(cons("alt"))])),[appl(prod([char-class([97]),char-class([108]),char-class([116])],lit("alt"),no-attrs),[97,108,116]),<"ws-after-alt"("OptLayout")>,appl(prod([char-class([40])],lit("("),no-attrs),[40]),<"ws-after-("("OptLayout")>,<"lhs"("Symbol")>,<"ws-after-lhs"("OptLayout")>,appl(prod([char-class([44])],lit(","),no-attrs),[44]),<"ws-after-,"("OptLayout")>,<"rhs"("Symbol")>,<"ws-after-rhs"("OptLayout")>,appl(prod([char-class([41])],lit(")"),no-attrs),[41])]). May not be used to assert correctness of the PTPT_Symbol
 * \param[in] arg input PTPT_Symbol
 * \return ATtrue if #arg corresponds to the signature of a alt, or ATfalse otherwise
 */
inline ATbool PTPT_isSymbolAlt(PTPT_Symbol arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == PTPT_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == PTPT_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lit */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: alt */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun60) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
              /* checking for: cf */
              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                /* checking for: opt */
                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                  /* checking for: layout */
                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                      arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                      arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                      /* checking for: lit */
                      if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
                        ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                        /* checking for: ( */
                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun21) {
                          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                            arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                            arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                            /* checking for: cf */
                            if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                              ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                              /* checking for: opt */
                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                /* checking for: layout */
                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                  if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                    arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                    arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                    /* checking for: cf */
                                    if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                      ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                      /* checking for: sort */
                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun9) {
                                        ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                        /* checking for: Symbol */
                                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun25) {
                                          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                            arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                            arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                            /* checking for: cf */
                                            if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                              ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                              /* checking for: opt */
                                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                                ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                /* checking for: layout */
                                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                                  if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                    arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                    arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                    /* checking for: lit */
                                                    if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
                                                      ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                      /* checking for: , */
                                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun19) {
                                                        if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                          arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                          arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                          /* checking for: cf */
                                                          if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                                            ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                            /* checking for: opt */
                                                            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                                              ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                              /* checking for: layout */
                                                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                                                if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                                  arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                                  arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                                  /* checking for: cf */
                                                                  if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                                                    ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                                    /* checking for: sort */
                                                                    if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun9) {
                                                                      ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                                      /* checking for: Symbol */
                                                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun25) {
                                                                        if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                                          arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                                          arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                                          /* checking for: cf */
                                                                          if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                                                            ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                                            /* checking for: opt */
                                                                            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                                                              ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                                              /* checking for: layout */
                                                                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                                                                if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                                                  arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                                                  arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                                                  /* checking for: lit */
                                                                                  if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
                                                                                    ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                                                    /* checking for: ) */
                                                                                    if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun17) {
                                                                                      if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                                                                                        ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                                                                        /* checking for: cf */
                                                                                        if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == PTPT_afun2) {
                                                                                          ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                                                                          /* checking for: sort */
                                                                                          if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == PTPT_afun9) {
                                                                                            ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                                                                            /* checking for: Symbol */
                                                                                            if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == PTPT_afun25) {
                                                                                              ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                                                                              /* checking for: attrs */
                                                                                              if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == PTPT_afun12) {
                                                                                                ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                                                                                if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                                                                                  ATerm arg_arg0_arg2_arg0_head;
                                                                                                  ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                                                                                  arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                                                                                  arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                                                                                  /* checking for: term */
                                                                                                  if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == PTPT_afun13) {
                                                                                                    ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                                                                                    /* checking for: cons */
                                                                                                    if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == PTPT_afun14) {
                                                                                                      ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                                                                                      /* checking for: alt */
                                                                                                      if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == PTPT_afun60) {
                                                                                                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                                                                          ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                                                                          if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                                                                            ATerm arg_arg1_head;
                                                                                                            ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                                                                            arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                            arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                            /* checking for: appl */
                                                                                                            if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                              ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                              /* checking for: prod */
                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                                                ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                  ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                  arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                  arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                  /* checking for: char-class */
                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                      ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 97) {

                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                            arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                            arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                            /* checking for: char-class */
                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 108) {

                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                      arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                      arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                      /* checking for: char-class */
                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                          ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                          arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                          arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 116) {

                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                /* checking for: lit */
                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                                  ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                  /* checking for: alt */
                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun60) {
                                                                                                                                                    ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                    /* checking for: no-attrs */
                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                      ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                        ATerm arg_arg1_head_arg1_head;
                                                                                                                                                        ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                        arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                        arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 97) {

                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                            arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                            arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 108) {

                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 116) {

                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                      arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                        arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                                                        arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                        /* checking for: appl */
                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                                                                                          ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                                                                          /* checking for: prod */
                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                                                                                                            ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                                                              ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                                                              ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                                                              arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                              arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                              /* checking for: char-class */
                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                  ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 40) {

                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                                                        /* checking for: lit */
                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                                                                          ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                                          /* checking for: ( */
                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun21) {
                                                                                                                                                                                            ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                                            /* checking for: no-attrs */
                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                                                              ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                                                ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                                                ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                                                arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 40) {

                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                      arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                        arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                          arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                            arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                                                                                            arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                            /* checking for: appl */
                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                                                                                                                              ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                                                                                                              /* checking for: prod */
                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                                                                                                                                                ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                                                                                                  ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                                                                                                  arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                  arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                  /* checking for: char-class */
                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                                                      ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 44) {

                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                                                                            ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                                                                                            /* checking for: lit */
                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                                                                                                              ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                                                                              /* checking for: , */
                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun19) {
                                                                                                                                                                                                                                ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                                                                                /* checking for: no-attrs */
                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                                                                                                  ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                                                                                    ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                                                                                    ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                                                                                    arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                    arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 44) {

                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                          arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                            arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                              arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                                                                                                                                arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                /* checking for: appl */
                                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                                                                                                                                                                  ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                                                                                                                                                  /* checking for: prod */
                                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                                                                                                                                                                                    ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                                                                                                                                      ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                                                                                                                                      ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                                                                                                                                      arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                                      arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                                      /* checking for: char-class */
                                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                                                                                          ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                                                                                          arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                                          arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 41) {

                                                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                                                ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                                                                                                                                /* checking for: lit */
                                                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                                                                                                                                                  ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                                                                                                                  /* checking for: ) */
                                                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun17) {
                                                                                                                                                                                                                                                                    ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                                                                                                                    /* checking for: no-attrs */
                                                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                                                                                                                                      ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                                                                                                                        ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                                                                                                                        ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                                                                                                                        arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                        arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 41) {

                                                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                                                                                                                                                                                              return ATtrue;
                                                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                }
                                                                                                                                                                                                                              }
                                                                                                                                                                                                                            }
                                                                                                                                                                                                                          }
                                                                                                                                                                                                                        }
                                                                                                                                                                                                                      }
                                                                                                                                                                                                                    }
                                                                                                                                                                                                                  }
                                                                                                                                                                                                                }
                                                                                                                                                                                                              }
                                                                                                                                                                                                            }
                                                                                                                                                                                                          }
                                                                                                                                                                                                        }
                                                                                                                                                                                                      }
                                                                                                                                                                                                    }
                                                                                                                                                                                                  }
                                                                                                                                                                                                }
                                                                                                                                                                                              }
                                                                                                                                                                                            }
                                                                                                                                                                                          }
                                                                                                                                                                                        }
                                                                                                                                                                                      }
                                                                                                                                                                                    }
                                                                                                                                                                                  }
                                                                                                                                                                                }
                                                                                                                                                                              }
                                                                                                                                                                            }
                                                                                                                                                                          }
                                                                                                                                                                        }
                                                                                                                                                                      }
                                                                                                                                                                    }
                                                                                                                                                                  }
                                                                                                                                                                }
                                                                                                                                                              }
                                                                                                                                                            }
                                                                                                                                                          }
                                                                                                                                                        }
                                                                                                                                                      }
                                                                                                                                                    }
                                                                                                                                                  }
                                                                                                                                                }
                                                                                                                                              }
                                                                                                                                            }
                                                                                                                                          }
                                                                                                                                        }
                                                                                                                                      }
                                                                                                                                    }
                                                                                                                                  }
                                                                                                                                }
                                                                                                                              }
                                                                                                                            }
                                                                                                                          }
                                                                                                                        }
                                                                                                                      }
                                                                                                                    }
                                                                                                                  }
                                                                                                                }
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Symbol is a seq by checking against the following ATerm pattern: appl(prod([lit("seq"),cf(opt(layout)),lit("("),cf(opt(layout)),cf(sort("Symbols")),cf(opt(layout)),lit(")")],cf(sort("Symbol")),attrs([term(cons("seq"))])),[appl(prod([char-class([115]),char-class([101]),char-class([113])],lit("seq"),no-attrs),[115,101,113]),<"ws-after-seq"("OptLayout")>,appl(prod([char-class([40])],lit("("),no-attrs),[40]),<"ws-after-("("OptLayout")>,<"symbols"("Symbols")>,<"ws-after-symbols"("OptLayout")>,appl(prod([char-class([41])],lit(")"),no-attrs),[41])]). May not be used to assert correctness of the PTPT_Symbol
 * \param[in] arg input PTPT_Symbol
 * \return ATtrue if #arg corresponds to the signature of a seq, or ATfalse otherwise
 */
inline ATbool PTPT_isSymbolSeq(PTPT_Symbol arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == PTPT_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == PTPT_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lit */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: seq */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun62) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
              /* checking for: cf */
              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                /* checking for: opt */
                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                  /* checking for: layout */
                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                      arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                      arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                      /* checking for: lit */
                      if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
                        ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                        /* checking for: ( */
                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun21) {
                          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                            arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                            arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                            /* checking for: cf */
                            if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                              ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                              /* checking for: opt */
                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                /* checking for: layout */
                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                  if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                    arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                    arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                    /* checking for: cf */
                                    if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                      ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                      /* checking for: sort */
                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun9) {
                                        ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                        /* checking for: Symbols */
                                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun61) {
                                          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                            arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                            arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                            /* checking for: cf */
                                            if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                              ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                              /* checking for: opt */
                                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                                ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                /* checking for: layout */
                                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                                  if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                    arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                    arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                    /* checking for: lit */
                                                    if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
                                                      ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                      /* checking for: ) */
                                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun17) {
                                                        if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                                                          ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                                          /* checking for: cf */
                                                          if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == PTPT_afun2) {
                                                            ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                                            /* checking for: sort */
                                                            if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == PTPT_afun9) {
                                                              ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                                              /* checking for: Symbol */
                                                              if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == PTPT_afun25) {
                                                                ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                                                /* checking for: attrs */
                                                                if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == PTPT_afun12) {
                                                                  ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                                                  if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                                                    ATerm arg_arg0_arg2_arg0_head;
                                                                    ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                                                    arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                                                    arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                                                    /* checking for: term */
                                                                    if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == PTPT_afun13) {
                                                                      ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                                                      /* checking for: cons */
                                                                      if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == PTPT_afun14) {
                                                                        ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                                                        /* checking for: seq */
                                                                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == PTPT_afun62) {
                                                                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                                            ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                                            if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                                              ATerm arg_arg1_head;
                                                                              ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                                              arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                              arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                              /* checking for: appl */
                                                                              if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                /* checking for: prod */
                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                  ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                    ATerm arg_arg1_head_arg0_arg0_head;
                                                                                    ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                    arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                    arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                    /* checking for: char-class */
                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                        ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                        arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                        arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 115) {

                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                              arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                              arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                              /* checking for: char-class */
                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                  ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 101) {

                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                        arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                        arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                        /* checking for: char-class */
                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                            ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                            arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                            arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 113) {

                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                  ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                  /* checking for: lit */
                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                    ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                    /* checking for: seq */
                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun62) {
                                                                                                                      ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                      /* checking for: no-attrs */
                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                        ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                          ATerm arg_arg1_head_arg1_head;
                                                                                                                          ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                          arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                          arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 115) {

                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                              arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                              arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 101) {

                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                  arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                  arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 113) {

                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                      if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                        arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                          arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                          arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                          /* checking for: appl */
                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                                                            ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                                            /* checking for: prod */
                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                                                                              ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                                ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                                ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                                arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                /* checking for: char-class */
                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                    ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                    arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                    arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 40) {

                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                          ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                          /* checking for: lit */
                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                                            ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                            /* checking for: ( */
                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun21) {
                                                                                                                                                              ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                              /* checking for: no-attrs */
                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                                ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                  ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                  ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                  arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                  arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 40) {

                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                        arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                          arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                            arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                              arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                                                              arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                              /* checking for: appl */
                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                                                                                                ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                                                                                /* checking for: prod */
                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                                                                                                                  ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                                                                    ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                                                                    arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                    arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                    /* checking for: char-class */
                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                        ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                        arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                        arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 41) {

                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                                              ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                                                              /* checking for: lit */
                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                                                                                ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                                                /* checking for: ) */
                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun17) {
                                                                                                                                                                                                  ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                                                  /* checking for: no-attrs */
                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                                                                    ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                                                      ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                                                      ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                                                      arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                      arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 41) {

                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                                                                                                                            return ATtrue;
                                                                                                                                                                                                          }
                                                                                                                                                                                                        }
                                                                                                                                                                                                      }
                                                                                                                                                                                                    }
                                                                                                                                                                                                  }
                                                                                                                                                                                                }
                                                                                                                                                                                              }
                                                                                                                                                                                            }
                                                                                                                                                                                          }
                                                                                                                                                                                        }
                                                                                                                                                                                      }
                                                                                                                                                                                    }
                                                                                                                                                                                  }
                                                                                                                                                                                }
                                                                                                                                                                              }
                                                                                                                                                                            }
                                                                                                                                                                          }
                                                                                                                                                                        }
                                                                                                                                                                      }
                                                                                                                                                                    }
                                                                                                                                                                  }
                                                                                                                                                                }
                                                                                                                                                              }
                                                                                                                                                            }
                                                                                                                                                          }
                                                                                                                                                        }
                                                                                                                                                      }
                                                                                                                                                    }
                                                                                                                                                  }
                                                                                                                                                }
                                                                                                                                              }
                                                                                                                                            }
                                                                                                                                          }
                                                                                                                                        }
                                                                                                                                      }
                                                                                                                                    }
                                                                                                                                  }
                                                                                                                                }
                                                                                                                              }
                                                                                                                            }
                                                                                                                          }
                                                                                                                        }
                                                                                                                      }
                                                                                                                    }
                                                                                                                  }
                                                                                                                }
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Symbol is a tuple by checking against the following ATerm pattern: appl(prod([lit("tuple"),cf(opt(layout)),lit("("),cf(opt(layout)),cf(sort("Symbol")),cf(opt(layout)),lit(","),cf(opt(layout)),cf(sort("Symbols")),cf(opt(layout)),lit(")")],cf(sort("Symbol")),attrs([term(cons("tuple"))])),[appl(prod([char-class([116]),char-class([117]),char-class([112]),char-class([108]),char-class([101])],lit("tuple"),no-attrs),[116,117,112,108,101]),<"ws-after-tuple"("OptLayout")>,appl(prod([char-class([40])],lit("("),no-attrs),[40]),<"ws-after-("("OptLayout")>,<"head"("Symbol")>,<"ws-after-head"("OptLayout")>,appl(prod([char-class([44])],lit(","),no-attrs),[44]),<"ws-after-,"("OptLayout")>,<"rest"("Symbols")>,<"ws-after-rest"("OptLayout")>,appl(prod([char-class([41])],lit(")"),no-attrs),[41])]). May not be used to assert correctness of the PTPT_Symbol
 * \param[in] arg input PTPT_Symbol
 * \return ATtrue if #arg corresponds to the signature of a tuple, or ATfalse otherwise
 */
inline ATbool PTPT_isSymbolTuple(PTPT_Symbol arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == PTPT_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == PTPT_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lit */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: tuple */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun63) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
              /* checking for: cf */
              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                /* checking for: opt */
                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                  /* checking for: layout */
                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                      arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                      arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                      /* checking for: lit */
                      if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
                        ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                        /* checking for: ( */
                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun21) {
                          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                            arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                            arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                            /* checking for: cf */
                            if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                              ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                              /* checking for: opt */
                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                /* checking for: layout */
                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                  if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                    arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                    arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                    /* checking for: cf */
                                    if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                      ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                      /* checking for: sort */
                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun9) {
                                        ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                        /* checking for: Symbol */
                                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun25) {
                                          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                            arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                            arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                            /* checking for: cf */
                                            if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                              ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                              /* checking for: opt */
                                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                                ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                /* checking for: layout */
                                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                                  if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                    arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                    arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                    /* checking for: lit */
                                                    if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
                                                      ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                      /* checking for: , */
                                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun19) {
                                                        if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                          arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                          arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                          /* checking for: cf */
                                                          if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                                            ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                            /* checking for: opt */
                                                            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                                              ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                              /* checking for: layout */
                                                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                                                if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                                  arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                                  arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                                  /* checking for: cf */
                                                                  if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                                                    ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                                    /* checking for: sort */
                                                                    if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun9) {
                                                                      ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                                      /* checking for: Symbols */
                                                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun61) {
                                                                        if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                                          arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                                          arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                                          /* checking for: cf */
                                                                          if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                                                            ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                                            /* checking for: opt */
                                                                            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                                                              ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                                              /* checking for: layout */
                                                                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                                                                if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                                                  arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                                                  arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                                                  /* checking for: lit */
                                                                                  if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
                                                                                    ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                                                    /* checking for: ) */
                                                                                    if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun17) {
                                                                                      if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                                                                                        ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                                                                        /* checking for: cf */
                                                                                        if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == PTPT_afun2) {
                                                                                          ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                                                                          /* checking for: sort */
                                                                                          if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == PTPT_afun9) {
                                                                                            ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                                                                            /* checking for: Symbol */
                                                                                            if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == PTPT_afun25) {
                                                                                              ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                                                                              /* checking for: attrs */
                                                                                              if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == PTPT_afun12) {
                                                                                                ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                                                                                if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                                                                                  ATerm arg_arg0_arg2_arg0_head;
                                                                                                  ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                                                                                  arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                                                                                  arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                                                                                  /* checking for: term */
                                                                                                  if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == PTPT_afun13) {
                                                                                                    ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                                                                                    /* checking for: cons */
                                                                                                    if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == PTPT_afun14) {
                                                                                                      ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                                                                                      /* checking for: tuple */
                                                                                                      if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == PTPT_afun63) {
                                                                                                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                                                                          ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                                                                          if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                                                                            ATerm arg_arg1_head;
                                                                                                            ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                                                                            arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                            arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                            /* checking for: appl */
                                                                                                            if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                              ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                              /* checking for: prod */
                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                                                ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                  ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                  arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                  arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                  /* checking for: char-class */
                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                      ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 116) {

                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                            arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                            arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                            /* checking for: char-class */
                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 117) {

                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                      arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                      arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                      /* checking for: char-class */
                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                          ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                          arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                          arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 112) {

                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                                arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                /* checking for: char-class */
                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                    ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                    arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                    arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 108) {

                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                                          arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                          arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                          /* checking for: char-class */
                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                              ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                              arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                              arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 101) {

                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                    ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                                    /* checking for: lit */
                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                                                      ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                      /* checking for: tuple */
                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun63) {
                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                        /* checking for: no-attrs */
                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                                          ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                            ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                            ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                            arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                            arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 116) {

                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 117) {

                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                    arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                    arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 112) {

                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                        arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                        arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 108) {

                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                            arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                            arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 101) {

                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                    arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                                                                                    arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                    /* checking for: appl */
                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                                                                                                                      ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                                                                                                      /* checking for: prod */
                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                                                                                          ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                                                                                          ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                                                                                          arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                          arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                          /* checking for: char-class */
                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                                              ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                                              arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                              arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 40) {

                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                                                                    ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                                                                                    /* checking for: lit */
                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                                                                                                      ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                                                                      /* checking for: ( */
                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun21) {
                                                                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                                                                        /* checking for: no-attrs */
                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                                                                                          ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                                                                            ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                                                                            ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                                                                            arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                            arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 40) {

                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                    arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                      arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                        arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                                                                                                                        arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                        /* checking for: appl */
                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                                                                                                                                                          ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                                                                                                                                          /* checking for: prod */
                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                                                                                                                                                                            ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                                                                                                                              ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                                                                                                                              ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                                                                                                                              arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                              arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                              /* checking for: char-class */
                                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                                                                                  ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 44) {

                                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                                                                                                                        /* checking for: lit */
                                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                                                                                                                                          ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                                                                                                          /* checking for: , */
                                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun19) {
                                                                                                                                                                                                                                                            ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                                                                                                            /* checking for: no-attrs */
                                                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                                                                                                                              ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                                                                                                                ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                                                                                                                ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                                                                                                                arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 44) {

                                                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                      arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                        arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                          arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                            arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                                                                                                                                                            arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                                            /* checking for: appl */
                                                                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                                                                                                                                                                                              ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                                                                                                                                                                              /* checking for: prod */
                                                                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                                                                                                                                                                                                                ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                                                                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                                                                                                                                                                  ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                                                                                                                                                                  arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                                                                  arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                                                                  /* checking for: char-class */
                                                                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                                                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                                                                                                                      ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 41) {

                                                                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                                                                            ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                                                                                                                                                            /* checking for: lit */
                                                                                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                                                                                                                                                                              ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                                                                                                                                              /* checking for: ) */
                                                                                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun17) {
                                                                                                                                                                                                                                                                                                ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                                                                                                                                                /* checking for: no-attrs */
                                                                                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                                                                                                                                                                  ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                                                                                                                                                    ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                                                                                                                                                    ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                                                                                                                                                    arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                                    arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 41) {

                                                                                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                                                                                                                                                                                                                          return ATtrue;
                                                                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                }
                                                                                                                                                                                                                              }
                                                                                                                                                                                                                            }
                                                                                                                                                                                                                          }
                                                                                                                                                                                                                        }
                                                                                                                                                                                                                      }
                                                                                                                                                                                                                    }
                                                                                                                                                                                                                  }
                                                                                                                                                                                                                }
                                                                                                                                                                                                              }
                                                                                                                                                                                                            }
                                                                                                                                                                                                          }
                                                                                                                                                                                                        }
                                                                                                                                                                                                      }
                                                                                                                                                                                                    }
                                                                                                                                                                                                  }
                                                                                                                                                                                                }
                                                                                                                                                                                              }
                                                                                                                                                                                            }
                                                                                                                                                                                          }
                                                                                                                                                                                        }
                                                                                                                                                                                      }
                                                                                                                                                                                    }
                                                                                                                                                                                  }
                                                                                                                                                                                }
                                                                                                                                                                              }
                                                                                                                                                                            }
                                                                                                                                                                          }
                                                                                                                                                                        }
                                                                                                                                                                      }
                                                                                                                                                                    }
                                                                                                                                                                  }
                                                                                                                                                                }
                                                                                                                                                              }
                                                                                                                                                            }
                                                                                                                                                          }
                                                                                                                                                        }
                                                                                                                                                      }
                                                                                                                                                    }
                                                                                                                                                  }
                                                                                                                                                }
                                                                                                                                              }
                                                                                                                                            }
                                                                                                                                          }
                                                                                                                                        }
                                                                                                                                      }
                                                                                                                                    }
                                                                                                                                  }
                                                                                                                                }
                                                                                                                              }
                                                                                                                            }
                                                                                                                          }
                                                                                                                        }
                                                                                                                      }
                                                                                                                    }
                                                                                                                  }
                                                                                                                }
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Symbol is a sort by checking against the following ATerm pattern: appl(prod([lit("sort"),cf(opt(layout)),lit("("),cf(opt(layout)),cf(sort("StrCon")),cf(opt(layout)),lit(")")],cf(sort("Symbol")),attrs([term(cons("sort"))])),[appl(prod([char-class([115]),char-class([111]),char-class([114]),char-class([116])],lit("sort"),no-attrs),[115,111,114,116]),<"ws-after-sort"("OptLayout")>,appl(prod([char-class([40])],lit("("),no-attrs),[40]),<"ws-after-("("OptLayout")>,<"string"("StrCon")>,<"ws-after-string"("OptLayout")>,appl(prod([char-class([41])],lit(")"),no-attrs),[41])]). May not be used to assert correctness of the PTPT_Symbol
 * \param[in] arg input PTPT_Symbol
 * \return ATtrue if #arg corresponds to the signature of a sort, or ATfalse otherwise
 */
inline ATbool PTPT_isSymbolSort(PTPT_Symbol arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == PTPT_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == PTPT_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lit */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: sort */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun64) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
              /* checking for: cf */
              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                /* checking for: opt */
                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                  /* checking for: layout */
                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                      arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                      arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                      /* checking for: lit */
                      if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
                        ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                        /* checking for: ( */
                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun21) {
                          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                            arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                            arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                            /* checking for: cf */
                            if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                              ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                              /* checking for: opt */
                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                /* checking for: layout */
                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                  if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                    arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                    arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                    /* checking for: cf */
                                    if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                      ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                      /* checking for: sort */
                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun9) {
                                        ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                        /* checking for: StrCon */
                                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun42) {
                                          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                            arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                            arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                            /* checking for: cf */
                                            if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                              ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                              /* checking for: opt */
                                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                                ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                /* checking for: layout */
                                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                                  if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                    arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                    arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                    /* checking for: lit */
                                                    if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
                                                      ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                      /* checking for: ) */
                                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun17) {
                                                        if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                                                          ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                                          /* checking for: cf */
                                                          if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == PTPT_afun2) {
                                                            ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                                            /* checking for: sort */
                                                            if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == PTPT_afun9) {
                                                              ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                                              /* checking for: Symbol */
                                                              if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == PTPT_afun25) {
                                                                ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                                                /* checking for: attrs */
                                                                if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == PTPT_afun12) {
                                                                  ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                                                  if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                                                    ATerm arg_arg0_arg2_arg0_head;
                                                                    ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                                                    arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                                                    arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                                                    /* checking for: term */
                                                                    if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == PTPT_afun13) {
                                                                      ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                                                      /* checking for: cons */
                                                                      if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == PTPT_afun14) {
                                                                        ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                                                        /* checking for: sort */
                                                                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == PTPT_afun64) {
                                                                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                                            ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                                            if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                                              ATerm arg_arg1_head;
                                                                              ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                                              arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                              arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                              /* checking for: appl */
                                                                              if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                /* checking for: prod */
                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                  ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                    ATerm arg_arg1_head_arg0_arg0_head;
                                                                                    ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                    arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                    arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                    /* checking for: char-class */
                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                        ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                        arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                        arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 115) {

                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                              arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                              arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                              /* checking for: char-class */
                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                  ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 111) {

                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                        arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                        arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                        /* checking for: char-class */
                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                            ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                            arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                            arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 114) {

                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                  arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                  arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                  /* checking for: char-class */
                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                      ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 116) {

                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                            ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                            /* checking for: lit */
                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                              ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                              /* checking for: sort */
                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun64) {
                                                                                                                                ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                /* checking for: no-attrs */
                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                  ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                    ATerm arg_arg1_head_arg1_head;
                                                                                                                                    ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                    arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                    arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 115) {

                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                        arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                        arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 111) {

                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                            arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                            arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 114) {

                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 116) {

                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                      arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                        arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                                        arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                        /* checking for: appl */
                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                                                                          ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                                                          /* checking for: prod */
                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                                                                                            ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                                              ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                                              ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                                              arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                              arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                              /* checking for: char-class */
                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                  ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 40) {

                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                                        /* checking for: lit */
                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                                                          ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                          /* checking for: ( */
                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun21) {
                                                                                                                                                                            ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                            /* checking for: no-attrs */
                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                                              ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                                ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                                ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                                arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 40) {

                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                      arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                        arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                          arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                            arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                                                                            arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                            /* checking for: appl */
                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                                                                                                              ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                                                                                              /* checking for: prod */
                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                                                                                                                                ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                                                                                  ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                                                                                  arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                  arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                  /* checking for: char-class */
                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                                      ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 41) {

                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                                                            ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                                                                            /* checking for: lit */
                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                                                                                              ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                                                              /* checking for: ) */
                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun17) {
                                                                                                                                                                                                                ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                                                                /* checking for: no-attrs */
                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                                                                                  ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                                                                    ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                                                                    ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                                                                    arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                    arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 41) {

                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                                                                                                                                          return ATtrue;
                                                                                                                                                                                                                        }
                                                                                                                                                                                                                      }
                                                                                                                                                                                                                    }
                                                                                                                                                                                                                  }
                                                                                                                                                                                                                }
                                                                                                                                                                                                              }
                                                                                                                                                                                                            }
                                                                                                                                                                                                          }
                                                                                                                                                                                                        }
                                                                                                                                                                                                      }
                                                                                                                                                                                                    }
                                                                                                                                                                                                  }
                                                                                                                                                                                                }
                                                                                                                                                                                              }
                                                                                                                                                                                            }
                                                                                                                                                                                          }
                                                                                                                                                                                        }
                                                                                                                                                                                      }
                                                                                                                                                                                    }
                                                                                                                                                                                  }
                                                                                                                                                                                }
                                                                                                                                                                              }
                                                                                                                                                                            }
                                                                                                                                                                          }
                                                                                                                                                                        }
                                                                                                                                                                      }
                                                                                                                                                                    }
                                                                                                                                                                  }
                                                                                                                                                                }
                                                                                                                                                              }
                                                                                                                                                            }
                                                                                                                                                          }
                                                                                                                                                        }
                                                                                                                                                      }
                                                                                                                                                    }
                                                                                                                                                  }
                                                                                                                                                }
                                                                                                                                              }
                                                                                                                                            }
                                                                                                                                          }
                                                                                                                                        }
                                                                                                                                      }
                                                                                                                                    }
                                                                                                                                  }
                                                                                                                                }
                                                                                                                              }
                                                                                                                            }
                                                                                                                          }
                                                                                                                        }
                                                                                                                      }
                                                                                                                    }
                                                                                                                  }
                                                                                                                }
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Symbol is a iter by checking against the following ATerm pattern: appl(prod([lit("iter"),cf(opt(layout)),lit("("),cf(opt(layout)),cf(sort("Symbol")),cf(opt(layout)),lit(")")],cf(sort("Symbol")),attrs([term(cons("iter"))])),[appl(prod([char-class([105]),char-class([116]),char-class([101]),char-class([114])],lit("iter"),no-attrs),[105,116,101,114]),<"ws-after-iter"("OptLayout")>,appl(prod([char-class([40])],lit("("),no-attrs),[40]),<"ws-after-("("OptLayout")>,<"symbol"("Symbol")>,<"ws-after-symbol"("OptLayout")>,appl(prod([char-class([41])],lit(")"),no-attrs),[41])]). May not be used to assert correctness of the PTPT_Symbol
 * \param[in] arg input PTPT_Symbol
 * \return ATtrue if #arg corresponds to the signature of a iter, or ATfalse otherwise
 */
inline ATbool PTPT_isSymbolIter(PTPT_Symbol arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == PTPT_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == PTPT_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lit */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: iter */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun65) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
              /* checking for: cf */
              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                /* checking for: opt */
                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                  /* checking for: layout */
                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                      arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                      arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                      /* checking for: lit */
                      if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
                        ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                        /* checking for: ( */
                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun21) {
                          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                            arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                            arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                            /* checking for: cf */
                            if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                              ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                              /* checking for: opt */
                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                /* checking for: layout */
                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                  if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                    arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                    arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                    /* checking for: cf */
                                    if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                      ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                      /* checking for: sort */
                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun9) {
                                        ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                        /* checking for: Symbol */
                                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun25) {
                                          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                            arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                            arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                            /* checking for: cf */
                                            if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                              ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                              /* checking for: opt */
                                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                                ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                /* checking for: layout */
                                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                                  if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                    arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                    arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                    /* checking for: lit */
                                                    if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
                                                      ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                      /* checking for: ) */
                                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun17) {
                                                        if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                                                          ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                                          /* checking for: cf */
                                                          if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == PTPT_afun2) {
                                                            ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                                            /* checking for: sort */
                                                            if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == PTPT_afun9) {
                                                              ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                                              /* checking for: Symbol */
                                                              if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == PTPT_afun25) {
                                                                ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                                                /* checking for: attrs */
                                                                if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == PTPT_afun12) {
                                                                  ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                                                  if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                                                    ATerm arg_arg0_arg2_arg0_head;
                                                                    ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                                                    arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                                                    arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                                                    /* checking for: term */
                                                                    if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == PTPT_afun13) {
                                                                      ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                                                      /* checking for: cons */
                                                                      if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == PTPT_afun14) {
                                                                        ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                                                        /* checking for: iter */
                                                                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == PTPT_afun65) {
                                                                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                                            ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                                            if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                                              ATerm arg_arg1_head;
                                                                              ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                                              arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                              arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                              /* checking for: appl */
                                                                              if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                /* checking for: prod */
                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                  ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                    ATerm arg_arg1_head_arg0_arg0_head;
                                                                                    ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                    arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                    arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                    /* checking for: char-class */
                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                        ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                        arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                        arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 105) {

                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                              arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                              arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                              /* checking for: char-class */
                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                  ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 116) {

                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                        arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                        arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                        /* checking for: char-class */
                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                            ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                            arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                            arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 101) {

                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                  arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                  arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                  /* checking for: char-class */
                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                      ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 114) {

                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                            ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                            /* checking for: lit */
                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                              ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                              /* checking for: iter */
                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun65) {
                                                                                                                                ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                /* checking for: no-attrs */
                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                  ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                    ATerm arg_arg1_head_arg1_head;
                                                                                                                                    ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                    arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                    arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 105) {

                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                        arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                        arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 116) {

                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                            arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                            arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 101) {

                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 114) {

                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                      arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                        arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                                        arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                        /* checking for: appl */
                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                                                                          ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                                                          /* checking for: prod */
                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                                                                                            ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                                              ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                                              ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                                              arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                              arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                              /* checking for: char-class */
                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                  ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 40) {

                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                                        /* checking for: lit */
                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                                                          ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                          /* checking for: ( */
                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun21) {
                                                                                                                                                                            ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                            /* checking for: no-attrs */
                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                                              ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                                ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                                ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                                arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 40) {

                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                      arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                        arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                          arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                            arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                                                                            arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                            /* checking for: appl */
                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                                                                                                              ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                                                                                              /* checking for: prod */
                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                                                                                                                                ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                                                                                  ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                                                                                  arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                  arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                  /* checking for: char-class */
                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                                      ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 41) {

                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                                                            ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                                                                            /* checking for: lit */
                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                                                                                              ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                                                              /* checking for: ) */
                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun17) {
                                                                                                                                                                                                                ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                                                                /* checking for: no-attrs */
                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                                                                                  ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                                                                    ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                                                                    ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                                                                    arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                    arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 41) {

                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                                                                                                                                          return ATtrue;
                                                                                                                                                                                                                        }
                                                                                                                                                                                                                      }
                                                                                                                                                                                                                    }
                                                                                                                                                                                                                  }
                                                                                                                                                                                                                }
                                                                                                                                                                                                              }
                                                                                                                                                                                                            }
                                                                                                                                                                                                          }
                                                                                                                                                                                                        }
                                                                                                                                                                                                      }
                                                                                                                                                                                                    }
                                                                                                                                                                                                  }
                                                                                                                                                                                                }
                                                                                                                                                                                              }
                                                                                                                                                                                            }
                                                                                                                                                                                          }
                                                                                                                                                                                        }
                                                                                                                                                                                      }
                                                                                                                                                                                    }
                                                                                                                                                                                  }
                                                                                                                                                                                }
                                                                                                                                                                              }
                                                                                                                                                                            }
                                                                                                                                                                          }
                                                                                                                                                                        }
                                                                                                                                                                      }
                                                                                                                                                                    }
                                                                                                                                                                  }
                                                                                                                                                                }
                                                                                                                                                              }
                                                                                                                                                            }
                                                                                                                                                          }
                                                                                                                                                        }
                                                                                                                                                      }
                                                                                                                                                    }
                                                                                                                                                  }
                                                                                                                                                }
                                                                                                                                              }
                                                                                                                                            }
                                                                                                                                          }
                                                                                                                                        }
                                                                                                                                      }
                                                                                                                                    }
                                                                                                                                  }
                                                                                                                                }
                                                                                                                              }
                                                                                                                            }
                                                                                                                          }
                                                                                                                        }
                                                                                                                      }
                                                                                                                    }
                                                                                                                  }
                                                                                                                }
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Symbol is a iter-star by checking against the following ATerm pattern: appl(prod([lit("iter-star"),cf(opt(layout)),lit("("),cf(opt(layout)),cf(sort("Symbol")),cf(opt(layout)),lit(")")],cf(sort("Symbol")),attrs([term(cons("iter-star"))])),[appl(prod([char-class([105]),char-class([116]),char-class([101]),char-class([114]),char-class([45]),char-class([115]),char-class([116]),char-class([97]),char-class([114])],lit("iter-star"),no-attrs),[105,116,101,114,45,115,116,97,114]),<"ws-after-iter-star"("OptLayout")>,appl(prod([char-class([40])],lit("("),no-attrs),[40]),<"ws-after-("("OptLayout")>,<"symbol"("Symbol")>,<"ws-after-symbol"("OptLayout")>,appl(prod([char-class([41])],lit(")"),no-attrs),[41])]). May not be used to assert correctness of the PTPT_Symbol
 * \param[in] arg input PTPT_Symbol
 * \return ATtrue if #arg corresponds to the signature of a iter-star, or ATfalse otherwise
 */
inline ATbool PTPT_isSymbolIterStar(PTPT_Symbol arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == PTPT_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == PTPT_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lit */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: iter-star */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun66) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
              /* checking for: cf */
              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                /* checking for: opt */
                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                  /* checking for: layout */
                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                      arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                      arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                      /* checking for: lit */
                      if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
                        ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                        /* checking for: ( */
                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun21) {
                          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                            arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                            arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                            /* checking for: cf */
                            if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                              ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                              /* checking for: opt */
                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                /* checking for: layout */
                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                  if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                    arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                    arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                    /* checking for: cf */
                                    if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                      ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                      /* checking for: sort */
                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun9) {
                                        ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                        /* checking for: Symbol */
                                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun25) {
                                          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                            arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                            arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                            /* checking for: cf */
                                            if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                              ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                              /* checking for: opt */
                                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                                ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                /* checking for: layout */
                                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                                  if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                    arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                    arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                    /* checking for: lit */
                                                    if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
                                                      ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                      /* checking for: ) */
                                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun17) {
                                                        if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                                                          ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                                          /* checking for: cf */
                                                          if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == PTPT_afun2) {
                                                            ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                                            /* checking for: sort */
                                                            if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == PTPT_afun9) {
                                                              ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                                              /* checking for: Symbol */
                                                              if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == PTPT_afun25) {
                                                                ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                                                /* checking for: attrs */
                                                                if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == PTPT_afun12) {
                                                                  ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                                                  if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                                                    ATerm arg_arg0_arg2_arg0_head;
                                                                    ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                                                    arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                                                    arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                                                    /* checking for: term */
                                                                    if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == PTPT_afun13) {
                                                                      ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                                                      /* checking for: cons */
                                                                      if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == PTPT_afun14) {
                                                                        ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                                                        /* checking for: iter-star */
                                                                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == PTPT_afun66) {
                                                                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                                            ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                                            if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                                              ATerm arg_arg1_head;
                                                                              ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                                              arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                              arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                              /* checking for: appl */
                                                                              if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                /* checking for: prod */
                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                  ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                    ATerm arg_arg1_head_arg0_arg0_head;
                                                                                    ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                    arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                    arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                    /* checking for: char-class */
                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                        ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                        arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                        arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 105) {

                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                              arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                              arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                              /* checking for: char-class */
                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                  ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 116) {

                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                        arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                        arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                        /* checking for: char-class */
                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                            ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                            arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                            arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 101) {

                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                  arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                  arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                  /* checking for: char-class */
                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                      ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 114) {

                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                            arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                            arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                            /* checking for: char-class */
                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 45) {

                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                      arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                      arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                      /* checking for: char-class */
                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                          ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                          arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                          arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 115) {

                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                                arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                /* checking for: char-class */
                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                    ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                    arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                    arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 116) {

                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                                          arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                          arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                          /* checking for: char-class */
                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                              ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                              arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                              arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 97) {

                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                                                    arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                    arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                    /* checking for: char-class */
                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                        ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                        arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                        arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 114) {

                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                              ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                                              /* checking for: lit */
                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                                                                ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                                /* checking for: iter-star */
                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun66) {
                                                                                                                                                                                  ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                                  /* checking for: no-attrs */
                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                                                    ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                                      ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                                      ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                                      arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                      arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 105) {

                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                          arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                          arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 116) {

                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                              arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                              arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 101) {

                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                  arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                  arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 114) {

                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                      arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                      arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 45) {

                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                          arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                          arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 115) {

                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                              arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                              arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 116) {

                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                                  arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                  arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 97) {

                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                                      arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                      arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 114) {

                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                            arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                              arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                                                                                                              arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                              /* checking for: appl */
                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                                                                                                                                                ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                                                                                                                                /* checking for: prod */
                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                                                                                                                                                                  ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                                                                                                                    ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                                                                                                                    arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                    arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                    /* checking for: char-class */
                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                                                                        ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                                                                        arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                        arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 40) {

                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                              ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                                                                                                              /* checking for: lit */
                                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                                                                                                                                ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                                                                                                /* checking for: ( */
                                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun21) {
                                                                                                                                                                                                                                                  ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                                                                                                  /* checking for: no-attrs */
                                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                                                                                                                    ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                                                                                                      ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                                                                                                      ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                                                                                                      arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                      arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 40) {

                                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                            arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                              arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                  arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                                                                                                                                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                                  /* checking for: appl */
                                                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                                                                                                                                                                                    ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                                                                                                                                                                    /* checking for: prod */
                                                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                                                                                                                                                                                                      ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                                                                                                                                                        ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                                                                                                                                                        arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                                                        arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                                                        /* checking for: char-class */
                                                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                                                                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                                                                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                                                                                                            ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                                                                                                            arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                                                            arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 41) {

                                                                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                                                                  ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                                                                                                                                                  /* checking for: lit */
                                                                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                                                                                                                                                                    ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                                                                                                                                    /* checking for: ) */
                                                                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun17) {
                                                                                                                                                                                                                                                                                      ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                                                                                                                                      /* checking for: no-attrs */
                                                                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                                                                                                                                                        ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                                                                                                                                          ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                                                                                                                                          ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                                                                                                                                          arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                          arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 41) {

                                                                                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                                                                                                                                                                                                                return ATtrue;
                                                                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                }
                                                                                                                                                                                                                              }
                                                                                                                                                                                                                            }
                                                                                                                                                                                                                          }
                                                                                                                                                                                                                        }
                                                                                                                                                                                                                      }
                                                                                                                                                                                                                    }
                                                                                                                                                                                                                  }
                                                                                                                                                                                                                }
                                                                                                                                                                                                              }
                                                                                                                                                                                                            }
                                                                                                                                                                                                          }
                                                                                                                                                                                                        }
                                                                                                                                                                                                      }
                                                                                                                                                                                                    }
                                                                                                                                                                                                  }
                                                                                                                                                                                                }
                                                                                                                                                                                              }
                                                                                                                                                                                            }
                                                                                                                                                                                          }
                                                                                                                                                                                        }
                                                                                                                                                                                      }
                                                                                                                                                                                    }
                                                                                                                                                                                  }
                                                                                                                                                                                }
                                                                                                                                                                              }
                                                                                                                                                                            }
                                                                                                                                                                          }
                                                                                                                                                                        }
                                                                                                                                                                      }
                                                                                                                                                                    }
                                                                                                                                                                  }
                                                                                                                                                                }
                                                                                                                                                              }
                                                                                                                                                            }
                                                                                                                                                          }
                                                                                                                                                        }
                                                                                                                                                      }
                                                                                                                                                    }
                                                                                                                                                  }
                                                                                                                                                }
                                                                                                                                              }
                                                                                                                                            }
                                                                                                                                          }
                                                                                                                                        }
                                                                                                                                      }
                                                                                                                                    }
                                                                                                                                  }
                                                                                                                                }
                                                                                                                              }
                                                                                                                            }
                                                                                                                          }
                                                                                                                        }
                                                                                                                      }
                                                                                                                    }
                                                                                                                  }
                                                                                                                }
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Symbol is a iter-sep by checking against the following ATerm pattern: appl(prod([lit("iter-sep"),cf(opt(layout)),lit("("),cf(opt(layout)),cf(sort("Symbol")),cf(opt(layout)),lit(","),cf(opt(layout)),cf(sort("Symbol")),cf(opt(layout)),lit(")")],cf(sort("Symbol")),attrs([term(cons("iter-sep"))])),[appl(prod([char-class([105]),char-class([116]),char-class([101]),char-class([114]),char-class([45]),char-class([115]),char-class([101]),char-class([112])],lit("iter-sep"),no-attrs),[105,116,101,114,45,115,101,112]),<"ws-after-iter-sep"("OptLayout")>,appl(prod([char-class([40])],lit("("),no-attrs),[40]),<"ws-after-("("OptLayout")>,<"symbol"("Symbol")>,<"ws-after-symbol"("OptLayout")>,appl(prod([char-class([44])],lit(","),no-attrs),[44]),<"ws-after-,"("OptLayout")>,<"separator"("Symbol")>,<"ws-after-separator"("OptLayout")>,appl(prod([char-class([41])],lit(")"),no-attrs),[41])]). May not be used to assert correctness of the PTPT_Symbol
 * \param[in] arg input PTPT_Symbol
 * \return ATtrue if #arg corresponds to the signature of a iter-sep, or ATfalse otherwise
 */
inline ATbool PTPT_isSymbolIterSep(PTPT_Symbol arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == PTPT_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == PTPT_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lit */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: iter-sep */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun67) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
              /* checking for: cf */
              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                /* checking for: opt */
                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                  /* checking for: layout */
                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                      arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                      arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                      /* checking for: lit */
                      if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
                        ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                        /* checking for: ( */
                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun21) {
                          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                            arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                            arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                            /* checking for: cf */
                            if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                              ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                              /* checking for: opt */
                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                /* checking for: layout */
                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                  if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                    arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                    arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                    /* checking for: cf */
                                    if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                      ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                      /* checking for: sort */
                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun9) {
                                        ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                        /* checking for: Symbol */
                                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun25) {
                                          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                            arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                            arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                            /* checking for: cf */
                                            if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                              ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                              /* checking for: opt */
                                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                                ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                /* checking for: layout */
                                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                                  if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                    arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                    arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                    /* checking for: lit */
                                                    if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
                                                      ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                      /* checking for: , */
                                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun19) {
                                                        if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                          arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                          arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                          /* checking for: cf */
                                                          if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                                            ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                            /* checking for: opt */
                                                            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                                              ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                              /* checking for: layout */
                                                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                                                if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                                  arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                                  arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                                  /* checking for: cf */
                                                                  if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                                                    ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                                    /* checking for: sort */
                                                                    if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun9) {
                                                                      ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                                      /* checking for: Symbol */
                                                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun25) {
                                                                        if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                                          arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                                          arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                                          /* checking for: cf */
                                                                          if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                                                            ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                                            /* checking for: opt */
                                                                            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                                                              ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                                              /* checking for: layout */
                                                                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                                                                if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                                                  arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                                                  arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                                                  /* checking for: lit */
                                                                                  if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
                                                                                    ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                                                    /* checking for: ) */
                                                                                    if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun17) {
                                                                                      if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                                                                                        ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                                                                        /* checking for: cf */
                                                                                        if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == PTPT_afun2) {
                                                                                          ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                                                                          /* checking for: sort */
                                                                                          if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == PTPT_afun9) {
                                                                                            ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                                                                            /* checking for: Symbol */
                                                                                            if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == PTPT_afun25) {
                                                                                              ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                                                                              /* checking for: attrs */
                                                                                              if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == PTPT_afun12) {
                                                                                                ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                                                                                if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                                                                                  ATerm arg_arg0_arg2_arg0_head;
                                                                                                  ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                                                                                  arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                                                                                  arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                                                                                  /* checking for: term */
                                                                                                  if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == PTPT_afun13) {
                                                                                                    ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                                                                                    /* checking for: cons */
                                                                                                    if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == PTPT_afun14) {
                                                                                                      ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                                                                                      /* checking for: iter-sep */
                                                                                                      if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == PTPT_afun67) {
                                                                                                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                                                                          ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                                                                          if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                                                                            ATerm arg_arg1_head;
                                                                                                            ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                                                                            arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                            arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                            /* checking for: appl */
                                                                                                            if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                              ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                              /* checking for: prod */
                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                                                ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                  ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                  arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                  arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                  /* checking for: char-class */
                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                      ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 105) {

                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                            arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                            arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                            /* checking for: char-class */
                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 116) {

                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                      arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                      arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                      /* checking for: char-class */
                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                          ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                          arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                          arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 101) {

                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                                arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                /* checking for: char-class */
                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                    ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                    arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                    arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 114) {

                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                                          arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                          arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                          /* checking for: char-class */
                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                              ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                              arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                              arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 45) {

                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                                                    arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                    arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                    /* checking for: char-class */
                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                        ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                        arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                        arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 115) {

                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                                                              arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                              arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                              /* checking for: char-class */
                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                  ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 101) {

                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                                                                        arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                        arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                        /* checking for: char-class */
                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                            ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                            arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                            arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 112) {

                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                                                  ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                                                                  /* checking for: lit */
                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                                                                                    ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                                                    /* checking for: iter-sep */
                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun67) {
                                                                                                                                                                                                      ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                                                      /* checking for: no-attrs */
                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                                                                        ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                                                          ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                                                          ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                                                          arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                          arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 105) {

                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                              arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                              arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 116) {

                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                                  arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                  arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 101) {

                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                                      arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                      arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 114) {

                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                                          arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                          arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 45) {

                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                                              arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                              arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 115) {

                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                  arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                  arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 101) {

                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                      arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                      arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 112) {

                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                            arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                              arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                                                                                                                              arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                              /* checking for: appl */
                                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                                                                                                                                                                ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                                                                                                                                                /* checking for: prod */
                                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                                                                                                                                                                                  ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                                                                                                                                    ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                                                                                                                                    arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                                    arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                                    /* checking for: char-class */
                                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                                                                                        ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                                                                                        arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                                        arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 40) {

                                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                                              ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                                                                                                                              /* checking for: lit */
                                                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                                                                                                                                                ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                                                                                                                /* checking for: ( */
                                                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun21) {
                                                                                                                                                                                                                                                                  ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                                                                                                                  /* checking for: no-attrs */
                                                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                                                                                                                                    ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                                                                                                                      ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                                                                                                                      ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                                                                                                                      arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                      arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 40) {

                                                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                            arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                              arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                  arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                                                                                                                                                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                                                  /* checking for: appl */
                                                                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                                                                                                                                                                                                    ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                                                                                                                                                                                    /* checking for: prod */
                                                                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                                                                                                                                                                                                                      ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                                                                                                                                                                        ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                                                                                                                                                                        arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                                                                        arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                                                                        /* checking for: char-class */
                                                                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                                                                                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                                                                                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                                                                                                                            ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                                                                                                                            arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                                                                            arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 44) {

                                                                                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                                                                                  ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                                                                                                                                                                  /* checking for: lit */
                                                                                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                                                                                                                                                                                    ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                                                                                                                                                    /* checking for: , */
                                                                                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun19) {
                                                                                                                                                                                                                                                                                                      ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                                                                                                                                                      /* checking for: no-attrs */
                                                                                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                                                                                                                                                                        ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                                                                                                                                                          ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                                                                                                                                                          ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                                                                                                                                                          arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                                          arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 44) {

                                                                                                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                                                arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                                                    arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                                                      arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                                                                                                                                                                                                      arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                                                                                      /* checking for: appl */
                                                                                                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                                                                                                                                                                                                                                        ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                                                                                                                                                                                                                        /* checking for: prod */
                                                                                                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                                                                                                                                                                                                                                                          ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                                                                                                                                                                                                            ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                                                                                                                                                                                                            ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                                                                                                                                                                                                            arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                                                                                                            arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                                                                                                            /* checking for: char-class */
                                                                                                                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                                                                                                                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                                                                                                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                                                                                                                                                                ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                                                                                                                                                                arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                                                                                                                arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 41) {

                                                                                                                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                                                                                                                      ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                                                                                                                                                                                                      /* checking for: lit */
                                                                                                                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                                                                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                                                                                                                                                                                        /* checking for: ) */
                                                                                                                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun17) {
                                                                                                                                                                                                                                                                                                                                          ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                                                                                                                                                                                          /* checking for: no-attrs */
                                                                                                                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                                                                                                                                                                                                            ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                                                                                                                                                                                              ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                                                                                                                                                                                              ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                                                                                                                                                                                              arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                                                                              arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 41) {

                                                                                                                                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                                                                                                                                                                                                                                                                    return ATtrue;
                                                                                                                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                }
                                                                                                                                                                                                                              }
                                                                                                                                                                                                                            }
                                                                                                                                                                                                                          }
                                                                                                                                                                                                                        }
                                                                                                                                                                                                                      }
                                                                                                                                                                                                                    }
                                                                                                                                                                                                                  }
                                                                                                                                                                                                                }
                                                                                                                                                                                                              }
                                                                                                                                                                                                            }
                                                                                                                                                                                                          }
                                                                                                                                                                                                        }
                                                                                                                                                                                                      }
                                                                                                                                                                                                    }
                                                                                                                                                                                                  }
                                                                                                                                                                                                }
                                                                                                                                                                                              }
                                                                                                                                                                                            }
                                                                                                                                                                                          }
                                                                                                                                                                                        }
                                                                                                                                                                                      }
                                                                                                                                                                                    }
                                                                                                                                                                                  }
                                                                                                                                                                                }
                                                                                                                                                                              }
                                                                                                                                                                            }
                                                                                                                                                                          }
                                                                                                                                                                        }
                                                                                                                                                                      }
                                                                                                                                                                    }
                                                                                                                                                                  }
                                                                                                                                                                }
                                                                                                                                                              }
                                                                                                                                                            }
                                                                                                                                                          }
                                                                                                                                                        }
                                                                                                                                                      }
                                                                                                                                                    }
                                                                                                                                                  }
                                                                                                                                                }
                                                                                                                                              }
                                                                                                                                            }
                                                                                                                                          }
                                                                                                                                        }
                                                                                                                                      }
                                                                                                                                    }
                                                                                                                                  }
                                                                                                                                }
                                                                                                                              }
                                                                                                                            }
                                                                                                                          }
                                                                                                                        }
                                                                                                                      }
                                                                                                                    }
                                                                                                                  }
                                                                                                                }
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Symbol is a iter-star-sep by checking against the following ATerm pattern: appl(prod([lit("iter-star-sep"),cf(opt(layout)),lit("("),cf(opt(layout)),cf(sort("Symbol")),cf(opt(layout)),lit(","),cf(opt(layout)),cf(sort("Symbol")),cf(opt(layout)),lit(")")],cf(sort("Symbol")),attrs([term(cons("iter-star-sep"))])),[appl(prod([char-class([105]),char-class([116]),char-class([101]),char-class([114]),char-class([45]),char-class([115]),char-class([116]),char-class([97]),char-class([114]),char-class([45]),char-class([115]),char-class([101]),char-class([112])],lit("iter-star-sep"),no-attrs),[105,116,101,114,45,115,116,97,114,45,115,101,112]),<"ws-after-iter-star-sep"("OptLayout")>,appl(prod([char-class([40])],lit("("),no-attrs),[40]),<"ws-after-("("OptLayout")>,<"symbol"("Symbol")>,<"ws-after-symbol"("OptLayout")>,appl(prod([char-class([44])],lit(","),no-attrs),[44]),<"ws-after-,"("OptLayout")>,<"separator"("Symbol")>,<"ws-after-separator"("OptLayout")>,appl(prod([char-class([41])],lit(")"),no-attrs),[41])]). May not be used to assert correctness of the PTPT_Symbol
 * \param[in] arg input PTPT_Symbol
 * \return ATtrue if #arg corresponds to the signature of a iter-star-sep, or ATfalse otherwise
 */
inline ATbool PTPT_isSymbolIterStarSep(PTPT_Symbol arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == PTPT_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == PTPT_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lit */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: iter-star-sep */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun68) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
              /* checking for: cf */
              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                /* checking for: opt */
                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                  /* checking for: layout */
                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                      arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                      arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                      /* checking for: lit */
                      if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
                        ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                        /* checking for: ( */
                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun21) {
                          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                            arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                            arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                            /* checking for: cf */
                            if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                              ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                              /* checking for: opt */
                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                /* checking for: layout */
                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                  if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                    arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                    arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                    /* checking for: cf */
                                    if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                      ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                      /* checking for: sort */
                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun9) {
                                        ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                        /* checking for: Symbol */
                                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun25) {
                                          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                            arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                            arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                            /* checking for: cf */
                                            if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                              ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                              /* checking for: opt */
                                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                                ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                /* checking for: layout */
                                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                                  if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                    arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                    arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                    /* checking for: lit */
                                                    if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
                                                      ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                      /* checking for: , */
                                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun19) {
                                                        if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                          arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                          arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                          /* checking for: cf */
                                                          if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                                            ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                            /* checking for: opt */
                                                            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                                              ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                              /* checking for: layout */
                                                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                                                if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                                  arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                                  arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                                  /* checking for: cf */
                                                                  if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                                                    ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                                    /* checking for: sort */
                                                                    if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun9) {
                                                                      ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                                      /* checking for: Symbol */
                                                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun25) {
                                                                        if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                                          arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                                          arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                                          /* checking for: cf */
                                                                          if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                                                            ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                                            /* checking for: opt */
                                                                            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                                                              ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                                              /* checking for: layout */
                                                                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                                                                if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                                                  arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                                                  arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                                                  /* checking for: lit */
                                                                                  if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
                                                                                    ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                                                    /* checking for: ) */
                                                                                    if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun17) {
                                                                                      if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                                                                                        ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                                                                        /* checking for: cf */
                                                                                        if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == PTPT_afun2) {
                                                                                          ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                                                                          /* checking for: sort */
                                                                                          if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == PTPT_afun9) {
                                                                                            ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                                                                            /* checking for: Symbol */
                                                                                            if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == PTPT_afun25) {
                                                                                              ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                                                                              /* checking for: attrs */
                                                                                              if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == PTPT_afun12) {
                                                                                                ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                                                                                if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                                                                                  ATerm arg_arg0_arg2_arg0_head;
                                                                                                  ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                                                                                  arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                                                                                  arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                                                                                  /* checking for: term */
                                                                                                  if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == PTPT_afun13) {
                                                                                                    ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                                                                                    /* checking for: cons */
                                                                                                    if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == PTPT_afun14) {
                                                                                                      ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                                                                                      /* checking for: iter-star-sep */
                                                                                                      if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == PTPT_afun68) {
                                                                                                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                                                                          ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                                                                          if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                                                                            ATerm arg_arg1_head;
                                                                                                            ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                                                                            arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                            arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                            /* checking for: appl */
                                                                                                            if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                              ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                              /* checking for: prod */
                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                                                ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                  ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                  arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                  arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                  /* checking for: char-class */
                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                      ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 105) {

                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                            arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                            arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                            /* checking for: char-class */
                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 116) {

                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                      arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                      arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                      /* checking for: char-class */
                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                          ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                          arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                          arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 101) {

                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                                arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                /* checking for: char-class */
                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                    ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                    arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                    arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 114) {

                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                                          arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                          arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                          /* checking for: char-class */
                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                              ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                              arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                              arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 45) {

                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                                                    arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                    arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                    /* checking for: char-class */
                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                        ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                        arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                        arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 115) {

                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                                                              arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                              arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                              /* checking for: char-class */
                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                  ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 116) {

                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                                                                        arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                        arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                        /* checking for: char-class */
                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                            ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                            arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                            arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 97) {

                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                                                                                  arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                  arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                  /* checking for: char-class */
                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                                      ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 114) {

                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                                                                                            arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                            arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                            /* checking for: char-class */
                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                                                ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                                                arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 45) {

                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                                                                                                      arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                      arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                      /* checking for: char-class */
                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                                                          ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                                                          arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                          arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 115) {

                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                                                                                                                arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                /* checking for: char-class */
                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                                                                    ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                                                                    arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                    arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 101) {

                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                                                                                                                          arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                          arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                          /* checking for: char-class */
                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                                                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                                                                              ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                                                                              arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                              arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 112) {

                                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                                    ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                                                                                                                    /* checking for: lit */
                                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                                                                                                                                      ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                                                                                                      /* checking for: iter-star-sep */
                                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun68) {
                                                                                                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                                                                                                        /* checking for: no-attrs */
                                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                                                                                                                          ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                                                                                                            ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                                                                                                            ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                                                                                                            arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                            arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 105) {

                                                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 116) {

                                                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                    arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                    arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 101) {

                                                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                        arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                        arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 114) {

                                                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                            arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                            arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 45) {

                                                                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 115) {

                                                                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                    arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                    arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 116) {

                                                                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                        arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                        arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 97) {

                                                                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                            arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                            arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 114) {

                                                                                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                                arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                                arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 45) {

                                                                                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                                    arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                                    arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 115) {

                                                                                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                                        arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                                        arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 101) {

                                                                                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                                            arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                                            arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 112) {

                                                                                                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                                                    arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                                                                                                                                                                                                    arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                                                                                    /* checking for: appl */
                                                                                                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                                                                                                                                                                                                                                      ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                                                                                                                                                                                                                      /* checking for: prod */
                                                                                                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                                                                                                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                                                                                                                                                                                                          ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                                                                                                                                                                                                          ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                                                                                                                                                                                                          arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                                                                                                          arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                                                                                                          /* checking for: char-class */
                                                                                                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                                                                                                                                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                                                                                                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                                                                                                                                                              ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                                                                                                                                                              arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                                                                                                              arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 40) {

                                                                                                                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                                                                                                                    ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                                                                                                                                                                                                    /* checking for: lit */
                                                                                                                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                                                                                                                                                                                                                      ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                                                                                                                                                                                      /* checking for: ( */
                                                                                                                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun21) {
                                                                                                                                                                                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                                                                                                                                                                                        /* checking for: no-attrs */
                                                                                                                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                                                                                                                                                                                                          ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                                                                                                                                                                                            ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                                                                                                                                                                                            ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                                                                                                                                                                                            arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                                                                            arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 40) {

                                                                                                                                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                                                                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                                                                                    arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                                                                                      arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                                                                                        arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                                                                                                                                                                                                                                        arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                                                                                                                        /* checking for: appl */
                                                                                                                                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                                                                                                                                                                                                                                                                          ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                                                                                                                                                                                                                                                          /* checking for: prod */
                                                                                                                                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                                                                                                                                                                                                                                                                                            ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                                                                                                                                                                                                                                              ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                                                                                                                                                                                                                                              ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                                                                                                                                                                                                                                              arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                                                                                                                                              arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                                                                                                                                              /* checking for: char-class */
                                                                                                                                                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                                                                                                                                                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                                                                                                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                                                                                                                                                                                                  ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                                                                                                                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                                                                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                                                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 44) {

                                                                                                                                                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                                                                                                                                                                                                                                        /* checking for: lit */
                                                                                                                                                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                                                                                                                                                                                                                                                          ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                                                                                                                                                                                                                          /* checking for: , */
                                                                                                                                                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun19) {
                                                                                                                                                                                                                                                                                                                                                                            ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                                                                                                                                                                                                                            /* checking for: no-attrs */
                                                                                                                                                                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                                                                                                                                                                                                                                              ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                                                                                                                                                                                                                                ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                                                                                                                                                                                                                                ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                                                                                                                                                                                                                                arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                                                                                                                arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 44) {

                                                                                                                                                                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                                                                                                                      arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                                                                                                                        arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                                                                                                                          arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                                                                                                                            arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                                                                                                                                                                                                                                                                            arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                                                                                                                                                            /* checking for: appl */
                                                                                                                                                                                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                                                                                                                                                                                                                                                                                                              ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                                                                                                                                                                                                                                                                                              /* checking for: prod */
                                                                                                                                                                                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                                                                                                                                                                                                                                                                                                                                ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                                                                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                                                                                                                                                                                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                                                                                                                                                                                                                                                                                  ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                                                                                                                                                                                                                                                                                  arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                                                                                                                                                                                  arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                                                                                                                                                                                  /* checking for: char-class */
                                                                                                                                                                                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                                                                                                                                                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                                                                                                                                                                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                                                                                                                                                                                                                                      ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                                                                                                                                                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                                                                                                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                                                                                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 41) {

                                                                                                                                                                                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                                                                                                                                                                                            ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                                                                                                                                                                                                                                                                            /* checking for: lit */
                                                                                                                                                                                                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                                                                                                                                                                                                                                                                                              ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                                                                                                                                                                                                                                                              /* checking for: ) */
                                                                                                                                                                                                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun17) {
                                                                                                                                                                                                                                                                                                                                                                                                                ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                                                                                                                                                                                                                                                                /* checking for: no-attrs */
                                                                                                                                                                                                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                                                                                                                                                                                                                                                                                  ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                                                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                                                                                                                                                                                                                                                                    ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                                                                                                                                                                                                                                                                    ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                                                                                                                                                                                                                                                                    arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                                                                                                                                                    arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                                                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 41) {

                                                                                                                                                                                                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                                                                                                                                                                                                                                                                                                                                          return ATtrue;
                                                                                                                                                                                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                }
                                                                                                                                                                                                                              }
                                                                                                                                                                                                                            }
                                                                                                                                                                                                                          }
                                                                                                                                                                                                                        }
                                                                                                                                                                                                                      }
                                                                                                                                                                                                                    }
                                                                                                                                                                                                                  }
                                                                                                                                                                                                                }
                                                                                                                                                                                                              }
                                                                                                                                                                                                            }
                                                                                                                                                                                                          }
                                                                                                                                                                                                        }
                                                                                                                                                                                                      }
                                                                                                                                                                                                    }
                                                                                                                                                                                                  }
                                                                                                                                                                                                }
                                                                                                                                                                                              }
                                                                                                                                                                                            }
                                                                                                                                                                                          }
                                                                                                                                                                                        }
                                                                                                                                                                                      }
                                                                                                                                                                                    }
                                                                                                                                                                                  }
                                                                                                                                                                                }
                                                                                                                                                                              }
                                                                                                                                                                            }
                                                                                                                                                                          }
                                                                                                                                                                        }
                                                                                                                                                                      }
                                                                                                                                                                    }
                                                                                                                                                                  }
                                                                                                                                                                }
                                                                                                                                                              }
                                                                                                                                                            }
                                                                                                                                                          }
                                                                                                                                                        }
                                                                                                                                                      }
                                                                                                                                                    }
                                                                                                                                                  }
                                                                                                                                                }
                                                                                                                                              }
                                                                                                                                            }
                                                                                                                                          }
                                                                                                                                        }
                                                                                                                                      }
                                                                                                                                    }
                                                                                                                                  }
                                                                                                                                }
                                                                                                                              }
                                                                                                                            }
                                                                                                                          }
                                                                                                                        }
                                                                                                                      }
                                                                                                                    }
                                                                                                                  }
                                                                                                                }
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Symbol is a iter-n by checking against the following ATerm pattern: appl(prod([lit("iter-n"),cf(opt(layout)),lit("("),cf(opt(layout)),cf(sort("Symbol")),cf(opt(layout)),lit(","),cf(opt(layout)),cf(sort("NatCon")),cf(opt(layout)),lit(")")],cf(sort("Symbol")),attrs([term(cons("iter-n"))])),[appl(prod([char-class([105]),char-class([116]),char-class([101]),char-class([114]),char-class([45]),char-class([110])],lit("iter-n"),no-attrs),[105,116,101,114,45,110]),<"ws-after-iter-n"("OptLayout")>,appl(prod([char-class([40])],lit("("),no-attrs),[40]),<"ws-after-("("OptLayout")>,<"symbol"("Symbol")>,<"ws-after-symbol"("OptLayout")>,appl(prod([char-class([44])],lit(","),no-attrs),[44]),<"ws-after-,"("OptLayout")>,<"number"("NatCon")>,<"ws-after-number"("OptLayout")>,appl(prod([char-class([41])],lit(")"),no-attrs),[41])]). May not be used to assert correctness of the PTPT_Symbol
 * \param[in] arg input PTPT_Symbol
 * \return ATtrue if #arg corresponds to the signature of a iter-n, or ATfalse otherwise
 */
inline ATbool PTPT_isSymbolIterN(PTPT_Symbol arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == PTPT_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == PTPT_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lit */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: iter-n */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun69) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
              /* checking for: cf */
              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                /* checking for: opt */
                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                  /* checking for: layout */
                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                      arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                      arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                      /* checking for: lit */
                      if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
                        ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                        /* checking for: ( */
                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun21) {
                          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                            arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                            arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                            /* checking for: cf */
                            if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                              ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                              /* checking for: opt */
                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                /* checking for: layout */
                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                  if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                    arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                    arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                    /* checking for: cf */
                                    if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                      ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                      /* checking for: sort */
                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun9) {
                                        ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                        /* checking for: Symbol */
                                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun25) {
                                          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                            arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                            arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                            /* checking for: cf */
                                            if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                              ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                              /* checking for: opt */
                                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                                ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                /* checking for: layout */
                                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                                  if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                    arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                    arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                    /* checking for: lit */
                                                    if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
                                                      ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                      /* checking for: , */
                                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun19) {
                                                        if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                          arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                          arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                          /* checking for: cf */
                                                          if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                                            ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                            /* checking for: opt */
                                                            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                                              ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                              /* checking for: layout */
                                                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                                                if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                                  arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                                  arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                                  /* checking for: cf */
                                                                  if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                                                    ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                                    /* checking for: sort */
                                                                    if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun9) {
                                                                      ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                                      /* checking for: NatCon */
                                                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun24) {
                                                                        if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                                          arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                                          arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                                          /* checking for: cf */
                                                                          if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                                                            ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                                            /* checking for: opt */
                                                                            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                                                              ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                                              /* checking for: layout */
                                                                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                                                                if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                                                  arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                                                  arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                                                  /* checking for: lit */
                                                                                  if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
                                                                                    ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                                                    /* checking for: ) */
                                                                                    if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun17) {
                                                                                      if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                                                                                        ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                                                                        /* checking for: cf */
                                                                                        if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == PTPT_afun2) {
                                                                                          ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                                                                          /* checking for: sort */
                                                                                          if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == PTPT_afun9) {
                                                                                            ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                                                                            /* checking for: Symbol */
                                                                                            if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == PTPT_afun25) {
                                                                                              ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                                                                              /* checking for: attrs */
                                                                                              if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == PTPT_afun12) {
                                                                                                ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                                                                                if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                                                                                  ATerm arg_arg0_arg2_arg0_head;
                                                                                                  ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                                                                                  arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                                                                                  arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                                                                                  /* checking for: term */
                                                                                                  if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == PTPT_afun13) {
                                                                                                    ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                                                                                    /* checking for: cons */
                                                                                                    if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == PTPT_afun14) {
                                                                                                      ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                                                                                      /* checking for: iter-n */
                                                                                                      if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == PTPT_afun69) {
                                                                                                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                                                                          ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                                                                          if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                                                                            ATerm arg_arg1_head;
                                                                                                            ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                                                                            arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                            arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                            /* checking for: appl */
                                                                                                            if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                              ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                              /* checking for: prod */
                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                                                ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                  ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                  arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                  arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                  /* checking for: char-class */
                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                      ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 105) {

                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                            arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                            arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                            /* checking for: char-class */
                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 116) {

                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                      arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                      arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                      /* checking for: char-class */
                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                          ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                          arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                          arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 101) {

                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                                arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                /* checking for: char-class */
                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                    ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                    arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                    arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 114) {

                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                                          arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                          arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                          /* checking for: char-class */
                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                              ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                              arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                              arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 45) {

                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                                                    arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                    arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                    /* checking for: char-class */
                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                        ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                        arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                        arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 110) {

                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                              ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                                              /* checking for: lit */
                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                                                                ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                                /* checking for: iter-n */
                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun69) {
                                                                                                                                                                                  ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                                  /* checking for: no-attrs */
                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                                                    ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                                      ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                                      ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                                      arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                      arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 105) {

                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                          arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                          arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 116) {

                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                              arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                              arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 101) {

                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                  arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                  arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 114) {

                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                      arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                      arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 45) {

                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                          arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                          arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 110) {

                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                  arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                                                                                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                  /* checking for: appl */
                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                                                                                                                                    ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                                                                                                                    /* checking for: prod */
                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                                                                                                                                                      ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                                                                                                        ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                                                                                                        arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                        arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                        /* checking for: char-class */
                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                                                            ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                                                            arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                            arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 40) {

                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                  ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                                                                                                  /* checking for: lit */
                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                                                                                                                    ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                                                                                    /* checking for: ( */
                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun21) {
                                                                                                                                                                                                                                      ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                                                                                      /* checking for: no-attrs */
                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                                                                                                        ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                                                                                          ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                                                                                          ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                                                                                          arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                          arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 40) {

                                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                    arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                      arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                                                                                                                                      arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                      /* checking for: appl */
                                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                                                                                                                                                                        ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                                                                                                                                                        /* checking for: prod */
                                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                                                                                                                                                                                          ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                                                                                                                                            ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                                                                                                                                            ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                                                                                                                                            arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                                            arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                                            /* checking for: char-class */
                                                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                                                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                                                                                                ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                                                                                                arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                                                arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 44) {

                                                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                                                      ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                                                                                                                                      /* checking for: lit */
                                                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                                                                                                                        /* checking for: , */
                                                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun19) {
                                                                                                                                                                                                                                                                          ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                                                                                                                          /* checking for: no-attrs */
                                                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                                                                                                                                            ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                                                                                                                              ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                                                                                                                              ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                                                                                                                              arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                              arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 44) {

                                                                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                    arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                      arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                        arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                          arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                                                                                                                                                                          arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                                                          /* checking for: appl */
                                                                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                                                                                                                                                                                                            ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                                                                                                                                                                                            /* checking for: prod */
                                                                                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                                                                                                                                                                                                                              ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                                                                                                                                                                                ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                                                                                                                                                                                ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                                                                                                                                                                                arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                                                                                arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                                                                                /* checking for: char-class */
                                                                                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                                                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                                                                                                                                    ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                                                                                                                                    arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                                                                                    arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 41) {

                                                                                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                                                                                          ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                                                                                                                                                                          /* checking for: lit */
                                                                                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                                                                                                                                                                                            ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                                                                                                                                                            /* checking for: ) */
                                                                                                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun17) {
                                                                                                                                                                                                                                                                                                              ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                                                                                                                                                              /* checking for: no-attrs */
                                                                                                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                                                                                                                                                                                ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                                                                                                                                                                  ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                                                                                                                                                                  ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                                                                                                                                                                  arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                                                  arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 41) {

                                                                                                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                                                                                                                                                                                                                                        return ATtrue;
                                                                                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                }
                                                                                                                                                                                                                              }
                                                                                                                                                                                                                            }
                                                                                                                                                                                                                          }
                                                                                                                                                                                                                        }
                                                                                                                                                                                                                      }
                                                                                                                                                                                                                    }
                                                                                                                                                                                                                  }
                                                                                                                                                                                                                }
                                                                                                                                                                                                              }
                                                                                                                                                                                                            }
                                                                                                                                                                                                          }
                                                                                                                                                                                                        }
                                                                                                                                                                                                      }
                                                                                                                                                                                                    }
                                                                                                                                                                                                  }
                                                                                                                                                                                                }
                                                                                                                                                                                              }
                                                                                                                                                                                            }
                                                                                                                                                                                          }
                                                                                                                                                                                        }
                                                                                                                                                                                      }
                                                                                                                                                                                    }
                                                                                                                                                                                  }
                                                                                                                                                                                }
                                                                                                                                                                              }
                                                                                                                                                                            }
                                                                                                                                                                          }
                                                                                                                                                                        }
                                                                                                                                                                      }
                                                                                                                                                                    }
                                                                                                                                                                  }
                                                                                                                                                                }
                                                                                                                                                              }
                                                                                                                                                            }
                                                                                                                                                          }
                                                                                                                                                        }
                                                                                                                                                      }
                                                                                                                                                    }
                                                                                                                                                  }
                                                                                                                                                }
                                                                                                                                              }
                                                                                                                                            }
                                                                                                                                          }
                                                                                                                                        }
                                                                                                                                      }
                                                                                                                                    }
                                                                                                                                  }
                                                                                                                                }
                                                                                                                              }
                                                                                                                            }
                                                                                                                          }
                                                                                                                        }
                                                                                                                      }
                                                                                                                    }
                                                                                                                  }
                                                                                                                }
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Symbol is a iter-sep-n by checking against the following ATerm pattern: appl(prod([lit("iter-sep-n"),cf(opt(layout)),lit("("),cf(opt(layout)),cf(sort("Symbol")),cf(opt(layout)),lit(","),cf(opt(layout)),cf(sort("Symbol")),cf(opt(layout)),lit(","),cf(opt(layout)),cf(sort("NatCon")),cf(opt(layout)),lit(")")],cf(sort("Symbol")),attrs([term(cons("iter-sep-n"))])),[appl(prod([char-class([105]),char-class([116]),char-class([101]),char-class([114]),char-class([45]),char-class([115]),char-class([101]),char-class([112]),char-class([45]),char-class([110])],lit("iter-sep-n"),no-attrs),[105,116,101,114,45,115,101,112,45,110]),<"ws-after-iter-sep-n"("OptLayout")>,appl(prod([char-class([40])],lit("("),no-attrs),[40]),<"ws-after-("("OptLayout")>,<"symbol"("Symbol")>,<"ws-after-symbol"("OptLayout")>,appl(prod([char-class([44])],lit(","),no-attrs),[44]),<"ws-after-comma1"("OptLayout")>,<"separator"("Symbol")>,<"ws-after-separator"("OptLayout")>,appl(prod([char-class([44])],lit(","),no-attrs),[44]),<"ws-after-comma2"("OptLayout")>,<"number"("NatCon")>,<"ws-after-number"("OptLayout")>,appl(prod([char-class([41])],lit(")"),no-attrs),[41])]). May not be used to assert correctness of the PTPT_Symbol
 * \param[in] arg input PTPT_Symbol
 * \return ATtrue if #arg corresponds to the signature of a iter-sep-n, or ATfalse otherwise
 */
inline ATbool PTPT_isSymbolIterSepN(PTPT_Symbol arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == PTPT_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == PTPT_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lit */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: iter-sep-n */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun70) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
              /* checking for: cf */
              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                /* checking for: opt */
                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                  /* checking for: layout */
                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                      arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                      arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                      /* checking for: lit */
                      if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
                        ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                        /* checking for: ( */
                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun21) {
                          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                            arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                            arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                            /* checking for: cf */
                            if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                              ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                              /* checking for: opt */
                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                /* checking for: layout */
                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                  if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                    arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                    arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                    /* checking for: cf */
                                    if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                      ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                      /* checking for: sort */
                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun9) {
                                        ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                        /* checking for: Symbol */
                                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun25) {
                                          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                            arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                            arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                            /* checking for: cf */
                                            if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                              ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                              /* checking for: opt */
                                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                                ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                /* checking for: layout */
                                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                                  if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                    arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                    arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                    /* checking for: lit */
                                                    if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
                                                      ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                      /* checking for: , */
                                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun19) {
                                                        if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                          arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                          arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                          /* checking for: cf */
                                                          if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                                            ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                            /* checking for: opt */
                                                            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                                              ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                              /* checking for: layout */
                                                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                                                if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                                  arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                                  arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                                  /* checking for: cf */
                                                                  if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                                                    ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                                    /* checking for: sort */
                                                                    if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun9) {
                                                                      ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                                      /* checking for: Symbol */
                                                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun25) {
                                                                        if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                                          arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                                          arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                                          /* checking for: cf */
                                                                          if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                                                            ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                                            /* checking for: opt */
                                                                            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                                                              ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                                              /* checking for: layout */
                                                                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                                                                if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                                                  arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                                                  arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                                                  /* checking for: lit */
                                                                                  if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
                                                                                    ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                                                    /* checking for: , */
                                                                                    if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun19) {
                                                                                      if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                                                        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                                                        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                                                        /* checking for: cf */
                                                                                        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                                                                          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                                                          /* checking for: opt */
                                                                                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                                                                            ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                                                            /* checking for: layout */
                                                                                            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                                                                              if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                                                                arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                                                                arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                                                                /* checking for: cf */
                                                                                                if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                                                                                  ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                                                                  /* checking for: sort */
                                                                                                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun9) {
                                                                                                    ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                                                                    /* checking for: NatCon */
                                                                                                    if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun24) {
                                                                                                      if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                                                                        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                                                                        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                                                                        /* checking for: cf */
                                                                                                        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                                                                                          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                                                                          /* checking for: opt */
                                                                                                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                                                                                            ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                                                                            /* checking for: layout */
                                                                                                            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                                                                                              if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                                                                                arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                                                                                arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                                                                                /* checking for: lit */
                                                                                                                if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
                                                                                                                  ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                                                                                  /* checking for: ) */
                                                                                                                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun17) {
                                                                                                                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                                                                                                                      ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                                                                                                      /* checking for: cf */
                                                                                                                      if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == PTPT_afun2) {
                                                                                                                        ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                                                                                                        /* checking for: sort */
                                                                                                                        if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == PTPT_afun9) {
                                                                                                                          ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                                                                                                          /* checking for: Symbol */
                                                                                                                          if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == PTPT_afun25) {
                                                                                                                            ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                                                                                                            /* checking for: attrs */
                                                                                                                            if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == PTPT_afun12) {
                                                                                                                              ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                                                                                                              if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                                                                                                                ATerm arg_arg0_arg2_arg0_head;
                                                                                                                                ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                                                                                                                arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                                                                                                                arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                                                                                                                /* checking for: term */
                                                                                                                                if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == PTPT_afun13) {
                                                                                                                                  ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                                                                                                                  /* checking for: cons */
                                                                                                                                  if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == PTPT_afun14) {
                                                                                                                                    ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                                                                                                                    /* checking for: iter-sep-n */
                                                                                                                                    if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == PTPT_afun70) {
                                                                                                                                      if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                                                                                                        ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                                                                                                        if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                                                                                                          ATerm arg_arg1_head;
                                                                                                                                          ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                                                                                                          arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                          arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                          /* checking for: appl */
                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                                                            ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                                            /* checking for: prod */
                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                                                                              ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                                ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                                ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                                arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                /* checking for: char-class */
                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                    ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                    arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                    arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 105) {

                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                                          arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                          arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                          /* checking for: char-class */
                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                              ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                              arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                              arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 116) {

                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                                                    arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                    arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                    /* checking for: char-class */
                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                        ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                        arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                        arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 101) {

                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                                                              arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                              arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                              /* checking for: char-class */
                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                  ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 114) {

                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                                                                        arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                        arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                        /* checking for: char-class */
                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                            ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                            arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                            arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 45) {

                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                                                                                  arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                  arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                  /* checking for: char-class */
                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                                      ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 115) {

                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                                                                                            arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                            arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                            /* checking for: char-class */
                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                                                ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                                                arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 101) {

                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                                                                                                      arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                      arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                      /* checking for: char-class */
                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                                                          ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                                                          arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                          arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 112) {

                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                                                                                                                arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                /* checking for: char-class */
                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                                                                    ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                                                                    arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                    arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 45) {

                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                                                                                                                          arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                          arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                          /* checking for: char-class */
                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                                                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                                                                              ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                                                                              arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                              arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 110) {

                                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                                    ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                                                                                                                    /* checking for: lit */
                                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                                                                                                                                      ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                                                                                                      /* checking for: iter-sep-n */
                                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun70) {
                                                                                                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                                                                                                        /* checking for: no-attrs */
                                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                                                                                                                          ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                                                                                                            ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                                                                                                            ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                                                                                                            arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                            arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 105) {

                                                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 116) {

                                                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                    arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                    arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 101) {

                                                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                        arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                        arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 114) {

                                                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                            arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                            arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 45) {

                                                                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 115) {

                                                                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                    arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                    arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 101) {

                                                                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                        arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                        arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 112) {

                                                                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                            arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                            arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 45) {

                                                                                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                                arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                                arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 110) {

                                                                                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                                      arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                                        arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                                                                                                                                                                                        arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                                                                        /* checking for: appl */
                                                                                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                                                                                                                                                                                                                          ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                                                                                                                                                                                                          /* checking for: prod */
                                                                                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                                                                                                                                                                                                                                            ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                                                                                                                                                                                              ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                                                                                                                                                                                              ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                                                                                                                                                                                              arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                                                                                              arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                                                                                              /* checking for: char-class */
                                                                                                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                                                                                                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                                                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                                                                                                                                                  ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                                                                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 40) {

                                                                                                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                                                                                                                                                                                        /* checking for: lit */
                                                                                                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                                                                                                                                                                                                          ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                                                                                                                                                                          /* checking for: ( */
                                                                                                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun21) {
                                                                                                                                                                                                                                                                                                                            ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                                                                                                                                                                            /* checking for: no-attrs */
                                                                                                                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                                                                                                                                                                                              ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                                                                                                                                                                                ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                                                                                                                                                                                ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                                                                                                                                                                                arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                                                                arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 40) {

                                                                                                                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                                                                      arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                                                                        arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                                                                          arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                                                                            arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                                                                                                                                                                                                                            arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                                                                                                            /* checking for: appl */
                                                                                                                                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                                                                                                                                                                                                                                                              ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                                                                                                                                                                                                                                              /* checking for: prod */
                                                                                                                                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                                                                                                                                                                                                                                                                                ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                                                                                                                                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                                                                                                                                                                                                                                  ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                                                                                                                                                                                                                                  arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                                                                                                                                  arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                                                                                                                                  /* checking for: char-class */
                                                                                                                                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                                                                                                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                                                                                                                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                                                                                                                                                                                      ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                                                                                                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                                                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 44) {

                                                                                                                                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                                                                                                                                            ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                                                                                                                                                                                                                            /* checking for: lit */
                                                                                                                                                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                                                                                                                                                                                                                                              ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                                                                                                                                                                                                              /* checking for: , */
                                                                                                                                                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun19) {
                                                                                                                                                                                                                                                                                                                                                                ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                                                                                                                                                                                                                /* checking for: no-attrs */
                                                                                                                                                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                                                                                                                                                                                                                                  ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                                                                                                                                                                                                                    ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                                                                                                                                                                                                                    ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                                                                                                                                                                                                                    arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                                                                                                    arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 44) {

                                                                                                                                                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                                                                                                          arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                                                                                                            arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                                                                                                              arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                                                                                                                arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                                                                                                                                                                                                                                                                arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                                                                                                                                                /* checking for: appl */
                                                                                                                                                                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                                                                                                                                                                                                                                                                                                  ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                                                                                                                                                                                                                                                                                  /* checking for: prod */
                                                                                                                                                                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                                                                                                                                                                                                                                                                                                                    ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                                                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                                                                                                                                                                                                                                                                      ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                                                                                                                                                                                                                                                                      ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                                                                                                                                                                                                                                                                      arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                                                                                                                                                                      arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                                                                                                                                                                      /* checking for: char-class */
                                                                                                                                                                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                                                                                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                                                                                                                                                                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                                                                                                                                                                                                                          ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                                                                                                                                                                                                                          arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                                                                                                                                                                          arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                                                                                                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 44) {

                                                                                                                                                                                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                                                                                                                                                                                ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                                                                                                                                                                                                                                                                /* checking for: lit */
                                                                                                                                                                                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                                                                                                                                                                                                                                                                                  ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                                                                                                                                                                                                                                                  /* checking for: , */
                                                                                                                                                                                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun19) {
                                                                                                                                                                                                                                                                                                                                                                                                    ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                                                                                                                                                                                                                                                    /* checking for: no-attrs */
                                                                                                                                                                                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                                                                                                                                                                                                                                                                      ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                                                                                                                                                                                                                                                        ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                                                                                                                                                                                                                                                        ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                                                                                                                                                                                                                                                        arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                                                                                                                                        arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                                                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 44) {

                                                                                                                                                                                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                                                                                                                                              arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                                                                                                                                                arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                                                                                                                                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                                                                                                                                                    arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                                                                                                                                                                                                                                                                                                    arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                                                                                                                                                                                    /* checking for: appl */
                                                                                                                                                                                                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                                                                                                                                                                                                                                                                                                                                      ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                                                                                                                                                                                                                                                                                                                      /* checking for: prod */
                                                                                                                                                                                                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                                                                                                                                                                                                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                                                                                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                                                                                                                                                                                                                                                                                                          ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                                                                                                                                                                                                                                                                                                          ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                                                                                                                                                                                                                                                                                                          arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                                                                                                                                                                                                          arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                                                                                                                                                                                                          /* checking for: char-class */
                                                                                                                                                                                                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                                                                                                                                                                                                                                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                                                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                                                                                                                                                                                                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                                                                                                                                                                                                                                                              ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                                                                                                                                                                                                                                                              arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                                                                                                                                                                                                              arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                                                                                                                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 41) {

                                                                                                                                                                                                                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                                                                                                                                                                                                                    ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                                                                                                                                                                                                                                                                                                    /* checking for: lit */
                                                                                                                                                                                                                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                                                                                                                                                                                                                                                                                                                      ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                                                                                                                                                                                                                                                                                      /* checking for: ) */
                                                                                                                                                                                                                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun17) {
                                                                                                                                                                                                                                                                                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                                                                                                                                                                                                                                                                                        /* checking for: no-attrs */
                                                                                                                                                                                                                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                                                                                                                                                                                                                                                                                                          ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                                                                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                                                                                                                                                                                                                                                                                            ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                                                                                                                                                                                                                                                                                            ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                                                                                                                                                                                                                                                                                            arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                                                                                                                                                                            arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                                                                                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 41) {

                                                                                                                                                                                                                                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                                                                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                                                                                                                                                                                                                                                                                                                                                                  return ATtrue;
                                                                                                                                                                                                                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                }
                                                                                                                                                                                                                              }
                                                                                                                                                                                                                            }
                                                                                                                                                                                                                          }
                                                                                                                                                                                                                        }
                                                                                                                                                                                                                      }
                                                                                                                                                                                                                    }
                                                                                                                                                                                                                  }
                                                                                                                                                                                                                }
                                                                                                                                                                                                              }
                                                                                                                                                                                                            }
                                                                                                                                                                                                          }
                                                                                                                                                                                                        }
                                                                                                                                                                                                      }
                                                                                                                                                                                                    }
                                                                                                                                                                                                  }
                                                                                                                                                                                                }
                                                                                                                                                                                              }
                                                                                                                                                                                            }
                                                                                                                                                                                          }
                                                                                                                                                                                        }
                                                                                                                                                                                      }
                                                                                                                                                                                    }
                                                                                                                                                                                  }
                                                                                                                                                                                }
                                                                                                                                                                              }
                                                                                                                                                                            }
                                                                                                                                                                          }
                                                                                                                                                                        }
                                                                                                                                                                      }
                                                                                                                                                                    }
                                                                                                                                                                  }
                                                                                                                                                                }
                                                                                                                                                              }
                                                                                                                                                            }
                                                                                                                                                          }
                                                                                                                                                        }
                                                                                                                                                      }
                                                                                                                                                    }
                                                                                                                                                  }
                                                                                                                                                }
                                                                                                                                              }
                                                                                                                                            }
                                                                                                                                          }
                                                                                                                                        }
                                                                                                                                      }
                                                                                                                                    }
                                                                                                                                  }
                                                                                                                                }
                                                                                                                              }
                                                                                                                            }
                                                                                                                          }
                                                                                                                        }
                                                                                                                      }
                                                                                                                    }
                                                                                                                  }
                                                                                                                }
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Symbol is a func by checking against the following ATerm pattern: appl(prod([lit("func"),cf(opt(layout)),lit("("),cf(opt(layout)),cf(sort("Symbols")),cf(opt(layout)),lit(","),cf(opt(layout)),cf(sort("Symbol")),cf(opt(layout)),lit(")")],cf(sort("Symbol")),attrs([term(cons("func"))])),[appl(prod([char-class([102]),char-class([117]),char-class([110]),char-class([99])],lit("func"),no-attrs),[102,117,110,99]),<"ws-after-func"("OptLayout")>,appl(prod([char-class([40])],lit("("),no-attrs),[40]),<"ws-after-("("OptLayout")>,<"symbols"("Symbols")>,<"ws-after-symbols"("OptLayout")>,appl(prod([char-class([44])],lit(","),no-attrs),[44]),<"ws-after-,"("OptLayout")>,<"symbol"("Symbol")>,<"ws-after-symbol"("OptLayout")>,appl(prod([char-class([41])],lit(")"),no-attrs),[41])]). May not be used to assert correctness of the PTPT_Symbol
 * \param[in] arg input PTPT_Symbol
 * \return ATtrue if #arg corresponds to the signature of a func, or ATfalse otherwise
 */
inline ATbool PTPT_isSymbolFunc(PTPT_Symbol arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == PTPT_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == PTPT_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lit */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: func */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun71) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
              /* checking for: cf */
              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                /* checking for: opt */
                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                  /* checking for: layout */
                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                      arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                      arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                      /* checking for: lit */
                      if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
                        ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                        /* checking for: ( */
                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun21) {
                          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                            arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                            arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                            /* checking for: cf */
                            if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                              ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                              /* checking for: opt */
                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                /* checking for: layout */
                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                  if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                    arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                    arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                    /* checking for: cf */
                                    if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                      ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                      /* checking for: sort */
                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun9) {
                                        ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                        /* checking for: Symbols */
                                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun61) {
                                          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                            arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                            arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                            /* checking for: cf */
                                            if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                              ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                              /* checking for: opt */
                                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                                ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                /* checking for: layout */
                                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                                  if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                    arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                    arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                    /* checking for: lit */
                                                    if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
                                                      ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                      /* checking for: , */
                                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun19) {
                                                        if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                          arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                          arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                          /* checking for: cf */
                                                          if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                                            ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                            /* checking for: opt */
                                                            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                                              ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                              /* checking for: layout */
                                                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                                                if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                                  arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                                  arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                                  /* checking for: cf */
                                                                  if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                                                    ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                                    /* checking for: sort */
                                                                    if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun9) {
                                                                      ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                                      /* checking for: Symbol */
                                                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun25) {
                                                                        if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                                          arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                                          arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                                          /* checking for: cf */
                                                                          if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                                                            ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                                            /* checking for: opt */
                                                                            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                                                              ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                                              /* checking for: layout */
                                                                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                                                                if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                                                  arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                                                  arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                                                  /* checking for: lit */
                                                                                  if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
                                                                                    ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                                                    /* checking for: ) */
                                                                                    if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun17) {
                                                                                      if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                                                                                        ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                                                                        /* checking for: cf */
                                                                                        if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == PTPT_afun2) {
                                                                                          ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                                                                          /* checking for: sort */
                                                                                          if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == PTPT_afun9) {
                                                                                            ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                                                                            /* checking for: Symbol */
                                                                                            if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == PTPT_afun25) {
                                                                                              ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                                                                              /* checking for: attrs */
                                                                                              if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == PTPT_afun12) {
                                                                                                ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                                                                                if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                                                                                  ATerm arg_arg0_arg2_arg0_head;
                                                                                                  ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                                                                                  arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                                                                                  arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                                                                                  /* checking for: term */
                                                                                                  if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == PTPT_afun13) {
                                                                                                    ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                                                                                    /* checking for: cons */
                                                                                                    if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == PTPT_afun14) {
                                                                                                      ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                                                                                      /* checking for: func */
                                                                                                      if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == PTPT_afun71) {
                                                                                                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                                                                          ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                                                                          if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                                                                            ATerm arg_arg1_head;
                                                                                                            ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                                                                            arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                            arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                            /* checking for: appl */
                                                                                                            if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                              ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                              /* checking for: prod */
                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                                                ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                  ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                  arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                  arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                  /* checking for: char-class */
                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                      ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 102) {

                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                            arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                            arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                            /* checking for: char-class */
                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 117) {

                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                      arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                      arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                      /* checking for: char-class */
                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                          ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                          arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                          arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 110) {

                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                                arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                /* checking for: char-class */
                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                    ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                    arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                    arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 99) {

                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                          ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                          /* checking for: lit */
                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                                            ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                            /* checking for: func */
                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun71) {
                                                                                                                                                              ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                              /* checking for: no-attrs */
                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                                ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                  ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                  ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                  arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                  arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 102) {

                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                      arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                      arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 117) {

                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                          arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                          arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 110) {

                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                              arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                              arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 99) {

                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                    arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                      arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                                                                      arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                      /* checking for: appl */
                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                                                                                                        ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                                                                                        /* checking for: prod */
                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                                                                                                                          ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                                                                            ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                                                                            ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                                                                            arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                            arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                            /* checking for: char-class */
                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                                ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                                arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 40) {

                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                                                      ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                                                                      /* checking for: lit */
                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                                                        /* checking for: ( */
                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun21) {
                                                                                                                                                                                                          ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                                                          /* checking for: no-attrs */
                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                                                                            ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                                                              ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                                                              ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                                                              arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                              arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 40) {

                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                    arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                      arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                        arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                          arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                                                                                                          arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                          /* checking for: appl */
                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                                                                                                                                            ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                                                                                                                            /* checking for: prod */
                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                                                                                                                                                              ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                                                                                                                ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                                                                                                                ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                                                                                                                arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                /* checking for: char-class */
                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                                                                    ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                                                                    arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                    arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 44) {

                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                          ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                                                                                                          /* checking for: lit */
                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                                                                                                                            ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                                                                                            /* checking for: , */
                                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun19) {
                                                                                                                                                                                                                                              ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                                                                                              /* checking for: no-attrs */
                                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                                                                                                                ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                                                                                                  ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                                                                                                  ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                                                                                                  arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                  arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 44) {

                                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                        arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                          arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                            arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                              arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                                                                                                                                              arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                              /* checking for: appl */
                                                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                                                                                                                                                                                ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                                                                                                                                                                /* checking for: prod */
                                                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                                                                                                                                                                                                  ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                                                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                                                                                                                                                    ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                                                                                                                                                    arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                                                    arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                                                    /* checking for: char-class */
                                                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                                                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                                                                                                        ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                                                                                                        arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                                                        arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 41) {

                                                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                                                              ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                                                                                                                                              /* checking for: lit */
                                                                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                                                                                                                                                                ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                                                                                                                                /* checking for: ) */
                                                                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun17) {
                                                                                                                                                                                                                                                                                  ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                                                                                                                                  /* checking for: no-attrs */
                                                                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                                                                                                                                                    ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                                                                                                                                      ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                                                                                                                                      ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                                                                                                                                      arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                      arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 41) {

                                                                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                                                                                                                                                                                                            return ATtrue;
                                                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                }
                                                                                                                                                                                                                              }
                                                                                                                                                                                                                            }
                                                                                                                                                                                                                          }
                                                                                                                                                                                                                        }
                                                                                                                                                                                                                      }
                                                                                                                                                                                                                    }
                                                                                                                                                                                                                  }
                                                                                                                                                                                                                }
                                                                                                                                                                                                              }
                                                                                                                                                                                                            }
                                                                                                                                                                                                          }
                                                                                                                                                                                                        }
                                                                                                                                                                                                      }
                                                                                                                                                                                                    }
                                                                                                                                                                                                  }
                                                                                                                                                                                                }
                                                                                                                                                                                              }
                                                                                                                                                                                            }
                                                                                                                                                                                          }
                                                                                                                                                                                        }
                                                                                                                                                                                      }
                                                                                                                                                                                    }
                                                                                                                                                                                  }
                                                                                                                                                                                }
                                                                                                                                                                              }
                                                                                                                                                                            }
                                                                                                                                                                          }
                                                                                                                                                                        }
                                                                                                                                                                      }
                                                                                                                                                                    }
                                                                                                                                                                  }
                                                                                                                                                                }
                                                                                                                                                              }
                                                                                                                                                            }
                                                                                                                                                          }
                                                                                                                                                        }
                                                                                                                                                      }
                                                                                                                                                    }
                                                                                                                                                  }
                                                                                                                                                }
                                                                                                                                              }
                                                                                                                                            }
                                                                                                                                          }
                                                                                                                                        }
                                                                                                                                      }
                                                                                                                                    }
                                                                                                                                  }
                                                                                                                                }
                                                                                                                              }
                                                                                                                            }
                                                                                                                          }
                                                                                                                        }
                                                                                                                      }
                                                                                                                    }
                                                                                                                  }
                                                                                                                }
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Symbol is a varsym by checking against the following ATerm pattern: appl(prod([lit("varsym"),cf(opt(layout)),lit("("),cf(opt(layout)),cf(sort("Symbol")),cf(opt(layout)),lit(")")],cf(sort("Symbol")),attrs([term(cons("varsym"))])),[appl(prod([char-class([118]),char-class([97]),char-class([114]),char-class([115]),char-class([121]),char-class([109])],lit("varsym"),no-attrs),[118,97,114,115,121,109]),<"ws-after-varsym"("OptLayout")>,appl(prod([char-class([40])],lit("("),no-attrs),[40]),<"ws-after-("("OptLayout")>,<"symbol"("Symbol")>,<"ws-after-symbol"("OptLayout")>,appl(prod([char-class([41])],lit(")"),no-attrs),[41])]). May not be used to assert correctness of the PTPT_Symbol
 * \param[in] arg input PTPT_Symbol
 * \return ATtrue if #arg corresponds to the signature of a varsym, or ATfalse otherwise
 */
inline ATbool PTPT_isSymbolVarsym(PTPT_Symbol arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == PTPT_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == PTPT_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lit */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: varsym */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun72) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
              /* checking for: cf */
              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                /* checking for: opt */
                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                  /* checking for: layout */
                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                      arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                      arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                      /* checking for: lit */
                      if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
                        ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                        /* checking for: ( */
                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun21) {
                          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                            arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                            arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                            /* checking for: cf */
                            if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                              ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                              /* checking for: opt */
                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                /* checking for: layout */
                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                  if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                    arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                    arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                    /* checking for: cf */
                                    if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                      ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                      /* checking for: sort */
                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun9) {
                                        ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                        /* checking for: Symbol */
                                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun25) {
                                          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                            arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                            arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                            /* checking for: cf */
                                            if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                              ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                              /* checking for: opt */
                                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                                ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                /* checking for: layout */
                                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                                  if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                    arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                    arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                    /* checking for: lit */
                                                    if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
                                                      ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                      /* checking for: ) */
                                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun17) {
                                                        if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                                                          ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                                          /* checking for: cf */
                                                          if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == PTPT_afun2) {
                                                            ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                                            /* checking for: sort */
                                                            if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == PTPT_afun9) {
                                                              ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                                              /* checking for: Symbol */
                                                              if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == PTPT_afun25) {
                                                                ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                                                /* checking for: attrs */
                                                                if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == PTPT_afun12) {
                                                                  ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                                                  if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                                                    ATerm arg_arg0_arg2_arg0_head;
                                                                    ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                                                    arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                                                    arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                                                    /* checking for: term */
                                                                    if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == PTPT_afun13) {
                                                                      ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                                                      /* checking for: cons */
                                                                      if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == PTPT_afun14) {
                                                                        ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                                                        /* checking for: varsym */
                                                                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == PTPT_afun72) {
                                                                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                                            ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                                            if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                                              ATerm arg_arg1_head;
                                                                              ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                                              arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                              arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                              /* checking for: appl */
                                                                              if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                /* checking for: prod */
                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                  ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                    ATerm arg_arg1_head_arg0_arg0_head;
                                                                                    ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                    arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                    arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                    /* checking for: char-class */
                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                        ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                        arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                        arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 118) {

                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                              arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                              arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                              /* checking for: char-class */
                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                  ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 97) {

                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                        arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                        arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                        /* checking for: char-class */
                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                            ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                            arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                            arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 114) {

                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                  arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                  arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                  /* checking for: char-class */
                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                      ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 115) {

                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                            arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                            arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                            /* checking for: char-class */
                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 121) {

                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                      arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                      arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                      /* checking for: char-class */
                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                          ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                          arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                          arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 109) {

                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                /* checking for: lit */
                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                                  ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                  /* checking for: varsym */
                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun72) {
                                                                                                                                                    ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                    /* checking for: no-attrs */
                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                      ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                        ATerm arg_arg1_head_arg1_head;
                                                                                                                                                        ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                        arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                        arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 118) {

                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                            arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                            arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 97) {

                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 114) {

                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                    arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                    arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 115) {

                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                        arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                        arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 121) {

                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                            arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                            arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 109) {

                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                    arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                                                                    arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                    /* checking for: appl */
                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                                                                                                      ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                                                                                      /* checking for: prod */
                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                                                                          ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                                                                          ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                                                                          arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                          arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                          /* checking for: char-class */
                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                              ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                              arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                              arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 40) {

                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                                                    ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                                                                    /* checking for: lit */
                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                                                                                      ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                                                      /* checking for: ( */
                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun21) {
                                                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                                                        /* checking for: no-attrs */
                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                                                                          ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                                                            ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                                                            ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                                                            arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                            arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 40) {

                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                    arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                      arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                        arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                                                                                                        arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                        /* checking for: appl */
                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                                                                                                                                          ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                                                                                                                          /* checking for: prod */
                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                                                                                                                                                            ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                                                                                                              ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                                                                                                              ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                                                                                                              arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                              arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                              /* checking for: char-class */
                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                                                                  ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 41) {

                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                                                                                                        /* checking for: lit */
                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                                                                                                                          ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                                                                                          /* checking for: ) */
                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun17) {
                                                                                                                                                                                                                                            ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                                                                                            /* checking for: no-attrs */
                                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                                                                                                              ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                                                                                                ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                                                                                                ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                                                                                                arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 41) {

                                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                                                                                                                                                                      return ATtrue;
                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                }
                                                                                                                                                                                                                              }
                                                                                                                                                                                                                            }
                                                                                                                                                                                                                          }
                                                                                                                                                                                                                        }
                                                                                                                                                                                                                      }
                                                                                                                                                                                                                    }
                                                                                                                                                                                                                  }
                                                                                                                                                                                                                }
                                                                                                                                                                                                              }
                                                                                                                                                                                                            }
                                                                                                                                                                                                          }
                                                                                                                                                                                                        }
                                                                                                                                                                                                      }
                                                                                                                                                                                                    }
                                                                                                                                                                                                  }
                                                                                                                                                                                                }
                                                                                                                                                                                              }
                                                                                                                                                                                            }
                                                                                                                                                                                          }
                                                                                                                                                                                        }
                                                                                                                                                                                      }
                                                                                                                                                                                    }
                                                                                                                                                                                  }
                                                                                                                                                                                }
                                                                                                                                                                              }
                                                                                                                                                                            }
                                                                                                                                                                          }
                                                                                                                                                                        }
                                                                                                                                                                      }
                                                                                                                                                                    }
                                                                                                                                                                  }
                                                                                                                                                                }
                                                                                                                                                              }
                                                                                                                                                            }
                                                                                                                                                          }
                                                                                                                                                        }
                                                                                                                                                      }
                                                                                                                                                    }
                                                                                                                                                  }
                                                                                                                                                }
                                                                                                                                              }
                                                                                                                                            }
                                                                                                                                          }
                                                                                                                                        }
                                                                                                                                      }
                                                                                                                                    }
                                                                                                                                  }
                                                                                                                                }
                                                                                                                              }
                                                                                                                            }
                                                                                                                          }
                                                                                                                        }
                                                                                                                      }
                                                                                                                    }
                                                                                                                  }
                                                                                                                }
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Symbol is a layout by checking against the following ATerm pattern: appl(prod([lit("layout")],cf(sort("Symbol")),attrs([term(cons("layout"))])),[appl(prod([char-class([108]),char-class([97]),char-class([121]),char-class([111]),char-class([117]),char-class([116])],lit("layout"),no-attrs),[108,97,121,111,117,116])]). May not be used to assert correctness of the PTPT_Symbol
 * \param[in] arg input PTPT_Symbol
 * \return ATtrue if #arg corresponds to the signature of a layout, or ATfalse otherwise
 */
inline ATbool PTPT_isSymbolLayout(PTPT_Symbol arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == PTPT_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == PTPT_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lit */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: layout */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun73) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
              ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
              /* checking for: cf */
              if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == PTPT_afun2) {
                ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                /* checking for: sort */
                if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == PTPT_afun9) {
                  ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                  /* checking for: Symbol */
                  if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == PTPT_afun25) {
                    ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                    /* checking for: attrs */
                    if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == PTPT_afun12) {
                      ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                      if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                        ATerm arg_arg0_arg2_arg0_head;
                        ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                        arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                        arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                        /* checking for: term */
                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == PTPT_afun13) {
                          ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                          /* checking for: cons */
                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == PTPT_afun14) {
                            ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                            /* checking for: layout */
                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == PTPT_afun73) {
                              if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                ATerm arg_arg1 = ATgetArgument(arg, 1);
                                if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                  ATerm arg_arg1_head;
                                  ATermList arg_arg1_list = (ATermList)arg_arg1;
                                  arg_arg1_head = ATgetFirst(arg_arg1_list);
                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                  /* checking for: appl */
                                  if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                    ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                    /* checking for: prod */
                                    if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                      ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                        ATerm arg_arg1_head_arg0_arg0_head;
                                        ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                        arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                        arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                        /* checking for: char-class */
                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                          ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                            ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                            ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                            arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                            arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                            if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 108) {

                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                  arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                  arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                  /* checking for: char-class */
                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                      ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                      arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                      arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 97) {

                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                            arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                            arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                            /* checking for: char-class */
                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 121) {

                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                      arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                      arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                      /* checking for: char-class */
                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                          ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                          arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                          arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 111) {

                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                /* checking for: char-class */
                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                    ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                    arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                    arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 117) {

                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                          arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                          arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                          /* checking for: char-class */
                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                              ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                              arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                              arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 116) {

                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                    ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                    /* checking for: lit */
                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                      ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                      /* checking for: layout */
                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun73) {
                                                                                                        ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                        /* checking for: no-attrs */
                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                          ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                            ATerm arg_arg1_head_arg1_head;
                                                                                                            ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                            arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                            arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 108) {

                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 97) {

                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                    arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                    arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 121) {

                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                        arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                        arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 111) {

                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                            arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                            arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 117) {

                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 116) {

                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                                                      return ATtrue;
                                                                                                                                    }
                                                                                                                                  }
                                                                                                                                }
                                                                                                                              }
                                                                                                                            }
                                                                                                                          }
                                                                                                                        }
                                                                                                                      }
                                                                                                                    }
                                                                                                                  }
                                                                                                                }
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Symbol is a char-class by checking against the following ATerm pattern: appl(prod([lit("char-class"),cf(opt(layout)),lit("("),cf(opt(layout)),cf(sort("CharRanges")),cf(opt(layout)),lit(")")],cf(sort("Symbol")),attrs([term(cons("char-class"))])),[appl(prod([char-class([99]),char-class([104]),char-class([97]),char-class([114]),char-class([45]),char-class([99]),char-class([108]),char-class([97]),char-class([115]),char-class([115])],lit("char-class"),no-attrs),[99,104,97,114,45,99,108,97,115,115]),<"ws-after-char-class"("OptLayout")>,appl(prod([char-class([40])],lit("("),no-attrs),[40]),<"ws-after-("("OptLayout")>,<"CharRanges"("CharRanges")>,<"ws-after-CharRanges"("OptLayout")>,appl(prod([char-class([41])],lit(")"),no-attrs),[41])]). May not be used to assert correctness of the PTPT_Symbol
 * \param[in] arg input PTPT_Symbol
 * \return ATtrue if #arg corresponds to the signature of a char-class, or ATfalse otherwise
 */
inline ATbool PTPT_isSymbolCharClass(PTPT_Symbol arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == PTPT_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == PTPT_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lit */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: char-class */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun75) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
              /* checking for: cf */
              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                /* checking for: opt */
                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                  /* checking for: layout */
                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                      arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                      arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                      /* checking for: lit */
                      if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
                        ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                        /* checking for: ( */
                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun21) {
                          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                            arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                            arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                            /* checking for: cf */
                            if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                              ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                              /* checking for: opt */
                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                /* checking for: layout */
                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                  if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                    arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                    arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                    /* checking for: cf */
                                    if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                      ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                      /* checking for: sort */
                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun9) {
                                        ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                        /* checking for: CharRanges */
                                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun74) {
                                          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                            arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                            arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                            /* checking for: cf */
                                            if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                              ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                              /* checking for: opt */
                                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                                ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                /* checking for: layout */
                                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                                  if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                    arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                    arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                    /* checking for: lit */
                                                    if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
                                                      ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                      /* checking for: ) */
                                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun17) {
                                                        if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                                                          ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                                          /* checking for: cf */
                                                          if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == PTPT_afun2) {
                                                            ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                                            /* checking for: sort */
                                                            if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == PTPT_afun9) {
                                                              ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                                              /* checking for: Symbol */
                                                              if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == PTPT_afun25) {
                                                                ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                                                /* checking for: attrs */
                                                                if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == PTPT_afun12) {
                                                                  ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                                                  if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                                                    ATerm arg_arg0_arg2_arg0_head;
                                                                    ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                                                    arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                                                    arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                                                    /* checking for: term */
                                                                    if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == PTPT_afun13) {
                                                                      ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                                                      /* checking for: cons */
                                                                      if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == PTPT_afun14) {
                                                                        ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                                                        /* checking for: char-class */
                                                                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == PTPT_afun75) {
                                                                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                                            ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                                            if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                                              ATerm arg_arg1_head;
                                                                              ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                                              arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                              arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                              /* checking for: appl */
                                                                              if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                /* checking for: prod */
                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                  ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                    ATerm arg_arg1_head_arg0_arg0_head;
                                                                                    ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                    arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                    arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                    /* checking for: char-class */
                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                        ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                        arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                        arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 99) {

                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                              arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                              arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                              /* checking for: char-class */
                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                  ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 104) {

                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                        arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                        arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                        /* checking for: char-class */
                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                            ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                            arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                            arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 97) {

                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                  arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                  arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                  /* checking for: char-class */
                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                      ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 114) {

                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                            arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                            arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                            /* checking for: char-class */
                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 45) {

                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                      arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                      arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                      /* checking for: char-class */
                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                          ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                          arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                          arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 99) {

                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                                arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                /* checking for: char-class */
                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                    ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                    arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                    arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 108) {

                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                                          arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                          arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                          /* checking for: char-class */
                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                              ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                              arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                              arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 97) {

                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                                                    arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                    arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                    /* checking for: char-class */
                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                        ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                        arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                        arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 115) {

                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                                                              arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                              arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                              /* checking for: char-class */
                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                  ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 115) {

                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                                                        /* checking for: lit */
                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                                                                          ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                                          /* checking for: char-class */
                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun75) {
                                                                                                                                                                                            ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                                            /* checking for: no-attrs */
                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                                                              ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                                                ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                                                ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                                                arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 99) {

                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                    arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                    arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 104) {

                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                        arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                        arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 97) {

                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                            arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                            arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 114) {

                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                                arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 45) {

                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                                    arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                    arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 99) {

                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                                        arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                        arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 108) {

                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                                            arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                            arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 97) {

                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 115) {

                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                    arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                    arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 115) {

                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                          arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                            arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                                                                                                                            arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                            /* checking for: appl */
                                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                                                                                                                                                              ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                                                                                                                                              /* checking for: prod */
                                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                                                                                                                                                                                ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                                                                                                                                  ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                                                                                                                                  arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                                  arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                                  /* checking for: char-class */
                                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                                                                                      ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 40) {

                                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                                            ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                                                                                                                            /* checking for: lit */
                                                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                                                                                                                                              ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                                                                                                              /* checking for: ( */
                                                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun21) {
                                                                                                                                                                                                                                                                ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                                                                                                                /* checking for: no-attrs */
                                                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                                                                                                                                  ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                                                                                                                    ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                                                                                                                    ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                                                                                                                    arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                    arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 40) {

                                                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                          arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                            arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                              arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                                                                                                                                                                arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                                                /* checking for: appl */
                                                                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                                                                                                                                                                                                  ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                                                                                                                                                                                  /* checking for: prod */
                                                                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                                                                                                                                                                                                                    ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                                                                                                                                                                      ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                                                                                                                                                                      ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                                                                                                                                                                      arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                                                                      arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                                                                      /* checking for: char-class */
                                                                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                                                                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                                                                                                                          ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                                                                                                                          arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                                                                          arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 41) {

                                                                                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                                                                                ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                                                                                                                                                                /* checking for: lit */
                                                                                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                                                                                                                                                                                  ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                                                                                                                                                  /* checking for: ) */
                                                                                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun17) {
                                                                                                                                                                                                                                                                                                    ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                                                                                                                                                    /* checking for: no-attrs */
                                                                                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                                                                                                                                                                      ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                                                                                                                                                        ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                                                                                                                                                        ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                                                                                                                                                        arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                                        arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 41) {

                                                                                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                                                                                                                                                                                                                              return ATtrue;
                                                                                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                }
                                                                                                                                                                                                                              }
                                                                                                                                                                                                                            }
                                                                                                                                                                                                                          }
                                                                                                                                                                                                                        }
                                                                                                                                                                                                                      }
                                                                                                                                                                                                                    }
                                                                                                                                                                                                                  }
                                                                                                                                                                                                                }
                                                                                                                                                                                                              }
                                                                                                                                                                                                            }
                                                                                                                                                                                                          }
                                                                                                                                                                                                        }
                                                                                                                                                                                                      }
                                                                                                                                                                                                    }
                                                                                                                                                                                                  }
                                                                                                                                                                                                }
                                                                                                                                                                                              }
                                                                                                                                                                                            }
                                                                                                                                                                                          }
                                                                                                                                                                                        }
                                                                                                                                                                                      }
                                                                                                                                                                                    }
                                                                                                                                                                                  }
                                                                                                                                                                                }
                                                                                                                                                                              }
                                                                                                                                                                            }
                                                                                                                                                                          }
                                                                                                                                                                        }
                                                                                                                                                                      }
                                                                                                                                                                    }
                                                                                                                                                                  }
                                                                                                                                                                }
                                                                                                                                                              }
                                                                                                                                                            }
                                                                                                                                                          }
                                                                                                                                                        }
                                                                                                                                                      }
                                                                                                                                                    }
                                                                                                                                                  }
                                                                                                                                                }
                                                                                                                                              }
                                                                                                                                            }
                                                                                                                                          }
                                                                                                                                        }
                                                                                                                                      }
                                                                                                                                    }
                                                                                                                                  }
                                                                                                                                }
                                                                                                                              }
                                                                                                                            }
                                                                                                                          }
                                                                                                                        }
                                                                                                                      }
                                                                                                                    }
                                                                                                                  }
                                                                                                                }
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Symbol is a strategy by checking against the following ATerm pattern: appl(prod([lit("strategy"),cf(opt(layout)),lit("("),cf(opt(layout)),cf(sort("Symbol")),cf(opt(layout)),lit(","),cf(opt(layout)),cf(sort("Symbol")),cf(opt(layout)),lit(")")],cf(sort("Symbol")),attrs([term(cons("strategy"))])),[appl(prod([char-class([115]),char-class([116]),char-class([114]),char-class([97]),char-class([116]),char-class([101]),char-class([103]),char-class([121])],lit("strategy"),no-attrs),[115,116,114,97,116,101,103,121]),<"ws-after-strategy"("OptLayout")>,appl(prod([char-class([40])],lit("("),no-attrs),[40]),<"ws-after-("("OptLayout")>,<"lhs"("Symbol")>,<"ws-after-lhs"("OptLayout")>,appl(prod([char-class([44])],lit(","),no-attrs),[44]),<"ws-after-,"("OptLayout")>,<"rhs"("Symbol")>,<"ws-after-rhs"("OptLayout")>,appl(prod([char-class([41])],lit(")"),no-attrs),[41])]). May not be used to assert correctness of the PTPT_Symbol
 * \param[in] arg input PTPT_Symbol
 * \return ATtrue if #arg corresponds to the signature of a strategy, or ATfalse otherwise
 */
inline ATbool PTPT_isSymbolStrategy(PTPT_Symbol arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == PTPT_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == PTPT_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lit */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: strategy */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun76) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
              /* checking for: cf */
              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                /* checking for: opt */
                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                  /* checking for: layout */
                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                      arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                      arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                      /* checking for: lit */
                      if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
                        ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                        /* checking for: ( */
                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun21) {
                          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                            arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                            arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                            /* checking for: cf */
                            if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                              ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                              /* checking for: opt */
                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                /* checking for: layout */
                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                  if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                    arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                    arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                    /* checking for: cf */
                                    if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                      ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                      /* checking for: sort */
                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun9) {
                                        ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                        /* checking for: Symbol */
                                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun25) {
                                          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                            arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                            arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                            /* checking for: cf */
                                            if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                              ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                              /* checking for: opt */
                                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                                ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                /* checking for: layout */
                                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                                  if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                    arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                    arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                    /* checking for: lit */
                                                    if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
                                                      ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                      /* checking for: , */
                                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun19) {
                                                        if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                          arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                          arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                          /* checking for: cf */
                                                          if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                                            ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                            /* checking for: opt */
                                                            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                                              ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                              /* checking for: layout */
                                                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                                                if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                                  arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                                  arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                                  /* checking for: cf */
                                                                  if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                                                    ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                                    /* checking for: sort */
                                                                    if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun9) {
                                                                      ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                                      /* checking for: Symbol */
                                                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun25) {
                                                                        if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                                          arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                                          arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                                          /* checking for: cf */
                                                                          if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                                                            ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                                            /* checking for: opt */
                                                                            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                                                              ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                                              /* checking for: layout */
                                                                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                                                                if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                                                  arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                                                  arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                                                  /* checking for: lit */
                                                                                  if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
                                                                                    ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                                                    /* checking for: ) */
                                                                                    if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun17) {
                                                                                      if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                                                                                        ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                                                                        /* checking for: cf */
                                                                                        if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == PTPT_afun2) {
                                                                                          ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                                                                          /* checking for: sort */
                                                                                          if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == PTPT_afun9) {
                                                                                            ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                                                                            /* checking for: Symbol */
                                                                                            if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == PTPT_afun25) {
                                                                                              ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                                                                              /* checking for: attrs */
                                                                                              if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == PTPT_afun12) {
                                                                                                ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                                                                                if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                                                                                  ATerm arg_arg0_arg2_arg0_head;
                                                                                                  ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                                                                                  arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                                                                                  arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                                                                                  /* checking for: term */
                                                                                                  if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == PTPT_afun13) {
                                                                                                    ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                                                                                    /* checking for: cons */
                                                                                                    if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == PTPT_afun14) {
                                                                                                      ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                                                                                      /* checking for: strategy */
                                                                                                      if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == PTPT_afun76) {
                                                                                                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                                                                          ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                                                                          if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                                                                            ATerm arg_arg1_head;
                                                                                                            ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                                                                            arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                            arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                            /* checking for: appl */
                                                                                                            if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                              ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                              /* checking for: prod */
                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                                                ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                  ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                  arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                  arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                  /* checking for: char-class */
                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                      ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 115) {

                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                            arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                            arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                            /* checking for: char-class */
                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 116) {

                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                      arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                      arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                      /* checking for: char-class */
                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                          ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                          arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                          arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 114) {

                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                                arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                /* checking for: char-class */
                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                    ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                    arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                    arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 97) {

                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                                          arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                          arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                          /* checking for: char-class */
                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                              ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                              arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                              arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 116) {

                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                                                    arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                    arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                    /* checking for: char-class */
                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                        ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                        arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                        arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 101) {

                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                                                              arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                              arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                              /* checking for: char-class */
                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                  ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 103) {

                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                                                                        arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                        arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                        /* checking for: char-class */
                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                            ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                            arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                            arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 121) {

                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                                                  ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                                                                  /* checking for: lit */
                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                                                                                    ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                                                    /* checking for: strategy */
                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun76) {
                                                                                                                                                                                                      ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                                                      /* checking for: no-attrs */
                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                                                                        ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                                                          ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                                                          ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                                                          arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                          arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 115) {

                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                              arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                              arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 116) {

                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                                  arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                  arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 114) {

                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                                      arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                      arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 97) {

                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                                          arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                          arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 116) {

                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                                              arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                              arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 101) {

                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                  arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                  arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 103) {

                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                      arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                      arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 121) {

                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                            arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                              arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                                                                                                                              arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                              /* checking for: appl */
                                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                                                                                                                                                                ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                                                                                                                                                /* checking for: prod */
                                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                                                                                                                                                                                  ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                                                                                                                                    ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                                                                                                                                    arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                                    arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                                    /* checking for: char-class */
                                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                                                                                        ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                                                                                        arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                                        arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 40) {

                                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                                              ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                                                                                                                              /* checking for: lit */
                                                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                                                                                                                                                ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                                                                                                                /* checking for: ( */
                                                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun21) {
                                                                                                                                                                                                                                                                  ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                                                                                                                  /* checking for: no-attrs */
                                                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                                                                                                                                    ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                                                                                                                      ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                                                                                                                      ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                                                                                                                      arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                      arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 40) {

                                                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                            arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                              arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                  arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                                                                                                                                                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                                                  /* checking for: appl */
                                                                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                                                                                                                                                                                                    ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                                                                                                                                                                                    /* checking for: prod */
                                                                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                                                                                                                                                                                                                      ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                                                                                                                                                                        ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                                                                                                                                                                        arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                                                                        arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                                                                        /* checking for: char-class */
                                                                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                                                                                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                                                                                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                                                                                                                            ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                                                                                                                            arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                                                                            arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 44) {

                                                                                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                                                                                  ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                                                                                                                                                                  /* checking for: lit */
                                                                                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                                                                                                                                                                                    ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                                                                                                                                                    /* checking for: , */
                                                                                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun19) {
                                                                                                                                                                                                                                                                                                      ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                                                                                                                                                      /* checking for: no-attrs */
                                                                                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                                                                                                                                                                        ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                                                                                                                                                          ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                                                                                                                                                          ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                                                                                                                                                          arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                                          arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 44) {

                                                                                                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                                                arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                                                    arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                                                      arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                                                                                                                                                                                                      arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                                                                                      /* checking for: appl */
                                                                                                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                                                                                                                                                                                                                                        ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                                                                                                                                                                                                                        /* checking for: prod */
                                                                                                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                                                                                                                                                                                                                                                          ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                                                                                                                                                                                                            ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                                                                                                                                                                                                            ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                                                                                                                                                                                                            arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                                                                                                            arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                                                                                                            /* checking for: char-class */
                                                                                                                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                                                                                                                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                                                                                                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                                                                                                                                                                ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                                                                                                                                                                arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                                                                                                                arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 41) {

                                                                                                                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                                                                                                                      ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                                                                                                                                                                                                      /* checking for: lit */
                                                                                                                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                                                                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                                                                                                                                                                                        /* checking for: ) */
                                                                                                                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun17) {
                                                                                                                                                                                                                                                                                                                                          ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                                                                                                                                                                                          /* checking for: no-attrs */
                                                                                                                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                                                                                                                                                                                                            ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                                                                                                                                                                                              ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                                                                                                                                                                                              ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                                                                                                                                                                                              arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                                                                              arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 41) {

                                                                                                                                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                                                                                                                                                                                                                                                                    return ATtrue;
                                                                                                                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                }
                                                                                                                                                                                                                              }
                                                                                                                                                                                                                            }
                                                                                                                                                                                                                          }
                                                                                                                                                                                                                        }
                                                                                                                                                                                                                      }
                                                                                                                                                                                                                    }
                                                                                                                                                                                                                  }
                                                                                                                                                                                                                }
                                                                                                                                                                                                              }
                                                                                                                                                                                                            }
                                                                                                                                                                                                          }
                                                                                                                                                                                                        }
                                                                                                                                                                                                      }
                                                                                                                                                                                                    }
                                                                                                                                                                                                  }
                                                                                                                                                                                                }
                                                                                                                                                                                              }
                                                                                                                                                                                            }
                                                                                                                                                                                          }
                                                                                                                                                                                        }
                                                                                                                                                                                      }
                                                                                                                                                                                    }
                                                                                                                                                                                  }
                                                                                                                                                                                }
                                                                                                                                                                              }
                                                                                                                                                                            }
                                                                                                                                                                          }
                                                                                                                                                                        }
                                                                                                                                                                      }
                                                                                                                                                                    }
                                                                                                                                                                  }
                                                                                                                                                                }
                                                                                                                                                              }
                                                                                                                                                            }
                                                                                                                                                          }
                                                                                                                                                        }
                                                                                                                                                      }
                                                                                                                                                    }
                                                                                                                                                  }
                                                                                                                                                }
                                                                                                                                              }
                                                                                                                                            }
                                                                                                                                          }
                                                                                                                                        }
                                                                                                                                      }
                                                                                                                                    }
                                                                                                                                  }
                                                                                                                                }
                                                                                                                              }
                                                                                                                            }
                                                                                                                          }
                                                                                                                        }
                                                                                                                      }
                                                                                                                    }
                                                                                                                  }
                                                                                                                }
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Symbol is a parameterized-sort by checking against the following ATerm pattern: appl(prod([lit("parameterized-sort"),cf(opt(layout)),lit("("),cf(opt(layout)),cf(sort("StrCon")),cf(opt(layout)),lit(","),cf(opt(layout)),cf(sort("Symbols")),cf(opt(layout)),lit(")")],cf(sort("Symbol")),attrs([term(cons("parameterized-sort"))])),[appl(prod([char-class([112]),char-class([97]),char-class([114]),char-class([97]),char-class([109]),char-class([101]),char-class([116]),char-class([101]),char-class([114]),char-class([105]),char-class([122]),char-class([101]),char-class([100]),char-class([45]),char-class([115]),char-class([111]),char-class([114]),char-class([116])],lit("parameterized-sort"),no-attrs),[112,97,114,97,109,101,116,101,114,105,122,101,100,45,115,111,114,116]),<"ws-after-parameterized-sort"("OptLayout")>,appl(prod([char-class([40])],lit("("),no-attrs),[40]),<"ws-after-("("OptLayout")>,<"sort"("StrCon")>,<"ws-after-sort"("OptLayout")>,appl(prod([char-class([44])],lit(","),no-attrs),[44]),<"ws-after-,"("OptLayout")>,<"parameters"("Symbols")>,<"ws-after-parameters"("OptLayout")>,appl(prod([char-class([41])],lit(")"),no-attrs),[41])]). May not be used to assert correctness of the PTPT_Symbol
 * \param[in] arg input PTPT_Symbol
 * \return ATtrue if #arg corresponds to the signature of a parameterized-sort, or ATfalse otherwise
 */
inline ATbool PTPT_isSymbolParameterizedSort(PTPT_Symbol arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == PTPT_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == PTPT_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lit */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: parameterized-sort */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun77) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
              /* checking for: cf */
              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                /* checking for: opt */
                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                  /* checking for: layout */
                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                      arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                      arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                      /* checking for: lit */
                      if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
                        ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                        /* checking for: ( */
                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun21) {
                          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                            arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                            arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                            /* checking for: cf */
                            if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                              ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                              /* checking for: opt */
                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                /* checking for: layout */
                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                  if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                    arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                    arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                    /* checking for: cf */
                                    if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                      ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                      /* checking for: sort */
                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun9) {
                                        ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                        /* checking for: StrCon */
                                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun42) {
                                          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                            arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                            arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                            /* checking for: cf */
                                            if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                              ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                              /* checking for: opt */
                                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                                ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                /* checking for: layout */
                                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                                  if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                    arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                    arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                    /* checking for: lit */
                                                    if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
                                                      ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                      /* checking for: , */
                                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun19) {
                                                        if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                          arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                          arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                          /* checking for: cf */
                                                          if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                                            ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                            /* checking for: opt */
                                                            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                                              ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                              /* checking for: layout */
                                                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                                                if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                                  arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                                  arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                                  /* checking for: cf */
                                                                  if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                                                    ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                                    /* checking for: sort */
                                                                    if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun9) {
                                                                      ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                                      /* checking for: Symbols */
                                                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun61) {
                                                                        if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                                          arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                                          arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                                          /* checking for: cf */
                                                                          if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                                                            ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                                            /* checking for: opt */
                                                                            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                                                              ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                                              /* checking for: layout */
                                                                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                                                                if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                                                  arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                                                  arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                                                  /* checking for: lit */
                                                                                  if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
                                                                                    ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                                                    /* checking for: ) */
                                                                                    if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun17) {
                                                                                      if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                                                                                        ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                                                                        /* checking for: cf */
                                                                                        if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == PTPT_afun2) {
                                                                                          ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                                                                          /* checking for: sort */
                                                                                          if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == PTPT_afun9) {
                                                                                            ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                                                                            /* checking for: Symbol */
                                                                                            if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == PTPT_afun25) {
                                                                                              ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                                                                              /* checking for: attrs */
                                                                                              if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == PTPT_afun12) {
                                                                                                ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                                                                                if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                                                                                  ATerm arg_arg0_arg2_arg0_head;
                                                                                                  ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                                                                                  arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                                                                                  arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                                                                                  /* checking for: term */
                                                                                                  if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == PTPT_afun13) {
                                                                                                    ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                                                                                    /* checking for: cons */
                                                                                                    if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == PTPT_afun14) {
                                                                                                      ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                                                                                      /* checking for: parameterized-sort */
                                                                                                      if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == PTPT_afun77) {
                                                                                                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                                                                          ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                                                                          if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                                                                            ATerm arg_arg1_head;
                                                                                                            ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                                                                            arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                            arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                            /* checking for: appl */
                                                                                                            if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                              ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                              /* checking for: prod */
                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                                                ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                  ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                  arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                  arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                  /* checking for: char-class */
                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                      ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 112) {

                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                            arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                            arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                            /* checking for: char-class */
                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 97) {

                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                      arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                      arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                      /* checking for: char-class */
                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                          ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                          arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                          arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 114) {

                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                                arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                /* checking for: char-class */
                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                    ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                    arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                    arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 97) {

                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                                          arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                          arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                          /* checking for: char-class */
                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                              ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                              arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                              arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 109) {

                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                                                    arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                    arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                    /* checking for: char-class */
                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                        ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                        arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                        arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 101) {

                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                                                              arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                              arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                              /* checking for: char-class */
                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                  ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 116) {

                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                                                                        arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                        arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                        /* checking for: char-class */
                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                            ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                            arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                            arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 101) {

                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                                                                                  arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                  arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                  /* checking for: char-class */
                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                                      ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 114) {

                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                                                                                            arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                            arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                            /* checking for: char-class */
                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                                                ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                                                arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 105) {

                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                                                                                                      arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                      arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                      /* checking for: char-class */
                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                                                          ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                                                          arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                          arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 122) {

                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                                                                                                                arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                /* checking for: char-class */
                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                                                                    ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                                                                    arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                    arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 101) {

                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                                                                                                                          arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                          arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                          /* checking for: char-class */
                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                                                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                                                                              ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                                                                              arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                              arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 100) {

                                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                                                                                                                                    arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                                    arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                                    /* checking for: char-class */
                                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                                                                                        ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                                                                                        arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                                        arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 45) {

                                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                                                                                                                                              arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                                              arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                                              /* checking for: char-class */
                                                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                                                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                                                                                                  ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 115) {

                                                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                                                                                                                                                        arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                                                        arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                                                        /* checking for: char-class */
                                                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                                                                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                                                                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                                                                                                            ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                                                                                                            arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                                                            arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 111) {

                                                                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                                                                                                                                                                  arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                                                                  arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                                                                  /* checking for: char-class */
                                                                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                                                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                                                                                                                      ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 114) {

                                                                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                                                                                                                                                                            arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                                                                            arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                                                                            /* checking for: char-class */
                                                                                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                                                                                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                                                                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                                                                                                                                ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                                                                                                                                arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                                                                                arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 116) {

                                                                                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                                                                                      ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                                                                                                                                                                      /* checking for: lit */
                                                                                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                                                                                                                                                        /* checking for: parameterized-sort */
                                                                                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun77) {
                                                                                                                                                                                                                                                                                                          ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                                                                                                                                                          /* checking for: no-attrs */
                                                                                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                                                                                                                                                                            ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                                                                                                                                                              ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                                                                                                                                                              ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                                                                                                                                                              arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                                              arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 112) {

                                                                                                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                                                  arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                                                  arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 97) {

                                                                                                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                                                      arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                                                      arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 114) {

                                                                                                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                                                          arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                                                          arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 97) {

                                                                                                                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                                                              arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                                                              arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 109) {

                                                                                                                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                                                                  arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                                                                  arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 101) {

                                                                                                                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                                                                      arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                                                                      arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 116) {

                                                                                                                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                                                                          arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                                                                          arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 101) {

                                                                                                                                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                                                                              arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                                                                              arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 114) {

                                                                                                                                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                                                                                  arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                                                                                  arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 105) {

                                                                                                                                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                                                                                      arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                                                                                      arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 122) {

                                                                                                                                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                                                                                          arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                                                                                          arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 101) {

                                                                                                                                                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                                                                                              arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                                                                                              arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 100) {

                                                                                                                                                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                                                                                                  arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                                                                                                  arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 45) {

                                                                                                                                                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                                                                                                      arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                                                                                                      arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 115) {

                                                                                                                                                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                                                                                                          arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                                                                                                          arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 111) {

                                                                                                                                                                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                                                                                                              arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                                                                                                              arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 114) {

                                                                                                                                                                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                                                                                                                  arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                                                                                                                  arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 116) {

                                                                                                                                                                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                                                                                                                        arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                                                                                                                          arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                                                                                                                                                                                                                                                                          arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                                                                                                                                                          /* checking for: appl */
                                                                                                                                                                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                                                                                                                                                                                                                                                                                                            ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                                                                                                                                                                                                                                                                                            /* checking for: prod */
                                                                                                                                                                                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                                                                                                                                                                                                                                                                                                                              ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                                                                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                                                                                                                                                                                                                                                                                ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                                                                                                                                                                                                                                                                                ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                                                                                                                                                                                                                                                                                arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                                                                                                                                                                                arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                                                                                                                                                                                /* checking for: char-class */
                                                                                                                                                                                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                                                                                                                                                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                                                                                                                                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                                                                                                                                                                                                                                    ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                                                                                                                                                                                                                                    arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                                                                                                                                                                                    arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                                                                                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 40) {

                                                                                                                                                                                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                                                                                                                                                                                          ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                                                                                                                                                                                                                                                                          /* checking for: lit */
                                                                                                                                                                                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                                                                                                                                                                                                                                                                                            ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                                                                                                                                                                                                                                                            /* checking for: ( */
                                                                                                                                                                                                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun21) {
                                                                                                                                                                                                                                                                                                                                                                                                              ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                                                                                                                                                                                                                                                              /* checking for: no-attrs */
                                                                                                                                                                                                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                                                                                                                                                                                                                                                                                ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                                                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                                                                                                                                                                                                                                                                  ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                                                                                                                                                                                                                                                                  ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                                                                                                                                                                                                                                                                  arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                                                                                                                                                  arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                                                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 40) {

                                                                                                                                                                                                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                                                                                                                                                        arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                                                                                                                                                          arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                                                                                                                                                            arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                                                                                                                                                              arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                                                                                                                                                                                                                                                                                                              arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                                                                                                                                                                                              /* checking for: appl */
                                                                                                                                                                                                                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                                                                                                                                                                                                                                                                                                                                                ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                                                                                                                                                                                                                                                                                                                                /* checking for: prod */
                                                                                                                                                                                                                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                                                                                                                                                                                                                                                                                                                                                                  ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                                                                                                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                                                                                                                                                                                                                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                                                                                                                                                                                                                                                                                                                    ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                                                                                                                                                                                                                                                                                                                    arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                                                                                                                                                                                                                    arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                                                                                                                                                                                                                    /* checking for: char-class */
                                                                                                                                                                                                                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                                                                                                                                                                                                                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                                                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                                                                                                                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                                                                                                                                                                                                                                                                        ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                                                                                                                                                                                                                                                                        arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                                                                                                                                                                                                                        arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                                                                                                                                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 44) {

                                                                                                                                                                                                                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                                                                                                                                                                                                                              ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                                                                                                                                                                                                                                                                                                              /* checking for: lit */
                                                                                                                                                                                                                                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                                                                                                                                                                                                                                                                                                                                ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                                                                                                                                                                                                                                                                                                /* checking for: , */
                                                                                                                                                                                                                                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun19) {
                                                                                                                                                                                                                                                                                                                                                                                                                                                  ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                                                                                                                                                                                                                                                                                                  /* checking for: no-attrs */
                                                                                                                                                                                                                                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                                                                                                                                                                                                                                                                                                                    ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                                                                                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                                                                                                                                                                                                                                                                                                      ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                                                                                                                                                                                                                                                                                                      ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                                                                                                                                                                                                                                                                                                      arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                                                                                                                                                                                      arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                                                                                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 44) {

                                                                                                                                                                                                                                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                                                                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                                                                                                                                                                                            arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                                                                                                                                                                                              arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                                                                                                                                                                                                arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                                                                                                                                                                                                  arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                                                                                                                                                                                                                                                                                                                                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                                                                                                                                                                                                                                  /* checking for: appl */
                                                                                                                                                                                                                                                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                                                                                                                                                                                                                                                                                                                                                                                    ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                                                                                                                                                                                                                                                                                                                                                                    /* checking for: prod */
                                                                                                                                                                                                                                                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                                                                                                                                                                                                                                                                                                                                                                                                      ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                                                                                                                                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                                                                                                                                                                                                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                                                                                                                                                                                                                                                                                                                                                        ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                                                                                                                                                                                                                                                                                                                                                        arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                                                                                                                                                                                                                                                        arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                                                                                                                                                                                                                                                        /* checking for: char-class */
                                                                                                                                                                                                                                                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                                                                                                                                                                                                                                                                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                                                                                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                                                                                                                                                                                                                                                                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                                                                                                                                                                                                                                                                                                            ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                                                                                                                                                                                                                                                                                                            arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                                                                                                                                                                                                                                                            arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                                                                                                                                                                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 41) {

                                                                                                                                                                                                                                                                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  /* checking for: lit */
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    /* checking for: ) */
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun17) {
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      /* checking for: no-attrs */
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 41) {

                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                return ATtrue;
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                }
                                                                                                                                                                                                                              }
                                                                                                                                                                                                                            }
                                                                                                                                                                                                                          }
                                                                                                                                                                                                                        }
                                                                                                                                                                                                                      }
                                                                                                                                                                                                                    }
                                                                                                                                                                                                                  }
                                                                                                                                                                                                                }
                                                                                                                                                                                                              }
                                                                                                                                                                                                            }
                                                                                                                                                                                                          }
                                                                                                                                                                                                        }
                                                                                                                                                                                                      }
                                                                                                                                                                                                    }
                                                                                                                                                                                                  }
                                                                                                                                                                                                }
                                                                                                                                                                                              }
                                                                                                                                                                                            }
                                                                                                                                                                                          }
                                                                                                                                                                                        }
                                                                                                                                                                                      }
                                                                                                                                                                                    }
                                                                                                                                                                                  }
                                                                                                                                                                                }
                                                                                                                                                                              }
                                                                                                                                                                            }
                                                                                                                                                                          }
                                                                                                                                                                        }
                                                                                                                                                                      }
                                                                                                                                                                    }
                                                                                                                                                                  }
                                                                                                                                                                }
                                                                                                                                                              }
                                                                                                                                                            }
                                                                                                                                                          }
                                                                                                                                                        }
                                                                                                                                                      }
                                                                                                                                                    }
                                                                                                                                                  }
                                                                                                                                                }
                                                                                                                                              }
                                                                                                                                            }
                                                                                                                                          }
                                                                                                                                        }
                                                                                                                                      }
                                                                                                                                    }
                                                                                                                                  }
                                                                                                                                }
                                                                                                                              }
                                                                                                                            }
                                                                                                                          }
                                                                                                                        }
                                                                                                                      }
                                                                                                                    }
                                                                                                                  }
                                                                                                                }
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Symbol has a ws-after-lit. 
 * \param[in] arg input PTPT_Symbol
 * \return ATtrue if the PTPT_Symbol had a ws-after-lit, or ATfalse otherwise
 */
ATbool PTPT_hasSymbolWsAfterLit(PTPT_Symbol arg) {
  if (PTPT_isSymbolLit(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Symbol has a ws-after-(. 
 * \param[in] arg input PTPT_Symbol
 * \return ATtrue if the PTPT_Symbol had a ws-after-(, or ATfalse otherwise
 */
ATbool PTPT_hasSymbolWsAfterParenOpen(PTPT_Symbol arg) {
  if (PTPT_isSymbolLit(arg)) {
    return ATtrue;
  }
  else if (PTPT_isSymbolCilit(arg)) {
    return ATtrue;
  }
  else if (PTPT_isSymbolCf(arg)) {
    return ATtrue;
  }
  else if (PTPT_isSymbolLex(arg)) {
    return ATtrue;
  }
  else if (PTPT_isSymbolOpt(arg)) {
    return ATtrue;
  }
  else if (PTPT_isSymbolAlt(arg)) {
    return ATtrue;
  }
  else if (PTPT_isSymbolSeq(arg)) {
    return ATtrue;
  }
  else if (PTPT_isSymbolTuple(arg)) {
    return ATtrue;
  }
  else if (PTPT_isSymbolSort(arg)) {
    return ATtrue;
  }
  else if (PTPT_isSymbolIter(arg)) {
    return ATtrue;
  }
  else if (PTPT_isSymbolIterStar(arg)) {
    return ATtrue;
  }
  else if (PTPT_isSymbolIterSep(arg)) {
    return ATtrue;
  }
  else if (PTPT_isSymbolIterStarSep(arg)) {
    return ATtrue;
  }
  else if (PTPT_isSymbolIterN(arg)) {
    return ATtrue;
  }
  else if (PTPT_isSymbolIterSepN(arg)) {
    return ATtrue;
  }
  else if (PTPT_isSymbolFunc(arg)) {
    return ATtrue;
  }
  else if (PTPT_isSymbolVarsym(arg)) {
    return ATtrue;
  }
  else if (PTPT_isSymbolCharClass(arg)) {
    return ATtrue;
  }
  else if (PTPT_isSymbolStrategy(arg)) {
    return ATtrue;
  }
  else if (PTPT_isSymbolParameterizedSort(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Symbol has a string. 
 * \param[in] arg input PTPT_Symbol
 * \return ATtrue if the PTPT_Symbol had a string, or ATfalse otherwise
 */
ATbool PTPT_hasSymbolString(PTPT_Symbol arg) {
  if (PTPT_isSymbolLit(arg)) {
    return ATtrue;
  }
  else if (PTPT_isSymbolCilit(arg)) {
    return ATtrue;
  }
  else if (PTPT_isSymbolSort(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Symbol has a ws-after-string. 
 * \param[in] arg input PTPT_Symbol
 * \return ATtrue if the PTPT_Symbol had a ws-after-string, or ATfalse otherwise
 */
ATbool PTPT_hasSymbolWsAfterString(PTPT_Symbol arg) {
  if (PTPT_isSymbolLit(arg)) {
    return ATtrue;
  }
  else if (PTPT_isSymbolCilit(arg)) {
    return ATtrue;
  }
  else if (PTPT_isSymbolSort(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Symbol has a ws-after-cilit. 
 * \param[in] arg input PTPT_Symbol
 * \return ATtrue if the PTPT_Symbol had a ws-after-cilit, or ATfalse otherwise
 */
ATbool PTPT_hasSymbolWsAfterCilit(PTPT_Symbol arg) {
  if (PTPT_isSymbolCilit(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Symbol has a ws-after-cf. 
 * \param[in] arg input PTPT_Symbol
 * \return ATtrue if the PTPT_Symbol had a ws-after-cf, or ATfalse otherwise
 */
ATbool PTPT_hasSymbolWsAfterCf(PTPT_Symbol arg) {
  if (PTPT_isSymbolCf(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Symbol has a symbol. 
 * \param[in] arg input PTPT_Symbol
 * \return ATtrue if the PTPT_Symbol had a symbol, or ATfalse otherwise
 */
ATbool PTPT_hasSymbolSymbol(PTPT_Symbol arg) {
  if (PTPT_isSymbolCf(arg)) {
    return ATtrue;
  }
  else if (PTPT_isSymbolLex(arg)) {
    return ATtrue;
  }
  else if (PTPT_isSymbolOpt(arg)) {
    return ATtrue;
  }
  else if (PTPT_isSymbolIter(arg)) {
    return ATtrue;
  }
  else if (PTPT_isSymbolIterStar(arg)) {
    return ATtrue;
  }
  else if (PTPT_isSymbolIterSep(arg)) {
    return ATtrue;
  }
  else if (PTPT_isSymbolIterStarSep(arg)) {
    return ATtrue;
  }
  else if (PTPT_isSymbolIterN(arg)) {
    return ATtrue;
  }
  else if (PTPT_isSymbolIterSepN(arg)) {
    return ATtrue;
  }
  else if (PTPT_isSymbolFunc(arg)) {
    return ATtrue;
  }
  else if (PTPT_isSymbolVarsym(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Symbol has a ws-after-symbol. 
 * \param[in] arg input PTPT_Symbol
 * \return ATtrue if the PTPT_Symbol had a ws-after-symbol, or ATfalse otherwise
 */
ATbool PTPT_hasSymbolWsAfterSymbol(PTPT_Symbol arg) {
  if (PTPT_isSymbolCf(arg)) {
    return ATtrue;
  }
  else if (PTPT_isSymbolLex(arg)) {
    return ATtrue;
  }
  else if (PTPT_isSymbolOpt(arg)) {
    return ATtrue;
  }
  else if (PTPT_isSymbolIter(arg)) {
    return ATtrue;
  }
  else if (PTPT_isSymbolIterStar(arg)) {
    return ATtrue;
  }
  else if (PTPT_isSymbolIterSep(arg)) {
    return ATtrue;
  }
  else if (PTPT_isSymbolIterStarSep(arg)) {
    return ATtrue;
  }
  else if (PTPT_isSymbolIterN(arg)) {
    return ATtrue;
  }
  else if (PTPT_isSymbolIterSepN(arg)) {
    return ATtrue;
  }
  else if (PTPT_isSymbolFunc(arg)) {
    return ATtrue;
  }
  else if (PTPT_isSymbolVarsym(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Symbol has a ws-after-lex. 
 * \param[in] arg input PTPT_Symbol
 * \return ATtrue if the PTPT_Symbol had a ws-after-lex, or ATfalse otherwise
 */
ATbool PTPT_hasSymbolWsAfterLex(PTPT_Symbol arg) {
  if (PTPT_isSymbolLex(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Symbol has a ws-after-opt. 
 * \param[in] arg input PTPT_Symbol
 * \return ATtrue if the PTPT_Symbol had a ws-after-opt, or ATfalse otherwise
 */
ATbool PTPT_hasSymbolWsAfterOpt(PTPT_Symbol arg) {
  if (PTPT_isSymbolOpt(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Symbol has a ws-after-alt. 
 * \param[in] arg input PTPT_Symbol
 * \return ATtrue if the PTPT_Symbol had a ws-after-alt, or ATfalse otherwise
 */
ATbool PTPT_hasSymbolWsAfterAlt(PTPT_Symbol arg) {
  if (PTPT_isSymbolAlt(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Symbol has a lhs. 
 * \param[in] arg input PTPT_Symbol
 * \return ATtrue if the PTPT_Symbol had a lhs, or ATfalse otherwise
 */
ATbool PTPT_hasSymbolLhs(PTPT_Symbol arg) {
  if (PTPT_isSymbolAlt(arg)) {
    return ATtrue;
  }
  else if (PTPT_isSymbolStrategy(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Symbol has a ws-after-lhs. 
 * \param[in] arg input PTPT_Symbol
 * \return ATtrue if the PTPT_Symbol had a ws-after-lhs, or ATfalse otherwise
 */
ATbool PTPT_hasSymbolWsAfterLhs(PTPT_Symbol arg) {
  if (PTPT_isSymbolAlt(arg)) {
    return ATtrue;
  }
  else if (PTPT_isSymbolStrategy(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Symbol has a ws-after-,. 
 * \param[in] arg input PTPT_Symbol
 * \return ATtrue if the PTPT_Symbol had a ws-after-,, or ATfalse otherwise
 */
ATbool PTPT_hasSymbolWsAfterComma(PTPT_Symbol arg) {
  if (PTPT_isSymbolAlt(arg)) {
    return ATtrue;
  }
  else if (PTPT_isSymbolTuple(arg)) {
    return ATtrue;
  }
  else if (PTPT_isSymbolIterSep(arg)) {
    return ATtrue;
  }
  else if (PTPT_isSymbolIterStarSep(arg)) {
    return ATtrue;
  }
  else if (PTPT_isSymbolIterN(arg)) {
    return ATtrue;
  }
  else if (PTPT_isSymbolFunc(arg)) {
    return ATtrue;
  }
  else if (PTPT_isSymbolStrategy(arg)) {
    return ATtrue;
  }
  else if (PTPT_isSymbolParameterizedSort(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Symbol has a rhs. 
 * \param[in] arg input PTPT_Symbol
 * \return ATtrue if the PTPT_Symbol had a rhs, or ATfalse otherwise
 */
ATbool PTPT_hasSymbolRhs(PTPT_Symbol arg) {
  if (PTPT_isSymbolAlt(arg)) {
    return ATtrue;
  }
  else if (PTPT_isSymbolStrategy(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Symbol has a ws-after-rhs. 
 * \param[in] arg input PTPT_Symbol
 * \return ATtrue if the PTPT_Symbol had a ws-after-rhs, or ATfalse otherwise
 */
ATbool PTPT_hasSymbolWsAfterRhs(PTPT_Symbol arg) {
  if (PTPT_isSymbolAlt(arg)) {
    return ATtrue;
  }
  else if (PTPT_isSymbolStrategy(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Symbol has a ws-after-seq. 
 * \param[in] arg input PTPT_Symbol
 * \return ATtrue if the PTPT_Symbol had a ws-after-seq, or ATfalse otherwise
 */
ATbool PTPT_hasSymbolWsAfterSeq(PTPT_Symbol arg) {
  if (PTPT_isSymbolSeq(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Symbol has a symbols. 
 * \param[in] arg input PTPT_Symbol
 * \return ATtrue if the PTPT_Symbol had a symbols, or ATfalse otherwise
 */
ATbool PTPT_hasSymbolSymbols(PTPT_Symbol arg) {
  if (PTPT_isSymbolSeq(arg)) {
    return ATtrue;
  }
  else if (PTPT_isSymbolFunc(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Symbol has a ws-after-symbols. 
 * \param[in] arg input PTPT_Symbol
 * \return ATtrue if the PTPT_Symbol had a ws-after-symbols, or ATfalse otherwise
 */
ATbool PTPT_hasSymbolWsAfterSymbols(PTPT_Symbol arg) {
  if (PTPT_isSymbolSeq(arg)) {
    return ATtrue;
  }
  else if (PTPT_isSymbolFunc(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Symbol has a ws-after-tuple. 
 * \param[in] arg input PTPT_Symbol
 * \return ATtrue if the PTPT_Symbol had a ws-after-tuple, or ATfalse otherwise
 */
ATbool PTPT_hasSymbolWsAfterTuple(PTPT_Symbol arg) {
  if (PTPT_isSymbolTuple(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Symbol has a head. 
 * \param[in] arg input PTPT_Symbol
 * \return ATtrue if the PTPT_Symbol had a head, or ATfalse otherwise
 */
ATbool PTPT_hasSymbolHead(PTPT_Symbol arg) {
  if (PTPT_isSymbolTuple(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Symbol has a ws-after-head. 
 * \param[in] arg input PTPT_Symbol
 * \return ATtrue if the PTPT_Symbol had a ws-after-head, or ATfalse otherwise
 */
ATbool PTPT_hasSymbolWsAfterHead(PTPT_Symbol arg) {
  if (PTPT_isSymbolTuple(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Symbol has a rest. 
 * \param[in] arg input PTPT_Symbol
 * \return ATtrue if the PTPT_Symbol had a rest, or ATfalse otherwise
 */
ATbool PTPT_hasSymbolRest(PTPT_Symbol arg) {
  if (PTPT_isSymbolTuple(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Symbol has a ws-after-rest. 
 * \param[in] arg input PTPT_Symbol
 * \return ATtrue if the PTPT_Symbol had a ws-after-rest, or ATfalse otherwise
 */
ATbool PTPT_hasSymbolWsAfterRest(PTPT_Symbol arg) {
  if (PTPT_isSymbolTuple(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Symbol has a ws-after-sort. 
 * \param[in] arg input PTPT_Symbol
 * \return ATtrue if the PTPT_Symbol had a ws-after-sort, or ATfalse otherwise
 */
ATbool PTPT_hasSymbolWsAfterSort(PTPT_Symbol arg) {
  if (PTPT_isSymbolSort(arg)) {
    return ATtrue;
  }
  else if (PTPT_isSymbolParameterizedSort(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Symbol has a ws-after-iter. 
 * \param[in] arg input PTPT_Symbol
 * \return ATtrue if the PTPT_Symbol had a ws-after-iter, or ATfalse otherwise
 */
ATbool PTPT_hasSymbolWsAfterIter(PTPT_Symbol arg) {
  if (PTPT_isSymbolIter(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Symbol has a ws-after-iter-star. 
 * \param[in] arg input PTPT_Symbol
 * \return ATtrue if the PTPT_Symbol had a ws-after-iter-star, or ATfalse otherwise
 */
ATbool PTPT_hasSymbolWsAfterIterStar(PTPT_Symbol arg) {
  if (PTPT_isSymbolIterStar(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Symbol has a ws-after-iter-sep. 
 * \param[in] arg input PTPT_Symbol
 * \return ATtrue if the PTPT_Symbol had a ws-after-iter-sep, or ATfalse otherwise
 */
ATbool PTPT_hasSymbolWsAfterIterSep(PTPT_Symbol arg) {
  if (PTPT_isSymbolIterSep(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Symbol has a separator. 
 * \param[in] arg input PTPT_Symbol
 * \return ATtrue if the PTPT_Symbol had a separator, or ATfalse otherwise
 */
ATbool PTPT_hasSymbolSeparator(PTPT_Symbol arg) {
  if (PTPT_isSymbolIterSep(arg)) {
    return ATtrue;
  }
  else if (PTPT_isSymbolIterStarSep(arg)) {
    return ATtrue;
  }
  else if (PTPT_isSymbolIterSepN(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Symbol has a ws-after-separator. 
 * \param[in] arg input PTPT_Symbol
 * \return ATtrue if the PTPT_Symbol had a ws-after-separator, or ATfalse otherwise
 */
ATbool PTPT_hasSymbolWsAfterSeparator(PTPT_Symbol arg) {
  if (PTPT_isSymbolIterSep(arg)) {
    return ATtrue;
  }
  else if (PTPT_isSymbolIterStarSep(arg)) {
    return ATtrue;
  }
  else if (PTPT_isSymbolIterSepN(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Symbol has a ws-after-iter-star-sep. 
 * \param[in] arg input PTPT_Symbol
 * \return ATtrue if the PTPT_Symbol had a ws-after-iter-star-sep, or ATfalse otherwise
 */
ATbool PTPT_hasSymbolWsAfterIterStarSep(PTPT_Symbol arg) {
  if (PTPT_isSymbolIterStarSep(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Symbol has a ws-after-iter-n. 
 * \param[in] arg input PTPT_Symbol
 * \return ATtrue if the PTPT_Symbol had a ws-after-iter-n, or ATfalse otherwise
 */
ATbool PTPT_hasSymbolWsAfterIterN(PTPT_Symbol arg) {
  if (PTPT_isSymbolIterN(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Symbol has a number. 
 * \param[in] arg input PTPT_Symbol
 * \return ATtrue if the PTPT_Symbol had a number, or ATfalse otherwise
 */
ATbool PTPT_hasSymbolNumber(PTPT_Symbol arg) {
  if (PTPT_isSymbolIterN(arg)) {
    return ATtrue;
  }
  else if (PTPT_isSymbolIterSepN(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Symbol has a ws-after-number. 
 * \param[in] arg input PTPT_Symbol
 * \return ATtrue if the PTPT_Symbol had a ws-after-number, or ATfalse otherwise
 */
ATbool PTPT_hasSymbolWsAfterNumber(PTPT_Symbol arg) {
  if (PTPT_isSymbolIterN(arg)) {
    return ATtrue;
  }
  else if (PTPT_isSymbolIterSepN(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Symbol has a ws-after-iter-sep-n. 
 * \param[in] arg input PTPT_Symbol
 * \return ATtrue if the PTPT_Symbol had a ws-after-iter-sep-n, or ATfalse otherwise
 */
ATbool PTPT_hasSymbolWsAfterIterSepN(PTPT_Symbol arg) {
  if (PTPT_isSymbolIterSepN(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Symbol has a ws-after-comma1. 
 * \param[in] arg input PTPT_Symbol
 * \return ATtrue if the PTPT_Symbol had a ws-after-comma1, or ATfalse otherwise
 */
ATbool PTPT_hasSymbolWsAfterComma1(PTPT_Symbol arg) {
  if (PTPT_isSymbolIterSepN(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Symbol has a ws-after-comma2. 
 * \param[in] arg input PTPT_Symbol
 * \return ATtrue if the PTPT_Symbol had a ws-after-comma2, or ATfalse otherwise
 */
ATbool PTPT_hasSymbolWsAfterComma2(PTPT_Symbol arg) {
  if (PTPT_isSymbolIterSepN(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Symbol has a ws-after-func. 
 * \param[in] arg input PTPT_Symbol
 * \return ATtrue if the PTPT_Symbol had a ws-after-func, or ATfalse otherwise
 */
ATbool PTPT_hasSymbolWsAfterFunc(PTPT_Symbol arg) {
  if (PTPT_isSymbolFunc(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Symbol has a ws-after-varsym. 
 * \param[in] arg input PTPT_Symbol
 * \return ATtrue if the PTPT_Symbol had a ws-after-varsym, or ATfalse otherwise
 */
ATbool PTPT_hasSymbolWsAfterVarsym(PTPT_Symbol arg) {
  if (PTPT_isSymbolVarsym(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Symbol has a ws-after-char-class. 
 * \param[in] arg input PTPT_Symbol
 * \return ATtrue if the PTPT_Symbol had a ws-after-char-class, or ATfalse otherwise
 */
ATbool PTPT_hasSymbolWsAfterCharClass(PTPT_Symbol arg) {
  if (PTPT_isSymbolCharClass(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Symbol has a CharRanges. 
 * \param[in] arg input PTPT_Symbol
 * \return ATtrue if the PTPT_Symbol had a CharRanges, or ATfalse otherwise
 */
ATbool PTPT_hasSymbolCharRanges(PTPT_Symbol arg) {
  if (PTPT_isSymbolCharClass(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Symbol has a ws-after-CharRanges. 
 * \param[in] arg input PTPT_Symbol
 * \return ATtrue if the PTPT_Symbol had a ws-after-CharRanges, or ATfalse otherwise
 */
ATbool PTPT_hasSymbolWsAfterCharRanges(PTPT_Symbol arg) {
  if (PTPT_isSymbolCharClass(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Symbol has a ws-after-strategy. 
 * \param[in] arg input PTPT_Symbol
 * \return ATtrue if the PTPT_Symbol had a ws-after-strategy, or ATfalse otherwise
 */
ATbool PTPT_hasSymbolWsAfterStrategy(PTPT_Symbol arg) {
  if (PTPT_isSymbolStrategy(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Symbol has a ws-after-parameterized-sort. 
 * \param[in] arg input PTPT_Symbol
 * \return ATtrue if the PTPT_Symbol had a ws-after-parameterized-sort, or ATfalse otherwise
 */
ATbool PTPT_hasSymbolWsAfterParameterizedSort(PTPT_Symbol arg) {
  if (PTPT_isSymbolParameterizedSort(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Symbol has a sort. 
 * \param[in] arg input PTPT_Symbol
 * \return ATtrue if the PTPT_Symbol had a sort, or ATfalse otherwise
 */
ATbool PTPT_hasSymbolSort(PTPT_Symbol arg) {
  if (PTPT_isSymbolParameterizedSort(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Symbol has a parameters. 
 * \param[in] arg input PTPT_Symbol
 * \return ATtrue if the PTPT_Symbol had a parameters, or ATfalse otherwise
 */
ATbool PTPT_hasSymbolParameters(PTPT_Symbol arg) {
  if (PTPT_isSymbolParameterizedSort(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Symbol has a ws-after-parameters. 
 * \param[in] arg input PTPT_Symbol
 * \return ATtrue if the PTPT_Symbol had a ws-after-parameters, or ATfalse otherwise
 */
ATbool PTPT_hasSymbolWsAfterParameters(PTPT_Symbol arg) {
  if (PTPT_isSymbolParameterizedSort(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Get the ws-after-lit PTPT_OptLayout of a PTPT_Symbol. Note that the precondition is that this PTPT_Symbol actually has a ws-after-lit
 * \param[in] arg input PTPT_Symbol
 * \return the ws-after-lit of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getSymbolWsAfterLit(PTPT_Symbol arg) {
  
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1);
}

/**
 * Get the ws-after-( PTPT_OptLayout of a PTPT_Symbol. Note that the precondition is that this PTPT_Symbol actually has a ws-after-(
 * \param[in] arg input PTPT_Symbol
 * \return the ws-after-( of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getSymbolWsAfterParenOpen(PTPT_Symbol arg) {
  if (PTPT_isSymbolLit(arg)) {
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 3);
  }
  else if (PTPT_isSymbolCilit(arg)) {
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 3);
  }
  else if (PTPT_isSymbolCf(arg)) {
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 3);
  }
  else if (PTPT_isSymbolLex(arg)) {
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 3);
  }
  else if (PTPT_isSymbolOpt(arg)) {
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 3);
  }
  else if (PTPT_isSymbolAlt(arg)) {
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 3);
  }
  else if (PTPT_isSymbolSeq(arg)) {
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 3);
  }
  else if (PTPT_isSymbolTuple(arg)) {
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 3);
  }
  else if (PTPT_isSymbolSort(arg)) {
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 3);
  }
  else if (PTPT_isSymbolIter(arg)) {
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 3);
  }
  else if (PTPT_isSymbolIterStar(arg)) {
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 3);
  }
  else if (PTPT_isSymbolIterSep(arg)) {
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 3);
  }
  else if (PTPT_isSymbolIterStarSep(arg)) {
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 3);
  }
  else if (PTPT_isSymbolIterN(arg)) {
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 3);
  }
  else if (PTPT_isSymbolIterSepN(arg)) {
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 3);
  }
  else if (PTPT_isSymbolFunc(arg)) {
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 3);
  }
  else if (PTPT_isSymbolVarsym(arg)) {
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 3);
  }
  else if (PTPT_isSymbolCharClass(arg)) {
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 3);
  }
  else if (PTPT_isSymbolStrategy(arg)) {
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 3);
  }
  else 
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 3);
}

/**
 * Get the string PTPT_StrCon of a PTPT_Symbol. Note that the precondition is that this PTPT_Symbol actually has a string
 * \param[in] arg input PTPT_Symbol
 * \return the string of #arg, if it exist or an undefined value if it does not
 */
PTPT_StrCon PTPT_getSymbolString(PTPT_Symbol arg) {
  if (PTPT_isSymbolLit(arg)) {
    return (PTPT_StrCon)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 4);
  }
  else if (PTPT_isSymbolCilit(arg)) {
    return (PTPT_StrCon)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 4);
  }
  else 
    return (PTPT_StrCon)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 4);
}

/**
 * Get the ws-after-string PTPT_OptLayout of a PTPT_Symbol. Note that the precondition is that this PTPT_Symbol actually has a ws-after-string
 * \param[in] arg input PTPT_Symbol
 * \return the ws-after-string of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getSymbolWsAfterString(PTPT_Symbol arg) {
  if (PTPT_isSymbolLit(arg)) {
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 5);
  }
  else if (PTPT_isSymbolCilit(arg)) {
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 5);
  }
  else 
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 5);
}

/**
 * Get the ws-after-cilit PTPT_OptLayout of a PTPT_Symbol. Note that the precondition is that this PTPT_Symbol actually has a ws-after-cilit
 * \param[in] arg input PTPT_Symbol
 * \return the ws-after-cilit of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getSymbolWsAfterCilit(PTPT_Symbol arg) {
  
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1);
}

/**
 * Get the ws-after-cf PTPT_OptLayout of a PTPT_Symbol. Note that the precondition is that this PTPT_Symbol actually has a ws-after-cf
 * \param[in] arg input PTPT_Symbol
 * \return the ws-after-cf of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getSymbolWsAfterCf(PTPT_Symbol arg) {
  
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1);
}

/**
 * Get the symbol PTPT_Symbol of a PTPT_Symbol. Note that the precondition is that this PTPT_Symbol actually has a symbol
 * \param[in] arg input PTPT_Symbol
 * \return the symbol of #arg, if it exist or an undefined value if it does not
 */
PTPT_Symbol PTPT_getSymbolSymbol(PTPT_Symbol arg) {
  if (PTPT_isSymbolCf(arg)) {
    return (PTPT_Symbol)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 4);
  }
  else if (PTPT_isSymbolLex(arg)) {
    return (PTPT_Symbol)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 4);
  }
  else if (PTPT_isSymbolOpt(arg)) {
    return (PTPT_Symbol)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 4);
  }
  else if (PTPT_isSymbolIter(arg)) {
    return (PTPT_Symbol)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 4);
  }
  else if (PTPT_isSymbolIterStar(arg)) {
    return (PTPT_Symbol)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 4);
  }
  else if (PTPT_isSymbolIterSep(arg)) {
    return (PTPT_Symbol)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 4);
  }
  else if (PTPT_isSymbolIterStarSep(arg)) {
    return (PTPT_Symbol)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 4);
  }
  else if (PTPT_isSymbolIterN(arg)) {
    return (PTPT_Symbol)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 4);
  }
  else if (PTPT_isSymbolIterSepN(arg)) {
    return (PTPT_Symbol)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 4);
  }
  else if (PTPT_isSymbolFunc(arg)) {
    return (PTPT_Symbol)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 8);
  }
  else 
    return (PTPT_Symbol)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 4);
}

/**
 * Get the ws-after-symbol PTPT_OptLayout of a PTPT_Symbol. Note that the precondition is that this PTPT_Symbol actually has a ws-after-symbol
 * \param[in] arg input PTPT_Symbol
 * \return the ws-after-symbol of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getSymbolWsAfterSymbol(PTPT_Symbol arg) {
  if (PTPT_isSymbolCf(arg)) {
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 5);
  }
  else if (PTPT_isSymbolLex(arg)) {
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 5);
  }
  else if (PTPT_isSymbolOpt(arg)) {
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 5);
  }
  else if (PTPT_isSymbolIter(arg)) {
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 5);
  }
  else if (PTPT_isSymbolIterStar(arg)) {
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 5);
  }
  else if (PTPT_isSymbolIterSep(arg)) {
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 5);
  }
  else if (PTPT_isSymbolIterStarSep(arg)) {
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 5);
  }
  else if (PTPT_isSymbolIterN(arg)) {
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 5);
  }
  else if (PTPT_isSymbolIterSepN(arg)) {
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 5);
  }
  else if (PTPT_isSymbolFunc(arg)) {
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 9);
  }
  else 
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 5);
}

/**
 * Get the ws-after-lex PTPT_OptLayout of a PTPT_Symbol. Note that the precondition is that this PTPT_Symbol actually has a ws-after-lex
 * \param[in] arg input PTPT_Symbol
 * \return the ws-after-lex of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getSymbolWsAfterLex(PTPT_Symbol arg) {
  
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1);
}

/**
 * Get the ws-after-opt PTPT_OptLayout of a PTPT_Symbol. Note that the precondition is that this PTPT_Symbol actually has a ws-after-opt
 * \param[in] arg input PTPT_Symbol
 * \return the ws-after-opt of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getSymbolWsAfterOpt(PTPT_Symbol arg) {
  
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1);
}

/**
 * Get the ws-after-alt PTPT_OptLayout of a PTPT_Symbol. Note that the precondition is that this PTPT_Symbol actually has a ws-after-alt
 * \param[in] arg input PTPT_Symbol
 * \return the ws-after-alt of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getSymbolWsAfterAlt(PTPT_Symbol arg) {
  
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1);
}

/**
 * Get the lhs PTPT_Symbol of a PTPT_Symbol. Note that the precondition is that this PTPT_Symbol actually has a lhs
 * \param[in] arg input PTPT_Symbol
 * \return the lhs of #arg, if it exist or an undefined value if it does not
 */
PTPT_Symbol PTPT_getSymbolLhs(PTPT_Symbol arg) {
  if (PTPT_isSymbolAlt(arg)) {
    return (PTPT_Symbol)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 4);
  }
  else 
    return (PTPT_Symbol)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 4);
}

/**
 * Get the ws-after-lhs PTPT_OptLayout of a PTPT_Symbol. Note that the precondition is that this PTPT_Symbol actually has a ws-after-lhs
 * \param[in] arg input PTPT_Symbol
 * \return the ws-after-lhs of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getSymbolWsAfterLhs(PTPT_Symbol arg) {
  if (PTPT_isSymbolAlt(arg)) {
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 5);
  }
  else 
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 5);
}

/**
 * Get the ws-after-, PTPT_OptLayout of a PTPT_Symbol. Note that the precondition is that this PTPT_Symbol actually has a ws-after-,
 * \param[in] arg input PTPT_Symbol
 * \return the ws-after-, of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getSymbolWsAfterComma(PTPT_Symbol arg) {
  if (PTPT_isSymbolAlt(arg)) {
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 7);
  }
  else if (PTPT_isSymbolTuple(arg)) {
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 7);
  }
  else if (PTPT_isSymbolIterSep(arg)) {
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 7);
  }
  else if (PTPT_isSymbolIterStarSep(arg)) {
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 7);
  }
  else if (PTPT_isSymbolIterN(arg)) {
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 7);
  }
  else if (PTPT_isSymbolFunc(arg)) {
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 7);
  }
  else if (PTPT_isSymbolStrategy(arg)) {
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 7);
  }
  else 
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 7);
}

/**
 * Get the rhs PTPT_Symbol of a PTPT_Symbol. Note that the precondition is that this PTPT_Symbol actually has a rhs
 * \param[in] arg input PTPT_Symbol
 * \return the rhs of #arg, if it exist or an undefined value if it does not
 */
PTPT_Symbol PTPT_getSymbolRhs(PTPT_Symbol arg) {
  if (PTPT_isSymbolAlt(arg)) {
    return (PTPT_Symbol)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 8);
  }
  else 
    return (PTPT_Symbol)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 8);
}

/**
 * Get the ws-after-rhs PTPT_OptLayout of a PTPT_Symbol. Note that the precondition is that this PTPT_Symbol actually has a ws-after-rhs
 * \param[in] arg input PTPT_Symbol
 * \return the ws-after-rhs of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getSymbolWsAfterRhs(PTPT_Symbol arg) {
  if (PTPT_isSymbolAlt(arg)) {
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 9);
  }
  else 
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 9);
}

/**
 * Get the ws-after-seq PTPT_OptLayout of a PTPT_Symbol. Note that the precondition is that this PTPT_Symbol actually has a ws-after-seq
 * \param[in] arg input PTPT_Symbol
 * \return the ws-after-seq of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getSymbolWsAfterSeq(PTPT_Symbol arg) {
  
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1);
}

/**
 * Get the symbols PTPT_Symbols of a PTPT_Symbol. Note that the precondition is that this PTPT_Symbol actually has a symbols
 * \param[in] arg input PTPT_Symbol
 * \return the symbols of #arg, if it exist or an undefined value if it does not
 */
PTPT_Symbols PTPT_getSymbolSymbols(PTPT_Symbol arg) {
  if (PTPT_isSymbolSeq(arg)) {
    return (PTPT_Symbols)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 4);
  }
  else 
    return (PTPT_Symbols)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 4);
}

/**
 * Get the ws-after-symbols PTPT_OptLayout of a PTPT_Symbol. Note that the precondition is that this PTPT_Symbol actually has a ws-after-symbols
 * \param[in] arg input PTPT_Symbol
 * \return the ws-after-symbols of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getSymbolWsAfterSymbols(PTPT_Symbol arg) {
  if (PTPT_isSymbolSeq(arg)) {
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 5);
  }
  else 
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 5);
}

/**
 * Get the ws-after-tuple PTPT_OptLayout of a PTPT_Symbol. Note that the precondition is that this PTPT_Symbol actually has a ws-after-tuple
 * \param[in] arg input PTPT_Symbol
 * \return the ws-after-tuple of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getSymbolWsAfterTuple(PTPT_Symbol arg) {
  
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1);
}

/**
 * Get the head PTPT_Symbol of a PTPT_Symbol. Note that the precondition is that this PTPT_Symbol actually has a head
 * \param[in] arg input PTPT_Symbol
 * \return the head of #arg, if it exist or an undefined value if it does not
 */
PTPT_Symbol PTPT_getSymbolHead(PTPT_Symbol arg) {
  
    return (PTPT_Symbol)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 4);
}

/**
 * Get the ws-after-head PTPT_OptLayout of a PTPT_Symbol. Note that the precondition is that this PTPT_Symbol actually has a ws-after-head
 * \param[in] arg input PTPT_Symbol
 * \return the ws-after-head of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getSymbolWsAfterHead(PTPT_Symbol arg) {
  
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 5);
}

/**
 * Get the rest PTPT_Symbols of a PTPT_Symbol. Note that the precondition is that this PTPT_Symbol actually has a rest
 * \param[in] arg input PTPT_Symbol
 * \return the rest of #arg, if it exist or an undefined value if it does not
 */
PTPT_Symbols PTPT_getSymbolRest(PTPT_Symbol arg) {
  
    return (PTPT_Symbols)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 8);
}

/**
 * Get the ws-after-rest PTPT_OptLayout of a PTPT_Symbol. Note that the precondition is that this PTPT_Symbol actually has a ws-after-rest
 * \param[in] arg input PTPT_Symbol
 * \return the ws-after-rest of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getSymbolWsAfterRest(PTPT_Symbol arg) {
  
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 9);
}

/**
 * Get the ws-after-sort PTPT_OptLayout of a PTPT_Symbol. Note that the precondition is that this PTPT_Symbol actually has a ws-after-sort
 * \param[in] arg input PTPT_Symbol
 * \return the ws-after-sort of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getSymbolWsAfterSort(PTPT_Symbol arg) {
  if (PTPT_isSymbolSort(arg)) {
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1);
  }
  else 
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 5);
}

/**
 * Get the ws-after-iter PTPT_OptLayout of a PTPT_Symbol. Note that the precondition is that this PTPT_Symbol actually has a ws-after-iter
 * \param[in] arg input PTPT_Symbol
 * \return the ws-after-iter of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getSymbolWsAfterIter(PTPT_Symbol arg) {
  
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1);
}

/**
 * Get the ws-after-iter-star PTPT_OptLayout of a PTPT_Symbol. Note that the precondition is that this PTPT_Symbol actually has a ws-after-iter-star
 * \param[in] arg input PTPT_Symbol
 * \return the ws-after-iter-star of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getSymbolWsAfterIterStar(PTPT_Symbol arg) {
  
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1);
}

/**
 * Get the ws-after-iter-sep PTPT_OptLayout of a PTPT_Symbol. Note that the precondition is that this PTPT_Symbol actually has a ws-after-iter-sep
 * \param[in] arg input PTPT_Symbol
 * \return the ws-after-iter-sep of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getSymbolWsAfterIterSep(PTPT_Symbol arg) {
  
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1);
}

/**
 * Get the separator PTPT_Symbol of a PTPT_Symbol. Note that the precondition is that this PTPT_Symbol actually has a separator
 * \param[in] arg input PTPT_Symbol
 * \return the separator of #arg, if it exist or an undefined value if it does not
 */
PTPT_Symbol PTPT_getSymbolSeparator(PTPT_Symbol arg) {
  if (PTPT_isSymbolIterSep(arg)) {
    return (PTPT_Symbol)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 8);
  }
  else if (PTPT_isSymbolIterStarSep(arg)) {
    return (PTPT_Symbol)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 8);
  }
  else 
    return (PTPT_Symbol)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 8);
}

/**
 * Get the ws-after-separator PTPT_OptLayout of a PTPT_Symbol. Note that the precondition is that this PTPT_Symbol actually has a ws-after-separator
 * \param[in] arg input PTPT_Symbol
 * \return the ws-after-separator of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getSymbolWsAfterSeparator(PTPT_Symbol arg) {
  if (PTPT_isSymbolIterSep(arg)) {
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 9);
  }
  else if (PTPT_isSymbolIterStarSep(arg)) {
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 9);
  }
  else 
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 9);
}

/**
 * Get the ws-after-iter-star-sep PTPT_OptLayout of a PTPT_Symbol. Note that the precondition is that this PTPT_Symbol actually has a ws-after-iter-star-sep
 * \param[in] arg input PTPT_Symbol
 * \return the ws-after-iter-star-sep of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getSymbolWsAfterIterStarSep(PTPT_Symbol arg) {
  
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1);
}

/**
 * Get the ws-after-iter-n PTPT_OptLayout of a PTPT_Symbol. Note that the precondition is that this PTPT_Symbol actually has a ws-after-iter-n
 * \param[in] arg input PTPT_Symbol
 * \return the ws-after-iter-n of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getSymbolWsAfterIterN(PTPT_Symbol arg) {
  
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1);
}

/**
 * Get the number PTPT_NatCon of a PTPT_Symbol. Note that the precondition is that this PTPT_Symbol actually has a number
 * \param[in] arg input PTPT_Symbol
 * \return the number of #arg, if it exist or an undefined value if it does not
 */
PTPT_NatCon PTPT_getSymbolNumber(PTPT_Symbol arg) {
  if (PTPT_isSymbolIterN(arg)) {
    return (PTPT_NatCon)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 8);
  }
  else 
    return (PTPT_NatCon)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 12);
}

/**
 * Get the ws-after-number PTPT_OptLayout of a PTPT_Symbol. Note that the precondition is that this PTPT_Symbol actually has a ws-after-number
 * \param[in] arg input PTPT_Symbol
 * \return the ws-after-number of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getSymbolWsAfterNumber(PTPT_Symbol arg) {
  if (PTPT_isSymbolIterN(arg)) {
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 9);
  }
  else 
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 13);
}

/**
 * Get the ws-after-iter-sep-n PTPT_OptLayout of a PTPT_Symbol. Note that the precondition is that this PTPT_Symbol actually has a ws-after-iter-sep-n
 * \param[in] arg input PTPT_Symbol
 * \return the ws-after-iter-sep-n of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getSymbolWsAfterIterSepN(PTPT_Symbol arg) {
  
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1);
}

/**
 * Get the ws-after-comma1 PTPT_OptLayout of a PTPT_Symbol. Note that the precondition is that this PTPT_Symbol actually has a ws-after-comma1
 * \param[in] arg input PTPT_Symbol
 * \return the ws-after-comma1 of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getSymbolWsAfterComma1(PTPT_Symbol arg) {
  
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 7);
}

/**
 * Get the ws-after-comma2 PTPT_OptLayout of a PTPT_Symbol. Note that the precondition is that this PTPT_Symbol actually has a ws-after-comma2
 * \param[in] arg input PTPT_Symbol
 * \return the ws-after-comma2 of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getSymbolWsAfterComma2(PTPT_Symbol arg) {
  
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 11);
}

/**
 * Get the ws-after-func PTPT_OptLayout of a PTPT_Symbol. Note that the precondition is that this PTPT_Symbol actually has a ws-after-func
 * \param[in] arg input PTPT_Symbol
 * \return the ws-after-func of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getSymbolWsAfterFunc(PTPT_Symbol arg) {
  
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1);
}

/**
 * Get the ws-after-varsym PTPT_OptLayout of a PTPT_Symbol. Note that the precondition is that this PTPT_Symbol actually has a ws-after-varsym
 * \param[in] arg input PTPT_Symbol
 * \return the ws-after-varsym of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getSymbolWsAfterVarsym(PTPT_Symbol arg) {
  
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1);
}

/**
 * Get the ws-after-char-class PTPT_OptLayout of a PTPT_Symbol. Note that the precondition is that this PTPT_Symbol actually has a ws-after-char-class
 * \param[in] arg input PTPT_Symbol
 * \return the ws-after-char-class of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getSymbolWsAfterCharClass(PTPT_Symbol arg) {
  
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1);
}

/**
 * Get the CharRanges PTPT_CharRanges of a PTPT_Symbol. Note that the precondition is that this PTPT_Symbol actually has a CharRanges
 * \param[in] arg input PTPT_Symbol
 * \return the CharRanges of #arg, if it exist or an undefined value if it does not
 */
PTPT_CharRanges PTPT_getSymbolCharRanges(PTPT_Symbol arg) {
  
    return (PTPT_CharRanges)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 4);
}

/**
 * Get the ws-after-CharRanges PTPT_OptLayout of a PTPT_Symbol. Note that the precondition is that this PTPT_Symbol actually has a ws-after-CharRanges
 * \param[in] arg input PTPT_Symbol
 * \return the ws-after-CharRanges of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getSymbolWsAfterCharRanges(PTPT_Symbol arg) {
  
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 5);
}

/**
 * Get the ws-after-strategy PTPT_OptLayout of a PTPT_Symbol. Note that the precondition is that this PTPT_Symbol actually has a ws-after-strategy
 * \param[in] arg input PTPT_Symbol
 * \return the ws-after-strategy of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getSymbolWsAfterStrategy(PTPT_Symbol arg) {
  
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1);
}

/**
 * Get the ws-after-parameterized-sort PTPT_OptLayout of a PTPT_Symbol. Note that the precondition is that this PTPT_Symbol actually has a ws-after-parameterized-sort
 * \param[in] arg input PTPT_Symbol
 * \return the ws-after-parameterized-sort of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getSymbolWsAfterParameterizedSort(PTPT_Symbol arg) {
  
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1);
}

/**
 * Get the sort PTPT_StrCon of a PTPT_Symbol. Note that the precondition is that this PTPT_Symbol actually has a sort
 * \param[in] arg input PTPT_Symbol
 * \return the sort of #arg, if it exist or an undefined value if it does not
 */
PTPT_StrCon PTPT_getSymbolSort(PTPT_Symbol arg) {
  
    return (PTPT_StrCon)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 4);
}

/**
 * Get the parameters PTPT_Symbols of a PTPT_Symbol. Note that the precondition is that this PTPT_Symbol actually has a parameters
 * \param[in] arg input PTPT_Symbol
 * \return the parameters of #arg, if it exist or an undefined value if it does not
 */
PTPT_Symbols PTPT_getSymbolParameters(PTPT_Symbol arg) {
  
    return (PTPT_Symbols)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 8);
}

/**
 * Get the ws-after-parameters PTPT_OptLayout of a PTPT_Symbol. Note that the precondition is that this PTPT_Symbol actually has a ws-after-parameters
 * \param[in] arg input PTPT_Symbol
 * \return the ws-after-parameters of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getSymbolWsAfterParameters(PTPT_Symbol arg) {
  
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 9);
}

/**
 * Set the ws-after-lit of a PTPT_Symbol. The precondition being that this PTPT_Symbol actually has a ws-after-lit
 * \param[in] arg input PTPT_Symbol
 * \param[in] wsAfterLit new PTPT_OptLayout to set in #arg
 * \return A new PTPT_Symbol with wsAfterLit at the right place, or a core dump if #arg did not have a wsAfterLit
 */
PTPT_Symbol PTPT_setSymbolWsAfterLit(PTPT_Symbol arg, PTPT_OptLayout wsAfterLit) {
  if (PTPT_isSymbolLit(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterLit), 1), 1);
  }

  ATabort("Symbol has no WsAfterLit: %t\n", arg);
  return (PTPT_Symbol)NULL;
}

/**
 * Set the ws-after-( of a PTPT_Symbol. The precondition being that this PTPT_Symbol actually has a ws-after-(
 * \param[in] arg input PTPT_Symbol
 * \param[in] wsAfterParenOpen new PTPT_OptLayout to set in #arg
 * \return A new PTPT_Symbol with wsAfterParenOpen at the right place, or a core dump if #arg did not have a wsAfterParenOpen
 */
PTPT_Symbol PTPT_setSymbolWsAfterParenOpen(PTPT_Symbol arg, PTPT_OptLayout wsAfterParenOpen) {
  if (PTPT_isSymbolLit(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterParenOpen), 3), 1);
  }
  else if (PTPT_isSymbolCilit(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterParenOpen), 3), 1);
  }
  else if (PTPT_isSymbolCf(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterParenOpen), 3), 1);
  }
  else if (PTPT_isSymbolLex(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterParenOpen), 3), 1);
  }
  else if (PTPT_isSymbolOpt(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterParenOpen), 3), 1);
  }
  else if (PTPT_isSymbolAlt(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterParenOpen), 3), 1);
  }
  else if (PTPT_isSymbolSeq(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterParenOpen), 3), 1);
  }
  else if (PTPT_isSymbolTuple(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterParenOpen), 3), 1);
  }
  else if (PTPT_isSymbolSort(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterParenOpen), 3), 1);
  }
  else if (PTPT_isSymbolIter(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterParenOpen), 3), 1);
  }
  else if (PTPT_isSymbolIterStar(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterParenOpen), 3), 1);
  }
  else if (PTPT_isSymbolIterSep(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterParenOpen), 3), 1);
  }
  else if (PTPT_isSymbolIterStarSep(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterParenOpen), 3), 1);
  }
  else if (PTPT_isSymbolIterN(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterParenOpen), 3), 1);
  }
  else if (PTPT_isSymbolIterSepN(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterParenOpen), 3), 1);
  }
  else if (PTPT_isSymbolFunc(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterParenOpen), 3), 1);
  }
  else if (PTPT_isSymbolVarsym(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterParenOpen), 3), 1);
  }
  else if (PTPT_isSymbolCharClass(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterParenOpen), 3), 1);
  }
  else if (PTPT_isSymbolStrategy(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterParenOpen), 3), 1);
  }
  else if (PTPT_isSymbolParameterizedSort(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterParenOpen), 3), 1);
  }

  ATabort("Symbol has no WsAfterParenOpen: %t\n", arg);
  return (PTPT_Symbol)NULL;
}

/**
 * Set the string of a PTPT_Symbol. The precondition being that this PTPT_Symbol actually has a string
 * \param[in] arg input PTPT_Symbol
 * \param[in] string new PTPT_StrCon to set in #arg
 * \return A new PTPT_Symbol with string at the right place, or a core dump if #arg did not have a string
 */
PTPT_Symbol PTPT_setSymbolString(PTPT_Symbol arg, PTPT_StrCon string) {
  if (PTPT_isSymbolLit(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) string), 4), 1);
  }
  else if (PTPT_isSymbolCilit(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) string), 4), 1);
  }
  else if (PTPT_isSymbolSort(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) string), 4), 1);
  }

  ATabort("Symbol has no String: %t\n", arg);
  return (PTPT_Symbol)NULL;
}

/**
 * Set the ws-after-string of a PTPT_Symbol. The precondition being that this PTPT_Symbol actually has a ws-after-string
 * \param[in] arg input PTPT_Symbol
 * \param[in] wsAfterString new PTPT_OptLayout to set in #arg
 * \return A new PTPT_Symbol with wsAfterString at the right place, or a core dump if #arg did not have a wsAfterString
 */
PTPT_Symbol PTPT_setSymbolWsAfterString(PTPT_Symbol arg, PTPT_OptLayout wsAfterString) {
  if (PTPT_isSymbolLit(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterString), 5), 1);
  }
  else if (PTPT_isSymbolCilit(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterString), 5), 1);
  }
  else if (PTPT_isSymbolSort(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterString), 5), 1);
  }

  ATabort("Symbol has no WsAfterString: %t\n", arg);
  return (PTPT_Symbol)NULL;
}

/**
 * Set the ws-after-cilit of a PTPT_Symbol. The precondition being that this PTPT_Symbol actually has a ws-after-cilit
 * \param[in] arg input PTPT_Symbol
 * \param[in] wsAfterCilit new PTPT_OptLayout to set in #arg
 * \return A new PTPT_Symbol with wsAfterCilit at the right place, or a core dump if #arg did not have a wsAfterCilit
 */
PTPT_Symbol PTPT_setSymbolWsAfterCilit(PTPT_Symbol arg, PTPT_OptLayout wsAfterCilit) {
  if (PTPT_isSymbolCilit(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterCilit), 1), 1);
  }

  ATabort("Symbol has no WsAfterCilit: %t\n", arg);
  return (PTPT_Symbol)NULL;
}

/**
 * Set the ws-after-cf of a PTPT_Symbol. The precondition being that this PTPT_Symbol actually has a ws-after-cf
 * \param[in] arg input PTPT_Symbol
 * \param[in] wsAfterCf new PTPT_OptLayout to set in #arg
 * \return A new PTPT_Symbol with wsAfterCf at the right place, or a core dump if #arg did not have a wsAfterCf
 */
PTPT_Symbol PTPT_setSymbolWsAfterCf(PTPT_Symbol arg, PTPT_OptLayout wsAfterCf) {
  if (PTPT_isSymbolCf(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterCf), 1), 1);
  }

  ATabort("Symbol has no WsAfterCf: %t\n", arg);
  return (PTPT_Symbol)NULL;
}

/**
 * Set the symbol of a PTPT_Symbol. The precondition being that this PTPT_Symbol actually has a symbol
 * \param[in] arg input PTPT_Symbol
 * \param[in] symbol new PTPT_Symbol to set in #arg
 * \return A new PTPT_Symbol with symbol at the right place, or a core dump if #arg did not have a symbol
 */
PTPT_Symbol PTPT_setSymbolSymbol(PTPT_Symbol arg, PTPT_Symbol symbol) {
  if (PTPT_isSymbolCf(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) symbol), 4), 1);
  }
  else if (PTPT_isSymbolLex(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) symbol), 4), 1);
  }
  else if (PTPT_isSymbolOpt(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) symbol), 4), 1);
  }
  else if (PTPT_isSymbolIter(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) symbol), 4), 1);
  }
  else if (PTPT_isSymbolIterStar(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) symbol), 4), 1);
  }
  else if (PTPT_isSymbolIterSep(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) symbol), 4), 1);
  }
  else if (PTPT_isSymbolIterStarSep(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) symbol), 4), 1);
  }
  else if (PTPT_isSymbolIterN(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) symbol), 4), 1);
  }
  else if (PTPT_isSymbolIterSepN(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) symbol), 4), 1);
  }
  else if (PTPT_isSymbolFunc(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) symbol), 8), 1);
  }
  else if (PTPT_isSymbolVarsym(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) symbol), 4), 1);
  }

  ATabort("Symbol has no Symbol: %t\n", arg);
  return (PTPT_Symbol)NULL;
}

/**
 * Set the ws-after-symbol of a PTPT_Symbol. The precondition being that this PTPT_Symbol actually has a ws-after-symbol
 * \param[in] arg input PTPT_Symbol
 * \param[in] wsAfterSymbol new PTPT_OptLayout to set in #arg
 * \return A new PTPT_Symbol with wsAfterSymbol at the right place, or a core dump if #arg did not have a wsAfterSymbol
 */
PTPT_Symbol PTPT_setSymbolWsAfterSymbol(PTPT_Symbol arg, PTPT_OptLayout wsAfterSymbol) {
  if (PTPT_isSymbolCf(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterSymbol), 5), 1);
  }
  else if (PTPT_isSymbolLex(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterSymbol), 5), 1);
  }
  else if (PTPT_isSymbolOpt(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterSymbol), 5), 1);
  }
  else if (PTPT_isSymbolIter(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterSymbol), 5), 1);
  }
  else if (PTPT_isSymbolIterStar(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterSymbol), 5), 1);
  }
  else if (PTPT_isSymbolIterSep(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterSymbol), 5), 1);
  }
  else if (PTPT_isSymbolIterStarSep(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterSymbol), 5), 1);
  }
  else if (PTPT_isSymbolIterN(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterSymbol), 5), 1);
  }
  else if (PTPT_isSymbolIterSepN(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterSymbol), 5), 1);
  }
  else if (PTPT_isSymbolFunc(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterSymbol), 9), 1);
  }
  else if (PTPT_isSymbolVarsym(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterSymbol), 5), 1);
  }

  ATabort("Symbol has no WsAfterSymbol: %t\n", arg);
  return (PTPT_Symbol)NULL;
}

/**
 * Set the ws-after-lex of a PTPT_Symbol. The precondition being that this PTPT_Symbol actually has a ws-after-lex
 * \param[in] arg input PTPT_Symbol
 * \param[in] wsAfterLex new PTPT_OptLayout to set in #arg
 * \return A new PTPT_Symbol with wsAfterLex at the right place, or a core dump if #arg did not have a wsAfterLex
 */
PTPT_Symbol PTPT_setSymbolWsAfterLex(PTPT_Symbol arg, PTPT_OptLayout wsAfterLex) {
  if (PTPT_isSymbolLex(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterLex), 1), 1);
  }

  ATabort("Symbol has no WsAfterLex: %t\n", arg);
  return (PTPT_Symbol)NULL;
}

/**
 * Set the ws-after-opt of a PTPT_Symbol. The precondition being that this PTPT_Symbol actually has a ws-after-opt
 * \param[in] arg input PTPT_Symbol
 * \param[in] wsAfterOpt new PTPT_OptLayout to set in #arg
 * \return A new PTPT_Symbol with wsAfterOpt at the right place, or a core dump if #arg did not have a wsAfterOpt
 */
PTPT_Symbol PTPT_setSymbolWsAfterOpt(PTPT_Symbol arg, PTPT_OptLayout wsAfterOpt) {
  if (PTPT_isSymbolOpt(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterOpt), 1), 1);
  }

  ATabort("Symbol has no WsAfterOpt: %t\n", arg);
  return (PTPT_Symbol)NULL;
}

/**
 * Set the ws-after-alt of a PTPT_Symbol. The precondition being that this PTPT_Symbol actually has a ws-after-alt
 * \param[in] arg input PTPT_Symbol
 * \param[in] wsAfterAlt new PTPT_OptLayout to set in #arg
 * \return A new PTPT_Symbol with wsAfterAlt at the right place, or a core dump if #arg did not have a wsAfterAlt
 */
PTPT_Symbol PTPT_setSymbolWsAfterAlt(PTPT_Symbol arg, PTPT_OptLayout wsAfterAlt) {
  if (PTPT_isSymbolAlt(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterAlt), 1), 1);
  }

  ATabort("Symbol has no WsAfterAlt: %t\n", arg);
  return (PTPT_Symbol)NULL;
}

/**
 * Set the lhs of a PTPT_Symbol. The precondition being that this PTPT_Symbol actually has a lhs
 * \param[in] arg input PTPT_Symbol
 * \param[in] lhs new PTPT_Symbol to set in #arg
 * \return A new PTPT_Symbol with lhs at the right place, or a core dump if #arg did not have a lhs
 */
PTPT_Symbol PTPT_setSymbolLhs(PTPT_Symbol arg, PTPT_Symbol lhs) {
  if (PTPT_isSymbolAlt(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) lhs), 4), 1);
  }
  else if (PTPT_isSymbolStrategy(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) lhs), 4), 1);
  }

  ATabort("Symbol has no Lhs: %t\n", arg);
  return (PTPT_Symbol)NULL;
}

/**
 * Set the ws-after-lhs of a PTPT_Symbol. The precondition being that this PTPT_Symbol actually has a ws-after-lhs
 * \param[in] arg input PTPT_Symbol
 * \param[in] wsAfterLhs new PTPT_OptLayout to set in #arg
 * \return A new PTPT_Symbol with wsAfterLhs at the right place, or a core dump if #arg did not have a wsAfterLhs
 */
PTPT_Symbol PTPT_setSymbolWsAfterLhs(PTPT_Symbol arg, PTPT_OptLayout wsAfterLhs) {
  if (PTPT_isSymbolAlt(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterLhs), 5), 1);
  }
  else if (PTPT_isSymbolStrategy(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterLhs), 5), 1);
  }

  ATabort("Symbol has no WsAfterLhs: %t\n", arg);
  return (PTPT_Symbol)NULL;
}

/**
 * Set the ws-after-, of a PTPT_Symbol. The precondition being that this PTPT_Symbol actually has a ws-after-,
 * \param[in] arg input PTPT_Symbol
 * \param[in] wsAfterComma new PTPT_OptLayout to set in #arg
 * \return A new PTPT_Symbol with wsAfterComma at the right place, or a core dump if #arg did not have a wsAfterComma
 */
PTPT_Symbol PTPT_setSymbolWsAfterComma(PTPT_Symbol arg, PTPT_OptLayout wsAfterComma) {
  if (PTPT_isSymbolAlt(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterComma), 7), 1);
  }
  else if (PTPT_isSymbolTuple(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterComma), 7), 1);
  }
  else if (PTPT_isSymbolIterSep(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterComma), 7), 1);
  }
  else if (PTPT_isSymbolIterStarSep(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterComma), 7), 1);
  }
  else if (PTPT_isSymbolIterN(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterComma), 7), 1);
  }
  else if (PTPT_isSymbolFunc(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterComma), 7), 1);
  }
  else if (PTPT_isSymbolStrategy(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterComma), 7), 1);
  }
  else if (PTPT_isSymbolParameterizedSort(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterComma), 7), 1);
  }

  ATabort("Symbol has no WsAfterComma: %t\n", arg);
  return (PTPT_Symbol)NULL;
}

/**
 * Set the rhs of a PTPT_Symbol. The precondition being that this PTPT_Symbol actually has a rhs
 * \param[in] arg input PTPT_Symbol
 * \param[in] rhs new PTPT_Symbol to set in #arg
 * \return A new PTPT_Symbol with rhs at the right place, or a core dump if #arg did not have a rhs
 */
PTPT_Symbol PTPT_setSymbolRhs(PTPT_Symbol arg, PTPT_Symbol rhs) {
  if (PTPT_isSymbolAlt(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) rhs), 8), 1);
  }
  else if (PTPT_isSymbolStrategy(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) rhs), 8), 1);
  }

  ATabort("Symbol has no Rhs: %t\n", arg);
  return (PTPT_Symbol)NULL;
}

/**
 * Set the ws-after-rhs of a PTPT_Symbol. The precondition being that this PTPT_Symbol actually has a ws-after-rhs
 * \param[in] arg input PTPT_Symbol
 * \param[in] wsAfterRhs new PTPT_OptLayout to set in #arg
 * \return A new PTPT_Symbol with wsAfterRhs at the right place, or a core dump if #arg did not have a wsAfterRhs
 */
PTPT_Symbol PTPT_setSymbolWsAfterRhs(PTPT_Symbol arg, PTPT_OptLayout wsAfterRhs) {
  if (PTPT_isSymbolAlt(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterRhs), 9), 1);
  }
  else if (PTPT_isSymbolStrategy(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterRhs), 9), 1);
  }

  ATabort("Symbol has no WsAfterRhs: %t\n", arg);
  return (PTPT_Symbol)NULL;
}

/**
 * Set the ws-after-seq of a PTPT_Symbol. The precondition being that this PTPT_Symbol actually has a ws-after-seq
 * \param[in] arg input PTPT_Symbol
 * \param[in] wsAfterSeq new PTPT_OptLayout to set in #arg
 * \return A new PTPT_Symbol with wsAfterSeq at the right place, or a core dump if #arg did not have a wsAfterSeq
 */
PTPT_Symbol PTPT_setSymbolWsAfterSeq(PTPT_Symbol arg, PTPT_OptLayout wsAfterSeq) {
  if (PTPT_isSymbolSeq(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterSeq), 1), 1);
  }

  ATabort("Symbol has no WsAfterSeq: %t\n", arg);
  return (PTPT_Symbol)NULL;
}

/**
 * Set the symbols of a PTPT_Symbol. The precondition being that this PTPT_Symbol actually has a symbols
 * \param[in] arg input PTPT_Symbol
 * \param[in] symbols new PTPT_Symbols to set in #arg
 * \return A new PTPT_Symbol with symbols at the right place, or a core dump if #arg did not have a symbols
 */
PTPT_Symbol PTPT_setSymbolSymbols(PTPT_Symbol arg, PTPT_Symbols symbols) {
  if (PTPT_isSymbolSeq(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) symbols), 4), 1);
  }
  else if (PTPT_isSymbolFunc(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) symbols), 4), 1);
  }

  ATabort("Symbol has no Symbols: %t\n", arg);
  return (PTPT_Symbol)NULL;
}

/**
 * Set the ws-after-symbols of a PTPT_Symbol. The precondition being that this PTPT_Symbol actually has a ws-after-symbols
 * \param[in] arg input PTPT_Symbol
 * \param[in] wsAfterSymbols new PTPT_OptLayout to set in #arg
 * \return A new PTPT_Symbol with wsAfterSymbols at the right place, or a core dump if #arg did not have a wsAfterSymbols
 */
PTPT_Symbol PTPT_setSymbolWsAfterSymbols(PTPT_Symbol arg, PTPT_OptLayout wsAfterSymbols) {
  if (PTPT_isSymbolSeq(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterSymbols), 5), 1);
  }
  else if (PTPT_isSymbolFunc(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterSymbols), 5), 1);
  }

  ATabort("Symbol has no WsAfterSymbols: %t\n", arg);
  return (PTPT_Symbol)NULL;
}

/**
 * Set the ws-after-tuple of a PTPT_Symbol. The precondition being that this PTPT_Symbol actually has a ws-after-tuple
 * \param[in] arg input PTPT_Symbol
 * \param[in] wsAfterTuple new PTPT_OptLayout to set in #arg
 * \return A new PTPT_Symbol with wsAfterTuple at the right place, or a core dump if #arg did not have a wsAfterTuple
 */
PTPT_Symbol PTPT_setSymbolWsAfterTuple(PTPT_Symbol arg, PTPT_OptLayout wsAfterTuple) {
  if (PTPT_isSymbolTuple(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterTuple), 1), 1);
  }

  ATabort("Symbol has no WsAfterTuple: %t\n", arg);
  return (PTPT_Symbol)NULL;
}

/**
 * Set the head of a PTPT_Symbol. The precondition being that this PTPT_Symbol actually has a head
 * \param[in] arg input PTPT_Symbol
 * \param[in] head new PTPT_Symbol to set in #arg
 * \return A new PTPT_Symbol with head at the right place, or a core dump if #arg did not have a head
 */
PTPT_Symbol PTPT_setSymbolHead(PTPT_Symbol arg, PTPT_Symbol head) {
  if (PTPT_isSymbolTuple(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) head), 4), 1);
  }

  ATabort("Symbol has no Head: %t\n", arg);
  return (PTPT_Symbol)NULL;
}

/**
 * Set the ws-after-head of a PTPT_Symbol. The precondition being that this PTPT_Symbol actually has a ws-after-head
 * \param[in] arg input PTPT_Symbol
 * \param[in] wsAfterHead new PTPT_OptLayout to set in #arg
 * \return A new PTPT_Symbol with wsAfterHead at the right place, or a core dump if #arg did not have a wsAfterHead
 */
PTPT_Symbol PTPT_setSymbolWsAfterHead(PTPT_Symbol arg, PTPT_OptLayout wsAfterHead) {
  if (PTPT_isSymbolTuple(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterHead), 5), 1);
  }

  ATabort("Symbol has no WsAfterHead: %t\n", arg);
  return (PTPT_Symbol)NULL;
}

/**
 * Set the rest of a PTPT_Symbol. The precondition being that this PTPT_Symbol actually has a rest
 * \param[in] arg input PTPT_Symbol
 * \param[in] rest new PTPT_Symbols to set in #arg
 * \return A new PTPT_Symbol with rest at the right place, or a core dump if #arg did not have a rest
 */
PTPT_Symbol PTPT_setSymbolRest(PTPT_Symbol arg, PTPT_Symbols rest) {
  if (PTPT_isSymbolTuple(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) rest), 8), 1);
  }

  ATabort("Symbol has no Rest: %t\n", arg);
  return (PTPT_Symbol)NULL;
}

/**
 * Set the ws-after-rest of a PTPT_Symbol. The precondition being that this PTPT_Symbol actually has a ws-after-rest
 * \param[in] arg input PTPT_Symbol
 * \param[in] wsAfterRest new PTPT_OptLayout to set in #arg
 * \return A new PTPT_Symbol with wsAfterRest at the right place, or a core dump if #arg did not have a wsAfterRest
 */
PTPT_Symbol PTPT_setSymbolWsAfterRest(PTPT_Symbol arg, PTPT_OptLayout wsAfterRest) {
  if (PTPT_isSymbolTuple(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterRest), 9), 1);
  }

  ATabort("Symbol has no WsAfterRest: %t\n", arg);
  return (PTPT_Symbol)NULL;
}

/**
 * Set the ws-after-sort of a PTPT_Symbol. The precondition being that this PTPT_Symbol actually has a ws-after-sort
 * \param[in] arg input PTPT_Symbol
 * \param[in] wsAfterSort new PTPT_OptLayout to set in #arg
 * \return A new PTPT_Symbol with wsAfterSort at the right place, or a core dump if #arg did not have a wsAfterSort
 */
PTPT_Symbol PTPT_setSymbolWsAfterSort(PTPT_Symbol arg, PTPT_OptLayout wsAfterSort) {
  if (PTPT_isSymbolSort(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterSort), 1), 1);
  }
  else if (PTPT_isSymbolParameterizedSort(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterSort), 5), 1);
  }

  ATabort("Symbol has no WsAfterSort: %t\n", arg);
  return (PTPT_Symbol)NULL;
}

/**
 * Set the ws-after-iter of a PTPT_Symbol. The precondition being that this PTPT_Symbol actually has a ws-after-iter
 * \param[in] arg input PTPT_Symbol
 * \param[in] wsAfterIter new PTPT_OptLayout to set in #arg
 * \return A new PTPT_Symbol with wsAfterIter at the right place, or a core dump if #arg did not have a wsAfterIter
 */
PTPT_Symbol PTPT_setSymbolWsAfterIter(PTPT_Symbol arg, PTPT_OptLayout wsAfterIter) {
  if (PTPT_isSymbolIter(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterIter), 1), 1);
  }

  ATabort("Symbol has no WsAfterIter: %t\n", arg);
  return (PTPT_Symbol)NULL;
}

/**
 * Set the ws-after-iter-star of a PTPT_Symbol. The precondition being that this PTPT_Symbol actually has a ws-after-iter-star
 * \param[in] arg input PTPT_Symbol
 * \param[in] wsAfterIterStar new PTPT_OptLayout to set in #arg
 * \return A new PTPT_Symbol with wsAfterIterStar at the right place, or a core dump if #arg did not have a wsAfterIterStar
 */
PTPT_Symbol PTPT_setSymbolWsAfterIterStar(PTPT_Symbol arg, PTPT_OptLayout wsAfterIterStar) {
  if (PTPT_isSymbolIterStar(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterIterStar), 1), 1);
  }

  ATabort("Symbol has no WsAfterIterStar: %t\n", arg);
  return (PTPT_Symbol)NULL;
}

/**
 * Set the ws-after-iter-sep of a PTPT_Symbol. The precondition being that this PTPT_Symbol actually has a ws-after-iter-sep
 * \param[in] arg input PTPT_Symbol
 * \param[in] wsAfterIterSep new PTPT_OptLayout to set in #arg
 * \return A new PTPT_Symbol with wsAfterIterSep at the right place, or a core dump if #arg did not have a wsAfterIterSep
 */
PTPT_Symbol PTPT_setSymbolWsAfterIterSep(PTPT_Symbol arg, PTPT_OptLayout wsAfterIterSep) {
  if (PTPT_isSymbolIterSep(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterIterSep), 1), 1);
  }

  ATabort("Symbol has no WsAfterIterSep: %t\n", arg);
  return (PTPT_Symbol)NULL;
}

/**
 * Set the separator of a PTPT_Symbol. The precondition being that this PTPT_Symbol actually has a separator
 * \param[in] arg input PTPT_Symbol
 * \param[in] separator new PTPT_Symbol to set in #arg
 * \return A new PTPT_Symbol with separator at the right place, or a core dump if #arg did not have a separator
 */
PTPT_Symbol PTPT_setSymbolSeparator(PTPT_Symbol arg, PTPT_Symbol separator) {
  if (PTPT_isSymbolIterSep(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) separator), 8), 1);
  }
  else if (PTPT_isSymbolIterStarSep(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) separator), 8), 1);
  }
  else if (PTPT_isSymbolIterSepN(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) separator), 8), 1);
  }

  ATabort("Symbol has no Separator: %t\n", arg);
  return (PTPT_Symbol)NULL;
}

/**
 * Set the ws-after-separator of a PTPT_Symbol. The precondition being that this PTPT_Symbol actually has a ws-after-separator
 * \param[in] arg input PTPT_Symbol
 * \param[in] wsAfterSeparator new PTPT_OptLayout to set in #arg
 * \return A new PTPT_Symbol with wsAfterSeparator at the right place, or a core dump if #arg did not have a wsAfterSeparator
 */
PTPT_Symbol PTPT_setSymbolWsAfterSeparator(PTPT_Symbol arg, PTPT_OptLayout wsAfterSeparator) {
  if (PTPT_isSymbolIterSep(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterSeparator), 9), 1);
  }
  else if (PTPT_isSymbolIterStarSep(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterSeparator), 9), 1);
  }
  else if (PTPT_isSymbolIterSepN(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterSeparator), 9), 1);
  }

  ATabort("Symbol has no WsAfterSeparator: %t\n", arg);
  return (PTPT_Symbol)NULL;
}

/**
 * Set the ws-after-iter-star-sep of a PTPT_Symbol. The precondition being that this PTPT_Symbol actually has a ws-after-iter-star-sep
 * \param[in] arg input PTPT_Symbol
 * \param[in] wsAfterIterStarSep new PTPT_OptLayout to set in #arg
 * \return A new PTPT_Symbol with wsAfterIterStarSep at the right place, or a core dump if #arg did not have a wsAfterIterStarSep
 */
PTPT_Symbol PTPT_setSymbolWsAfterIterStarSep(PTPT_Symbol arg, PTPT_OptLayout wsAfterIterStarSep) {
  if (PTPT_isSymbolIterStarSep(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterIterStarSep), 1), 1);
  }

  ATabort("Symbol has no WsAfterIterStarSep: %t\n", arg);
  return (PTPT_Symbol)NULL;
}

/**
 * Set the ws-after-iter-n of a PTPT_Symbol. The precondition being that this PTPT_Symbol actually has a ws-after-iter-n
 * \param[in] arg input PTPT_Symbol
 * \param[in] wsAfterIterN new PTPT_OptLayout to set in #arg
 * \return A new PTPT_Symbol with wsAfterIterN at the right place, or a core dump if #arg did not have a wsAfterIterN
 */
PTPT_Symbol PTPT_setSymbolWsAfterIterN(PTPT_Symbol arg, PTPT_OptLayout wsAfterIterN) {
  if (PTPT_isSymbolIterN(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterIterN), 1), 1);
  }

  ATabort("Symbol has no WsAfterIterN: %t\n", arg);
  return (PTPT_Symbol)NULL;
}

/**
 * Set the number of a PTPT_Symbol. The precondition being that this PTPT_Symbol actually has a number
 * \param[in] arg input PTPT_Symbol
 * \param[in] number new PTPT_NatCon to set in #arg
 * \return A new PTPT_Symbol with number at the right place, or a core dump if #arg did not have a number
 */
PTPT_Symbol PTPT_setSymbolNumber(PTPT_Symbol arg, PTPT_NatCon number) {
  if (PTPT_isSymbolIterN(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) number), 8), 1);
  }
  else if (PTPT_isSymbolIterSepN(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) number), 12), 1);
  }

  ATabort("Symbol has no Number: %t\n", arg);
  return (PTPT_Symbol)NULL;
}

/**
 * Set the ws-after-number of a PTPT_Symbol. The precondition being that this PTPT_Symbol actually has a ws-after-number
 * \param[in] arg input PTPT_Symbol
 * \param[in] wsAfterNumber new PTPT_OptLayout to set in #arg
 * \return A new PTPT_Symbol with wsAfterNumber at the right place, or a core dump if #arg did not have a wsAfterNumber
 */
PTPT_Symbol PTPT_setSymbolWsAfterNumber(PTPT_Symbol arg, PTPT_OptLayout wsAfterNumber) {
  if (PTPT_isSymbolIterN(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterNumber), 9), 1);
  }
  else if (PTPT_isSymbolIterSepN(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterNumber), 13), 1);
  }

  ATabort("Symbol has no WsAfterNumber: %t\n", arg);
  return (PTPT_Symbol)NULL;
}

/**
 * Set the ws-after-iter-sep-n of a PTPT_Symbol. The precondition being that this PTPT_Symbol actually has a ws-after-iter-sep-n
 * \param[in] arg input PTPT_Symbol
 * \param[in] wsAfterIterSepN new PTPT_OptLayout to set in #arg
 * \return A new PTPT_Symbol with wsAfterIterSepN at the right place, or a core dump if #arg did not have a wsAfterIterSepN
 */
PTPT_Symbol PTPT_setSymbolWsAfterIterSepN(PTPT_Symbol arg, PTPT_OptLayout wsAfterIterSepN) {
  if (PTPT_isSymbolIterSepN(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterIterSepN), 1), 1);
  }

  ATabort("Symbol has no WsAfterIterSepN: %t\n", arg);
  return (PTPT_Symbol)NULL;
}

/**
 * Set the ws-after-comma1 of a PTPT_Symbol. The precondition being that this PTPT_Symbol actually has a ws-after-comma1
 * \param[in] arg input PTPT_Symbol
 * \param[in] wsAfterComma1 new PTPT_OptLayout to set in #arg
 * \return A new PTPT_Symbol with wsAfterComma1 at the right place, or a core dump if #arg did not have a wsAfterComma1
 */
PTPT_Symbol PTPT_setSymbolWsAfterComma1(PTPT_Symbol arg, PTPT_OptLayout wsAfterComma1) {
  if (PTPT_isSymbolIterSepN(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterComma1), 7), 1);
  }

  ATabort("Symbol has no WsAfterComma1: %t\n", arg);
  return (PTPT_Symbol)NULL;
}

/**
 * Set the ws-after-comma2 of a PTPT_Symbol. The precondition being that this PTPT_Symbol actually has a ws-after-comma2
 * \param[in] arg input PTPT_Symbol
 * \param[in] wsAfterComma2 new PTPT_OptLayout to set in #arg
 * \return A new PTPT_Symbol with wsAfterComma2 at the right place, or a core dump if #arg did not have a wsAfterComma2
 */
PTPT_Symbol PTPT_setSymbolWsAfterComma2(PTPT_Symbol arg, PTPT_OptLayout wsAfterComma2) {
  if (PTPT_isSymbolIterSepN(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterComma2), 11), 1);
  }

  ATabort("Symbol has no WsAfterComma2: %t\n", arg);
  return (PTPT_Symbol)NULL;
}

/**
 * Set the ws-after-func of a PTPT_Symbol. The precondition being that this PTPT_Symbol actually has a ws-after-func
 * \param[in] arg input PTPT_Symbol
 * \param[in] wsAfterFunc new PTPT_OptLayout to set in #arg
 * \return A new PTPT_Symbol with wsAfterFunc at the right place, or a core dump if #arg did not have a wsAfterFunc
 */
PTPT_Symbol PTPT_setSymbolWsAfterFunc(PTPT_Symbol arg, PTPT_OptLayout wsAfterFunc) {
  if (PTPT_isSymbolFunc(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterFunc), 1), 1);
  }

  ATabort("Symbol has no WsAfterFunc: %t\n", arg);
  return (PTPT_Symbol)NULL;
}

/**
 * Set the ws-after-varsym of a PTPT_Symbol. The precondition being that this PTPT_Symbol actually has a ws-after-varsym
 * \param[in] arg input PTPT_Symbol
 * \param[in] wsAfterVarsym new PTPT_OptLayout to set in #arg
 * \return A new PTPT_Symbol with wsAfterVarsym at the right place, or a core dump if #arg did not have a wsAfterVarsym
 */
PTPT_Symbol PTPT_setSymbolWsAfterVarsym(PTPT_Symbol arg, PTPT_OptLayout wsAfterVarsym) {
  if (PTPT_isSymbolVarsym(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterVarsym), 1), 1);
  }

  ATabort("Symbol has no WsAfterVarsym: %t\n", arg);
  return (PTPT_Symbol)NULL;
}

/**
 * Set the ws-after-char-class of a PTPT_Symbol. The precondition being that this PTPT_Symbol actually has a ws-after-char-class
 * \param[in] arg input PTPT_Symbol
 * \param[in] wsAfterCharClass new PTPT_OptLayout to set in #arg
 * \return A new PTPT_Symbol with wsAfterCharClass at the right place, or a core dump if #arg did not have a wsAfterCharClass
 */
PTPT_Symbol PTPT_setSymbolWsAfterCharClass(PTPT_Symbol arg, PTPT_OptLayout wsAfterCharClass) {
  if (PTPT_isSymbolCharClass(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterCharClass), 1), 1);
  }

  ATabort("Symbol has no WsAfterCharClass: %t\n", arg);
  return (PTPT_Symbol)NULL;
}

/**
 * Set the CharRanges of a PTPT_Symbol. The precondition being that this PTPT_Symbol actually has a CharRanges
 * \param[in] arg input PTPT_Symbol
 * \param[in] CharRanges new PTPT_CharRanges to set in #arg
 * \return A new PTPT_Symbol with CharRanges at the right place, or a core dump if #arg did not have a CharRanges
 */
PTPT_Symbol PTPT_setSymbolCharRanges(PTPT_Symbol arg, PTPT_CharRanges CharRanges) {
  if (PTPT_isSymbolCharClass(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) CharRanges), 4), 1);
  }

  ATabort("Symbol has no CharRanges: %t\n", arg);
  return (PTPT_Symbol)NULL;
}

/**
 * Set the ws-after-CharRanges of a PTPT_Symbol. The precondition being that this PTPT_Symbol actually has a ws-after-CharRanges
 * \param[in] arg input PTPT_Symbol
 * \param[in] wsAfterCharRanges new PTPT_OptLayout to set in #arg
 * \return A new PTPT_Symbol with wsAfterCharRanges at the right place, or a core dump if #arg did not have a wsAfterCharRanges
 */
PTPT_Symbol PTPT_setSymbolWsAfterCharRanges(PTPT_Symbol arg, PTPT_OptLayout wsAfterCharRanges) {
  if (PTPT_isSymbolCharClass(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterCharRanges), 5), 1);
  }

  ATabort("Symbol has no WsAfterCharRanges: %t\n", arg);
  return (PTPT_Symbol)NULL;
}

/**
 * Set the ws-after-strategy of a PTPT_Symbol. The precondition being that this PTPT_Symbol actually has a ws-after-strategy
 * \param[in] arg input PTPT_Symbol
 * \param[in] wsAfterStrategy new PTPT_OptLayout to set in #arg
 * \return A new PTPT_Symbol with wsAfterStrategy at the right place, or a core dump if #arg did not have a wsAfterStrategy
 */
PTPT_Symbol PTPT_setSymbolWsAfterStrategy(PTPT_Symbol arg, PTPT_OptLayout wsAfterStrategy) {
  if (PTPT_isSymbolStrategy(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterStrategy), 1), 1);
  }

  ATabort("Symbol has no WsAfterStrategy: %t\n", arg);
  return (PTPT_Symbol)NULL;
}

/**
 * Set the ws-after-parameterized-sort of a PTPT_Symbol. The precondition being that this PTPT_Symbol actually has a ws-after-parameterized-sort
 * \param[in] arg input PTPT_Symbol
 * \param[in] wsAfterParameterizedSort new PTPT_OptLayout to set in #arg
 * \return A new PTPT_Symbol with wsAfterParameterizedSort at the right place, or a core dump if #arg did not have a wsAfterParameterizedSort
 */
PTPT_Symbol PTPT_setSymbolWsAfterParameterizedSort(PTPT_Symbol arg, PTPT_OptLayout wsAfterParameterizedSort) {
  if (PTPT_isSymbolParameterizedSort(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterParameterizedSort), 1), 1);
  }

  ATabort("Symbol has no WsAfterParameterizedSort: %t\n", arg);
  return (PTPT_Symbol)NULL;
}

/**
 * Set the sort of a PTPT_Symbol. The precondition being that this PTPT_Symbol actually has a sort
 * \param[in] arg input PTPT_Symbol
 * \param[in] sort new PTPT_StrCon to set in #arg
 * \return A new PTPT_Symbol with sort at the right place, or a core dump if #arg did not have a sort
 */
PTPT_Symbol PTPT_setSymbolSort(PTPT_Symbol arg, PTPT_StrCon sort) {
  if (PTPT_isSymbolParameterizedSort(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) sort), 4), 1);
  }

  ATabort("Symbol has no Sort: %t\n", arg);
  return (PTPT_Symbol)NULL;
}

/**
 * Set the parameters of a PTPT_Symbol. The precondition being that this PTPT_Symbol actually has a parameters
 * \param[in] arg input PTPT_Symbol
 * \param[in] parameters new PTPT_Symbols to set in #arg
 * \return A new PTPT_Symbol with parameters at the right place, or a core dump if #arg did not have a parameters
 */
PTPT_Symbol PTPT_setSymbolParameters(PTPT_Symbol arg, PTPT_Symbols parameters) {
  if (PTPT_isSymbolParameterizedSort(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) parameters), 8), 1);
  }

  ATabort("Symbol has no Parameters: %t\n", arg);
  return (PTPT_Symbol)NULL;
}

/**
 * Set the ws-after-parameters of a PTPT_Symbol. The precondition being that this PTPT_Symbol actually has a ws-after-parameters
 * \param[in] arg input PTPT_Symbol
 * \param[in] wsAfterParameters new PTPT_OptLayout to set in #arg
 * \return A new PTPT_Symbol with wsAfterParameters at the right place, or a core dump if #arg did not have a wsAfterParameters
 */
PTPT_Symbol PTPT_setSymbolWsAfterParameters(PTPT_Symbol arg, PTPT_OptLayout wsAfterParameters) {
  if (PTPT_isSymbolParameterizedSort(arg)) {
    return (PTPT_Symbol)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterParameters), 9), 1);
  }

  ATabort("Symbol has no WsAfterParameters: %t\n", arg);
  return (PTPT_Symbol)NULL;
}

/**
 * Assert whether a PTPT_Symbols is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input PTPT_Symbols
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool PTPT_isValidSymbols(PTPT_Symbols arg) {
  if (PTPT_isSymbolsList(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Symbols is a list by checking against the following ATerm pattern: appl(prod([lit("["),cf(opt(layout)),cf(iter-star-sep(sort("Symbol"),lit(","))),cf(opt(layout)),lit("]")],cf(sort("Symbols")),attrs([term(cons("list"))])),[appl(prod([char-class([91])],lit("["),no-attrs),[91]),<"ws-after-["("OptLayout")>,appl(list(cf(iter-star-sep(sort("Symbol"),lit(",")))),<"list"("Symbol-list")>),<"ws-after-list"("OptLayout")>,appl(prod([char-class([93])],lit("]"),no-attrs),[93])]). Always returns ATtrue
 * \param[in] arg input PTPT_Symbols
 * \return ATtrue if #arg corresponds to the signature of a list, or ATfalse otherwise
 */
inline ATbool PTPT_isSymbolsList(PTPT_Symbols arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == PTPT_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == PTPT_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lit */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: [ */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun36) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
              /* checking for: cf */
              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                /* checking for: opt */
                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                  /* checking for: layout */
                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                      arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                      arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                      /* checking for: cf */
                      if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                        ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                        /* checking for: iter-star-sep */
                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun78) {
                          ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                          /* checking for: sort */
                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun9) {
                            ATerm arg_arg0_arg0_head_arg0_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0_arg0, 0);
                            /* checking for: Symbol */
                            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0_arg0) == PTPT_afun25) {
                              ATerm arg_arg0_arg0_head_arg0_arg1 = ATgetArgument(arg_arg0_arg0_head_arg0, 1);
                              /* checking for: lit */
                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg1) == PTPT_afun16) {
                                ATerm arg_arg0_arg0_head_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0_arg1, 0);
                                /* checking for: , */
                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg1_arg0) == PTPT_afun19) {
                                  if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                    arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                    arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                    /* checking for: cf */
                                    if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                      ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                      /* checking for: opt */
                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                        ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                        /* checking for: layout */
                                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                            arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                            arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                            /* checking for: lit */
                                            if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
                                              ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                              /* checking for: ] */
                                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun33) {
                                                if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                                                  ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                                  /* checking for: cf */
                                                  if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == PTPT_afun2) {
                                                    ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                                    /* checking for: sort */
                                                    if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == PTPT_afun9) {
                                                      ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                                      /* checking for: Symbols */
                                                      if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == PTPT_afun61) {
                                                        ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                                        /* checking for: attrs */
                                                        if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == PTPT_afun12) {
                                                          ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                                          if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                                            ATerm arg_arg0_arg2_arg0_head;
                                                            ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                                            arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                                            arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                                            /* checking for: term */
                                                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == PTPT_afun13) {
                                                              ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                                              /* checking for: cons */
                                                              if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == PTPT_afun14) {
                                                                ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                                                /* checking for: list */
                                                                if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == PTPT_afun79) {
                                                                  if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                                    ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                                    if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                                      ATerm arg_arg1_head;
                                                                      ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                                      arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                      arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                      /* checking for: appl */
                                                                      if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                        ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                        /* checking for: prod */
                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                          ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                            ATerm arg_arg1_head_arg0_arg0_head;
                                                                            ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                            arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                            arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                            /* checking for: char-class */
                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 91) {

                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                      ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                      /* checking for: lit */
                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                        ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                        /* checking for: [ */
                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun36) {
                                                                                          ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                          /* checking for: no-attrs */
                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                            ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                              ATerm arg_arg1_head_arg1_head;
                                                                                              ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                              arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                              arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 91) {

                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                  if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                    arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                      arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                      arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                      /* checking for: appl */
                                                                                                      if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                        ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                        /* checking for: list */
                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun8) {
                                                                                                          ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                          /* checking for: cf */
                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0) == PTPT_afun2) {
                                                                                                            ATerm arg_arg1_head_arg0_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0, 0);
                                                                                                            /* checking for: iter-star-sep */
                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0) == PTPT_afun78) {
                                                                                                              ATerm arg_arg1_head_arg0_arg0_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0, 0);
                                                                                                              /* checking for: sort */
                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg0) == PTPT_afun9) {
                                                                                                                ATerm arg_arg1_head_arg0_arg0_arg0_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0_arg0, 0);
                                                                                                                /* checking for: Symbol */
                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg0_arg0) == PTPT_afun25) {
                                                                                                                  ATerm arg_arg1_head_arg0_arg0_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0, 1);
                                                                                                                  /* checking for: lit */
                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg1) == PTPT_afun16) {
                                                                                                                    ATerm arg_arg1_head_arg0_arg0_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0_arg1, 0);
                                                                                                                    /* checking for: , */
                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg1_arg0) == PTPT_afun19) {
                                                                                                                      if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                        arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                          arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                          arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                          /* checking for: appl */
                                                                                                                          if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                                            ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                            /* checking for: prod */
                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                                                              ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                /* checking for: char-class */
                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                    ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                    arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                    arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 93) {

                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                          ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                          /* checking for: lit */
                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                            ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                            /* checking for: ] */
                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun33) {
                                                                                                                                              ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                              /* checking for: no-attrs */
                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                  ATerm arg_arg1_head_arg1_head;
                                                                                                                                                  ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                  arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                  arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 93) {

                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                                                                        return ATtrue;
                                                                                                                                                      }
                                                                                                                                                    }
                                                                                                                                                  }
                                                                                                                                                }
                                                                                                                                              }
                                                                                                                                            }
                                                                                                                                          }
                                                                                                                                        }
                                                                                                                                      }
                                                                                                                                    }
                                                                                                                                  }
                                                                                                                                }
                                                                                                                              }
                                                                                                                            }
                                                                                                                          }
                                                                                                                        }
                                                                                                                      }
                                                                                                                    }
                                                                                                                  }
                                                                                                                }
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Symbols has a ws-after-[. 
 * \param[in] arg input PTPT_Symbols
 * \return ATtrue if the PTPT_Symbols had a ws-after-[, or ATfalse otherwise
 */
ATbool PTPT_hasSymbolsWsAfterBracketOpen(PTPT_Symbols arg) {
  if (PTPT_isSymbolsList(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Symbols has a list. 
 * \param[in] arg input PTPT_Symbols
 * \return ATtrue if the PTPT_Symbols had a list, or ATfalse otherwise
 */
ATbool PTPT_hasSymbolsList(PTPT_Symbols arg) {
  if (PTPT_isSymbolsList(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Symbols has a ws-after-list. 
 * \param[in] arg input PTPT_Symbols
 * \return ATtrue if the PTPT_Symbols had a ws-after-list, or ATfalse otherwise
 */
ATbool PTPT_hasSymbolsWsAfterList(PTPT_Symbols arg) {
  if (PTPT_isSymbolsList(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Get the ws-after-[ PTPT_OptLayout of a PTPT_Symbols. Note that the precondition is that this PTPT_Symbols actually has a ws-after-[
 * \param[in] arg input PTPT_Symbols
 * \return the ws-after-[ of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getSymbolsWsAfterBracketOpen(PTPT_Symbols arg) {
  
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1);
}

/**
 * Get the list PTPT_SymbolList of a PTPT_Symbols. Note that the precondition is that this PTPT_Symbols actually has a list
 * \param[in] arg input PTPT_Symbols
 * \return the list of #arg, if it exist or an undefined value if it does not
 */
PTPT_SymbolList PTPT_getSymbolsList(PTPT_Symbols arg) {
  
    return (PTPT_SymbolList)ATgetArgument((ATermAppl)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 2), 1);
}

/**
 * Get the ws-after-list PTPT_OptLayout of a PTPT_Symbols. Note that the precondition is that this PTPT_Symbols actually has a ws-after-list
 * \param[in] arg input PTPT_Symbols
 * \return the ws-after-list of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getSymbolsWsAfterList(PTPT_Symbols arg) {
  
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 3);
}

/**
 * Set the ws-after-[ of a PTPT_Symbols. The precondition being that this PTPT_Symbols actually has a ws-after-[
 * \param[in] arg input PTPT_Symbols
 * \param[in] wsAfterBracketOpen new PTPT_OptLayout to set in #arg
 * \return A new PTPT_Symbols with wsAfterBracketOpen at the right place, or a core dump if #arg did not have a wsAfterBracketOpen
 */
PTPT_Symbols PTPT_setSymbolsWsAfterBracketOpen(PTPT_Symbols arg, PTPT_OptLayout wsAfterBracketOpen) {
  if (PTPT_isSymbolsList(arg)) {
    return (PTPT_Symbols)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterBracketOpen), 1), 1);
  }

  ATabort("Symbols has no WsAfterBracketOpen: %t\n", arg);
  return (PTPT_Symbols)NULL;
}

/**
 * Set the list of a PTPT_Symbols. The precondition being that this PTPT_Symbols actually has a list
 * \param[in] arg input PTPT_Symbols
 * \param[in] list new PTPT_SymbolList to set in #arg
 * \return A new PTPT_Symbols with list at the right place, or a core dump if #arg did not have a list
 */
PTPT_Symbols PTPT_setSymbolsList(PTPT_Symbols arg, PTPT_SymbolList list) {
  if (PTPT_isSymbolsList(arg)) {
    return (PTPT_Symbols)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)ATsetArgument((ATermAppl)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 2), (ATerm)((ATerm) list), 1), 2), 1);
  }

  ATabort("Symbols has no List: %t\n", arg);
  return (PTPT_Symbols)NULL;
}

/**
 * Set the ws-after-list of a PTPT_Symbols. The precondition being that this PTPT_Symbols actually has a ws-after-list
 * \param[in] arg input PTPT_Symbols
 * \param[in] wsAfterList new PTPT_OptLayout to set in #arg
 * \return A new PTPT_Symbols with wsAfterList at the right place, or a core dump if #arg did not have a wsAfterList
 */
PTPT_Symbols PTPT_setSymbolsWsAfterList(PTPT_Symbols arg, PTPT_OptLayout wsAfterList) {
  if (PTPT_isSymbolsList(arg)) {
    return (PTPT_Symbols)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterList), 3), 1);
  }

  ATabort("Symbols has no WsAfterList: %t\n", arg);
  return (PTPT_Symbols)NULL;
}

/**
 * Assert whether a PTPT_CharRanges is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input PTPT_CharRanges
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool PTPT_isValidCharRanges(PTPT_CharRanges arg) {
  if (PTPT_isCharRangesList(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_CharRanges is a list by checking against the following ATerm pattern: appl(prod([lit("["),cf(opt(layout)),cf(iter-star-sep(sort("CharRange"),lit(","))),cf(opt(layout)),lit("]")],cf(sort("CharRanges")),attrs([term(cons("list"))])),[appl(prod([char-class([91])],lit("["),no-attrs),[91]),<"ws-after-["("OptLayout")>,appl(list(cf(iter-star-sep(sort("CharRange"),lit(",")))),<"list"("CharRange-list")>),<"ws-after-list"("OptLayout")>,appl(prod([char-class([93])],lit("]"),no-attrs),[93])]). Always returns ATtrue
 * \param[in] arg input PTPT_CharRanges
 * \return ATtrue if #arg corresponds to the signature of a list, or ATfalse otherwise
 */
inline ATbool PTPT_isCharRangesList(PTPT_CharRanges arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == PTPT_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == PTPT_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lit */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: [ */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun36) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
              /* checking for: cf */
              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                /* checking for: opt */
                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                  /* checking for: layout */
                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                      arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                      arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                      /* checking for: cf */
                      if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                        ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                        /* checking for: iter-star-sep */
                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun78) {
                          ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                          /* checking for: sort */
                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun9) {
                            ATerm arg_arg0_arg0_head_arg0_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0_arg0, 0);
                            /* checking for: CharRange */
                            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0_arg0) == PTPT_afun80) {
                              ATerm arg_arg0_arg0_head_arg0_arg1 = ATgetArgument(arg_arg0_arg0_head_arg0, 1);
                              /* checking for: lit */
                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg1) == PTPT_afun16) {
                                ATerm arg_arg0_arg0_head_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0_arg1, 0);
                                /* checking for: , */
                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg1_arg0) == PTPT_afun19) {
                                  if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                    arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                    arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                    /* checking for: cf */
                                    if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                      ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                      /* checking for: opt */
                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                        ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                        /* checking for: layout */
                                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                            arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                            arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                            /* checking for: lit */
                                            if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
                                              ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                              /* checking for: ] */
                                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun33) {
                                                if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                                                  ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                                  /* checking for: cf */
                                                  if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == PTPT_afun2) {
                                                    ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                                    /* checking for: sort */
                                                    if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == PTPT_afun9) {
                                                      ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                                      /* checking for: CharRanges */
                                                      if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == PTPT_afun74) {
                                                        ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                                        /* checking for: attrs */
                                                        if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == PTPT_afun12) {
                                                          ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                                          if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                                            ATerm arg_arg0_arg2_arg0_head;
                                                            ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                                            arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                                            arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                                            /* checking for: term */
                                                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == PTPT_afun13) {
                                                              ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                                              /* checking for: cons */
                                                              if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == PTPT_afun14) {
                                                                ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                                                /* checking for: list */
                                                                if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == PTPT_afun79) {
                                                                  if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                                    ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                                    if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                                      ATerm arg_arg1_head;
                                                                      ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                                      arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                      arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                      /* checking for: appl */
                                                                      if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                        ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                        /* checking for: prod */
                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                          ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                            ATerm arg_arg1_head_arg0_arg0_head;
                                                                            ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                            arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                            arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                            /* checking for: char-class */
                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 91) {

                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                      ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                      /* checking for: lit */
                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                        ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                        /* checking for: [ */
                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun36) {
                                                                                          ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                          /* checking for: no-attrs */
                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                            ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                              ATerm arg_arg1_head_arg1_head;
                                                                                              ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                              arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                              arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 91) {

                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                  if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                    arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                      arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                      arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                      /* checking for: appl */
                                                                                                      if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                        ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                        /* checking for: list */
                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun8) {
                                                                                                          ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                          /* checking for: cf */
                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0) == PTPT_afun2) {
                                                                                                            ATerm arg_arg1_head_arg0_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0, 0);
                                                                                                            /* checking for: iter-star-sep */
                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0) == PTPT_afun78) {
                                                                                                              ATerm arg_arg1_head_arg0_arg0_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0, 0);
                                                                                                              /* checking for: sort */
                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg0) == PTPT_afun9) {
                                                                                                                ATerm arg_arg1_head_arg0_arg0_arg0_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0_arg0, 0);
                                                                                                                /* checking for: CharRange */
                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg0_arg0) == PTPT_afun80) {
                                                                                                                  ATerm arg_arg1_head_arg0_arg0_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0, 1);
                                                                                                                  /* checking for: lit */
                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg1) == PTPT_afun16) {
                                                                                                                    ATerm arg_arg1_head_arg0_arg0_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0_arg1, 0);
                                                                                                                    /* checking for: , */
                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg1_arg0) == PTPT_afun19) {
                                                                                                                      if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                        arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                          arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                          arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                          /* checking for: appl */
                                                                                                                          if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                                            ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                            /* checking for: prod */
                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                                                              ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                /* checking for: char-class */
                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                    ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                    arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                    arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 93) {

                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                          ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                          /* checking for: lit */
                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                            ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                            /* checking for: ] */
                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun33) {
                                                                                                                                              ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                              /* checking for: no-attrs */
                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                  ATerm arg_arg1_head_arg1_head;
                                                                                                                                                  ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                  arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                  arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 93) {

                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                                                                        return ATtrue;
                                                                                                                                                      }
                                                                                                                                                    }
                                                                                                                                                  }
                                                                                                                                                }
                                                                                                                                              }
                                                                                                                                            }
                                                                                                                                          }
                                                                                                                                        }
                                                                                                                                      }
                                                                                                                                    }
                                                                                                                                  }
                                                                                                                                }
                                                                                                                              }
                                                                                                                            }
                                                                                                                          }
                                                                                                                        }
                                                                                                                      }
                                                                                                                    }
                                                                                                                  }
                                                                                                                }
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_CharRanges has a ws-after-[. 
 * \param[in] arg input PTPT_CharRanges
 * \return ATtrue if the PTPT_CharRanges had a ws-after-[, or ATfalse otherwise
 */
ATbool PTPT_hasCharRangesWsAfterBracketOpen(PTPT_CharRanges arg) {
  if (PTPT_isCharRangesList(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_CharRanges has a list. 
 * \param[in] arg input PTPT_CharRanges
 * \return ATtrue if the PTPT_CharRanges had a list, or ATfalse otherwise
 */
ATbool PTPT_hasCharRangesList(PTPT_CharRanges arg) {
  if (PTPT_isCharRangesList(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_CharRanges has a ws-after-list. 
 * \param[in] arg input PTPT_CharRanges
 * \return ATtrue if the PTPT_CharRanges had a ws-after-list, or ATfalse otherwise
 */
ATbool PTPT_hasCharRangesWsAfterList(PTPT_CharRanges arg) {
  if (PTPT_isCharRangesList(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Get the ws-after-[ PTPT_OptLayout of a PTPT_CharRanges. Note that the precondition is that this PTPT_CharRanges actually has a ws-after-[
 * \param[in] arg input PTPT_CharRanges
 * \return the ws-after-[ of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getCharRangesWsAfterBracketOpen(PTPT_CharRanges arg) {
  
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1);
}

/**
 * Get the list PTPT_CharRangeList of a PTPT_CharRanges. Note that the precondition is that this PTPT_CharRanges actually has a list
 * \param[in] arg input PTPT_CharRanges
 * \return the list of #arg, if it exist or an undefined value if it does not
 */
PTPT_CharRangeList PTPT_getCharRangesList(PTPT_CharRanges arg) {
  
    return (PTPT_CharRangeList)ATgetArgument((ATermAppl)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 2), 1);
}

/**
 * Get the ws-after-list PTPT_OptLayout of a PTPT_CharRanges. Note that the precondition is that this PTPT_CharRanges actually has a ws-after-list
 * \param[in] arg input PTPT_CharRanges
 * \return the ws-after-list of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getCharRangesWsAfterList(PTPT_CharRanges arg) {
  
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 3);
}

/**
 * Set the ws-after-[ of a PTPT_CharRanges. The precondition being that this PTPT_CharRanges actually has a ws-after-[
 * \param[in] arg input PTPT_CharRanges
 * \param[in] wsAfterBracketOpen new PTPT_OptLayout to set in #arg
 * \return A new PTPT_CharRanges with wsAfterBracketOpen at the right place, or a core dump if #arg did not have a wsAfterBracketOpen
 */
PTPT_CharRanges PTPT_setCharRangesWsAfterBracketOpen(PTPT_CharRanges arg, PTPT_OptLayout wsAfterBracketOpen) {
  if (PTPT_isCharRangesList(arg)) {
    return (PTPT_CharRanges)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterBracketOpen), 1), 1);
  }

  ATabort("CharRanges has no WsAfterBracketOpen: %t\n", arg);
  return (PTPT_CharRanges)NULL;
}

/**
 * Set the list of a PTPT_CharRanges. The precondition being that this PTPT_CharRanges actually has a list
 * \param[in] arg input PTPT_CharRanges
 * \param[in] list new PTPT_CharRangeList to set in #arg
 * \return A new PTPT_CharRanges with list at the right place, or a core dump if #arg did not have a list
 */
PTPT_CharRanges PTPT_setCharRangesList(PTPT_CharRanges arg, PTPT_CharRangeList list) {
  if (PTPT_isCharRangesList(arg)) {
    return (PTPT_CharRanges)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)ATsetArgument((ATermAppl)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 2), (ATerm)((ATerm) list), 1), 2), 1);
  }

  ATabort("CharRanges has no List: %t\n", arg);
  return (PTPT_CharRanges)NULL;
}

/**
 * Set the ws-after-list of a PTPT_CharRanges. The precondition being that this PTPT_CharRanges actually has a ws-after-list
 * \param[in] arg input PTPT_CharRanges
 * \param[in] wsAfterList new PTPT_OptLayout to set in #arg
 * \return A new PTPT_CharRanges with wsAfterList at the right place, or a core dump if #arg did not have a wsAfterList
 */
PTPT_CharRanges PTPT_setCharRangesWsAfterList(PTPT_CharRanges arg, PTPT_OptLayout wsAfterList) {
  if (PTPT_isCharRangesList(arg)) {
    return (PTPT_CharRanges)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterList), 3), 1);
  }

  ATabort("CharRanges has no WsAfterList: %t\n", arg);
  return (PTPT_CharRanges)NULL;
}

/**
 * Assert whether a PTPT_CharRange is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input PTPT_CharRange
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool PTPT_isValidCharRange(PTPT_CharRange arg) {
  if (PTPT_isCharRangeCharacter(arg)) {
    return ATtrue;
  }
  else if (PTPT_isCharRangeRange(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_CharRange is a character by checking against the following ATerm pattern: appl(prod([cf(sort("NatCon"))],cf(sort("CharRange")),attrs([term(cons("character"))])),[<"integer"("NatCon")>]). May not be used to assert correctness of the PTPT_CharRange
 * \param[in] arg input PTPT_CharRange
 * \return ATtrue if #arg corresponds to the signature of a character, or ATfalse otherwise
 */
inline ATbool PTPT_isCharRangeCharacter(PTPT_CharRange arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == PTPT_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == PTPT_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: cf */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: sort */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun9) {
            ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
            /* checking for: NatCon */
            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun24) {
              if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                /* checking for: cf */
                if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == PTPT_afun2) {
                  ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                  /* checking for: sort */
                  if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == PTPT_afun9) {
                    ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                    /* checking for: CharRange */
                    if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == PTPT_afun80) {
                      ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                      /* checking for: attrs */
                      if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == PTPT_afun12) {
                        ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                        if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                          ATerm arg_arg0_arg2_arg0_head;
                          ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                          arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                          arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                          /* checking for: term */
                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == PTPT_afun13) {
                            ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                            /* checking for: cons */
                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == PTPT_afun14) {
                              ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                              /* checking for: character */
                              if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == PTPT_afun81) {
                                if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                  ATerm arg_arg1 = ATgetArgument(arg, 1);
                                  if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                    ATermList arg_arg1_list = (ATermList)arg_arg1;
                                    arg_arg1_list = ATgetNext(arg_arg1_list);
                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                      return ATtrue;
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_CharRange is a range by checking against the following ATerm pattern: appl(prod([lit("range"),cf(opt(layout)),lit("("),cf(opt(layout)),cf(sort("NatCon")),cf(opt(layout)),lit(","),cf(opt(layout)),cf(sort("NatCon")),cf(opt(layout)),lit(")")],cf(sort("CharRange")),attrs([term(cons("range"))])),[appl(prod([char-class([114]),char-class([97]),char-class([110]),char-class([103]),char-class([101])],lit("range"),no-attrs),[114,97,110,103,101]),<"ws-after-range"("OptLayout")>,appl(prod([char-class([40])],lit("("),no-attrs),[40]),<"ws-after-("("OptLayout")>,<"start"("NatCon")>,<"ws-after-start"("OptLayout")>,appl(prod([char-class([44])],lit(","),no-attrs),[44]),<"ws-after-,"("OptLayout")>,<"end"("NatCon")>,<"ws-after-end"("OptLayout")>,appl(prod([char-class([41])],lit(")"),no-attrs),[41])]). May not be used to assert correctness of the PTPT_CharRange
 * \param[in] arg input PTPT_CharRange
 * \return ATtrue if #arg corresponds to the signature of a range, or ATfalse otherwise
 */
inline ATbool PTPT_isCharRangeRange(PTPT_CharRange arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == PTPT_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == PTPT_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lit */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: range */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun82) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
              /* checking for: cf */
              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                /* checking for: opt */
                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                  /* checking for: layout */
                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                      arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                      arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                      /* checking for: lit */
                      if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
                        ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                        /* checking for: ( */
                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun21) {
                          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                            arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                            arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                            /* checking for: cf */
                            if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                              ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                              /* checking for: opt */
                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                /* checking for: layout */
                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                  if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                    arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                    arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                    /* checking for: cf */
                                    if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                      ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                      /* checking for: sort */
                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun9) {
                                        ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                        /* checking for: NatCon */
                                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun24) {
                                          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                            arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                            arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                            /* checking for: cf */
                                            if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                              ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                              /* checking for: opt */
                                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                                ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                /* checking for: layout */
                                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                                  if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                    arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                    arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                    /* checking for: lit */
                                                    if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
                                                      ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                      /* checking for: , */
                                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun19) {
                                                        if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                          arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                          arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                          /* checking for: cf */
                                                          if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                                            ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                            /* checking for: opt */
                                                            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                                              ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                              /* checking for: layout */
                                                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                                                if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                                  arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                                  arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                                  /* checking for: cf */
                                                                  if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                                                    ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                                    /* checking for: sort */
                                                                    if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun9) {
                                                                      ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                                      /* checking for: NatCon */
                                                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun24) {
                                                                        if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                                          arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                                          arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                                          /* checking for: cf */
                                                                          if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                                                            ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                                            /* checking for: opt */
                                                                            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                                                              ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                                              /* checking for: layout */
                                                                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                                                                if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                                                  arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                                                  arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                                                  /* checking for: lit */
                                                                                  if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
                                                                                    ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                                                    /* checking for: ) */
                                                                                    if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun17) {
                                                                                      if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                                                                                        ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                                                                        /* checking for: cf */
                                                                                        if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == PTPT_afun2) {
                                                                                          ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                                                                          /* checking for: sort */
                                                                                          if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == PTPT_afun9) {
                                                                                            ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                                                                            /* checking for: CharRange */
                                                                                            if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == PTPT_afun80) {
                                                                                              ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                                                                              /* checking for: attrs */
                                                                                              if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == PTPT_afun12) {
                                                                                                ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                                                                                if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                                                                                  ATerm arg_arg0_arg2_arg0_head;
                                                                                                  ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                                                                                  arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                                                                                  arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                                                                                  /* checking for: term */
                                                                                                  if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == PTPT_afun13) {
                                                                                                    ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                                                                                    /* checking for: cons */
                                                                                                    if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == PTPT_afun14) {
                                                                                                      ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                                                                                      /* checking for: range */
                                                                                                      if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == PTPT_afun82) {
                                                                                                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                                                                          ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                                                                          if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                                                                            ATerm arg_arg1_head;
                                                                                                            ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                                                                            arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                            arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                            /* checking for: appl */
                                                                                                            if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                              ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                              /* checking for: prod */
                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                                                ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                  ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                  arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                  arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                  /* checking for: char-class */
                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                      ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 114) {

                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                            arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                            arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                            /* checking for: char-class */
                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 97) {

                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                      arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                      arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                      /* checking for: char-class */
                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                          ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                          arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                          arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 110) {

                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                                arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                /* checking for: char-class */
                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                    ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                    arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                    arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 103) {

                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                                          arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                          arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                          /* checking for: char-class */
                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                              ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                              arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                              arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 101) {

                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                    ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                                    /* checking for: lit */
                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                                                      ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                      /* checking for: range */
                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun82) {
                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                        /* checking for: no-attrs */
                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                                          ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                            ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                            ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                            arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                            arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 114) {

                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 97) {

                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                    arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                    arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 110) {

                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                        arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                        arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 103) {

                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                            arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                            arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 101) {

                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                    arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                                                                                    arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                    /* checking for: appl */
                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                                                                                                                      ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                                                                                                      /* checking for: prod */
                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                                                                                          ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                                                                                          ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                                                                                          arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                          arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                          /* checking for: char-class */
                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                                              ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                                              arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                              arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 40) {

                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                                                                    ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                                                                                    /* checking for: lit */
                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                                                                                                      ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                                                                      /* checking for: ( */
                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun21) {
                                                                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                                                                        /* checking for: no-attrs */
                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                                                                                          ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                                                                            ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                                                                            ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                                                                            arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                            arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 40) {

                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                    arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                      arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                        arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                                                                                                                        arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                        /* checking for: appl */
                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                                                                                                                                                          ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                                                                                                                                          /* checking for: prod */
                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                                                                                                                                                                            ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                                                                                                                              ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                                                                                                                              ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                                                                                                                              arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                              arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                              /* checking for: char-class */
                                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                                                                                  ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 44) {

                                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                                                                                                                        /* checking for: lit */
                                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                                                                                                                                          ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                                                                                                          /* checking for: , */
                                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun19) {
                                                                                                                                                                                                                                                            ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                                                                                                            /* checking for: no-attrs */
                                                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                                                                                                                              ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                                                                                                                ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                                                                                                                ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                                                                                                                arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 44) {

                                                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                      arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                        arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                          arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                            arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                                                                                                                                                            arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                                            /* checking for: appl */
                                                                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                                                                                                                                                                                              ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                                                                                                                                                                              /* checking for: prod */
                                                                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                                                                                                                                                                                                                ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                                                                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                                                                                                                                                                  ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                                                                                                                                                                  arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                                                                  arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                                                                  /* checking for: char-class */
                                                                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                                                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                                                                                                                      ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 41) {

                                                                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                                                                            ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                                                                                                                                                            /* checking for: lit */
                                                                                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                                                                                                                                                                              ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                                                                                                                                              /* checking for: ) */
                                                                                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun17) {
                                                                                                                                                                                                                                                                                                ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                                                                                                                                                /* checking for: no-attrs */
                                                                                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                                                                                                                                                                  ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                                                                                                                                                    ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                                                                                                                                                    ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                                                                                                                                                    arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                                    arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 41) {

                                                                                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                                                                                                                                                                                                                          return ATtrue;
                                                                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                }
                                                                                                                                                                                                                              }
                                                                                                                                                                                                                            }
                                                                                                                                                                                                                          }
                                                                                                                                                                                                                        }
                                                                                                                                                                                                                      }
                                                                                                                                                                                                                    }
                                                                                                                                                                                                                  }
                                                                                                                                                                                                                }
                                                                                                                                                                                                              }
                                                                                                                                                                                                            }
                                                                                                                                                                                                          }
                                                                                                                                                                                                        }
                                                                                                                                                                                                      }
                                                                                                                                                                                                    }
                                                                                                                                                                                                  }
                                                                                                                                                                                                }
                                                                                                                                                                                              }
                                                                                                                                                                                            }
                                                                                                                                                                                          }
                                                                                                                                                                                        }
                                                                                                                                                                                      }
                                                                                                                                                                                    }
                                                                                                                                                                                  }
                                                                                                                                                                                }
                                                                                                                                                                              }
                                                                                                                                                                            }
                                                                                                                                                                          }
                                                                                                                                                                        }
                                                                                                                                                                      }
                                                                                                                                                                    }
                                                                                                                                                                  }
                                                                                                                                                                }
                                                                                                                                                              }
                                                                                                                                                            }
                                                                                                                                                          }
                                                                                                                                                        }
                                                                                                                                                      }
                                                                                                                                                    }
                                                                                                                                                  }
                                                                                                                                                }
                                                                                                                                              }
                                                                                                                                            }
                                                                                                                                          }
                                                                                                                                        }
                                                                                                                                      }
                                                                                                                                    }
                                                                                                                                  }
                                                                                                                                }
                                                                                                                              }
                                                                                                                            }
                                                                                                                          }
                                                                                                                        }
                                                                                                                      }
                                                                                                                    }
                                                                                                                  }
                                                                                                                }
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_CharRange has a integer. 
 * \param[in] arg input PTPT_CharRange
 * \return ATtrue if the PTPT_CharRange had a integer, or ATfalse otherwise
 */
ATbool PTPT_hasCharRangeInteger(PTPT_CharRange arg) {
  if (PTPT_isCharRangeCharacter(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_CharRange has a ws-after-range. 
 * \param[in] arg input PTPT_CharRange
 * \return ATtrue if the PTPT_CharRange had a ws-after-range, or ATfalse otherwise
 */
ATbool PTPT_hasCharRangeWsAfterRange(PTPT_CharRange arg) {
  if (PTPT_isCharRangeRange(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_CharRange has a ws-after-(. 
 * \param[in] arg input PTPT_CharRange
 * \return ATtrue if the PTPT_CharRange had a ws-after-(, or ATfalse otherwise
 */
ATbool PTPT_hasCharRangeWsAfterParenOpen(PTPT_CharRange arg) {
  if (PTPT_isCharRangeRange(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_CharRange has a start. 
 * \param[in] arg input PTPT_CharRange
 * \return ATtrue if the PTPT_CharRange had a start, or ATfalse otherwise
 */
ATbool PTPT_hasCharRangeStart(PTPT_CharRange arg) {
  if (PTPT_isCharRangeRange(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_CharRange has a ws-after-start. 
 * \param[in] arg input PTPT_CharRange
 * \return ATtrue if the PTPT_CharRange had a ws-after-start, or ATfalse otherwise
 */
ATbool PTPT_hasCharRangeWsAfterStart(PTPT_CharRange arg) {
  if (PTPT_isCharRangeRange(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_CharRange has a ws-after-,. 
 * \param[in] arg input PTPT_CharRange
 * \return ATtrue if the PTPT_CharRange had a ws-after-,, or ATfalse otherwise
 */
ATbool PTPT_hasCharRangeWsAfterComma(PTPT_CharRange arg) {
  if (PTPT_isCharRangeRange(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_CharRange has a end. 
 * \param[in] arg input PTPT_CharRange
 * \return ATtrue if the PTPT_CharRange had a end, or ATfalse otherwise
 */
ATbool PTPT_hasCharRangeEnd(PTPT_CharRange arg) {
  if (PTPT_isCharRangeRange(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_CharRange has a ws-after-end. 
 * \param[in] arg input PTPT_CharRange
 * \return ATtrue if the PTPT_CharRange had a ws-after-end, or ATfalse otherwise
 */
ATbool PTPT_hasCharRangeWsAfterEnd(PTPT_CharRange arg) {
  if (PTPT_isCharRangeRange(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Get the integer PTPT_NatCon of a PTPT_CharRange. Note that the precondition is that this PTPT_CharRange actually has a integer
 * \param[in] arg input PTPT_CharRange
 * \return the integer of #arg, if it exist or an undefined value if it does not
 */
PTPT_NatCon PTPT_getCharRangeInteger(PTPT_CharRange arg) {
  
    return (PTPT_NatCon)ATgetFirst((ATermList)ATgetArgument((ATermAppl)arg, 1));
}

/**
 * Get the ws-after-range PTPT_OptLayout of a PTPT_CharRange. Note that the precondition is that this PTPT_CharRange actually has a ws-after-range
 * \param[in] arg input PTPT_CharRange
 * \return the ws-after-range of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getCharRangeWsAfterRange(PTPT_CharRange arg) {
  
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1);
}

/**
 * Get the ws-after-( PTPT_OptLayout of a PTPT_CharRange. Note that the precondition is that this PTPT_CharRange actually has a ws-after-(
 * \param[in] arg input PTPT_CharRange
 * \return the ws-after-( of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getCharRangeWsAfterParenOpen(PTPT_CharRange arg) {
  
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 3);
}

/**
 * Get the start PTPT_NatCon of a PTPT_CharRange. Note that the precondition is that this PTPT_CharRange actually has a start
 * \param[in] arg input PTPT_CharRange
 * \return the start of #arg, if it exist or an undefined value if it does not
 */
PTPT_NatCon PTPT_getCharRangeStart(PTPT_CharRange arg) {
  
    return (PTPT_NatCon)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 4);
}

/**
 * Get the ws-after-start PTPT_OptLayout of a PTPT_CharRange. Note that the precondition is that this PTPT_CharRange actually has a ws-after-start
 * \param[in] arg input PTPT_CharRange
 * \return the ws-after-start of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getCharRangeWsAfterStart(PTPT_CharRange arg) {
  
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 5);
}

/**
 * Get the ws-after-, PTPT_OptLayout of a PTPT_CharRange. Note that the precondition is that this PTPT_CharRange actually has a ws-after-,
 * \param[in] arg input PTPT_CharRange
 * \return the ws-after-, of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getCharRangeWsAfterComma(PTPT_CharRange arg) {
  
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 7);
}

/**
 * Get the end PTPT_NatCon of a PTPT_CharRange. Note that the precondition is that this PTPT_CharRange actually has a end
 * \param[in] arg input PTPT_CharRange
 * \return the end of #arg, if it exist or an undefined value if it does not
 */
PTPT_NatCon PTPT_getCharRangeEnd(PTPT_CharRange arg) {
  
    return (PTPT_NatCon)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 8);
}

/**
 * Get the ws-after-end PTPT_OptLayout of a PTPT_CharRange. Note that the precondition is that this PTPT_CharRange actually has a ws-after-end
 * \param[in] arg input PTPT_CharRange
 * \return the ws-after-end of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getCharRangeWsAfterEnd(PTPT_CharRange arg) {
  
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 9);
}

/**
 * Set the integer of a PTPT_CharRange. The precondition being that this PTPT_CharRange actually has a integer
 * \param[in] arg input PTPT_CharRange
 * \param[in] integer new PTPT_NatCon to set in #arg
 * \return A new PTPT_CharRange with integer at the right place, or a core dump if #arg did not have a integer
 */
PTPT_CharRange PTPT_setCharRangeInteger(PTPT_CharRange arg, PTPT_NatCon integer) {
  if (PTPT_isCharRangeCharacter(arg)) {
    return (PTPT_CharRange)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) integer), 0), 1);
  }

  ATabort("CharRange has no Integer: %t\n", arg);
  return (PTPT_CharRange)NULL;
}

/**
 * Set the ws-after-range of a PTPT_CharRange. The precondition being that this PTPT_CharRange actually has a ws-after-range
 * \param[in] arg input PTPT_CharRange
 * \param[in] wsAfterRange new PTPT_OptLayout to set in #arg
 * \return A new PTPT_CharRange with wsAfterRange at the right place, or a core dump if #arg did not have a wsAfterRange
 */
PTPT_CharRange PTPT_setCharRangeWsAfterRange(PTPT_CharRange arg, PTPT_OptLayout wsAfterRange) {
  if (PTPT_isCharRangeRange(arg)) {
    return (PTPT_CharRange)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterRange), 1), 1);
  }

  ATabort("CharRange has no WsAfterRange: %t\n", arg);
  return (PTPT_CharRange)NULL;
}

/**
 * Set the ws-after-( of a PTPT_CharRange. The precondition being that this PTPT_CharRange actually has a ws-after-(
 * \param[in] arg input PTPT_CharRange
 * \param[in] wsAfterParenOpen new PTPT_OptLayout to set in #arg
 * \return A new PTPT_CharRange with wsAfterParenOpen at the right place, or a core dump if #arg did not have a wsAfterParenOpen
 */
PTPT_CharRange PTPT_setCharRangeWsAfterParenOpen(PTPT_CharRange arg, PTPT_OptLayout wsAfterParenOpen) {
  if (PTPT_isCharRangeRange(arg)) {
    return (PTPT_CharRange)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterParenOpen), 3), 1);
  }

  ATabort("CharRange has no WsAfterParenOpen: %t\n", arg);
  return (PTPT_CharRange)NULL;
}

/**
 * Set the start of a PTPT_CharRange. The precondition being that this PTPT_CharRange actually has a start
 * \param[in] arg input PTPT_CharRange
 * \param[in] start new PTPT_NatCon to set in #arg
 * \return A new PTPT_CharRange with start at the right place, or a core dump if #arg did not have a start
 */
PTPT_CharRange PTPT_setCharRangeStart(PTPT_CharRange arg, PTPT_NatCon start) {
  if (PTPT_isCharRangeRange(arg)) {
    return (PTPT_CharRange)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) start), 4), 1);
  }

  ATabort("CharRange has no Start: %t\n", arg);
  return (PTPT_CharRange)NULL;
}

/**
 * Set the ws-after-start of a PTPT_CharRange. The precondition being that this PTPT_CharRange actually has a ws-after-start
 * \param[in] arg input PTPT_CharRange
 * \param[in] wsAfterStart new PTPT_OptLayout to set in #arg
 * \return A new PTPT_CharRange with wsAfterStart at the right place, or a core dump if #arg did not have a wsAfterStart
 */
PTPT_CharRange PTPT_setCharRangeWsAfterStart(PTPT_CharRange arg, PTPT_OptLayout wsAfterStart) {
  if (PTPT_isCharRangeRange(arg)) {
    return (PTPT_CharRange)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterStart), 5), 1);
  }

  ATabort("CharRange has no WsAfterStart: %t\n", arg);
  return (PTPT_CharRange)NULL;
}

/**
 * Set the ws-after-, of a PTPT_CharRange. The precondition being that this PTPT_CharRange actually has a ws-after-,
 * \param[in] arg input PTPT_CharRange
 * \param[in] wsAfterComma new PTPT_OptLayout to set in #arg
 * \return A new PTPT_CharRange with wsAfterComma at the right place, or a core dump if #arg did not have a wsAfterComma
 */
PTPT_CharRange PTPT_setCharRangeWsAfterComma(PTPT_CharRange arg, PTPT_OptLayout wsAfterComma) {
  if (PTPT_isCharRangeRange(arg)) {
    return (PTPT_CharRange)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterComma), 7), 1);
  }

  ATabort("CharRange has no WsAfterComma: %t\n", arg);
  return (PTPT_CharRange)NULL;
}

/**
 * Set the end of a PTPT_CharRange. The precondition being that this PTPT_CharRange actually has a end
 * \param[in] arg input PTPT_CharRange
 * \param[in] end new PTPT_NatCon to set in #arg
 * \return A new PTPT_CharRange with end at the right place, or a core dump if #arg did not have a end
 */
PTPT_CharRange PTPT_setCharRangeEnd(PTPT_CharRange arg, PTPT_NatCon end) {
  if (PTPT_isCharRangeRange(arg)) {
    return (PTPT_CharRange)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) end), 8), 1);
  }

  ATabort("CharRange has no End: %t\n", arg);
  return (PTPT_CharRange)NULL;
}

/**
 * Set the ws-after-end of a PTPT_CharRange. The precondition being that this PTPT_CharRange actually has a ws-after-end
 * \param[in] arg input PTPT_CharRange
 * \param[in] wsAfterEnd new PTPT_OptLayout to set in #arg
 * \return A new PTPT_CharRange with wsAfterEnd at the right place, or a core dump if #arg did not have a wsAfterEnd
 */
PTPT_CharRange PTPT_setCharRangeWsAfterEnd(PTPT_CharRange arg, PTPT_OptLayout wsAfterEnd) {
  if (PTPT_isCharRangeRange(arg)) {
    return (PTPT_CharRange)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterEnd), 9), 1);
  }

  ATabort("CharRange has no WsAfterEnd: %t\n", arg);
  return (PTPT_CharRange)NULL;
}

/**
 * Assert whether a PTPT_Start is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input PTPT_Start
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool PTPT_isValidStart(PTPT_Start arg) {
  if (PTPT_isStartSymbol(arg)) {
    return ATtrue;
  }
  else if (PTPT_isStartTree(arg)) {
    return ATtrue;
  }
  else if (PTPT_isStartATerm(arg)) {
    return ATtrue;
  }
  else if (PTPT_isStartIntCon(arg)) {
    return ATtrue;
  }
  else if (PTPT_isStartRealCon(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Start is a Symbol by checking against the following ATerm pattern: parsetree(appl(prod([cf(opt(layout)),cf(sort("Symbol")),cf(opt(layout))],sort("<START>"),no-attrs),[<"ws-before"("OptLayout")>,<"top-Symbol"("Symbol")>,<"ws-after"("OptLayout")>]),<amb-cnt(int)>). May not be used to assert correctness of the PTPT_Start
 * \param[in] arg input PTPT_Start
 * \return ATtrue if #arg corresponds to the signature of a Symbol, or ATfalse otherwise
 */
inline ATbool PTPT_isStartSymbol(PTPT_Start arg){
  /* checking for: parsetree */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == PTPT_afun83) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: appl */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == PTPT_afun0) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      /* checking for: prod */
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0) == PTPT_afun1) {
        ATerm arg_arg0_arg0_arg0 = ATgetArgument(arg_arg0_arg0, 0);
        if (ATgetType((ATerm)arg_arg0_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_arg0) == ATfalse) {
          ATerm arg_arg0_arg0_arg0_head;
          ATermList arg_arg0_arg0_arg0_list = (ATermList)arg_arg0_arg0_arg0;
          arg_arg0_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_arg0_list);
          arg_arg0_arg0_arg0_list = ATgetNext(arg_arg0_arg0_arg0_list);
          /* checking for: cf */
          if (ATgetType((ATerm)arg_arg0_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_arg0_head) == PTPT_afun2) {
            ATerm arg_arg0_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_arg0_head, 0);
            /* checking for: opt */
            if (ATgetType((ATerm)arg_arg0_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_arg0_head_arg0) == PTPT_afun3) {
              ATerm arg_arg0_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_arg0_head_arg0, 0);
              /* checking for: layout */
              if (ATgetType((ATerm)arg_arg0_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                if (ATgetType((ATerm)arg_arg0_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_arg0_list) == ATfalse) {
                  arg_arg0_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_arg0_list);
                  arg_arg0_arg0_arg0_list = ATgetNext(arg_arg0_arg0_arg0_list);
                  /* checking for: cf */
                  if (ATgetType((ATerm)arg_arg0_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_arg0_head) == PTPT_afun2) {
                    ATerm arg_arg0_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_arg0_head, 0);
                    /* checking for: sort */
                    if (ATgetType((ATerm)arg_arg0_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_arg0_head_arg0) == PTPT_afun9) {
                      ATerm arg_arg0_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_arg0_head_arg0, 0);
                      /* checking for: Symbol */
                      if (ATgetType((ATerm)arg_arg0_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_arg0_head_arg0_arg0) == PTPT_afun25) {
                        if (ATgetType((ATerm)arg_arg0_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_arg0_list) == ATfalse) {
                          arg_arg0_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_arg0_list);
                          arg_arg0_arg0_arg0_list = ATgetNext(arg_arg0_arg0_arg0_list);
                          /* checking for: cf */
                          if (ATgetType((ATerm)arg_arg0_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_arg0_head) == PTPT_afun2) {
                            ATerm arg_arg0_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_arg0_head, 0);
                            /* checking for: opt */
                            if (ATgetType((ATerm)arg_arg0_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_arg0_head_arg0) == PTPT_afun3) {
                              ATerm arg_arg0_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_arg0_head_arg0, 0);
                              /* checking for: layout */
                              if (ATgetType((ATerm)arg_arg0_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                if (ATgetType((ATerm)arg_arg0_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_arg0_list) == ATtrue) {
                                  ATerm arg_arg0_arg0_arg1 = ATgetArgument(arg_arg0_arg0, 1);
                                  /* checking for: sort */
                                  if (ATgetType((ATerm)arg_arg0_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_arg1) == PTPT_afun9) {
                                    ATerm arg_arg0_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg0_arg1, 0);
                                    /* checking for: <START> */
                                    if (ATgetType((ATerm)arg_arg0_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_arg1_arg0) == PTPT_afun84) {
                                      ATerm arg_arg0_arg0_arg2 = ATgetArgument(arg_arg0_arg0, 2);
                                      /* checking for: no-attrs */
                                      if (ATgetType((ATerm)arg_arg0_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_arg2) == PTPT_afun5) {
                                        ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                        if (ATgetType((ATerm)arg_arg0_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg1) == ATfalse) {
                                          ATermList arg_arg0_arg1_list = (ATermList)arg_arg0_arg1;
                                          arg_arg0_arg1_list = ATgetNext(arg_arg0_arg1_list);
                                          if (ATgetType((ATerm)arg_arg0_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg1_list) == ATfalse) {
                                            arg_arg0_arg1_list = ATgetNext(arg_arg0_arg1_list);
                                            if (ATgetType((ATerm)arg_arg0_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg1_list) == ATfalse) {
                                              arg_arg0_arg1_list = ATgetNext(arg_arg0_arg1_list);
                                              if (ATgetType((ATerm)arg_arg0_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg1_list) == ATtrue) {
                                                ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                if (ATgetType((ATerm)arg_arg1) == AT_INT) {
                                                  return ATtrue;
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Start is a Tree by checking against the following ATerm pattern: parsetree(appl(prod([cf(opt(layout)),cf(sort("Tree")),cf(opt(layout))],sort("<START>"),no-attrs),[<"ws-before"("OptLayout")>,<"top-Tree"("Tree")>,<"ws-after"("OptLayout")>]),<amb-cnt(int)>). May not be used to assert correctness of the PTPT_Start
 * \param[in] arg input PTPT_Start
 * \return ATtrue if #arg corresponds to the signature of a Tree, or ATfalse otherwise
 */
inline ATbool PTPT_isStartTree(PTPT_Start arg){
  /* checking for: parsetree */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == PTPT_afun83) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: appl */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == PTPT_afun0) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      /* checking for: prod */
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0) == PTPT_afun1) {
        ATerm arg_arg0_arg0_arg0 = ATgetArgument(arg_arg0_arg0, 0);
        if (ATgetType((ATerm)arg_arg0_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_arg0) == ATfalse) {
          ATerm arg_arg0_arg0_arg0_head;
          ATermList arg_arg0_arg0_arg0_list = (ATermList)arg_arg0_arg0_arg0;
          arg_arg0_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_arg0_list);
          arg_arg0_arg0_arg0_list = ATgetNext(arg_arg0_arg0_arg0_list);
          /* checking for: cf */
          if (ATgetType((ATerm)arg_arg0_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_arg0_head) == PTPT_afun2) {
            ATerm arg_arg0_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_arg0_head, 0);
            /* checking for: opt */
            if (ATgetType((ATerm)arg_arg0_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_arg0_head_arg0) == PTPT_afun3) {
              ATerm arg_arg0_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_arg0_head_arg0, 0);
              /* checking for: layout */
              if (ATgetType((ATerm)arg_arg0_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                if (ATgetType((ATerm)arg_arg0_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_arg0_list) == ATfalse) {
                  arg_arg0_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_arg0_list);
                  arg_arg0_arg0_arg0_list = ATgetNext(arg_arg0_arg0_arg0_list);
                  /* checking for: cf */
                  if (ATgetType((ATerm)arg_arg0_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_arg0_head) == PTPT_afun2) {
                    ATerm arg_arg0_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_arg0_head, 0);
                    /* checking for: sort */
                    if (ATgetType((ATerm)arg_arg0_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_arg0_head_arg0) == PTPT_afun9) {
                      ATerm arg_arg0_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_arg0_head_arg0, 0);
                      /* checking for: Tree */
                      if (ATgetType((ATerm)arg_arg0_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_arg0_head_arg0_arg0) == PTPT_afun11) {
                        if (ATgetType((ATerm)arg_arg0_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_arg0_list) == ATfalse) {
                          arg_arg0_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_arg0_list);
                          arg_arg0_arg0_arg0_list = ATgetNext(arg_arg0_arg0_arg0_list);
                          /* checking for: cf */
                          if (ATgetType((ATerm)arg_arg0_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_arg0_head) == PTPT_afun2) {
                            ATerm arg_arg0_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_arg0_head, 0);
                            /* checking for: opt */
                            if (ATgetType((ATerm)arg_arg0_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_arg0_head_arg0) == PTPT_afun3) {
                              ATerm arg_arg0_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_arg0_head_arg0, 0);
                              /* checking for: layout */
                              if (ATgetType((ATerm)arg_arg0_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                if (ATgetType((ATerm)arg_arg0_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_arg0_list) == ATtrue) {
                                  ATerm arg_arg0_arg0_arg1 = ATgetArgument(arg_arg0_arg0, 1);
                                  /* checking for: sort */
                                  if (ATgetType((ATerm)arg_arg0_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_arg1) == PTPT_afun9) {
                                    ATerm arg_arg0_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg0_arg1, 0);
                                    /* checking for: <START> */
                                    if (ATgetType((ATerm)arg_arg0_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_arg1_arg0) == PTPT_afun84) {
                                      ATerm arg_arg0_arg0_arg2 = ATgetArgument(arg_arg0_arg0, 2);
                                      /* checking for: no-attrs */
                                      if (ATgetType((ATerm)arg_arg0_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_arg2) == PTPT_afun5) {
                                        ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                        if (ATgetType((ATerm)arg_arg0_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg1) == ATfalse) {
                                          ATermList arg_arg0_arg1_list = (ATermList)arg_arg0_arg1;
                                          arg_arg0_arg1_list = ATgetNext(arg_arg0_arg1_list);
                                          if (ATgetType((ATerm)arg_arg0_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg1_list) == ATfalse) {
                                            arg_arg0_arg1_list = ATgetNext(arg_arg0_arg1_list);
                                            if (ATgetType((ATerm)arg_arg0_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg1_list) == ATfalse) {
                                              arg_arg0_arg1_list = ATgetNext(arg_arg0_arg1_list);
                                              if (ATgetType((ATerm)arg_arg0_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg1_list) == ATtrue) {
                                                ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                if (ATgetType((ATerm)arg_arg1) == AT_INT) {
                                                  return ATtrue;
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Start is a ATerm by checking against the following ATerm pattern: parsetree(appl(prod([cf(opt(layout)),cf(sort("ATerm")),cf(opt(layout))],sort("<START>"),no-attrs),[<"ws-before"("OptLayout")>,<"top-ATerm"("ATerm")>,<"ws-after"("OptLayout")>]),<amb-cnt(int)>). May not be used to assert correctness of the PTPT_Start
 * \param[in] arg input PTPT_Start
 * \return ATtrue if #arg corresponds to the signature of a ATerm, or ATfalse otherwise
 */
inline ATbool PTPT_isStartATerm(PTPT_Start arg){
  /* checking for: parsetree */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == PTPT_afun83) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: appl */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == PTPT_afun0) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      /* checking for: prod */
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0) == PTPT_afun1) {
        ATerm arg_arg0_arg0_arg0 = ATgetArgument(arg_arg0_arg0, 0);
        if (ATgetType((ATerm)arg_arg0_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_arg0) == ATfalse) {
          ATerm arg_arg0_arg0_arg0_head;
          ATermList arg_arg0_arg0_arg0_list = (ATermList)arg_arg0_arg0_arg0;
          arg_arg0_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_arg0_list);
          arg_arg0_arg0_arg0_list = ATgetNext(arg_arg0_arg0_arg0_list);
          /* checking for: cf */
          if (ATgetType((ATerm)arg_arg0_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_arg0_head) == PTPT_afun2) {
            ATerm arg_arg0_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_arg0_head, 0);
            /* checking for: opt */
            if (ATgetType((ATerm)arg_arg0_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_arg0_head_arg0) == PTPT_afun3) {
              ATerm arg_arg0_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_arg0_head_arg0, 0);
              /* checking for: layout */
              if (ATgetType((ATerm)arg_arg0_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                if (ATgetType((ATerm)arg_arg0_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_arg0_list) == ATfalse) {
                  arg_arg0_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_arg0_list);
                  arg_arg0_arg0_arg0_list = ATgetNext(arg_arg0_arg0_arg0_list);
                  /* checking for: cf */
                  if (ATgetType((ATerm)arg_arg0_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_arg0_head) == PTPT_afun2) {
                    ATerm arg_arg0_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_arg0_head, 0);
                    /* checking for: sort */
                    if (ATgetType((ATerm)arg_arg0_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_arg0_head_arg0) == PTPT_afun9) {
                      ATerm arg_arg0_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_arg0_head_arg0, 0);
                      /* checking for: ATerm */
                      if (ATgetType((ATerm)arg_arg0_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_arg0_head_arg0_arg0) == PTPT_afun40) {
                        if (ATgetType((ATerm)arg_arg0_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_arg0_list) == ATfalse) {
                          arg_arg0_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_arg0_list);
                          arg_arg0_arg0_arg0_list = ATgetNext(arg_arg0_arg0_arg0_list);
                          /* checking for: cf */
                          if (ATgetType((ATerm)arg_arg0_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_arg0_head) == PTPT_afun2) {
                            ATerm arg_arg0_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_arg0_head, 0);
                            /* checking for: opt */
                            if (ATgetType((ATerm)arg_arg0_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_arg0_head_arg0) == PTPT_afun3) {
                              ATerm arg_arg0_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_arg0_head_arg0, 0);
                              /* checking for: layout */
                              if (ATgetType((ATerm)arg_arg0_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                if (ATgetType((ATerm)arg_arg0_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_arg0_list) == ATtrue) {
                                  ATerm arg_arg0_arg0_arg1 = ATgetArgument(arg_arg0_arg0, 1);
                                  /* checking for: sort */
                                  if (ATgetType((ATerm)arg_arg0_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_arg1) == PTPT_afun9) {
                                    ATerm arg_arg0_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg0_arg1, 0);
                                    /* checking for: <START> */
                                    if (ATgetType((ATerm)arg_arg0_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_arg1_arg0) == PTPT_afun84) {
                                      ATerm arg_arg0_arg0_arg2 = ATgetArgument(arg_arg0_arg0, 2);
                                      /* checking for: no-attrs */
                                      if (ATgetType((ATerm)arg_arg0_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_arg2) == PTPT_afun5) {
                                        ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                        if (ATgetType((ATerm)arg_arg0_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg1) == ATfalse) {
                                          ATermList arg_arg0_arg1_list = (ATermList)arg_arg0_arg1;
                                          arg_arg0_arg1_list = ATgetNext(arg_arg0_arg1_list);
                                          if (ATgetType((ATerm)arg_arg0_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg1_list) == ATfalse) {
                                            arg_arg0_arg1_list = ATgetNext(arg_arg0_arg1_list);
                                            if (ATgetType((ATerm)arg_arg0_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg1_list) == ATfalse) {
                                              arg_arg0_arg1_list = ATgetNext(arg_arg0_arg1_list);
                                              if (ATgetType((ATerm)arg_arg0_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg1_list) == ATtrue) {
                                                ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                if (ATgetType((ATerm)arg_arg1) == AT_INT) {
                                                  return ATtrue;
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Start is a IntCon by checking against the following ATerm pattern: parsetree(appl(prod([cf(opt(layout)),cf(sort("IntCon")),cf(opt(layout))],sort("<START>"),no-attrs),[<"ws-before"("OptLayout")>,<"top-IntCon"("IntCon")>,<"ws-after"("OptLayout")>]),<amb-cnt(int)>). May not be used to assert correctness of the PTPT_Start
 * \param[in] arg input PTPT_Start
 * \return ATtrue if #arg corresponds to the signature of a IntCon, or ATfalse otherwise
 */
inline ATbool PTPT_isStartIntCon(PTPT_Start arg){
  /* checking for: parsetree */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == PTPT_afun83) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: appl */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == PTPT_afun0) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      /* checking for: prod */
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0) == PTPT_afun1) {
        ATerm arg_arg0_arg0_arg0 = ATgetArgument(arg_arg0_arg0, 0);
        if (ATgetType((ATerm)arg_arg0_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_arg0) == ATfalse) {
          ATerm arg_arg0_arg0_arg0_head;
          ATermList arg_arg0_arg0_arg0_list = (ATermList)arg_arg0_arg0_arg0;
          arg_arg0_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_arg0_list);
          arg_arg0_arg0_arg0_list = ATgetNext(arg_arg0_arg0_arg0_list);
          /* checking for: cf */
          if (ATgetType((ATerm)arg_arg0_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_arg0_head) == PTPT_afun2) {
            ATerm arg_arg0_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_arg0_head, 0);
            /* checking for: opt */
            if (ATgetType((ATerm)arg_arg0_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_arg0_head_arg0) == PTPT_afun3) {
              ATerm arg_arg0_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_arg0_head_arg0, 0);
              /* checking for: layout */
              if (ATgetType((ATerm)arg_arg0_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                if (ATgetType((ATerm)arg_arg0_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_arg0_list) == ATfalse) {
                  arg_arg0_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_arg0_list);
                  arg_arg0_arg0_arg0_list = ATgetNext(arg_arg0_arg0_arg0_list);
                  /* checking for: cf */
                  if (ATgetType((ATerm)arg_arg0_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_arg0_head) == PTPT_afun2) {
                    ATerm arg_arg0_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_arg0_head, 0);
                    /* checking for: sort */
                    if (ATgetType((ATerm)arg_arg0_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_arg0_head_arg0) == PTPT_afun9) {
                      ATerm arg_arg0_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_arg0_head_arg0, 0);
                      /* checking for: IntCon */
                      if (ATgetType((ATerm)arg_arg0_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_arg0_head_arg0_arg0) == PTPT_afun85) {
                        if (ATgetType((ATerm)arg_arg0_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_arg0_list) == ATfalse) {
                          arg_arg0_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_arg0_list);
                          arg_arg0_arg0_arg0_list = ATgetNext(arg_arg0_arg0_arg0_list);
                          /* checking for: cf */
                          if (ATgetType((ATerm)arg_arg0_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_arg0_head) == PTPT_afun2) {
                            ATerm arg_arg0_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_arg0_head, 0);
                            /* checking for: opt */
                            if (ATgetType((ATerm)arg_arg0_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_arg0_head_arg0) == PTPT_afun3) {
                              ATerm arg_arg0_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_arg0_head_arg0, 0);
                              /* checking for: layout */
                              if (ATgetType((ATerm)arg_arg0_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                if (ATgetType((ATerm)arg_arg0_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_arg0_list) == ATtrue) {
                                  ATerm arg_arg0_arg0_arg1 = ATgetArgument(arg_arg0_arg0, 1);
                                  /* checking for: sort */
                                  if (ATgetType((ATerm)arg_arg0_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_arg1) == PTPT_afun9) {
                                    ATerm arg_arg0_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg0_arg1, 0);
                                    /* checking for: <START> */
                                    if (ATgetType((ATerm)arg_arg0_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_arg1_arg0) == PTPT_afun84) {
                                      ATerm arg_arg0_arg0_arg2 = ATgetArgument(arg_arg0_arg0, 2);
                                      /* checking for: no-attrs */
                                      if (ATgetType((ATerm)arg_arg0_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_arg2) == PTPT_afun5) {
                                        ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                        if (ATgetType((ATerm)arg_arg0_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg1) == ATfalse) {
                                          ATermList arg_arg0_arg1_list = (ATermList)arg_arg0_arg1;
                                          arg_arg0_arg1_list = ATgetNext(arg_arg0_arg1_list);
                                          if (ATgetType((ATerm)arg_arg0_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg1_list) == ATfalse) {
                                            arg_arg0_arg1_list = ATgetNext(arg_arg0_arg1_list);
                                            if (ATgetType((ATerm)arg_arg0_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg1_list) == ATfalse) {
                                              arg_arg0_arg1_list = ATgetNext(arg_arg0_arg1_list);
                                              if (ATgetType((ATerm)arg_arg0_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg1_list) == ATtrue) {
                                                ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                if (ATgetType((ATerm)arg_arg1) == AT_INT) {
                                                  return ATtrue;
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Start is a RealCon by checking against the following ATerm pattern: parsetree(appl(prod([cf(opt(layout)),cf(sort("RealCon")),cf(opt(layout))],sort("<START>"),no-attrs),[<"ws-before"("OptLayout")>,<"top-RealCon"("RealCon")>,<"ws-after"("OptLayout")>]),<amb-cnt(int)>). May not be used to assert correctness of the PTPT_Start
 * \param[in] arg input PTPT_Start
 * \return ATtrue if #arg corresponds to the signature of a RealCon, or ATfalse otherwise
 */
inline ATbool PTPT_isStartRealCon(PTPT_Start arg){
  /* checking for: parsetree */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == PTPT_afun83) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: appl */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == PTPT_afun0) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      /* checking for: prod */
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0) == PTPT_afun1) {
        ATerm arg_arg0_arg0_arg0 = ATgetArgument(arg_arg0_arg0, 0);
        if (ATgetType((ATerm)arg_arg0_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_arg0) == ATfalse) {
          ATerm arg_arg0_arg0_arg0_head;
          ATermList arg_arg0_arg0_arg0_list = (ATermList)arg_arg0_arg0_arg0;
          arg_arg0_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_arg0_list);
          arg_arg0_arg0_arg0_list = ATgetNext(arg_arg0_arg0_arg0_list);
          /* checking for: cf */
          if (ATgetType((ATerm)arg_arg0_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_arg0_head) == PTPT_afun2) {
            ATerm arg_arg0_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_arg0_head, 0);
            /* checking for: opt */
            if (ATgetType((ATerm)arg_arg0_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_arg0_head_arg0) == PTPT_afun3) {
              ATerm arg_arg0_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_arg0_head_arg0, 0);
              /* checking for: layout */
              if (ATgetType((ATerm)arg_arg0_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                if (ATgetType((ATerm)arg_arg0_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_arg0_list) == ATfalse) {
                  arg_arg0_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_arg0_list);
                  arg_arg0_arg0_arg0_list = ATgetNext(arg_arg0_arg0_arg0_list);
                  /* checking for: cf */
                  if (ATgetType((ATerm)arg_arg0_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_arg0_head) == PTPT_afun2) {
                    ATerm arg_arg0_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_arg0_head, 0);
                    /* checking for: sort */
                    if (ATgetType((ATerm)arg_arg0_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_arg0_head_arg0) == PTPT_afun9) {
                      ATerm arg_arg0_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_arg0_head_arg0, 0);
                      /* checking for: RealCon */
                      if (ATgetType((ATerm)arg_arg0_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_arg0_head_arg0_arg0) == PTPT_afun86) {
                        if (ATgetType((ATerm)arg_arg0_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_arg0_list) == ATfalse) {
                          arg_arg0_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_arg0_list);
                          arg_arg0_arg0_arg0_list = ATgetNext(arg_arg0_arg0_arg0_list);
                          /* checking for: cf */
                          if (ATgetType((ATerm)arg_arg0_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_arg0_head) == PTPT_afun2) {
                            ATerm arg_arg0_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_arg0_head, 0);
                            /* checking for: opt */
                            if (ATgetType((ATerm)arg_arg0_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_arg0_head_arg0) == PTPT_afun3) {
                              ATerm arg_arg0_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_arg0_head_arg0, 0);
                              /* checking for: layout */
                              if (ATgetType((ATerm)arg_arg0_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                if (ATgetType((ATerm)arg_arg0_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_arg0_list) == ATtrue) {
                                  ATerm arg_arg0_arg0_arg1 = ATgetArgument(arg_arg0_arg0, 1);
                                  /* checking for: sort */
                                  if (ATgetType((ATerm)arg_arg0_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_arg1) == PTPT_afun9) {
                                    ATerm arg_arg0_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg0_arg1, 0);
                                    /* checking for: <START> */
                                    if (ATgetType((ATerm)arg_arg0_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_arg1_arg0) == PTPT_afun84) {
                                      ATerm arg_arg0_arg0_arg2 = ATgetArgument(arg_arg0_arg0, 2);
                                      /* checking for: no-attrs */
                                      if (ATgetType((ATerm)arg_arg0_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_arg2) == PTPT_afun5) {
                                        ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                        if (ATgetType((ATerm)arg_arg0_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg1) == ATfalse) {
                                          ATermList arg_arg0_arg1_list = (ATermList)arg_arg0_arg1;
                                          arg_arg0_arg1_list = ATgetNext(arg_arg0_arg1_list);
                                          if (ATgetType((ATerm)arg_arg0_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg1_list) == ATfalse) {
                                            arg_arg0_arg1_list = ATgetNext(arg_arg0_arg1_list);
                                            if (ATgetType((ATerm)arg_arg0_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg1_list) == ATfalse) {
                                              arg_arg0_arg1_list = ATgetNext(arg_arg0_arg1_list);
                                              if (ATgetType((ATerm)arg_arg0_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg1_list) == ATtrue) {
                                                ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                if (ATgetType((ATerm)arg_arg1) == AT_INT) {
                                                  return ATtrue;
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Start has a ws-before. 
 * \param[in] arg input PTPT_Start
 * \return ATtrue if the PTPT_Start had a ws-before, or ATfalse otherwise
 */
ATbool PTPT_hasStartWsBefore(PTPT_Start arg) {
  if (PTPT_isStartSymbol(arg)) {
    return ATtrue;
  }
  else if (PTPT_isStartTree(arg)) {
    return ATtrue;
  }
  else if (PTPT_isStartATerm(arg)) {
    return ATtrue;
  }
  else if (PTPT_isStartIntCon(arg)) {
    return ATtrue;
  }
  else if (PTPT_isStartRealCon(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Start has a top-Symbol. 
 * \param[in] arg input PTPT_Start
 * \return ATtrue if the PTPT_Start had a top-Symbol, or ATfalse otherwise
 */
ATbool PTPT_hasStartTopSymbol(PTPT_Start arg) {
  if (PTPT_isStartSymbol(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Start has a ws-after. 
 * \param[in] arg input PTPT_Start
 * \return ATtrue if the PTPT_Start had a ws-after, or ATfalse otherwise
 */
ATbool PTPT_hasStartWsAfter(PTPT_Start arg) {
  if (PTPT_isStartSymbol(arg)) {
    return ATtrue;
  }
  else if (PTPT_isStartTree(arg)) {
    return ATtrue;
  }
  else if (PTPT_isStartATerm(arg)) {
    return ATtrue;
  }
  else if (PTPT_isStartIntCon(arg)) {
    return ATtrue;
  }
  else if (PTPT_isStartRealCon(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Start has a amb-cnt. 
 * \param[in] arg input PTPT_Start
 * \return ATtrue if the PTPT_Start had a amb-cnt, or ATfalse otherwise
 */
ATbool PTPT_hasStartAmbCnt(PTPT_Start arg) {
  if (PTPT_isStartSymbol(arg)) {
    return ATtrue;
  }
  else if (PTPT_isStartTree(arg)) {
    return ATtrue;
  }
  else if (PTPT_isStartATerm(arg)) {
    return ATtrue;
  }
  else if (PTPT_isStartIntCon(arg)) {
    return ATtrue;
  }
  else if (PTPT_isStartRealCon(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Start has a top-Tree. 
 * \param[in] arg input PTPT_Start
 * \return ATtrue if the PTPT_Start had a top-Tree, or ATfalse otherwise
 */
ATbool PTPT_hasStartTopTree(PTPT_Start arg) {
  if (PTPT_isStartTree(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Start has a top-ATerm. 
 * \param[in] arg input PTPT_Start
 * \return ATtrue if the PTPT_Start had a top-ATerm, or ATfalse otherwise
 */
ATbool PTPT_hasStartTopATerm(PTPT_Start arg) {
  if (PTPT_isStartATerm(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Start has a top-IntCon. 
 * \param[in] arg input PTPT_Start
 * \return ATtrue if the PTPT_Start had a top-IntCon, or ATfalse otherwise
 */
ATbool PTPT_hasStartTopIntCon(PTPT_Start arg) {
  if (PTPT_isStartIntCon(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Start has a top-RealCon. 
 * \param[in] arg input PTPT_Start
 * \return ATtrue if the PTPT_Start had a top-RealCon, or ATfalse otherwise
 */
ATbool PTPT_hasStartTopRealCon(PTPT_Start arg) {
  if (PTPT_isStartRealCon(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Get the ws-before PTPT_OptLayout of a PTPT_Start. Note that the precondition is that this PTPT_Start actually has a ws-before
 * \param[in] arg input PTPT_Start
 * \return the ws-before of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getStartWsBefore(PTPT_Start arg) {
  if (PTPT_isStartSymbol(arg)) {
    return (PTPT_OptLayout)ATgetFirst((ATermList)ATgetArgument((ATermAppl)ATgetArgument((ATermAppl)arg, 0), 1));
  }
  else if (PTPT_isStartTree(arg)) {
    return (PTPT_OptLayout)ATgetFirst((ATermList)ATgetArgument((ATermAppl)ATgetArgument((ATermAppl)arg, 0), 1));
  }
  else if (PTPT_isStartATerm(arg)) {
    return (PTPT_OptLayout)ATgetFirst((ATermList)ATgetArgument((ATermAppl)ATgetArgument((ATermAppl)arg, 0), 1));
  }
  else if (PTPT_isStartIntCon(arg)) {
    return (PTPT_OptLayout)ATgetFirst((ATermList)ATgetArgument((ATermAppl)ATgetArgument((ATermAppl)arg, 0), 1));
  }
  else 
    return (PTPT_OptLayout)ATgetFirst((ATermList)ATgetArgument((ATermAppl)ATgetArgument((ATermAppl)arg, 0), 1));
}

/**
 * Get the top-Symbol PTPT_Symbol of a PTPT_Start. Note that the precondition is that this PTPT_Start actually has a top-Symbol
 * \param[in] arg input PTPT_Start
 * \return the top-Symbol of #arg, if it exist or an undefined value if it does not
 */
PTPT_Symbol PTPT_getStartTopSymbol(PTPT_Start arg) {
  
    return (PTPT_Symbol)ATelementAt((ATermList)ATgetArgument((ATermAppl)ATgetArgument((ATermAppl)arg, 0), 1), 1);
}

/**
 * Get the ws-after PTPT_OptLayout of a PTPT_Start. Note that the precondition is that this PTPT_Start actually has a ws-after
 * \param[in] arg input PTPT_Start
 * \return the ws-after of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getStartWsAfter(PTPT_Start arg) {
  if (PTPT_isStartSymbol(arg)) {
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)ATgetArgument((ATermAppl)arg, 0), 1), 2);
  }
  else if (PTPT_isStartTree(arg)) {
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)ATgetArgument((ATermAppl)arg, 0), 1), 2);
  }
  else if (PTPT_isStartATerm(arg)) {
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)ATgetArgument((ATermAppl)arg, 0), 1), 2);
  }
  else if (PTPT_isStartIntCon(arg)) {
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)ATgetArgument((ATermAppl)arg, 0), 1), 2);
  }
  else 
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)ATgetArgument((ATermAppl)arg, 0), 1), 2);
}

/**
 * Get the amb-cnt int of a PTPT_Start. Note that the precondition is that this PTPT_Start actually has a amb-cnt
 * \param[in] arg input PTPT_Start
 * \return the amb-cnt of #arg, if it exist or an undefined value if it does not
 */
int PTPT_getStartAmbCnt(PTPT_Start arg) {
  if (PTPT_isStartSymbol(arg)) {
    return (int)ATgetInt((ATermInt) ATgetArgument((ATermAppl)arg, 1));
  }
  else if (PTPT_isStartTree(arg)) {
    return (int)ATgetInt((ATermInt) ATgetArgument((ATermAppl)arg, 1));
  }
  else if (PTPT_isStartATerm(arg)) {
    return (int)ATgetInt((ATermInt) ATgetArgument((ATermAppl)arg, 1));
  }
  else if (PTPT_isStartIntCon(arg)) {
    return (int)ATgetInt((ATermInt) ATgetArgument((ATermAppl)arg, 1));
  }
  else 
    return (int)ATgetInt((ATermInt) ATgetArgument((ATermAppl)arg, 1));
}

/**
 * Get the top-Tree PTPT_Tree of a PTPT_Start. Note that the precondition is that this PTPT_Start actually has a top-Tree
 * \param[in] arg input PTPT_Start
 * \return the top-Tree of #arg, if it exist or an undefined value if it does not
 */
PTPT_Tree PTPT_getStartTopTree(PTPT_Start arg) {
  
    return (PTPT_Tree)ATelementAt((ATermList)ATgetArgument((ATermAppl)ATgetArgument((ATermAppl)arg, 0), 1), 1);
}

/**
 * Get the top-ATerm PTPT_ATerm of a PTPT_Start. Note that the precondition is that this PTPT_Start actually has a top-ATerm
 * \param[in] arg input PTPT_Start
 * \return the top-ATerm of #arg, if it exist or an undefined value if it does not
 */
PTPT_ATerm PTPT_getStartTopATerm(PTPT_Start arg) {
  
    return (PTPT_ATerm)ATelementAt((ATermList)ATgetArgument((ATermAppl)ATgetArgument((ATermAppl)arg, 0), 1), 1);
}

/**
 * Get the top-IntCon PTPT_IntCon of a PTPT_Start. Note that the precondition is that this PTPT_Start actually has a top-IntCon
 * \param[in] arg input PTPT_Start
 * \return the top-IntCon of #arg, if it exist or an undefined value if it does not
 */
PTPT_IntCon PTPT_getStartTopIntCon(PTPT_Start arg) {
  
    return (PTPT_IntCon)ATelementAt((ATermList)ATgetArgument((ATermAppl)ATgetArgument((ATermAppl)arg, 0), 1), 1);
}

/**
 * Get the top-RealCon PTPT_RealCon of a PTPT_Start. Note that the precondition is that this PTPT_Start actually has a top-RealCon
 * \param[in] arg input PTPT_Start
 * \return the top-RealCon of #arg, if it exist or an undefined value if it does not
 */
PTPT_RealCon PTPT_getStartTopRealCon(PTPT_Start arg) {
  
    return (PTPT_RealCon)ATelementAt((ATermList)ATgetArgument((ATermAppl)ATgetArgument((ATermAppl)arg, 0), 1), 1);
}

/**
 * Set the ws-before of a PTPT_Start. The precondition being that this PTPT_Start actually has a ws-before
 * \param[in] arg input PTPT_Start
 * \param[in] wsBefore new PTPT_OptLayout to set in #arg
 * \return A new PTPT_Start with wsBefore at the right place, or a core dump if #arg did not have a wsBefore
 */
PTPT_Start PTPT_setStartWsBefore(PTPT_Start arg, PTPT_OptLayout wsBefore) {
  if (PTPT_isStartSymbol(arg)) {
    return (PTPT_Start)ATsetArgument((ATermAppl)arg, (ATerm)ATsetArgument((ATermAppl)ATgetArgument((ATermAppl)arg, 0), (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)ATgetArgument((ATermAppl)arg, 0), 1), (ATerm)((ATerm) wsBefore), 0), 1), 0);
  }
  else if (PTPT_isStartTree(arg)) {
    return (PTPT_Start)ATsetArgument((ATermAppl)arg, (ATerm)ATsetArgument((ATermAppl)ATgetArgument((ATermAppl)arg, 0), (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)ATgetArgument((ATermAppl)arg, 0), 1), (ATerm)((ATerm) wsBefore), 0), 1), 0);
  }
  else if (PTPT_isStartATerm(arg)) {
    return (PTPT_Start)ATsetArgument((ATermAppl)arg, (ATerm)ATsetArgument((ATermAppl)ATgetArgument((ATermAppl)arg, 0), (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)ATgetArgument((ATermAppl)arg, 0), 1), (ATerm)((ATerm) wsBefore), 0), 1), 0);
  }
  else if (PTPT_isStartIntCon(arg)) {
    return (PTPT_Start)ATsetArgument((ATermAppl)arg, (ATerm)ATsetArgument((ATermAppl)ATgetArgument((ATermAppl)arg, 0), (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)ATgetArgument((ATermAppl)arg, 0), 1), (ATerm)((ATerm) wsBefore), 0), 1), 0);
  }
  else if (PTPT_isStartRealCon(arg)) {
    return (PTPT_Start)ATsetArgument((ATermAppl)arg, (ATerm)ATsetArgument((ATermAppl)ATgetArgument((ATermAppl)arg, 0), (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)ATgetArgument((ATermAppl)arg, 0), 1), (ATerm)((ATerm) wsBefore), 0), 1), 0);
  }

  ATabort("Start has no WsBefore: %t\n", arg);
  return (PTPT_Start)NULL;
}

/**
 * Set the top-Symbol of a PTPT_Start. The precondition being that this PTPT_Start actually has a top-Symbol
 * \param[in] arg input PTPT_Start
 * \param[in] topSymbol new PTPT_Symbol to set in #arg
 * \return A new PTPT_Start with topSymbol at the right place, or a core dump if #arg did not have a topSymbol
 */
PTPT_Start PTPT_setStartTopSymbol(PTPT_Start arg, PTPT_Symbol topSymbol) {
  if (PTPT_isStartSymbol(arg)) {
    return (PTPT_Start)ATsetArgument((ATermAppl)arg, (ATerm)ATsetArgument((ATermAppl)ATgetArgument((ATermAppl)arg, 0), (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)ATgetArgument((ATermAppl)arg, 0), 1), (ATerm)((ATerm) topSymbol), 1), 1), 0);
  }

  ATabort("Start has no TopSymbol: %t\n", arg);
  return (PTPT_Start)NULL;
}

/**
 * Set the ws-after of a PTPT_Start. The precondition being that this PTPT_Start actually has a ws-after
 * \param[in] arg input PTPT_Start
 * \param[in] wsAfter new PTPT_OptLayout to set in #arg
 * \return A new PTPT_Start with wsAfter at the right place, or a core dump if #arg did not have a wsAfter
 */
PTPT_Start PTPT_setStartWsAfter(PTPT_Start arg, PTPT_OptLayout wsAfter) {
  if (PTPT_isStartSymbol(arg)) {
    return (PTPT_Start)ATsetArgument((ATermAppl)arg, (ATerm)ATsetArgument((ATermAppl)ATgetArgument((ATermAppl)arg, 0), (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)ATgetArgument((ATermAppl)arg, 0), 1), (ATerm)((ATerm) wsAfter), 2), 1), 0);
  }
  else if (PTPT_isStartTree(arg)) {
    return (PTPT_Start)ATsetArgument((ATermAppl)arg, (ATerm)ATsetArgument((ATermAppl)ATgetArgument((ATermAppl)arg, 0), (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)ATgetArgument((ATermAppl)arg, 0), 1), (ATerm)((ATerm) wsAfter), 2), 1), 0);
  }
  else if (PTPT_isStartATerm(arg)) {
    return (PTPT_Start)ATsetArgument((ATermAppl)arg, (ATerm)ATsetArgument((ATermAppl)ATgetArgument((ATermAppl)arg, 0), (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)ATgetArgument((ATermAppl)arg, 0), 1), (ATerm)((ATerm) wsAfter), 2), 1), 0);
  }
  else if (PTPT_isStartIntCon(arg)) {
    return (PTPT_Start)ATsetArgument((ATermAppl)arg, (ATerm)ATsetArgument((ATermAppl)ATgetArgument((ATermAppl)arg, 0), (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)ATgetArgument((ATermAppl)arg, 0), 1), (ATerm)((ATerm) wsAfter), 2), 1), 0);
  }
  else if (PTPT_isStartRealCon(arg)) {
    return (PTPT_Start)ATsetArgument((ATermAppl)arg, (ATerm)ATsetArgument((ATermAppl)ATgetArgument((ATermAppl)arg, 0), (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)ATgetArgument((ATermAppl)arg, 0), 1), (ATerm)((ATerm) wsAfter), 2), 1), 0);
  }

  ATabort("Start has no WsAfter: %t\n", arg);
  return (PTPT_Start)NULL;
}

/**
 * Set the amb-cnt of a PTPT_Start. The precondition being that this PTPT_Start actually has a amb-cnt
 * \param[in] arg input PTPT_Start
 * \param[in] ambCnt new int to set in #arg
 * \return A new PTPT_Start with ambCnt at the right place, or a core dump if #arg did not have a ambCnt
 */
PTPT_Start PTPT_setStartAmbCnt(PTPT_Start arg, int ambCnt) {
  if (PTPT_isStartSymbol(arg)) {
    return (PTPT_Start)ATsetArgument((ATermAppl)arg, (ATerm)((ATerm) (ATerm) ATmakeInt(ambCnt)), 1);
  }
  else if (PTPT_isStartTree(arg)) {
    return (PTPT_Start)ATsetArgument((ATermAppl)arg, (ATerm)((ATerm) (ATerm) ATmakeInt(ambCnt)), 1);
  }
  else if (PTPT_isStartATerm(arg)) {
    return (PTPT_Start)ATsetArgument((ATermAppl)arg, (ATerm)((ATerm) (ATerm) ATmakeInt(ambCnt)), 1);
  }
  else if (PTPT_isStartIntCon(arg)) {
    return (PTPT_Start)ATsetArgument((ATermAppl)arg, (ATerm)((ATerm) (ATerm) ATmakeInt(ambCnt)), 1);
  }
  else if (PTPT_isStartRealCon(arg)) {
    return (PTPT_Start)ATsetArgument((ATermAppl)arg, (ATerm)((ATerm) (ATerm) ATmakeInt(ambCnt)), 1);
  }

  ATabort("Start has no AmbCnt: %t\n", arg);
  return (PTPT_Start)NULL;
}

/**
 * Set the top-Tree of a PTPT_Start. The precondition being that this PTPT_Start actually has a top-Tree
 * \param[in] arg input PTPT_Start
 * \param[in] topTree new PTPT_Tree to set in #arg
 * \return A new PTPT_Start with topTree at the right place, or a core dump if #arg did not have a topTree
 */
PTPT_Start PTPT_setStartTopTree(PTPT_Start arg, PTPT_Tree topTree) {
  if (PTPT_isStartTree(arg)) {
    return (PTPT_Start)ATsetArgument((ATermAppl)arg, (ATerm)ATsetArgument((ATermAppl)ATgetArgument((ATermAppl)arg, 0), (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)ATgetArgument((ATermAppl)arg, 0), 1), (ATerm)((ATerm) topTree), 1), 1), 0);
  }

  ATabort("Start has no TopTree: %t\n", arg);
  return (PTPT_Start)NULL;
}

/**
 * Set the top-ATerm of a PTPT_Start. The precondition being that this PTPT_Start actually has a top-ATerm
 * \param[in] arg input PTPT_Start
 * \param[in] topATerm new PTPT_ATerm to set in #arg
 * \return A new PTPT_Start with topATerm at the right place, or a core dump if #arg did not have a topATerm
 */
PTPT_Start PTPT_setStartTopATerm(PTPT_Start arg, PTPT_ATerm topATerm) {
  if (PTPT_isStartATerm(arg)) {
    return (PTPT_Start)ATsetArgument((ATermAppl)arg, (ATerm)ATsetArgument((ATermAppl)ATgetArgument((ATermAppl)arg, 0), (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)ATgetArgument((ATermAppl)arg, 0), 1), (ATerm)((ATerm) topATerm), 1), 1), 0);
  }

  ATabort("Start has no TopATerm: %t\n", arg);
  return (PTPT_Start)NULL;
}

/**
 * Set the top-IntCon of a PTPT_Start. The precondition being that this PTPT_Start actually has a top-IntCon
 * \param[in] arg input PTPT_Start
 * \param[in] topIntCon new PTPT_IntCon to set in #arg
 * \return A new PTPT_Start with topIntCon at the right place, or a core dump if #arg did not have a topIntCon
 */
PTPT_Start PTPT_setStartTopIntCon(PTPT_Start arg, PTPT_IntCon topIntCon) {
  if (PTPT_isStartIntCon(arg)) {
    return (PTPT_Start)ATsetArgument((ATermAppl)arg, (ATerm)ATsetArgument((ATermAppl)ATgetArgument((ATermAppl)arg, 0), (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)ATgetArgument((ATermAppl)arg, 0), 1), (ATerm)((ATerm) topIntCon), 1), 1), 0);
  }

  ATabort("Start has no TopIntCon: %t\n", arg);
  return (PTPT_Start)NULL;
}

/**
 * Set the top-RealCon of a PTPT_Start. The precondition being that this PTPT_Start actually has a top-RealCon
 * \param[in] arg input PTPT_Start
 * \param[in] topRealCon new PTPT_RealCon to set in #arg
 * \return A new PTPT_Start with topRealCon at the right place, or a core dump if #arg did not have a topRealCon
 */
PTPT_Start PTPT_setStartTopRealCon(PTPT_Start arg, PTPT_RealCon topRealCon) {
  if (PTPT_isStartRealCon(arg)) {
    return (PTPT_Start)ATsetArgument((ATermAppl)arg, (ATerm)ATsetArgument((ATermAppl)ATgetArgument((ATermAppl)arg, 0), (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)ATgetArgument((ATermAppl)arg, 0), 1), (ATerm)((ATerm) topRealCon), 1), 1), 0);
  }

  ATabort("Start has no TopRealCon: %t\n", arg);
  return (PTPT_Start)NULL;
}

/**
 * Assert whether a PTPT_SymbolList is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input PTPT_SymbolList
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool PTPT_isValidSymbolList(PTPT_SymbolList arg) {
  if (PTPT_isSymbolListEmpty(arg)) {
    return ATtrue;
  }
  else if (PTPT_isSymbolListSingle(arg)) {
    return ATtrue;
  }
  else if (PTPT_isSymbolListMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_SymbolList is a empty by checking against the following ATerm pattern: []. May not be used to assert correctness of the PTPT_SymbolList
 * \param[in] arg input PTPT_SymbolList
 * \return ATtrue if #arg corresponds to the signature of a empty, or ATfalse otherwise
 */
inline ATbool PTPT_isSymbolListEmpty(PTPT_SymbolList arg){
  if (ATisEmpty((ATermList)arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_SymbolList is a single by checking against the following ATerm pattern: [<head(Symbol)>]. May not be used to assert correctness of the PTPT_SymbolList
 * \param[in] arg input PTPT_SymbolList
 * \return ATtrue if #arg corresponds to the signature of a single, or ATfalse otherwise
 */
inline ATbool PTPT_isSymbolListSingle(PTPT_SymbolList arg){
  if (ATgetType((ATerm)arg) == AT_LIST && ATisEmpty((ATermList)arg) == ATfalse) {
    ATermList arg_list = (ATermList)arg;
    arg_list = ATgetNext(arg_list);
    if (ATgetType((ATerm)arg_list) == AT_LIST && ATisEmpty((ATermList)arg_list) == ATtrue) {
      return ATtrue;
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_SymbolList is a many by checking against the following ATerm pattern: [<head(Symbol)>,<ws-after-head("OptLayout")>,appl(prod([char-class([44])],lit(","),no-attrs),[44]),<ws-after-sep("OptLayout")>,<[tail(Symbol-list)]>]. May not be used to assert correctness of the PTPT_SymbolList
 * \param[in] arg input PTPT_SymbolList
 * \return ATtrue if #arg corresponds to the signature of a many, or ATfalse otherwise
 */
inline ATbool PTPT_isSymbolListMany(PTPT_SymbolList arg){
  if (ATgetType((ATerm)arg) == AT_LIST && ATisEmpty((ATermList)arg) == ATfalse) {
    ATerm arg_head;
    ATermList arg_list = (ATermList)arg;
    arg_list = ATgetNext(arg_list);
    if (ATgetType((ATerm)arg_list) == AT_LIST && ATisEmpty((ATermList)arg_list) == ATfalse) {
      arg_list = ATgetNext(arg_list);
      if (ATgetType((ATerm)arg_list) == AT_LIST && ATisEmpty((ATermList)arg_list) == ATfalse) {
        arg_head = ATgetFirst(arg_list);
        arg_list = ATgetNext(arg_list);
        /* checking for: appl */
        if (ATgetType((ATerm)arg_head) == AT_APPL && ATgetAFun((ATermAppl)arg_head) == PTPT_afun0) {
          ATerm arg_head_arg0 = ATgetArgument(arg_head, 0);
          /* checking for: prod */
          if (ATgetType((ATerm)arg_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_head_arg0) == PTPT_afun1) {
            ATerm arg_head_arg0_arg0 = ATgetArgument(arg_head_arg0, 0);
            if (ATgetType((ATerm)arg_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_head_arg0_arg0) == ATfalse) {
              ATerm arg_head_arg0_arg0_head;
              ATermList arg_head_arg0_arg0_list = (ATermList)arg_head_arg0_arg0;
              arg_head_arg0_arg0_head = ATgetFirst(arg_head_arg0_arg0_list);
              arg_head_arg0_arg0_list = ATgetNext(arg_head_arg0_arg0_list);
              /* checking for: char-class */
              if (ATgetType((ATerm)arg_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_head_arg0_arg0_head) == PTPT_afun23) {
                ATerm arg_head_arg0_arg0_head_arg0 = ATgetArgument(arg_head_arg0_arg0_head, 0);
                if (ATgetType((ATerm)arg_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_head_arg0_arg0_head_arg0) == ATfalse) {
                  ATerm arg_head_arg0_arg0_head_arg0_head;
                  ATermList arg_head_arg0_arg0_head_arg0_list = (ATermList)arg_head_arg0_arg0_head_arg0;
                  arg_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_head_arg0_arg0_head_arg0_list);
                  arg_head_arg0_arg0_head_arg0_list = ATgetNext(arg_head_arg0_arg0_head_arg0_list);
                  if (ATgetInt((ATermInt)arg_head_arg0_arg0_head_arg0_head) == 44) {

                    if (ATgetType((ATerm)arg_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_head_arg0_arg0_head_arg0_list) == ATtrue) {
                      if (ATgetType((ATerm)arg_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_head_arg0_arg0_list) == ATtrue) {
                        ATerm arg_head_arg0_arg1 = ATgetArgument(arg_head_arg0, 1);
                        /* checking for: lit */
                        if (ATgetType((ATerm)arg_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_head_arg0_arg1) == PTPT_afun16) {
                          ATerm arg_head_arg0_arg1_arg0 = ATgetArgument(arg_head_arg0_arg1, 0);
                          /* checking for: , */
                          if (ATgetType((ATerm)arg_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_head_arg0_arg1_arg0) == PTPT_afun19) {
                            ATerm arg_head_arg0_arg2 = ATgetArgument(arg_head_arg0, 2);
                            /* checking for: no-attrs */
                            if (ATgetType((ATerm)arg_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_head_arg0_arg2) == PTPT_afun5) {
                              ATerm arg_head_arg1 = ATgetArgument(arg_head, 1);
                              if (ATgetType((ATerm)arg_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_head_arg1) == ATfalse) {
                                ATerm arg_head_arg1_head;
                                ATermList arg_head_arg1_list = (ATermList)arg_head_arg1;
                                arg_head_arg1_head = ATgetFirst(arg_head_arg1_list);
                                arg_head_arg1_list = ATgetNext(arg_head_arg1_list);
                                if (ATgetInt((ATermInt)arg_head_arg1_head) == 44) {

                                  if (ATgetType((ATerm)arg_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_head_arg1_list) == ATtrue) {
                                    if (ATgetType((ATerm)arg_list) == AT_LIST && ATisEmpty((ATermList)arg_list) == ATfalse) {
                                      return ATtrue;
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_SymbolList has a head. 
 * \param[in] arg input PTPT_SymbolList
 * \return ATtrue if the PTPT_SymbolList had a head, or ATfalse otherwise
 */
ATbool PTPT_hasSymbolListHead(PTPT_SymbolList arg) {
  if (PTPT_isSymbolListSingle(arg)) {
    return ATtrue;
  }
  else if (PTPT_isSymbolListMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_SymbolList has a ws-after-head. 
 * \param[in] arg input PTPT_SymbolList
 * \return ATtrue if the PTPT_SymbolList had a ws-after-head, or ATfalse otherwise
 */
ATbool PTPT_hasSymbolListWsAfterHead(PTPT_SymbolList arg) {
  if (PTPT_isSymbolListMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_SymbolList has a ws-after-sep. 
 * \param[in] arg input PTPT_SymbolList
 * \return ATtrue if the PTPT_SymbolList had a ws-after-sep, or ATfalse otherwise
 */
ATbool PTPT_hasSymbolListWsAfterSep(PTPT_SymbolList arg) {
  if (PTPT_isSymbolListMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_SymbolList has a tail. 
 * \param[in] arg input PTPT_SymbolList
 * \return ATtrue if the PTPT_SymbolList had a tail, or ATfalse otherwise
 */
ATbool PTPT_hasSymbolListTail(PTPT_SymbolList arg) {
  if (PTPT_isSymbolListMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Returns a list of all but the first element of a PTPT_SymbolList. 
 * \param[in] arg input PTPT_SymbolList
 * \return A new PTPT_SymbolList, without the first element and the separator(s) just after it.)
 */
PTPT_SymbolList PTPT_getSymbolListTail(PTPT_SymbolList arg) {
  assert(!PTPT_isSymbolListEmpty(arg) && "getTail on an empty list");
  if (PTPT_isSymbolListSingle(arg)) {
    return (PTPT_SymbolList) PTPT_makeSymbolListEmpty();
  }
  else {
  
    return (PTPT_SymbolList)ATgetTail((ATermList)arg, 4);
  }
}

/**
 * Get the head PTPT_Symbol of a PTPT_SymbolList. Note that the precondition is that this PTPT_SymbolList actually has a head
 * \param[in] arg input PTPT_SymbolList
 * \return the head of #arg, if it exist or an undefined value if it does not
 */
PTPT_Symbol PTPT_getSymbolListHead(PTPT_SymbolList arg) {
  if (PTPT_isSymbolListSingle(arg)) {
    return (PTPT_Symbol)ATgetFirst((ATermList)arg);
  }
  else 
    return (PTPT_Symbol)ATgetFirst((ATermList)arg);
}

/**
 * Get the ws-after-head PTPT_OptLayout of a PTPT_SymbolList. Note that the precondition is that this PTPT_SymbolList actually has a ws-after-head
 * \param[in] arg input PTPT_SymbolList
 * \return the ws-after-head of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getSymbolListWsAfterHead(PTPT_SymbolList arg) {
  
    return (PTPT_OptLayout)ATelementAt((ATermList)arg, 1);
}

/**
 * Get the ws-after-sep PTPT_OptLayout of a PTPT_SymbolList. Note that the precondition is that this PTPT_SymbolList actually has a ws-after-sep
 * \param[in] arg input PTPT_SymbolList
 * \return the ws-after-sep of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getSymbolListWsAfterSep(PTPT_SymbolList arg) {
  
    return (PTPT_OptLayout)ATelementAt((ATermList)arg, 3);
}

/**
 * Set the head of a PTPT_SymbolList. The precondition being that this PTPT_SymbolList actually has a head
 * \param[in] arg input PTPT_SymbolList
 * \param[in] head new PTPT_Symbol to set in #arg
 * \return A new PTPT_SymbolList with head at the right place, or a core dump if #arg did not have a head
 */
PTPT_SymbolList PTPT_setSymbolListHead(PTPT_SymbolList arg, PTPT_Symbol head) {
  if (PTPT_isSymbolListSingle(arg)) {
    return (PTPT_SymbolList)ATreplace((ATermList)arg, (ATerm)((ATerm) head), 0);
  }
  else if (PTPT_isSymbolListMany(arg)) {
    return (PTPT_SymbolList)ATreplace((ATermList)arg, (ATerm)((ATerm) head), 0);
  }

  ATabort("SymbolList has no Head: %t\n", arg);
  return (PTPT_SymbolList)NULL;
}

/**
 * Set the ws-after-head of a PTPT_SymbolList. The precondition being that this PTPT_SymbolList actually has a ws-after-head
 * \param[in] arg input PTPT_SymbolList
 * \param[in] wsAfterHead new PTPT_OptLayout to set in #arg
 * \return A new PTPT_SymbolList with wsAfterHead at the right place, or a core dump if #arg did not have a wsAfterHead
 */
PTPT_SymbolList PTPT_setSymbolListWsAfterHead(PTPT_SymbolList arg, PTPT_OptLayout wsAfterHead) {
  if (PTPT_isSymbolListMany(arg)) {
    return (PTPT_SymbolList)ATreplace((ATermList)arg, (ATerm)((ATerm) wsAfterHead), 1);
  }

  ATabort("SymbolList has no WsAfterHead: %t\n", arg);
  return (PTPT_SymbolList)NULL;
}

/**
 * Set the ws-after-sep of a PTPT_SymbolList. The precondition being that this PTPT_SymbolList actually has a ws-after-sep
 * \param[in] arg input PTPT_SymbolList
 * \param[in] wsAfterSep new PTPT_OptLayout to set in #arg
 * \return A new PTPT_SymbolList with wsAfterSep at the right place, or a core dump if #arg did not have a wsAfterSep
 */
PTPT_SymbolList PTPT_setSymbolListWsAfterSep(PTPT_SymbolList arg, PTPT_OptLayout wsAfterSep) {
  if (PTPT_isSymbolListMany(arg)) {
    return (PTPT_SymbolList)ATreplace((ATermList)arg, (ATerm)((ATerm) wsAfterSep), 3);
  }

  ATabort("SymbolList has no WsAfterSep: %t\n", arg);
  return (PTPT_SymbolList)NULL;
}

/**
 * Set the tail of a PTPT_SymbolList. The precondition being that this PTPT_SymbolList actually has a tail
 * \param[in] arg input PTPT_SymbolList
 * \param[in] tail new PTPT_SymbolList to set in #arg
 * \return A new PTPT_SymbolList with tail at the right place, or a core dump if #arg did not have a tail
 */
PTPT_SymbolList PTPT_setSymbolListTail(PTPT_SymbolList arg, PTPT_SymbolList tail) {
  if (PTPT_isSymbolListMany(arg)) {
    return (PTPT_SymbolList)ATreplaceTail((ATermList)arg, (ATermList)((ATerm) tail), 4);
  }

  ATabort("SymbolList has no Tail: %t\n", arg);
  return (PTPT_SymbolList)NULL;
}

/**
 * Assert whether a PTPT_CharRangeList is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input PTPT_CharRangeList
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool PTPT_isValidCharRangeList(PTPT_CharRangeList arg) {
  if (PTPT_isCharRangeListEmpty(arg)) {
    return ATtrue;
  }
  else if (PTPT_isCharRangeListSingle(arg)) {
    return ATtrue;
  }
  else if (PTPT_isCharRangeListMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_CharRangeList is a empty by checking against the following ATerm pattern: []. May not be used to assert correctness of the PTPT_CharRangeList
 * \param[in] arg input PTPT_CharRangeList
 * \return ATtrue if #arg corresponds to the signature of a empty, or ATfalse otherwise
 */
inline ATbool PTPT_isCharRangeListEmpty(PTPT_CharRangeList arg){
  if (ATisEmpty((ATermList)arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_CharRangeList is a single by checking against the following ATerm pattern: [<head(CharRange)>]. May not be used to assert correctness of the PTPT_CharRangeList
 * \param[in] arg input PTPT_CharRangeList
 * \return ATtrue if #arg corresponds to the signature of a single, or ATfalse otherwise
 */
inline ATbool PTPT_isCharRangeListSingle(PTPT_CharRangeList arg){
  if (ATgetType((ATerm)arg) == AT_LIST && ATisEmpty((ATermList)arg) == ATfalse) {
    ATermList arg_list = (ATermList)arg;
    arg_list = ATgetNext(arg_list);
    if (ATgetType((ATerm)arg_list) == AT_LIST && ATisEmpty((ATermList)arg_list) == ATtrue) {
      return ATtrue;
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_CharRangeList is a many by checking against the following ATerm pattern: [<head(CharRange)>,<ws-after-head("OptLayout")>,appl(prod([char-class([44])],lit(","),no-attrs),[44]),<ws-after-sep("OptLayout")>,<[tail(CharRange-list)]>]. May not be used to assert correctness of the PTPT_CharRangeList
 * \param[in] arg input PTPT_CharRangeList
 * \return ATtrue if #arg corresponds to the signature of a many, or ATfalse otherwise
 */
inline ATbool PTPT_isCharRangeListMany(PTPT_CharRangeList arg){
  if (ATgetType((ATerm)arg) == AT_LIST && ATisEmpty((ATermList)arg) == ATfalse) {
    ATerm arg_head;
    ATermList arg_list = (ATermList)arg;
    arg_list = ATgetNext(arg_list);
    if (ATgetType((ATerm)arg_list) == AT_LIST && ATisEmpty((ATermList)arg_list) == ATfalse) {
      arg_list = ATgetNext(arg_list);
      if (ATgetType((ATerm)arg_list) == AT_LIST && ATisEmpty((ATermList)arg_list) == ATfalse) {
        arg_head = ATgetFirst(arg_list);
        arg_list = ATgetNext(arg_list);
        /* checking for: appl */
        if (ATgetType((ATerm)arg_head) == AT_APPL && ATgetAFun((ATermAppl)arg_head) == PTPT_afun0) {
          ATerm arg_head_arg0 = ATgetArgument(arg_head, 0);
          /* checking for: prod */
          if (ATgetType((ATerm)arg_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_head_arg0) == PTPT_afun1) {
            ATerm arg_head_arg0_arg0 = ATgetArgument(arg_head_arg0, 0);
            if (ATgetType((ATerm)arg_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_head_arg0_arg0) == ATfalse) {
              ATerm arg_head_arg0_arg0_head;
              ATermList arg_head_arg0_arg0_list = (ATermList)arg_head_arg0_arg0;
              arg_head_arg0_arg0_head = ATgetFirst(arg_head_arg0_arg0_list);
              arg_head_arg0_arg0_list = ATgetNext(arg_head_arg0_arg0_list);
              /* checking for: char-class */
              if (ATgetType((ATerm)arg_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_head_arg0_arg0_head) == PTPT_afun23) {
                ATerm arg_head_arg0_arg0_head_arg0 = ATgetArgument(arg_head_arg0_arg0_head, 0);
                if (ATgetType((ATerm)arg_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_head_arg0_arg0_head_arg0) == ATfalse) {
                  ATerm arg_head_arg0_arg0_head_arg0_head;
                  ATermList arg_head_arg0_arg0_head_arg0_list = (ATermList)arg_head_arg0_arg0_head_arg0;
                  arg_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_head_arg0_arg0_head_arg0_list);
                  arg_head_arg0_arg0_head_arg0_list = ATgetNext(arg_head_arg0_arg0_head_arg0_list);
                  if (ATgetInt((ATermInt)arg_head_arg0_arg0_head_arg0_head) == 44) {

                    if (ATgetType((ATerm)arg_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_head_arg0_arg0_head_arg0_list) == ATtrue) {
                      if (ATgetType((ATerm)arg_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_head_arg0_arg0_list) == ATtrue) {
                        ATerm arg_head_arg0_arg1 = ATgetArgument(arg_head_arg0, 1);
                        /* checking for: lit */
                        if (ATgetType((ATerm)arg_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_head_arg0_arg1) == PTPT_afun16) {
                          ATerm arg_head_arg0_arg1_arg0 = ATgetArgument(arg_head_arg0_arg1, 0);
                          /* checking for: , */
                          if (ATgetType((ATerm)arg_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_head_arg0_arg1_arg0) == PTPT_afun19) {
                            ATerm arg_head_arg0_arg2 = ATgetArgument(arg_head_arg0, 2);
                            /* checking for: no-attrs */
                            if (ATgetType((ATerm)arg_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_head_arg0_arg2) == PTPT_afun5) {
                              ATerm arg_head_arg1 = ATgetArgument(arg_head, 1);
                              if (ATgetType((ATerm)arg_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_head_arg1) == ATfalse) {
                                ATerm arg_head_arg1_head;
                                ATermList arg_head_arg1_list = (ATermList)arg_head_arg1;
                                arg_head_arg1_head = ATgetFirst(arg_head_arg1_list);
                                arg_head_arg1_list = ATgetNext(arg_head_arg1_list);
                                if (ATgetInt((ATermInt)arg_head_arg1_head) == 44) {

                                  if (ATgetType((ATerm)arg_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_head_arg1_list) == ATtrue) {
                                    if (ATgetType((ATerm)arg_list) == AT_LIST && ATisEmpty((ATermList)arg_list) == ATfalse) {
                                      return ATtrue;
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_CharRangeList has a head. 
 * \param[in] arg input PTPT_CharRangeList
 * \return ATtrue if the PTPT_CharRangeList had a head, or ATfalse otherwise
 */
ATbool PTPT_hasCharRangeListHead(PTPT_CharRangeList arg) {
  if (PTPT_isCharRangeListSingle(arg)) {
    return ATtrue;
  }
  else if (PTPT_isCharRangeListMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_CharRangeList has a ws-after-head. 
 * \param[in] arg input PTPT_CharRangeList
 * \return ATtrue if the PTPT_CharRangeList had a ws-after-head, or ATfalse otherwise
 */
ATbool PTPT_hasCharRangeListWsAfterHead(PTPT_CharRangeList arg) {
  if (PTPT_isCharRangeListMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_CharRangeList has a ws-after-sep. 
 * \param[in] arg input PTPT_CharRangeList
 * \return ATtrue if the PTPT_CharRangeList had a ws-after-sep, or ATfalse otherwise
 */
ATbool PTPT_hasCharRangeListWsAfterSep(PTPT_CharRangeList arg) {
  if (PTPT_isCharRangeListMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_CharRangeList has a tail. 
 * \param[in] arg input PTPT_CharRangeList
 * \return ATtrue if the PTPT_CharRangeList had a tail, or ATfalse otherwise
 */
ATbool PTPT_hasCharRangeListTail(PTPT_CharRangeList arg) {
  if (PTPT_isCharRangeListMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Returns a list of all but the first element of a PTPT_CharRangeList. 
 * \param[in] arg input PTPT_CharRangeList
 * \return A new PTPT_CharRangeList, without the first element and the separator(s) just after it.)
 */
PTPT_CharRangeList PTPT_getCharRangeListTail(PTPT_CharRangeList arg) {
  assert(!PTPT_isCharRangeListEmpty(arg) && "getTail on an empty list");
  if (PTPT_isCharRangeListSingle(arg)) {
    return (PTPT_CharRangeList) PTPT_makeCharRangeListEmpty();
  }
  else {
  
    return (PTPT_CharRangeList)ATgetTail((ATermList)arg, 4);
  }
}

/**
 * Get the head PTPT_CharRange of a PTPT_CharRangeList. Note that the precondition is that this PTPT_CharRangeList actually has a head
 * \param[in] arg input PTPT_CharRangeList
 * \return the head of #arg, if it exist or an undefined value if it does not
 */
PTPT_CharRange PTPT_getCharRangeListHead(PTPT_CharRangeList arg) {
  if (PTPT_isCharRangeListSingle(arg)) {
    return (PTPT_CharRange)ATgetFirst((ATermList)arg);
  }
  else 
    return (PTPT_CharRange)ATgetFirst((ATermList)arg);
}

/**
 * Get the ws-after-head PTPT_OptLayout of a PTPT_CharRangeList. Note that the precondition is that this PTPT_CharRangeList actually has a ws-after-head
 * \param[in] arg input PTPT_CharRangeList
 * \return the ws-after-head of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getCharRangeListWsAfterHead(PTPT_CharRangeList arg) {
  
    return (PTPT_OptLayout)ATelementAt((ATermList)arg, 1);
}

/**
 * Get the ws-after-sep PTPT_OptLayout of a PTPT_CharRangeList. Note that the precondition is that this PTPT_CharRangeList actually has a ws-after-sep
 * \param[in] arg input PTPT_CharRangeList
 * \return the ws-after-sep of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getCharRangeListWsAfterSep(PTPT_CharRangeList arg) {
  
    return (PTPT_OptLayout)ATelementAt((ATermList)arg, 3);
}

/**
 * Set the head of a PTPT_CharRangeList. The precondition being that this PTPT_CharRangeList actually has a head
 * \param[in] arg input PTPT_CharRangeList
 * \param[in] head new PTPT_CharRange to set in #arg
 * \return A new PTPT_CharRangeList with head at the right place, or a core dump if #arg did not have a head
 */
PTPT_CharRangeList PTPT_setCharRangeListHead(PTPT_CharRangeList arg, PTPT_CharRange head) {
  if (PTPT_isCharRangeListSingle(arg)) {
    return (PTPT_CharRangeList)ATreplace((ATermList)arg, (ATerm)((ATerm) head), 0);
  }
  else if (PTPT_isCharRangeListMany(arg)) {
    return (PTPT_CharRangeList)ATreplace((ATermList)arg, (ATerm)((ATerm) head), 0);
  }

  ATabort("CharRangeList has no Head: %t\n", arg);
  return (PTPT_CharRangeList)NULL;
}

/**
 * Set the ws-after-head of a PTPT_CharRangeList. The precondition being that this PTPT_CharRangeList actually has a ws-after-head
 * \param[in] arg input PTPT_CharRangeList
 * \param[in] wsAfterHead new PTPT_OptLayout to set in #arg
 * \return A new PTPT_CharRangeList with wsAfterHead at the right place, or a core dump if #arg did not have a wsAfterHead
 */
PTPT_CharRangeList PTPT_setCharRangeListWsAfterHead(PTPT_CharRangeList arg, PTPT_OptLayout wsAfterHead) {
  if (PTPT_isCharRangeListMany(arg)) {
    return (PTPT_CharRangeList)ATreplace((ATermList)arg, (ATerm)((ATerm) wsAfterHead), 1);
  }

  ATabort("CharRangeList has no WsAfterHead: %t\n", arg);
  return (PTPT_CharRangeList)NULL;
}

/**
 * Set the ws-after-sep of a PTPT_CharRangeList. The precondition being that this PTPT_CharRangeList actually has a ws-after-sep
 * \param[in] arg input PTPT_CharRangeList
 * \param[in] wsAfterSep new PTPT_OptLayout to set in #arg
 * \return A new PTPT_CharRangeList with wsAfterSep at the right place, or a core dump if #arg did not have a wsAfterSep
 */
PTPT_CharRangeList PTPT_setCharRangeListWsAfterSep(PTPT_CharRangeList arg, PTPT_OptLayout wsAfterSep) {
  if (PTPT_isCharRangeListMany(arg)) {
    return (PTPT_CharRangeList)ATreplace((ATermList)arg, (ATerm)((ATerm) wsAfterSep), 3);
  }

  ATabort("CharRangeList has no WsAfterSep: %t\n", arg);
  return (PTPT_CharRangeList)NULL;
}

/**
 * Set the tail of a PTPT_CharRangeList. The precondition being that this PTPT_CharRangeList actually has a tail
 * \param[in] arg input PTPT_CharRangeList
 * \param[in] tail new PTPT_CharRangeList to set in #arg
 * \return A new PTPT_CharRangeList with tail at the right place, or a core dump if #arg did not have a tail
 */
PTPT_CharRangeList PTPT_setCharRangeListTail(PTPT_CharRangeList arg, PTPT_CharRangeList tail) {
  if (PTPT_isCharRangeListMany(arg)) {
    return (PTPT_CharRangeList)ATreplaceTail((ATermList)arg, (ATermList)((ATerm) tail), 4);
  }

  ATabort("CharRangeList has no Tail: %t\n", arg);
  return (PTPT_CharRangeList)NULL;
}

/**
 * Assert whether a PTPT_Args is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input PTPT_Args
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool PTPT_isValidArgs(PTPT_Args arg) {
  if (PTPT_isArgsList(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Args is a list by checking against the following ATerm pattern: appl(prod([lit("["),cf(opt(layout)),cf(iter-star-sep(sort("Tree"),lit(","))),cf(opt(layout)),lit("]")],cf(sort("Args")),attrs([term(cons("list"))])),[appl(prod([char-class([91])],lit("["),no-attrs),[91]),<"ws-after-["("OptLayout")>,appl(list(cf(iter-star-sep(sort("Tree"),lit(",")))),<"list"("Tree-list")>),<"ws-after-list"("OptLayout")>,appl(prod([char-class([93])],lit("]"),no-attrs),[93])]). Always returns ATtrue
 * \param[in] arg input PTPT_Args
 * \return ATtrue if #arg corresponds to the signature of a list, or ATfalse otherwise
 */
inline ATbool PTPT_isArgsList(PTPT_Args arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == PTPT_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == PTPT_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lit */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: [ */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun36) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
              /* checking for: cf */
              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                /* checking for: opt */
                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                  /* checking for: layout */
                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                      arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                      arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                      /* checking for: cf */
                      if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                        ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                        /* checking for: iter-star-sep */
                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun78) {
                          ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                          /* checking for: sort */
                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun9) {
                            ATerm arg_arg0_arg0_head_arg0_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0_arg0, 0);
                            /* checking for: Tree */
                            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0_arg0) == PTPT_afun11) {
                              ATerm arg_arg0_arg0_head_arg0_arg1 = ATgetArgument(arg_arg0_arg0_head_arg0, 1);
                              /* checking for: lit */
                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg1) == PTPT_afun16) {
                                ATerm arg_arg0_arg0_head_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0_arg1, 0);
                                /* checking for: , */
                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg1_arg0) == PTPT_afun19) {
                                  if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                    arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                    arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                    /* checking for: cf */
                                    if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                      ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                      /* checking for: opt */
                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                        ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                        /* checking for: layout */
                                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                            arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                            arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                            /* checking for: lit */
                                            if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
                                              ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                              /* checking for: ] */
                                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun33) {
                                                if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                                                  ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                                  /* checking for: cf */
                                                  if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == PTPT_afun2) {
                                                    ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                                    /* checking for: sort */
                                                    if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == PTPT_afun9) {
                                                      ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                                      /* checking for: Args */
                                                      if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == PTPT_afun18) {
                                                        ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                                        /* checking for: attrs */
                                                        if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == PTPT_afun12) {
                                                          ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                                          if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                                            ATerm arg_arg0_arg2_arg0_head;
                                                            ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                                            arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                                            arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                                            /* checking for: term */
                                                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == PTPT_afun13) {
                                                              ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                                              /* checking for: cons */
                                                              if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == PTPT_afun14) {
                                                                ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                                                /* checking for: list */
                                                                if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == PTPT_afun79) {
                                                                  if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                                    ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                                    if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                                      ATerm arg_arg1_head;
                                                                      ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                                      arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                      arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                      /* checking for: appl */
                                                                      if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                        ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                        /* checking for: prod */
                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                          ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                            ATerm arg_arg1_head_arg0_arg0_head;
                                                                            ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                            arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                            arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                            /* checking for: char-class */
                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 91) {

                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                      ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                      /* checking for: lit */
                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                        ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                        /* checking for: [ */
                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun36) {
                                                                                          ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                          /* checking for: no-attrs */
                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                            ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                              ATerm arg_arg1_head_arg1_head;
                                                                                              ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                              arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                              arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 91) {

                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                  if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                    arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                      arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                      arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                      /* checking for: appl */
                                                                                                      if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                        ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                        /* checking for: list */
                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun8) {
                                                                                                          ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                          /* checking for: cf */
                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0) == PTPT_afun2) {
                                                                                                            ATerm arg_arg1_head_arg0_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0, 0);
                                                                                                            /* checking for: iter-star-sep */
                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0) == PTPT_afun78) {
                                                                                                              ATerm arg_arg1_head_arg0_arg0_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0, 0);
                                                                                                              /* checking for: sort */
                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg0) == PTPT_afun9) {
                                                                                                                ATerm arg_arg1_head_arg0_arg0_arg0_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0_arg0, 0);
                                                                                                                /* checking for: Tree */
                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg0_arg0) == PTPT_afun11) {
                                                                                                                  ATerm arg_arg1_head_arg0_arg0_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0, 1);
                                                                                                                  /* checking for: lit */
                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg1) == PTPT_afun16) {
                                                                                                                    ATerm arg_arg1_head_arg0_arg0_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0_arg1, 0);
                                                                                                                    /* checking for: , */
                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg1_arg0) == PTPT_afun19) {
                                                                                                                      if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                        arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                          arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                          arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                          /* checking for: appl */
                                                                                                                          if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                                            ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                            /* checking for: prod */
                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                                                              ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                /* checking for: char-class */
                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                    ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                    arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                    arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 93) {

                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                          ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                          /* checking for: lit */
                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                            ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                            /* checking for: ] */
                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun33) {
                                                                                                                                              ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                              /* checking for: no-attrs */
                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                  ATerm arg_arg1_head_arg1_head;
                                                                                                                                                  ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                  arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                  arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 93) {

                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                                                                        return ATtrue;
                                                                                                                                                      }
                                                                                                                                                    }
                                                                                                                                                  }
                                                                                                                                                }
                                                                                                                                              }
                                                                                                                                            }
                                                                                                                                          }
                                                                                                                                        }
                                                                                                                                      }
                                                                                                                                    }
                                                                                                                                  }
                                                                                                                                }
                                                                                                                              }
                                                                                                                            }
                                                                                                                          }
                                                                                                                        }
                                                                                                                      }
                                                                                                                    }
                                                                                                                  }
                                                                                                                }
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Args has a ws-after-[. 
 * \param[in] arg input PTPT_Args
 * \return ATtrue if the PTPT_Args had a ws-after-[, or ATfalse otherwise
 */
ATbool PTPT_hasArgsWsAfterBracketOpen(PTPT_Args arg) {
  if (PTPT_isArgsList(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Args has a list. 
 * \param[in] arg input PTPT_Args
 * \return ATtrue if the PTPT_Args had a list, or ATfalse otherwise
 */
ATbool PTPT_hasArgsList(PTPT_Args arg) {
  if (PTPT_isArgsList(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Args has a ws-after-list. 
 * \param[in] arg input PTPT_Args
 * \return ATtrue if the PTPT_Args had a ws-after-list, or ATfalse otherwise
 */
ATbool PTPT_hasArgsWsAfterList(PTPT_Args arg) {
  if (PTPT_isArgsList(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Get the ws-after-[ PTPT_OptLayout of a PTPT_Args. Note that the precondition is that this PTPT_Args actually has a ws-after-[
 * \param[in] arg input PTPT_Args
 * \return the ws-after-[ of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getArgsWsAfterBracketOpen(PTPT_Args arg) {
  
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1);
}

/**
 * Get the list PTPT_TreeList of a PTPT_Args. Note that the precondition is that this PTPT_Args actually has a list
 * \param[in] arg input PTPT_Args
 * \return the list of #arg, if it exist or an undefined value if it does not
 */
PTPT_TreeList PTPT_getArgsList(PTPT_Args arg) {
  
    return (PTPT_TreeList)ATgetArgument((ATermAppl)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 2), 1);
}

/**
 * Get the ws-after-list PTPT_OptLayout of a PTPT_Args. Note that the precondition is that this PTPT_Args actually has a ws-after-list
 * \param[in] arg input PTPT_Args
 * \return the ws-after-list of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getArgsWsAfterList(PTPT_Args arg) {
  
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 3);
}

/**
 * Set the ws-after-[ of a PTPT_Args. The precondition being that this PTPT_Args actually has a ws-after-[
 * \param[in] arg input PTPT_Args
 * \param[in] wsAfterBracketOpen new PTPT_OptLayout to set in #arg
 * \return A new PTPT_Args with wsAfterBracketOpen at the right place, or a core dump if #arg did not have a wsAfterBracketOpen
 */
PTPT_Args PTPT_setArgsWsAfterBracketOpen(PTPT_Args arg, PTPT_OptLayout wsAfterBracketOpen) {
  if (PTPT_isArgsList(arg)) {
    return (PTPT_Args)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterBracketOpen), 1), 1);
  }

  ATabort("Args has no WsAfterBracketOpen: %t\n", arg);
  return (PTPT_Args)NULL;
}

/**
 * Set the list of a PTPT_Args. The precondition being that this PTPT_Args actually has a list
 * \param[in] arg input PTPT_Args
 * \param[in] list new PTPT_TreeList to set in #arg
 * \return A new PTPT_Args with list at the right place, or a core dump if #arg did not have a list
 */
PTPT_Args PTPT_setArgsList(PTPT_Args arg, PTPT_TreeList list) {
  if (PTPT_isArgsList(arg)) {
    return (PTPT_Args)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)ATsetArgument((ATermAppl)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 2), (ATerm)((ATerm) list), 1), 2), 1);
  }

  ATabort("Args has no List: %t\n", arg);
  return (PTPT_Args)NULL;
}

/**
 * Set the ws-after-list of a PTPT_Args. The precondition being that this PTPT_Args actually has a ws-after-list
 * \param[in] arg input PTPT_Args
 * \param[in] wsAfterList new PTPT_OptLayout to set in #arg
 * \return A new PTPT_Args with wsAfterList at the right place, or a core dump if #arg did not have a wsAfterList
 */
PTPT_Args PTPT_setArgsWsAfterList(PTPT_Args arg, PTPT_OptLayout wsAfterList) {
  if (PTPT_isArgsList(arg)) {
    return (PTPT_Args)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterList), 3), 1);
  }

  ATabort("Args has no WsAfterList: %t\n", arg);
  return (PTPT_Args)NULL;
}

/**
 * Assert whether a PTPT_Production is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input PTPT_Production
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool PTPT_isValidProduction(PTPT_Production arg) {
  if (PTPT_isProductionDefault(arg)) {
    return ATtrue;
  }
  else if (PTPT_isProductionList(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Production is a default by checking against the following ATerm pattern: appl(prod([lit("prod"),cf(opt(layout)),lit("("),cf(opt(layout)),cf(sort("Symbols")),cf(opt(layout)),lit(","),cf(opt(layout)),cf(sort("Symbol")),cf(opt(layout)),lit(","),cf(opt(layout)),cf(sort("Attributes")),cf(opt(layout)),lit(")")],cf(sort("Production")),attrs([term(cons("default"))])),[appl(prod([char-class([112]),char-class([114]),char-class([111]),char-class([100])],lit("prod"),no-attrs),[112,114,111,100]),<"ws-after-prod"("OptLayout")>,appl(prod([char-class([40])],lit("("),no-attrs),[40]),<"ws-after-("("OptLayout")>,<"lhs"("Symbols")>,<"ws-after-lhs"("OptLayout")>,appl(prod([char-class([44])],lit(","),no-attrs),[44]),<"ws-after-comma1"("OptLayout")>,<"rhs"("Symbol")>,<"ws-after-rhs"("OptLayout")>,appl(prod([char-class([44])],lit(","),no-attrs),[44]),<"ws-after-comma2"("OptLayout")>,<"attributes"("Attributes")>,<"ws-after-attributes"("OptLayout")>,appl(prod([char-class([41])],lit(")"),no-attrs),[41])]). May not be used to assert correctness of the PTPT_Production
 * \param[in] arg input PTPT_Production
 * \return ATtrue if #arg corresponds to the signature of a default, or ATfalse otherwise
 */
inline ATbool PTPT_isProductionDefault(PTPT_Production arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == PTPT_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == PTPT_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lit */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: prod */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun87) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
              /* checking for: cf */
              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                /* checking for: opt */
                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                  /* checking for: layout */
                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                      arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                      arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                      /* checking for: lit */
                      if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
                        ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                        /* checking for: ( */
                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun21) {
                          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                            arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                            arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                            /* checking for: cf */
                            if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                              ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                              /* checking for: opt */
                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                /* checking for: layout */
                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                  if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                    arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                    arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                    /* checking for: cf */
                                    if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                      ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                      /* checking for: sort */
                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun9) {
                                        ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                        /* checking for: Symbols */
                                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun61) {
                                          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                            arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                            arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                            /* checking for: cf */
                                            if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                              ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                              /* checking for: opt */
                                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                                ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                /* checking for: layout */
                                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                                  if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                    arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                    arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                    /* checking for: lit */
                                                    if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
                                                      ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                      /* checking for: , */
                                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun19) {
                                                        if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                          arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                          arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                          /* checking for: cf */
                                                          if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                                            ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                            /* checking for: opt */
                                                            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                                              ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                              /* checking for: layout */
                                                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                                                if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                                  arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                                  arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                                  /* checking for: cf */
                                                                  if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                                                    ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                                    /* checking for: sort */
                                                                    if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun9) {
                                                                      ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                                      /* checking for: Symbol */
                                                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun25) {
                                                                        if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                                          arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                                          arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                                          /* checking for: cf */
                                                                          if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                                                            ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                                            /* checking for: opt */
                                                                            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                                                              ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                                              /* checking for: layout */
                                                                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                                                                if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                                                  arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                                                  arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                                                  /* checking for: lit */
                                                                                  if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
                                                                                    ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                                                    /* checking for: , */
                                                                                    if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun19) {
                                                                                      if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                                                        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                                                        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                                                        /* checking for: cf */
                                                                                        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                                                                          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                                                          /* checking for: opt */
                                                                                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                                                                            ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                                                            /* checking for: layout */
                                                                                            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                                                                              if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                                                                arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                                                                arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                                                                /* checking for: cf */
                                                                                                if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                                                                                  ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                                                                  /* checking for: sort */
                                                                                                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun9) {
                                                                                                    ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                                                                    /* checking for: Attributes */
                                                                                                    if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun30) {
                                                                                                      if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                                                                        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                                                                        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                                                                        /* checking for: cf */
                                                                                                        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                                                                                          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                                                                          /* checking for: opt */
                                                                                                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                                                                                            ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                                                                            /* checking for: layout */
                                                                                                            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                                                                                              if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                                                                                arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                                                                                arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                                                                                /* checking for: lit */
                                                                                                                if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
                                                                                                                  ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                                                                                  /* checking for: ) */
                                                                                                                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun17) {
                                                                                                                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                                                                                                                      ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                                                                                                      /* checking for: cf */
                                                                                                                      if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == PTPT_afun2) {
                                                                                                                        ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                                                                                                        /* checking for: sort */
                                                                                                                        if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == PTPT_afun9) {
                                                                                                                          ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                                                                                                          /* checking for: Production */
                                                                                                                          if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == PTPT_afun20) {
                                                                                                                            ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                                                                                                            /* checking for: attrs */
                                                                                                                            if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == PTPT_afun12) {
                                                                                                                              ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                                                                                                              if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                                                                                                                ATerm arg_arg0_arg2_arg0_head;
                                                                                                                                ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                                                                                                                arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                                                                                                                arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                                                                                                                /* checking for: term */
                                                                                                                                if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == PTPT_afun13) {
                                                                                                                                  ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                                                                                                                  /* checking for: cons */
                                                                                                                                  if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == PTPT_afun14) {
                                                                                                                                    ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                                                                                                                    /* checking for: default */
                                                                                                                                    if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == PTPT_afun88) {
                                                                                                                                      if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                                                                                                        ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                                                                                                        if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                                                                                                          ATerm arg_arg1_head;
                                                                                                                                          ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                                                                                                          arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                          arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                          /* checking for: appl */
                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                                                            ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                                            /* checking for: prod */
                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                                                                              ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                                ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                                ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                                arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                /* checking for: char-class */
                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                    ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                    arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                    arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 112) {

                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                                          arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                          arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                          /* checking for: char-class */
                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                              ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                              arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                              arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 114) {

                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                                                    arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                    arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                    /* checking for: char-class */
                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                        ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                        arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                        arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 111) {

                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                                                              arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                              arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                              /* checking for: char-class */
                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                  ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 100) {

                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                                                        /* checking for: lit */
                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                                                                          ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                                          /* checking for: prod */
                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun87) {
                                                                                                                                                                                            ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                                            /* checking for: no-attrs */
                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                                                              ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                                                ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                                                ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                                                arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 112) {

                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                    arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                    arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 114) {

                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                        arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                        arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 111) {

                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                            arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                            arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 100) {

                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                    arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                                                                                                    arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                    /* checking for: appl */
                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                                                                                                                                      ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                                                                                                                      /* checking for: prod */
                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                                                                                                          ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                                                                                                          ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                                                                                                          arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                          arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                          /* checking for: char-class */
                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                                                              ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                                                              arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                              arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 40) {

                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                    ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                                                                                                    /* checking for: lit */
                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                                                                                                                      ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                                                                                      /* checking for: ( */
                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun21) {
                                                                                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                                                                                        /* checking for: no-attrs */
                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                                                                                                          ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                                                                                            ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                                                                                            ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                                                                                            arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                            arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 40) {

                                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                    arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                      arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                        arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                                                                                                                                        arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                        /* checking for: appl */
                                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                                                                                                                                                                          ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                                                                                                                                                          /* checking for: prod */
                                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                                                                                                                                                                                            ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                                                                                                                                              ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                                                                                                                                              ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                                                                                                                                              arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                                              arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                                              /* checking for: char-class */
                                                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                                                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                                                                                                  ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 44) {

                                                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                                                                                                                                        /* checking for: lit */
                                                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                                                                                                                                                          ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                                                                                                                          /* checking for: , */
                                                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun19) {
                                                                                                                                                                                                                                                                            ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                                                                                                                            /* checking for: no-attrs */
                                                                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                                                                                                                                              ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                                                                                                                                ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                                                                                                                                ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                                                                                                                                arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 44) {

                                                                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                      arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                        arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                          arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                            arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                                                                                                                                                                            arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                                                            /* checking for: appl */
                                                                                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                                                                                                                                                                                                              ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                                                                                                                                                                                              /* checking for: prod */
                                                                                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                                                                                                                                                                                                                                ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                                                                                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                                                                                                                                                                                  ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                                                                                                                                                                                  arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                                                                                  arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                                                                                  /* checking for: char-class */
                                                                                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                                                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                                                                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                                                                                                                                      ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                                                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 44) {

                                                                                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                                                                                            ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                                                                                                                                                                            /* checking for: lit */
                                                                                                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                                                                                                                                                                                              ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                                                                                                                                                              /* checking for: , */
                                                                                                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun19) {
                                                                                                                                                                                                                                                                                                                ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                                                                                                                                                                /* checking for: no-attrs */
                                                                                                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                                                                                                                                                                                  ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                                                                                                                                                                    ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                                                                                                                                                                    ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                                                                                                                                                                    arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                                                    arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 44) {

                                                                                                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                                                          arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                                                            arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                                                              arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                                                                arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                                                                                                                                                                                                                arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                                                                                                /* checking for: appl */
                                                                                                                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                                                                                                                                                                                                                                                  ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                                                                                                                                                                                                                                  /* checking for: prod */
                                                                                                                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                                                                                                                                                                                                                                                                    ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                                                                                                                                                                                                                      ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                                                                                                                                                                                                                      ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                                                                                                                                                                                                                      arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                                                                                                                      arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                                                                                                                      /* checking for: char-class */
                                                                                                                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                                                                                                                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                                                                                                                                                                          ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                                                                                                                                                                          arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                                                                                                                          arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                                                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 41) {

                                                                                                                                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                                                                                                                                ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                                                                                                                                                                                                                /* checking for: lit */
                                                                                                                                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                                                                                                                                                                                                                                  ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                                                                                                                                                                                                  /* checking for: ) */
                                                                                                                                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun17) {
                                                                                                                                                                                                                                                                                                                                                    ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                                                                                                                                                                                                    /* checking for: no-attrs */
                                                                                                                                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                                                                                                                                                                                                                      ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                                                                                                                                                                                                        ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                                                                                                                                                                                                        ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                                                                                                                                                                                                        arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                                                                                        arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 41) {

                                                                                                                                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                                                                                                                                                                                                                                                                              return ATtrue;
                                                                                                                                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                }
                                                                                                                                                                                                                              }
                                                                                                                                                                                                                            }
                                                                                                                                                                                                                          }
                                                                                                                                                                                                                        }
                                                                                                                                                                                                                      }
                                                                                                                                                                                                                    }
                                                                                                                                                                                                                  }
                                                                                                                                                                                                                }
                                                                                                                                                                                                              }
                                                                                                                                                                                                            }
                                                                                                                                                                                                          }
                                                                                                                                                                                                        }
                                                                                                                                                                                                      }
                                                                                                                                                                                                    }
                                                                                                                                                                                                  }
                                                                                                                                                                                                }
                                                                                                                                                                                              }
                                                                                                                                                                                            }
                                                                                                                                                                                          }
                                                                                                                                                                                        }
                                                                                                                                                                                      }
                                                                                                                                                                                    }
                                                                                                                                                                                  }
                                                                                                                                                                                }
                                                                                                                                                                              }
                                                                                                                                                                            }
                                                                                                                                                                          }
                                                                                                                                                                        }
                                                                                                                                                                      }
                                                                                                                                                                    }
                                                                                                                                                                  }
                                                                                                                                                                }
                                                                                                                                                              }
                                                                                                                                                            }
                                                                                                                                                          }
                                                                                                                                                        }
                                                                                                                                                      }
                                                                                                                                                    }
                                                                                                                                                  }
                                                                                                                                                }
                                                                                                                                              }
                                                                                                                                            }
                                                                                                                                          }
                                                                                                                                        }
                                                                                                                                      }
                                                                                                                                    }
                                                                                                                                  }
                                                                                                                                }
                                                                                                                              }
                                                                                                                            }
                                                                                                                          }
                                                                                                                        }
                                                                                                                      }
                                                                                                                    }
                                                                                                                  }
                                                                                                                }
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Production is a list by checking against the following ATerm pattern: appl(prod([lit("list"),cf(opt(layout)),lit("("),cf(opt(layout)),cf(sort("Symbol")),cf(opt(layout)),lit(")")],cf(sort("Production")),attrs([term(cons("list"))])),[appl(prod([char-class([108]),char-class([105]),char-class([115]),char-class([116])],lit("list"),no-attrs),[108,105,115,116]),<"ws-after-list"("OptLayout")>,appl(prod([char-class([40])],lit("("),no-attrs),[40]),<"ws-after-("("OptLayout")>,<"rhs"("Symbol")>,<"ws-after-rhs"("OptLayout")>,appl(prod([char-class([41])],lit(")"),no-attrs),[41])]). May not be used to assert correctness of the PTPT_Production
 * \param[in] arg input PTPT_Production
 * \return ATtrue if #arg corresponds to the signature of a list, or ATfalse otherwise
 */
inline ATbool PTPT_isProductionList(PTPT_Production arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == PTPT_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == PTPT_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lit */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: list */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun79) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
              /* checking for: cf */
              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                /* checking for: opt */
                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                  /* checking for: layout */
                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                      arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                      arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                      /* checking for: lit */
                      if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
                        ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                        /* checking for: ( */
                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun21) {
                          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                            arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                            arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                            /* checking for: cf */
                            if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                              ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                              /* checking for: opt */
                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                /* checking for: layout */
                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                  if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                    arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                    arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                    /* checking for: cf */
                                    if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                      ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                      /* checking for: sort */
                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun9) {
                                        ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                        /* checking for: Symbol */
                                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun25) {
                                          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                            arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                            arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                            /* checking for: cf */
                                            if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                              ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                              /* checking for: opt */
                                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                                ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                /* checking for: layout */
                                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                                  if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                    arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                    arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                    /* checking for: lit */
                                                    if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
                                                      ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                      /* checking for: ) */
                                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun17) {
                                                        if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                                                          ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                                          /* checking for: cf */
                                                          if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == PTPT_afun2) {
                                                            ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                                            /* checking for: sort */
                                                            if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == PTPT_afun9) {
                                                              ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                                              /* checking for: Production */
                                                              if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == PTPT_afun20) {
                                                                ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                                                /* checking for: attrs */
                                                                if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == PTPT_afun12) {
                                                                  ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                                                  if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                                                    ATerm arg_arg0_arg2_arg0_head;
                                                                    ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                                                    arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                                                    arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                                                    /* checking for: term */
                                                                    if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == PTPT_afun13) {
                                                                      ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                                                      /* checking for: cons */
                                                                      if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == PTPT_afun14) {
                                                                        ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                                                        /* checking for: list */
                                                                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == PTPT_afun79) {
                                                                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                                            ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                                            if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                                              ATerm arg_arg1_head;
                                                                              ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                                              arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                              arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                              /* checking for: appl */
                                                                              if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                /* checking for: prod */
                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                  ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                    ATerm arg_arg1_head_arg0_arg0_head;
                                                                                    ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                    arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                    arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                    /* checking for: char-class */
                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                        ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                        arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                        arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 108) {

                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                              arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                              arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                              /* checking for: char-class */
                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                  ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 105) {

                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                        arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                        arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                        /* checking for: char-class */
                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                            ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                            arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                            arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 115) {

                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                  arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                  arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                  /* checking for: char-class */
                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                      ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 116) {

                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                            ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                            /* checking for: lit */
                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                              ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                              /* checking for: list */
                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun79) {
                                                                                                                                ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                /* checking for: no-attrs */
                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                  ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                    ATerm arg_arg1_head_arg1_head;
                                                                                                                                    ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                    arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                    arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 108) {

                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                        arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                        arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 105) {

                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                            arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                            arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 115) {

                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 116) {

                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                      arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                        arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                                        arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                        /* checking for: appl */
                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                                                                          ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                                                          /* checking for: prod */
                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                                                                                            ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                                              ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                                              ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                                              arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                              arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                              /* checking for: char-class */
                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                  ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 40) {

                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                                        /* checking for: lit */
                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                                                          ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                          /* checking for: ( */
                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun21) {
                                                                                                                                                                            ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                            /* checking for: no-attrs */
                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                                              ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                                ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                                ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                                arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 40) {

                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                      arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                        arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                          arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                            arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                                                                            arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                            /* checking for: appl */
                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                                                                                                              ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                                                                                              /* checking for: prod */
                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                                                                                                                                ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                                                                                  ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                                                                                  arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                  arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                  /* checking for: char-class */
                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                                      ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 41) {

                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                                                            ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                                                                            /* checking for: lit */
                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                                                                                              ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                                                              /* checking for: ) */
                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun17) {
                                                                                                                                                                                                                ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                                                                /* checking for: no-attrs */
                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                                                                                  ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                                                                    ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                                                                    ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                                                                    arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                    arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 41) {

                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                                                                                                                                          return ATtrue;
                                                                                                                                                                                                                        }
                                                                                                                                                                                                                      }
                                                                                                                                                                                                                    }
                                                                                                                                                                                                                  }
                                                                                                                                                                                                                }
                                                                                                                                                                                                              }
                                                                                                                                                                                                            }
                                                                                                                                                                                                          }
                                                                                                                                                                                                        }
                                                                                                                                                                                                      }
                                                                                                                                                                                                    }
                                                                                                                                                                                                  }
                                                                                                                                                                                                }
                                                                                                                                                                                              }
                                                                                                                                                                                            }
                                                                                                                                                                                          }
                                                                                                                                                                                        }
                                                                                                                                                                                      }
                                                                                                                                                                                    }
                                                                                                                                                                                  }
                                                                                                                                                                                }
                                                                                                                                                                              }
                                                                                                                                                                            }
                                                                                                                                                                          }
                                                                                                                                                                        }
                                                                                                                                                                      }
                                                                                                                                                                    }
                                                                                                                                                                  }
                                                                                                                                                                }
                                                                                                                                                              }
                                                                                                                                                            }
                                                                                                                                                          }
                                                                                                                                                        }
                                                                                                                                                      }
                                                                                                                                                    }
                                                                                                                                                  }
                                                                                                                                                }
                                                                                                                                              }
                                                                                                                                            }
                                                                                                                                          }
                                                                                                                                        }
                                                                                                                                      }
                                                                                                                                    }
                                                                                                                                  }
                                                                                                                                }
                                                                                                                              }
                                                                                                                            }
                                                                                                                          }
                                                                                                                        }
                                                                                                                      }
                                                                                                                    }
                                                                                                                  }
                                                                                                                }
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Production has a ws-after-prod. 
 * \param[in] arg input PTPT_Production
 * \return ATtrue if the PTPT_Production had a ws-after-prod, or ATfalse otherwise
 */
ATbool PTPT_hasProductionWsAfterProd(PTPT_Production arg) {
  if (PTPT_isProductionDefault(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Production has a ws-after-(. 
 * \param[in] arg input PTPT_Production
 * \return ATtrue if the PTPT_Production had a ws-after-(, or ATfalse otherwise
 */
ATbool PTPT_hasProductionWsAfterParenOpen(PTPT_Production arg) {
  if (PTPT_isProductionDefault(arg)) {
    return ATtrue;
  }
  else if (PTPT_isProductionList(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Production has a lhs. 
 * \param[in] arg input PTPT_Production
 * \return ATtrue if the PTPT_Production had a lhs, or ATfalse otherwise
 */
ATbool PTPT_hasProductionLhs(PTPT_Production arg) {
  if (PTPT_isProductionDefault(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Production has a ws-after-lhs. 
 * \param[in] arg input PTPT_Production
 * \return ATtrue if the PTPT_Production had a ws-after-lhs, or ATfalse otherwise
 */
ATbool PTPT_hasProductionWsAfterLhs(PTPT_Production arg) {
  if (PTPT_isProductionDefault(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Production has a ws-after-comma1. 
 * \param[in] arg input PTPT_Production
 * \return ATtrue if the PTPT_Production had a ws-after-comma1, or ATfalse otherwise
 */
ATbool PTPT_hasProductionWsAfterComma1(PTPT_Production arg) {
  if (PTPT_isProductionDefault(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Production has a rhs. 
 * \param[in] arg input PTPT_Production
 * \return ATtrue if the PTPT_Production had a rhs, or ATfalse otherwise
 */
ATbool PTPT_hasProductionRhs(PTPT_Production arg) {
  if (PTPT_isProductionDefault(arg)) {
    return ATtrue;
  }
  else if (PTPT_isProductionList(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Production has a ws-after-rhs. 
 * \param[in] arg input PTPT_Production
 * \return ATtrue if the PTPT_Production had a ws-after-rhs, or ATfalse otherwise
 */
ATbool PTPT_hasProductionWsAfterRhs(PTPT_Production arg) {
  if (PTPT_isProductionDefault(arg)) {
    return ATtrue;
  }
  else if (PTPT_isProductionList(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Production has a ws-after-comma2. 
 * \param[in] arg input PTPT_Production
 * \return ATtrue if the PTPT_Production had a ws-after-comma2, or ATfalse otherwise
 */
ATbool PTPT_hasProductionWsAfterComma2(PTPT_Production arg) {
  if (PTPT_isProductionDefault(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Production has a attributes. 
 * \param[in] arg input PTPT_Production
 * \return ATtrue if the PTPT_Production had a attributes, or ATfalse otherwise
 */
ATbool PTPT_hasProductionAttributes(PTPT_Production arg) {
  if (PTPT_isProductionDefault(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Production has a ws-after-attributes. 
 * \param[in] arg input PTPT_Production
 * \return ATtrue if the PTPT_Production had a ws-after-attributes, or ATfalse otherwise
 */
ATbool PTPT_hasProductionWsAfterAttributes(PTPT_Production arg) {
  if (PTPT_isProductionDefault(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Production has a ws-after-list. 
 * \param[in] arg input PTPT_Production
 * \return ATtrue if the PTPT_Production had a ws-after-list, or ATfalse otherwise
 */
ATbool PTPT_hasProductionWsAfterList(PTPT_Production arg) {
  if (PTPT_isProductionList(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Get the ws-after-prod PTPT_OptLayout of a PTPT_Production. Note that the precondition is that this PTPT_Production actually has a ws-after-prod
 * \param[in] arg input PTPT_Production
 * \return the ws-after-prod of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getProductionWsAfterProd(PTPT_Production arg) {
  
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1);
}

/**
 * Get the ws-after-( PTPT_OptLayout of a PTPT_Production. Note that the precondition is that this PTPT_Production actually has a ws-after-(
 * \param[in] arg input PTPT_Production
 * \return the ws-after-( of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getProductionWsAfterParenOpen(PTPT_Production arg) {
  if (PTPT_isProductionDefault(arg)) {
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 3);
  }
  else 
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 3);
}

/**
 * Get the lhs PTPT_Symbols of a PTPT_Production. Note that the precondition is that this PTPT_Production actually has a lhs
 * \param[in] arg input PTPT_Production
 * \return the lhs of #arg, if it exist or an undefined value if it does not
 */
PTPT_Symbols PTPT_getProductionLhs(PTPT_Production arg) {
  
    return (PTPT_Symbols)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 4);
}

/**
 * Get the ws-after-lhs PTPT_OptLayout of a PTPT_Production. Note that the precondition is that this PTPT_Production actually has a ws-after-lhs
 * \param[in] arg input PTPT_Production
 * \return the ws-after-lhs of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getProductionWsAfterLhs(PTPT_Production arg) {
  
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 5);
}

/**
 * Get the ws-after-comma1 PTPT_OptLayout of a PTPT_Production. Note that the precondition is that this PTPT_Production actually has a ws-after-comma1
 * \param[in] arg input PTPT_Production
 * \return the ws-after-comma1 of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getProductionWsAfterComma1(PTPT_Production arg) {
  
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 7);
}

/**
 * Get the rhs PTPT_Symbol of a PTPT_Production. Note that the precondition is that this PTPT_Production actually has a rhs
 * \param[in] arg input PTPT_Production
 * \return the rhs of #arg, if it exist or an undefined value if it does not
 */
PTPT_Symbol PTPT_getProductionRhs(PTPT_Production arg) {
  if (PTPT_isProductionDefault(arg)) {
    return (PTPT_Symbol)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 8);
  }
  else 
    return (PTPT_Symbol)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 4);
}

/**
 * Get the ws-after-rhs PTPT_OptLayout of a PTPT_Production. Note that the precondition is that this PTPT_Production actually has a ws-after-rhs
 * \param[in] arg input PTPT_Production
 * \return the ws-after-rhs of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getProductionWsAfterRhs(PTPT_Production arg) {
  if (PTPT_isProductionDefault(arg)) {
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 9);
  }
  else 
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 5);
}

/**
 * Get the ws-after-comma2 PTPT_OptLayout of a PTPT_Production. Note that the precondition is that this PTPT_Production actually has a ws-after-comma2
 * \param[in] arg input PTPT_Production
 * \return the ws-after-comma2 of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getProductionWsAfterComma2(PTPT_Production arg) {
  
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 11);
}

/**
 * Get the attributes PTPT_Attributes of a PTPT_Production. Note that the precondition is that this PTPT_Production actually has a attributes
 * \param[in] arg input PTPT_Production
 * \return the attributes of #arg, if it exist or an undefined value if it does not
 */
PTPT_Attributes PTPT_getProductionAttributes(PTPT_Production arg) {
  
    return (PTPT_Attributes)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 12);
}

/**
 * Get the ws-after-attributes PTPT_OptLayout of a PTPT_Production. Note that the precondition is that this PTPT_Production actually has a ws-after-attributes
 * \param[in] arg input PTPT_Production
 * \return the ws-after-attributes of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getProductionWsAfterAttributes(PTPT_Production arg) {
  
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 13);
}

/**
 * Get the ws-after-list PTPT_OptLayout of a PTPT_Production. Note that the precondition is that this PTPT_Production actually has a ws-after-list
 * \param[in] arg input PTPT_Production
 * \return the ws-after-list of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getProductionWsAfterList(PTPT_Production arg) {
  
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1);
}

/**
 * Set the ws-after-prod of a PTPT_Production. The precondition being that this PTPT_Production actually has a ws-after-prod
 * \param[in] arg input PTPT_Production
 * \param[in] wsAfterProd new PTPT_OptLayout to set in #arg
 * \return A new PTPT_Production with wsAfterProd at the right place, or a core dump if #arg did not have a wsAfterProd
 */
PTPT_Production PTPT_setProductionWsAfterProd(PTPT_Production arg, PTPT_OptLayout wsAfterProd) {
  if (PTPT_isProductionDefault(arg)) {
    return (PTPT_Production)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterProd), 1), 1);
  }

  ATabort("Production has no WsAfterProd: %t\n", arg);
  return (PTPT_Production)NULL;
}

/**
 * Set the ws-after-( of a PTPT_Production. The precondition being that this PTPT_Production actually has a ws-after-(
 * \param[in] arg input PTPT_Production
 * \param[in] wsAfterParenOpen new PTPT_OptLayout to set in #arg
 * \return A new PTPT_Production with wsAfterParenOpen at the right place, or a core dump if #arg did not have a wsAfterParenOpen
 */
PTPT_Production PTPT_setProductionWsAfterParenOpen(PTPT_Production arg, PTPT_OptLayout wsAfterParenOpen) {
  if (PTPT_isProductionDefault(arg)) {
    return (PTPT_Production)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterParenOpen), 3), 1);
  }
  else if (PTPT_isProductionList(arg)) {
    return (PTPT_Production)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterParenOpen), 3), 1);
  }

  ATabort("Production has no WsAfterParenOpen: %t\n", arg);
  return (PTPT_Production)NULL;
}

/**
 * Set the lhs of a PTPT_Production. The precondition being that this PTPT_Production actually has a lhs
 * \param[in] arg input PTPT_Production
 * \param[in] lhs new PTPT_Symbols to set in #arg
 * \return A new PTPT_Production with lhs at the right place, or a core dump if #arg did not have a lhs
 */
PTPT_Production PTPT_setProductionLhs(PTPT_Production arg, PTPT_Symbols lhs) {
  if (PTPT_isProductionDefault(arg)) {
    return (PTPT_Production)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) lhs), 4), 1);
  }

  ATabort("Production has no Lhs: %t\n", arg);
  return (PTPT_Production)NULL;
}

/**
 * Set the ws-after-lhs of a PTPT_Production. The precondition being that this PTPT_Production actually has a ws-after-lhs
 * \param[in] arg input PTPT_Production
 * \param[in] wsAfterLhs new PTPT_OptLayout to set in #arg
 * \return A new PTPT_Production with wsAfterLhs at the right place, or a core dump if #arg did not have a wsAfterLhs
 */
PTPT_Production PTPT_setProductionWsAfterLhs(PTPT_Production arg, PTPT_OptLayout wsAfterLhs) {
  if (PTPT_isProductionDefault(arg)) {
    return (PTPT_Production)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterLhs), 5), 1);
  }

  ATabort("Production has no WsAfterLhs: %t\n", arg);
  return (PTPT_Production)NULL;
}

/**
 * Set the ws-after-comma1 of a PTPT_Production. The precondition being that this PTPT_Production actually has a ws-after-comma1
 * \param[in] arg input PTPT_Production
 * \param[in] wsAfterComma1 new PTPT_OptLayout to set in #arg
 * \return A new PTPT_Production with wsAfterComma1 at the right place, or a core dump if #arg did not have a wsAfterComma1
 */
PTPT_Production PTPT_setProductionWsAfterComma1(PTPT_Production arg, PTPT_OptLayout wsAfterComma1) {
  if (PTPT_isProductionDefault(arg)) {
    return (PTPT_Production)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterComma1), 7), 1);
  }

  ATabort("Production has no WsAfterComma1: %t\n", arg);
  return (PTPT_Production)NULL;
}

/**
 * Set the rhs of a PTPT_Production. The precondition being that this PTPT_Production actually has a rhs
 * \param[in] arg input PTPT_Production
 * \param[in] rhs new PTPT_Symbol to set in #arg
 * \return A new PTPT_Production with rhs at the right place, or a core dump if #arg did not have a rhs
 */
PTPT_Production PTPT_setProductionRhs(PTPT_Production arg, PTPT_Symbol rhs) {
  if (PTPT_isProductionDefault(arg)) {
    return (PTPT_Production)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) rhs), 8), 1);
  }
  else if (PTPT_isProductionList(arg)) {
    return (PTPT_Production)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) rhs), 4), 1);
  }

  ATabort("Production has no Rhs: %t\n", arg);
  return (PTPT_Production)NULL;
}

/**
 * Set the ws-after-rhs of a PTPT_Production. The precondition being that this PTPT_Production actually has a ws-after-rhs
 * \param[in] arg input PTPT_Production
 * \param[in] wsAfterRhs new PTPT_OptLayout to set in #arg
 * \return A new PTPT_Production with wsAfterRhs at the right place, or a core dump if #arg did not have a wsAfterRhs
 */
PTPT_Production PTPT_setProductionWsAfterRhs(PTPT_Production arg, PTPT_OptLayout wsAfterRhs) {
  if (PTPT_isProductionDefault(arg)) {
    return (PTPT_Production)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterRhs), 9), 1);
  }
  else if (PTPT_isProductionList(arg)) {
    return (PTPT_Production)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterRhs), 5), 1);
  }

  ATabort("Production has no WsAfterRhs: %t\n", arg);
  return (PTPT_Production)NULL;
}

/**
 * Set the ws-after-comma2 of a PTPT_Production. The precondition being that this PTPT_Production actually has a ws-after-comma2
 * \param[in] arg input PTPT_Production
 * \param[in] wsAfterComma2 new PTPT_OptLayout to set in #arg
 * \return A new PTPT_Production with wsAfterComma2 at the right place, or a core dump if #arg did not have a wsAfterComma2
 */
PTPT_Production PTPT_setProductionWsAfterComma2(PTPT_Production arg, PTPT_OptLayout wsAfterComma2) {
  if (PTPT_isProductionDefault(arg)) {
    return (PTPT_Production)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterComma2), 11), 1);
  }

  ATabort("Production has no WsAfterComma2: %t\n", arg);
  return (PTPT_Production)NULL;
}

/**
 * Set the attributes of a PTPT_Production. The precondition being that this PTPT_Production actually has a attributes
 * \param[in] arg input PTPT_Production
 * \param[in] attributes new PTPT_Attributes to set in #arg
 * \return A new PTPT_Production with attributes at the right place, or a core dump if #arg did not have a attributes
 */
PTPT_Production PTPT_setProductionAttributes(PTPT_Production arg, PTPT_Attributes attributes) {
  if (PTPT_isProductionDefault(arg)) {
    return (PTPT_Production)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) attributes), 12), 1);
  }

  ATabort("Production has no Attributes: %t\n", arg);
  return (PTPT_Production)NULL;
}

/**
 * Set the ws-after-attributes of a PTPT_Production. The precondition being that this PTPT_Production actually has a ws-after-attributes
 * \param[in] arg input PTPT_Production
 * \param[in] wsAfterAttributes new PTPT_OptLayout to set in #arg
 * \return A new PTPT_Production with wsAfterAttributes at the right place, or a core dump if #arg did not have a wsAfterAttributes
 */
PTPT_Production PTPT_setProductionWsAfterAttributes(PTPT_Production arg, PTPT_OptLayout wsAfterAttributes) {
  if (PTPT_isProductionDefault(arg)) {
    return (PTPT_Production)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterAttributes), 13), 1);
  }

  ATabort("Production has no WsAfterAttributes: %t\n", arg);
  return (PTPT_Production)NULL;
}

/**
 * Set the ws-after-list of a PTPT_Production. The precondition being that this PTPT_Production actually has a ws-after-list
 * \param[in] arg input PTPT_Production
 * \param[in] wsAfterList new PTPT_OptLayout to set in #arg
 * \return A new PTPT_Production with wsAfterList at the right place, or a core dump if #arg did not have a wsAfterList
 */
PTPT_Production PTPT_setProductionWsAfterList(PTPT_Production arg, PTPT_OptLayout wsAfterList) {
  if (PTPT_isProductionList(arg)) {
    return (PTPT_Production)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterList), 1), 1);
  }

  ATabort("Production has no WsAfterList: %t\n", arg);
  return (PTPT_Production)NULL;
}

/**
 * Assert whether a PTPT_TreeList is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input PTPT_TreeList
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool PTPT_isValidTreeList(PTPT_TreeList arg) {
  if (PTPT_isTreeListEmpty(arg)) {
    return ATtrue;
  }
  else if (PTPT_isTreeListSingle(arg)) {
    return ATtrue;
  }
  else if (PTPT_isTreeListMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_TreeList is a empty by checking against the following ATerm pattern: []. May not be used to assert correctness of the PTPT_TreeList
 * \param[in] arg input PTPT_TreeList
 * \return ATtrue if #arg corresponds to the signature of a empty, or ATfalse otherwise
 */
inline ATbool PTPT_isTreeListEmpty(PTPT_TreeList arg){
  if (ATisEmpty((ATermList)arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_TreeList is a single by checking against the following ATerm pattern: [<head(Tree)>]. May not be used to assert correctness of the PTPT_TreeList
 * \param[in] arg input PTPT_TreeList
 * \return ATtrue if #arg corresponds to the signature of a single, or ATfalse otherwise
 */
inline ATbool PTPT_isTreeListSingle(PTPT_TreeList arg){
  if (ATgetType((ATerm)arg) == AT_LIST && ATisEmpty((ATermList)arg) == ATfalse) {
    ATermList arg_list = (ATermList)arg;
    arg_list = ATgetNext(arg_list);
    if (ATgetType((ATerm)arg_list) == AT_LIST && ATisEmpty((ATermList)arg_list) == ATtrue) {
      return ATtrue;
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_TreeList is a many by checking against the following ATerm pattern: [<head(Tree)>,<ws-after-head("OptLayout")>,appl(prod([char-class([44])],lit(","),no-attrs),[44]),<ws-after-sep("OptLayout")>,<[tail(Tree-list)]>]. May not be used to assert correctness of the PTPT_TreeList
 * \param[in] arg input PTPT_TreeList
 * \return ATtrue if #arg corresponds to the signature of a many, or ATfalse otherwise
 */
inline ATbool PTPT_isTreeListMany(PTPT_TreeList arg){
  if (ATgetType((ATerm)arg) == AT_LIST && ATisEmpty((ATermList)arg) == ATfalse) {
    ATerm arg_head;
    ATermList arg_list = (ATermList)arg;
    arg_list = ATgetNext(arg_list);
    if (ATgetType((ATerm)arg_list) == AT_LIST && ATisEmpty((ATermList)arg_list) == ATfalse) {
      arg_list = ATgetNext(arg_list);
      if (ATgetType((ATerm)arg_list) == AT_LIST && ATisEmpty((ATermList)arg_list) == ATfalse) {
        arg_head = ATgetFirst(arg_list);
        arg_list = ATgetNext(arg_list);
        /* checking for: appl */
        if (ATgetType((ATerm)arg_head) == AT_APPL && ATgetAFun((ATermAppl)arg_head) == PTPT_afun0) {
          ATerm arg_head_arg0 = ATgetArgument(arg_head, 0);
          /* checking for: prod */
          if (ATgetType((ATerm)arg_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_head_arg0) == PTPT_afun1) {
            ATerm arg_head_arg0_arg0 = ATgetArgument(arg_head_arg0, 0);
            if (ATgetType((ATerm)arg_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_head_arg0_arg0) == ATfalse) {
              ATerm arg_head_arg0_arg0_head;
              ATermList arg_head_arg0_arg0_list = (ATermList)arg_head_arg0_arg0;
              arg_head_arg0_arg0_head = ATgetFirst(arg_head_arg0_arg0_list);
              arg_head_arg0_arg0_list = ATgetNext(arg_head_arg0_arg0_list);
              /* checking for: char-class */
              if (ATgetType((ATerm)arg_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_head_arg0_arg0_head) == PTPT_afun23) {
                ATerm arg_head_arg0_arg0_head_arg0 = ATgetArgument(arg_head_arg0_arg0_head, 0);
                if (ATgetType((ATerm)arg_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_head_arg0_arg0_head_arg0) == ATfalse) {
                  ATerm arg_head_arg0_arg0_head_arg0_head;
                  ATermList arg_head_arg0_arg0_head_arg0_list = (ATermList)arg_head_arg0_arg0_head_arg0;
                  arg_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_head_arg0_arg0_head_arg0_list);
                  arg_head_arg0_arg0_head_arg0_list = ATgetNext(arg_head_arg0_arg0_head_arg0_list);
                  if (ATgetInt((ATermInt)arg_head_arg0_arg0_head_arg0_head) == 44) {

                    if (ATgetType((ATerm)arg_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_head_arg0_arg0_head_arg0_list) == ATtrue) {
                      if (ATgetType((ATerm)arg_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_head_arg0_arg0_list) == ATtrue) {
                        ATerm arg_head_arg0_arg1 = ATgetArgument(arg_head_arg0, 1);
                        /* checking for: lit */
                        if (ATgetType((ATerm)arg_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_head_arg0_arg1) == PTPT_afun16) {
                          ATerm arg_head_arg0_arg1_arg0 = ATgetArgument(arg_head_arg0_arg1, 0);
                          /* checking for: , */
                          if (ATgetType((ATerm)arg_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_head_arg0_arg1_arg0) == PTPT_afun19) {
                            ATerm arg_head_arg0_arg2 = ATgetArgument(arg_head_arg0, 2);
                            /* checking for: no-attrs */
                            if (ATgetType((ATerm)arg_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_head_arg0_arg2) == PTPT_afun5) {
                              ATerm arg_head_arg1 = ATgetArgument(arg_head, 1);
                              if (ATgetType((ATerm)arg_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_head_arg1) == ATfalse) {
                                ATerm arg_head_arg1_head;
                                ATermList arg_head_arg1_list = (ATermList)arg_head_arg1;
                                arg_head_arg1_head = ATgetFirst(arg_head_arg1_list);
                                arg_head_arg1_list = ATgetNext(arg_head_arg1_list);
                                if (ATgetInt((ATermInt)arg_head_arg1_head) == 44) {

                                  if (ATgetType((ATerm)arg_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_head_arg1_list) == ATtrue) {
                                    if (ATgetType((ATerm)arg_list) == AT_LIST && ATisEmpty((ATermList)arg_list) == ATfalse) {
                                      return ATtrue;
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_TreeList has a head. 
 * \param[in] arg input PTPT_TreeList
 * \return ATtrue if the PTPT_TreeList had a head, or ATfalse otherwise
 */
ATbool PTPT_hasTreeListHead(PTPT_TreeList arg) {
  if (PTPT_isTreeListSingle(arg)) {
    return ATtrue;
  }
  else if (PTPT_isTreeListMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_TreeList has a ws-after-head. 
 * \param[in] arg input PTPT_TreeList
 * \return ATtrue if the PTPT_TreeList had a ws-after-head, or ATfalse otherwise
 */
ATbool PTPT_hasTreeListWsAfterHead(PTPT_TreeList arg) {
  if (PTPT_isTreeListMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_TreeList has a ws-after-sep. 
 * \param[in] arg input PTPT_TreeList
 * \return ATtrue if the PTPT_TreeList had a ws-after-sep, or ATfalse otherwise
 */
ATbool PTPT_hasTreeListWsAfterSep(PTPT_TreeList arg) {
  if (PTPT_isTreeListMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_TreeList has a tail. 
 * \param[in] arg input PTPT_TreeList
 * \return ATtrue if the PTPT_TreeList had a tail, or ATfalse otherwise
 */
ATbool PTPT_hasTreeListTail(PTPT_TreeList arg) {
  if (PTPT_isTreeListMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Returns a list of all but the first element of a PTPT_TreeList. 
 * \param[in] arg input PTPT_TreeList
 * \return A new PTPT_TreeList, without the first element and the separator(s) just after it.)
 */
PTPT_TreeList PTPT_getTreeListTail(PTPT_TreeList arg) {
  assert(!PTPT_isTreeListEmpty(arg) && "getTail on an empty list");
  if (PTPT_isTreeListSingle(arg)) {
    return (PTPT_TreeList) PTPT_makeTreeListEmpty();
  }
  else {
  
    return (PTPT_TreeList)ATgetTail((ATermList)arg, 4);
  }
}

/**
 * Get the head PTPT_Tree of a PTPT_TreeList. Note that the precondition is that this PTPT_TreeList actually has a head
 * \param[in] arg input PTPT_TreeList
 * \return the head of #arg, if it exist or an undefined value if it does not
 */
PTPT_Tree PTPT_getTreeListHead(PTPT_TreeList arg) {
  if (PTPT_isTreeListSingle(arg)) {
    return (PTPT_Tree)ATgetFirst((ATermList)arg);
  }
  else 
    return (PTPT_Tree)ATgetFirst((ATermList)arg);
}

/**
 * Get the ws-after-head PTPT_OptLayout of a PTPT_TreeList. Note that the precondition is that this PTPT_TreeList actually has a ws-after-head
 * \param[in] arg input PTPT_TreeList
 * \return the ws-after-head of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getTreeListWsAfterHead(PTPT_TreeList arg) {
  
    return (PTPT_OptLayout)ATelementAt((ATermList)arg, 1);
}

/**
 * Get the ws-after-sep PTPT_OptLayout of a PTPT_TreeList. Note that the precondition is that this PTPT_TreeList actually has a ws-after-sep
 * \param[in] arg input PTPT_TreeList
 * \return the ws-after-sep of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getTreeListWsAfterSep(PTPT_TreeList arg) {
  
    return (PTPT_OptLayout)ATelementAt((ATermList)arg, 3);
}

/**
 * Set the head of a PTPT_TreeList. The precondition being that this PTPT_TreeList actually has a head
 * \param[in] arg input PTPT_TreeList
 * \param[in] head new PTPT_Tree to set in #arg
 * \return A new PTPT_TreeList with head at the right place, or a core dump if #arg did not have a head
 */
PTPT_TreeList PTPT_setTreeListHead(PTPT_TreeList arg, PTPT_Tree head) {
  if (PTPT_isTreeListSingle(arg)) {
    return (PTPT_TreeList)ATreplace((ATermList)arg, (ATerm)((ATerm) head), 0);
  }
  else if (PTPT_isTreeListMany(arg)) {
    return (PTPT_TreeList)ATreplace((ATermList)arg, (ATerm)((ATerm) head), 0);
  }

  ATabort("TreeList has no Head: %t\n", arg);
  return (PTPT_TreeList)NULL;
}

/**
 * Set the ws-after-head of a PTPT_TreeList. The precondition being that this PTPT_TreeList actually has a ws-after-head
 * \param[in] arg input PTPT_TreeList
 * \param[in] wsAfterHead new PTPT_OptLayout to set in #arg
 * \return A new PTPT_TreeList with wsAfterHead at the right place, or a core dump if #arg did not have a wsAfterHead
 */
PTPT_TreeList PTPT_setTreeListWsAfterHead(PTPT_TreeList arg, PTPT_OptLayout wsAfterHead) {
  if (PTPT_isTreeListMany(arg)) {
    return (PTPT_TreeList)ATreplace((ATermList)arg, (ATerm)((ATerm) wsAfterHead), 1);
  }

  ATabort("TreeList has no WsAfterHead: %t\n", arg);
  return (PTPT_TreeList)NULL;
}

/**
 * Set the ws-after-sep of a PTPT_TreeList. The precondition being that this PTPT_TreeList actually has a ws-after-sep
 * \param[in] arg input PTPT_TreeList
 * \param[in] wsAfterSep new PTPT_OptLayout to set in #arg
 * \return A new PTPT_TreeList with wsAfterSep at the right place, or a core dump if #arg did not have a wsAfterSep
 */
PTPT_TreeList PTPT_setTreeListWsAfterSep(PTPT_TreeList arg, PTPT_OptLayout wsAfterSep) {
  if (PTPT_isTreeListMany(arg)) {
    return (PTPT_TreeList)ATreplace((ATermList)arg, (ATerm)((ATerm) wsAfterSep), 3);
  }

  ATabort("TreeList has no WsAfterSep: %t\n", arg);
  return (PTPT_TreeList)NULL;
}

/**
 * Set the tail of a PTPT_TreeList. The precondition being that this PTPT_TreeList actually has a tail
 * \param[in] arg input PTPT_TreeList
 * \param[in] tail new PTPT_TreeList to set in #arg
 * \return A new PTPT_TreeList with tail at the right place, or a core dump if #arg did not have a tail
 */
PTPT_TreeList PTPT_setTreeListTail(PTPT_TreeList arg, PTPT_TreeList tail) {
  if (PTPT_isTreeListMany(arg)) {
    return (PTPT_TreeList)ATreplaceTail((ATermList)arg, (ATermList)((ATerm) tail), 4);
  }

  ATabort("TreeList has no Tail: %t\n", arg);
  return (PTPT_TreeList)NULL;
}

/**
 * Assert whether a PTPT_AFun is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input PTPT_AFun
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool PTPT_isValidAFun(PTPT_AFun arg) {
  if (PTPT_isAFunQuoted(arg)) {
    return ATtrue;
  }
  else if (PTPT_isAFunUnquoted(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_AFun is a quoted by checking against the following ATerm pattern: appl(prod([cf(sort("StrCon"))],cf(sort("AFun")),attrs([term(cons("quoted"))])),[<"StrCon"("StrCon")>]). May not be used to assert correctness of the PTPT_AFun
 * \param[in] arg input PTPT_AFun
 * \return ATtrue if #arg corresponds to the signature of a quoted, or ATfalse otherwise
 */
inline ATbool PTPT_isAFunQuoted(PTPT_AFun arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == PTPT_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == PTPT_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: cf */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: sort */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun9) {
            ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
            /* checking for: StrCon */
            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun42) {
              if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                /* checking for: cf */
                if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == PTPT_afun2) {
                  ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                  /* checking for: sort */
                  if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == PTPT_afun9) {
                    ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                    /* checking for: AFun */
                    if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == PTPT_afun89) {
                      ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                      /* checking for: attrs */
                      if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == PTPT_afun12) {
                        ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                        if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                          ATerm arg_arg0_arg2_arg0_head;
                          ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                          arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                          arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                          /* checking for: term */
                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == PTPT_afun13) {
                            ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                            /* checking for: cons */
                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == PTPT_afun14) {
                              ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                              /* checking for: quoted */
                              if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == PTPT_afun90) {
                                if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                  ATerm arg_arg1 = ATgetArgument(arg, 1);
                                  if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                    ATermList arg_arg1_list = (ATermList)arg_arg1;
                                    arg_arg1_list = ATgetNext(arg_arg1_list);
                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                      return ATtrue;
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_AFun is a unquoted by checking against the following ATerm pattern: appl(prod([cf(sort("IdCon"))],cf(sort("AFun")),attrs([term(cons("unquoted"))])),[<"IdCon"("IdCon")>]). May not be used to assert correctness of the PTPT_AFun
 * \param[in] arg input PTPT_AFun
 * \return ATtrue if #arg corresponds to the signature of a unquoted, or ATfalse otherwise
 */
inline ATbool PTPT_isAFunUnquoted(PTPT_AFun arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == PTPT_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == PTPT_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: cf */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: sort */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun9) {
            ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
            /* checking for: IdCon */
            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun91) {
              if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                /* checking for: cf */
                if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == PTPT_afun2) {
                  ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                  /* checking for: sort */
                  if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == PTPT_afun9) {
                    ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                    /* checking for: AFun */
                    if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == PTPT_afun89) {
                      ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                      /* checking for: attrs */
                      if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == PTPT_afun12) {
                        ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                        if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                          ATerm arg_arg0_arg2_arg0_head;
                          ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                          arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                          arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                          /* checking for: term */
                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == PTPT_afun13) {
                            ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                            /* checking for: cons */
                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == PTPT_afun14) {
                              ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                              /* checking for: unquoted */
                              if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == PTPT_afun92) {
                                if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                  ATerm arg_arg1 = ATgetArgument(arg, 1);
                                  if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                    ATermList arg_arg1_list = (ATermList)arg_arg1;
                                    arg_arg1_list = ATgetNext(arg_arg1_list);
                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                      return ATtrue;
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_AFun has a StrCon. 
 * \param[in] arg input PTPT_AFun
 * \return ATtrue if the PTPT_AFun had a StrCon, or ATfalse otherwise
 */
ATbool PTPT_hasAFunStrCon(PTPT_AFun arg) {
  if (PTPT_isAFunQuoted(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_AFun has a IdCon. 
 * \param[in] arg input PTPT_AFun
 * \return ATtrue if the PTPT_AFun had a IdCon, or ATfalse otherwise
 */
ATbool PTPT_hasAFunIdCon(PTPT_AFun arg) {
  if (PTPT_isAFunUnquoted(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Get the StrCon PTPT_StrCon of a PTPT_AFun. Note that the precondition is that this PTPT_AFun actually has a StrCon
 * \param[in] arg input PTPT_AFun
 * \return the StrCon of #arg, if it exist or an undefined value if it does not
 */
PTPT_StrCon PTPT_getAFunStrCon(PTPT_AFun arg) {
  
    return (PTPT_StrCon)ATgetFirst((ATermList)ATgetArgument((ATermAppl)arg, 1));
}

/**
 * Get the IdCon PTPT_IdCon of a PTPT_AFun. Note that the precondition is that this PTPT_AFun actually has a IdCon
 * \param[in] arg input PTPT_AFun
 * \return the IdCon of #arg, if it exist or an undefined value if it does not
 */
PTPT_IdCon PTPT_getAFunIdCon(PTPT_AFun arg) {
  
    return (PTPT_IdCon)ATgetFirst((ATermList)ATgetArgument((ATermAppl)arg, 1));
}

/**
 * Set the StrCon of a PTPT_AFun. The precondition being that this PTPT_AFun actually has a StrCon
 * \param[in] arg input PTPT_AFun
 * \param[in] StrCon new PTPT_StrCon to set in #arg
 * \return A new PTPT_AFun with StrCon at the right place, or a core dump if #arg did not have a StrCon
 */
PTPT_AFun PTPT_setAFunStrCon(PTPT_AFun arg, PTPT_StrCon StrCon) {
  if (PTPT_isAFunQuoted(arg)) {
    return (PTPT_AFun)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) StrCon), 0), 1);
  }

  ATabort("AFun has no StrCon: %t\n", arg);
  return (PTPT_AFun)NULL;
}

/**
 * Set the IdCon of a PTPT_AFun. The precondition being that this PTPT_AFun actually has a IdCon
 * \param[in] arg input PTPT_AFun
 * \param[in] IdCon new PTPT_IdCon to set in #arg
 * \return A new PTPT_AFun with IdCon at the right place, or a core dump if #arg did not have a IdCon
 */
PTPT_AFun PTPT_setAFunIdCon(PTPT_AFun arg, PTPT_IdCon IdCon) {
  if (PTPT_isAFunUnquoted(arg)) {
    return (PTPT_AFun)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) IdCon), 0), 1);
  }

  ATabort("AFun has no IdCon: %t\n", arg);
  return (PTPT_AFun)NULL;
}

/**
 * Assert whether a PTPT_ATerm is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input PTPT_ATerm
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool PTPT_isValidATerm(PTPT_ATerm arg) {
  if (PTPT_isATermInt(arg)) {
    return ATtrue;
  }
  else if (PTPT_isATermReal(arg)) {
    return ATtrue;
  }
  else if (PTPT_isATermFun(arg)) {
    return ATtrue;
  }
  else if (PTPT_isATermAppl(arg)) {
    return ATtrue;
  }
  else if (PTPT_isATermPlaceholder(arg)) {
    return ATtrue;
  }
  else if (PTPT_isATermList(arg)) {
    return ATtrue;
  }
  else if (PTPT_isATermAnnotated(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_ATerm is a int by checking against the following ATerm pattern: appl(prod([cf(sort("IntCon"))],cf(sort("ATerm")),attrs([term(cons("int"))])),[<"IntCon"("IntCon")>]). May not be used to assert correctness of the PTPT_ATerm
 * \param[in] arg input PTPT_ATerm
 * \return ATtrue if #arg corresponds to the signature of a int, or ATfalse otherwise
 */
inline ATbool PTPT_isATermInt(PTPT_ATerm arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == PTPT_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == PTPT_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: cf */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: sort */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun9) {
            ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
            /* checking for: IntCon */
            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun85) {
              if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                /* checking for: cf */
                if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == PTPT_afun2) {
                  ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                  /* checking for: sort */
                  if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == PTPT_afun9) {
                    ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                    /* checking for: ATerm */
                    if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == PTPT_afun40) {
                      ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                      /* checking for: attrs */
                      if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == PTPT_afun12) {
                        ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                        if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                          ATerm arg_arg0_arg2_arg0_head;
                          ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                          arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                          arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                          /* checking for: term */
                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == PTPT_afun13) {
                            ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                            /* checking for: cons */
                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == PTPT_afun14) {
                              ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                              /* checking for: int */
                              if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == PTPT_afun93) {
                                if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                  ATerm arg_arg1 = ATgetArgument(arg, 1);
                                  if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                    ATermList arg_arg1_list = (ATermList)arg_arg1;
                                    arg_arg1_list = ATgetNext(arg_arg1_list);
                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                      return ATtrue;
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_ATerm is a real by checking against the following ATerm pattern: appl(prod([cf(sort("RealCon"))],cf(sort("ATerm")),attrs([term(cons("real"))])),[<"RealCon"("RealCon")>]). May not be used to assert correctness of the PTPT_ATerm
 * \param[in] arg input PTPT_ATerm
 * \return ATtrue if #arg corresponds to the signature of a real, or ATfalse otherwise
 */
inline ATbool PTPT_isATermReal(PTPT_ATerm arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == PTPT_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == PTPT_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: cf */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: sort */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun9) {
            ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
            /* checking for: RealCon */
            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun86) {
              if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                /* checking for: cf */
                if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == PTPT_afun2) {
                  ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                  /* checking for: sort */
                  if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == PTPT_afun9) {
                    ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                    /* checking for: ATerm */
                    if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == PTPT_afun40) {
                      ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                      /* checking for: attrs */
                      if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == PTPT_afun12) {
                        ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                        if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                          ATerm arg_arg0_arg2_arg0_head;
                          ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                          arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                          arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                          /* checking for: term */
                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == PTPT_afun13) {
                            ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                            /* checking for: cons */
                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == PTPT_afun14) {
                              ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                              /* checking for: real */
                              if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == PTPT_afun94) {
                                if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                  ATerm arg_arg1 = ATgetArgument(arg, 1);
                                  if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                    ATermList arg_arg1_list = (ATermList)arg_arg1;
                                    arg_arg1_list = ATgetNext(arg_arg1_list);
                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                      return ATtrue;
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_ATerm is a fun by checking against the following ATerm pattern: appl(prod([cf(sort("AFun"))],cf(sort("ATerm")),attrs([term(cons("fun"))])),[<"fun"("AFun")>]). May not be used to assert correctness of the PTPT_ATerm
 * \param[in] arg input PTPT_ATerm
 * \return ATtrue if #arg corresponds to the signature of a fun, or ATfalse otherwise
 */
inline ATbool PTPT_isATermFun(PTPT_ATerm arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == PTPT_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == PTPT_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: cf */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: sort */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun9) {
            ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
            /* checking for: AFun */
            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun89) {
              if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                /* checking for: cf */
                if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == PTPT_afun2) {
                  ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                  /* checking for: sort */
                  if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == PTPT_afun9) {
                    ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                    /* checking for: ATerm */
                    if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == PTPT_afun40) {
                      ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                      /* checking for: attrs */
                      if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == PTPT_afun12) {
                        ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                        if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                          ATerm arg_arg0_arg2_arg0_head;
                          ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                          arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                          arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                          /* checking for: term */
                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == PTPT_afun13) {
                            ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                            /* checking for: cons */
                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == PTPT_afun14) {
                              ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                              /* checking for: fun */
                              if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == PTPT_afun95) {
                                if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                  ATerm arg_arg1 = ATgetArgument(arg, 1);
                                  if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                    ATermList arg_arg1_list = (ATermList)arg_arg1;
                                    arg_arg1_list = ATgetNext(arg_arg1_list);
                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                      return ATtrue;
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_ATerm is a appl by checking against the following ATerm pattern: appl(prod([cf(sort("AFun")),cf(opt(layout)),lit("("),cf(opt(layout)),cf(iter-sep(sort("ATerm"),lit(","))),cf(opt(layout)),lit(")")],cf(sort("ATerm")),attrs([term(cons("appl"))])),[<"fun"("AFun")>,<"ws-after-fun"("OptLayout")>,appl(prod([char-class([40])],lit("("),no-attrs),[40]),<"ws-after-("("OptLayout")>,appl(list(cf(iter-sep(sort("ATerm"),lit(",")))),<"args"("ATerm-args")>),<"ws-after-args"("OptLayout")>,appl(prod([char-class([41])],lit(")"),no-attrs),[41])]). May not be used to assert correctness of the PTPT_ATerm
 * \param[in] arg input PTPT_ATerm
 * \return ATtrue if #arg corresponds to the signature of a appl, or ATfalse otherwise
 */
inline ATbool PTPT_isATermAppl(PTPT_ATerm arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == PTPT_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == PTPT_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: cf */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: sort */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun9) {
            ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
            /* checking for: AFun */
            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun89) {
              if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                /* checking for: cf */
                if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                  ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                  /* checking for: opt */
                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                    ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                    /* checking for: layout */
                    if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                      if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                        /* checking for: lit */
                        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
                          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                          /* checking for: ( */
                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun21) {
                            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                              /* checking for: cf */
                              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                /* checking for: opt */
                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                  /* checking for: layout */
                                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                      arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                      arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                      /* checking for: cf */
                                      if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                        ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                        /* checking for: iter-sep */
                                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun34) {
                                          ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                          /* checking for: sort */
                                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun9) {
                                            ATerm arg_arg0_arg0_head_arg0_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0_arg0, 0);
                                            /* checking for: ATerm */
                                            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0_arg0) == PTPT_afun40) {
                                              ATerm arg_arg0_arg0_head_arg0_arg1 = ATgetArgument(arg_arg0_arg0_head_arg0, 1);
                                              /* checking for: lit */
                                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg1) == PTPT_afun16) {
                                                ATerm arg_arg0_arg0_head_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0_arg1, 0);
                                                /* checking for: , */
                                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg1_arg0) == PTPT_afun19) {
                                                  if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                    arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                    arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                    /* checking for: cf */
                                                    if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                                      ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                      /* checking for: opt */
                                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                                        ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                        /* checking for: layout */
                                                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                                          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                            arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                            arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                            /* checking for: lit */
                                                            if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
                                                              ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                              /* checking for: ) */
                                                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun17) {
                                                                if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                                                                  ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                                                  /* checking for: cf */
                                                                  if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == PTPT_afun2) {
                                                                    ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                                                    /* checking for: sort */
                                                                    if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == PTPT_afun9) {
                                                                      ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                                                      /* checking for: ATerm */
                                                                      if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == PTPT_afun40) {
                                                                        ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                                                        /* checking for: attrs */
                                                                        if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == PTPT_afun12) {
                                                                          ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                                                          if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                                                            ATerm arg_arg0_arg2_arg0_head;
                                                                            ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                                                            arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                                                            arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                                                            /* checking for: term */
                                                                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == PTPT_afun13) {
                                                                              ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                                                              /* checking for: cons */
                                                                              if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == PTPT_afun14) {
                                                                                ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                                                                /* checking for: appl */
                                                                                if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == PTPT_afun22) {
                                                                                  if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                                                    ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                                                    if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                                                      ATerm arg_arg1_head;
                                                                                      ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                                                      arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                      if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                        arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                          arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                          arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                          /* checking for: appl */
                                                                                          if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                            ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                            /* checking for: prod */
                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                              ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                /* checking for: char-class */
                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                    ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                    arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                    arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 40) {

                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                          ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                          /* checking for: lit */
                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                            ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                            /* checking for: ( */
                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun21) {
                                                                                                              ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                              /* checking for: no-attrs */
                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                  ATerm arg_arg1_head_arg1_head;
                                                                                                                  ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                  arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                  arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 40) {

                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                      if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                        arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                          arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                          arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                          /* checking for: appl */
                                                                                                                          if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                                            ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                            /* checking for: list */
                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun8) {
                                                                                                                              ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                              /* checking for: cf */
                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0) == PTPT_afun2) {
                                                                                                                                ATerm arg_arg1_head_arg0_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0, 0);
                                                                                                                                /* checking for: iter-sep */
                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0) == PTPT_afun34) {
                                                                                                                                  ATerm arg_arg1_head_arg0_arg0_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0, 0);
                                                                                                                                  /* checking for: sort */
                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg0) == PTPT_afun9) {
                                                                                                                                    ATerm arg_arg1_head_arg0_arg0_arg0_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0_arg0, 0);
                                                                                                                                    /* checking for: ATerm */
                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg0_arg0) == PTPT_afun40) {
                                                                                                                                      ATerm arg_arg1_head_arg0_arg0_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0, 1);
                                                                                                                                      /* checking for: lit */
                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg1) == PTPT_afun16) {
                                                                                                                                        ATerm arg_arg1_head_arg0_arg0_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0_arg1, 0);
                                                                                                                                        /* checking for: , */
                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg1_arg0) == PTPT_afun19) {
                                                                                                                                          if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                            arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                            if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                              arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                              arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                              /* checking for: appl */
                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                                                                ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                                                /* checking for: prod */
                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                                                                                  ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                                    ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                                    arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                    arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                    /* checking for: char-class */
                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                        ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                        arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                        arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 41) {

                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                              ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                              /* checking for: lit */
                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                                                ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                /* checking for: ) */
                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun17) {
                                                                                                                                                                  ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                  /* checking for: no-attrs */
                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                                    ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                      ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                      ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                      arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                      arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 41) {

                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                                                                                            return ATtrue;
                                                                                                                                                                          }
                                                                                                                                                                        }
                                                                                                                                                                      }
                                                                                                                                                                    }
                                                                                                                                                                  }
                                                                                                                                                                }
                                                                                                                                                              }
                                                                                                                                                            }
                                                                                                                                                          }
                                                                                                                                                        }
                                                                                                                                                      }
                                                                                                                                                    }
                                                                                                                                                  }
                                                                                                                                                }
                                                                                                                                              }
                                                                                                                                            }
                                                                                                                                          }
                                                                                                                                        }
                                                                                                                                      }
                                                                                                                                    }
                                                                                                                                  }
                                                                                                                                }
                                                                                                                              }
                                                                                                                            }
                                                                                                                          }
                                                                                                                        }
                                                                                                                      }
                                                                                                                    }
                                                                                                                  }
                                                                                                                }
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_ATerm is a placeholder by checking against the following ATerm pattern: appl(prod([lit("<"),cf(opt(layout)),cf(sort("ATerm")),cf(opt(layout)),lit(">")],cf(sort("ATerm")),attrs([term(cons("placeholder"))])),[appl(prod([char-class([60])],lit("<"),no-attrs),[60]),<"ws-after-<"("OptLayout")>,<"type"("ATerm")>,<"ws-after-type"("OptLayout")>,appl(prod([char-class([62])],lit(">"),no-attrs),[62])]). May not be used to assert correctness of the PTPT_ATerm
 * \param[in] arg input PTPT_ATerm
 * \return ATtrue if #arg corresponds to the signature of a placeholder, or ATfalse otherwise
 */
inline ATbool PTPT_isATermPlaceholder(PTPT_ATerm arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == PTPT_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == PTPT_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lit */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: < */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun97) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
              /* checking for: cf */
              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                /* checking for: opt */
                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                  /* checking for: layout */
                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                      arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                      arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                      /* checking for: cf */
                      if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                        ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                        /* checking for: sort */
                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun9) {
                          ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                          /* checking for: ATerm */
                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun40) {
                            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                              /* checking for: cf */
                              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                /* checking for: opt */
                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                  /* checking for: layout */
                                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                      arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                      arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                      /* checking for: lit */
                                      if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
                                        ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                        /* checking for: > */
                                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun96) {
                                          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                                            ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                            /* checking for: cf */
                                            if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == PTPT_afun2) {
                                              ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                              /* checking for: sort */
                                              if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == PTPT_afun9) {
                                                ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                                /* checking for: ATerm */
                                                if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == PTPT_afun40) {
                                                  ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                                  /* checking for: attrs */
                                                  if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == PTPT_afun12) {
                                                    ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                                    if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                                      ATerm arg_arg0_arg2_arg0_head;
                                                      ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                                      arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                                      arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                                      /* checking for: term */
                                                      if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == PTPT_afun13) {
                                                        ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                                        /* checking for: cons */
                                                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == PTPT_afun14) {
                                                          ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                                          /* checking for: placeholder */
                                                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == PTPT_afun98) {
                                                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                              ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                              if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                                ATerm arg_arg1_head;
                                                                ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                                arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                /* checking for: appl */
                                                                if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                  ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                  /* checking for: prod */
                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                    ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                      ATerm arg_arg1_head_arg0_arg0_head;
                                                                      ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                      arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                      arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                      /* checking for: char-class */
                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                          ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                          arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                          arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 60) {

                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                /* checking for: lit */
                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                  ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                  /* checking for: < */
                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun97) {
                                                                                    ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                    /* checking for: no-attrs */
                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                      ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                        ATerm arg_arg1_head_arg1_head;
                                                                                        ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                        arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                        arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 60) {

                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                            if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                              arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                              if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                  if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                    arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                    arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                    /* checking for: appl */
                                                                                                    if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                      ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                      /* checking for: prod */
                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                                        ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                          ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                          ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                          arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                          arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                          /* checking for: char-class */
                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                              ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                              arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                              arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 62) {

                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                    ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                    /* checking for: lit */
                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                      ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                      /* checking for: > */
                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun96) {
                                                                                                                        ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                        /* checking for: no-attrs */
                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                          ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                            ATerm arg_arg1_head_arg1_head;
                                                                                                                            ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                            arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                            arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 62) {

                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                                                  return ATtrue;
                                                                                                                                }
                                                                                                                              }
                                                                                                                            }
                                                                                                                          }
                                                                                                                        }
                                                                                                                      }
                                                                                                                    }
                                                                                                                  }
                                                                                                                }
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_ATerm is a list by checking against the following ATerm pattern: appl(prod([lit("["),cf(opt(layout)),cf(iter-star-sep(sort("ATerm"),lit(","))),cf(opt(layout)),lit("]")],cf(sort("ATerm")),attrs([term(cons("list"))])),[appl(prod([char-class([91])],lit("["),no-attrs),[91]),<"ws-after-["("OptLayout")>,appl(list(cf(iter-star-sep(sort("ATerm"),lit(",")))),<"elems"("ATerm-elems")>),<"ws-after-elems"("OptLayout")>,appl(prod([char-class([93])],lit("]"),no-attrs),[93])]). May not be used to assert correctness of the PTPT_ATerm
 * \param[in] arg input PTPT_ATerm
 * \return ATtrue if #arg corresponds to the signature of a list, or ATfalse otherwise
 */
inline ATbool PTPT_isATermList(PTPT_ATerm arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == PTPT_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == PTPT_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lit */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: [ */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun36) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
              /* checking for: cf */
              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                /* checking for: opt */
                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                  /* checking for: layout */
                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                      arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                      arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                      /* checking for: cf */
                      if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                        ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                        /* checking for: iter-star-sep */
                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun78) {
                          ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                          /* checking for: sort */
                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun9) {
                            ATerm arg_arg0_arg0_head_arg0_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0_arg0, 0);
                            /* checking for: ATerm */
                            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0_arg0) == PTPT_afun40) {
                              ATerm arg_arg0_arg0_head_arg0_arg1 = ATgetArgument(arg_arg0_arg0_head_arg0, 1);
                              /* checking for: lit */
                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg1) == PTPT_afun16) {
                                ATerm arg_arg0_arg0_head_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0_arg1, 0);
                                /* checking for: , */
                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg1_arg0) == PTPT_afun19) {
                                  if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                    arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                    arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                    /* checking for: cf */
                                    if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                      ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                      /* checking for: opt */
                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                        ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                        /* checking for: layout */
                                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                            arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                            arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                            /* checking for: lit */
                                            if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
                                              ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                              /* checking for: ] */
                                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun33) {
                                                if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                                                  ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                                  /* checking for: cf */
                                                  if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == PTPT_afun2) {
                                                    ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                                    /* checking for: sort */
                                                    if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == PTPT_afun9) {
                                                      ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                                      /* checking for: ATerm */
                                                      if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == PTPT_afun40) {
                                                        ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                                        /* checking for: attrs */
                                                        if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == PTPT_afun12) {
                                                          ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                                          if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                                            ATerm arg_arg0_arg2_arg0_head;
                                                            ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                                            arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                                            arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                                            /* checking for: term */
                                                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == PTPT_afun13) {
                                                              ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                                              /* checking for: cons */
                                                              if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == PTPT_afun14) {
                                                                ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                                                /* checking for: list */
                                                                if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == PTPT_afun79) {
                                                                  if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                                    ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                                    if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                                      ATerm arg_arg1_head;
                                                                      ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                                      arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                      arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                      /* checking for: appl */
                                                                      if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                        ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                        /* checking for: prod */
                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                          ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                            ATerm arg_arg1_head_arg0_arg0_head;
                                                                            ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                            arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                            arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                            /* checking for: char-class */
                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 91) {

                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                      ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                      /* checking for: lit */
                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                        ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                        /* checking for: [ */
                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun36) {
                                                                                          ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                          /* checking for: no-attrs */
                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                            ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                              ATerm arg_arg1_head_arg1_head;
                                                                                              ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                              arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                              arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 91) {

                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                  if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                    arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                      arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                      arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                      /* checking for: appl */
                                                                                                      if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                        ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                        /* checking for: list */
                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun8) {
                                                                                                          ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                          /* checking for: cf */
                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0) == PTPT_afun2) {
                                                                                                            ATerm arg_arg1_head_arg0_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0, 0);
                                                                                                            /* checking for: iter-star-sep */
                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0) == PTPT_afun78) {
                                                                                                              ATerm arg_arg1_head_arg0_arg0_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0, 0);
                                                                                                              /* checking for: sort */
                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg0) == PTPT_afun9) {
                                                                                                                ATerm arg_arg1_head_arg0_arg0_arg0_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0_arg0, 0);
                                                                                                                /* checking for: ATerm */
                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg0_arg0) == PTPT_afun40) {
                                                                                                                  ATerm arg_arg1_head_arg0_arg0_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0, 1);
                                                                                                                  /* checking for: lit */
                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg1) == PTPT_afun16) {
                                                                                                                    ATerm arg_arg1_head_arg0_arg0_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0_arg1, 0);
                                                                                                                    /* checking for: , */
                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg1_arg0) == PTPT_afun19) {
                                                                                                                      if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                        arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                          arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                          arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                          /* checking for: appl */
                                                                                                                          if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                                            ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                            /* checking for: prod */
                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                                                              ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                /* checking for: char-class */
                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                    ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                    arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                    arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 93) {

                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                          ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                          /* checking for: lit */
                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                            ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                            /* checking for: ] */
                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun33) {
                                                                                                                                              ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                              /* checking for: no-attrs */
                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                  ATerm arg_arg1_head_arg1_head;
                                                                                                                                                  ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                  arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                  arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 93) {

                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                                                                        return ATtrue;
                                                                                                                                                      }
                                                                                                                                                    }
                                                                                                                                                  }
                                                                                                                                                }
                                                                                                                                              }
                                                                                                                                            }
                                                                                                                                          }
                                                                                                                                        }
                                                                                                                                      }
                                                                                                                                    }
                                                                                                                                  }
                                                                                                                                }
                                                                                                                              }
                                                                                                                            }
                                                                                                                          }
                                                                                                                        }
                                                                                                                      }
                                                                                                                    }
                                                                                                                  }
                                                                                                                }
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_ATerm is a annotated by checking against the following ATerm pattern: appl(prod([cf(sort("ATerm")),cf(opt(layout)),cf(sort("Annotation"))],cf(sort("ATerm")),attrs([term(cons("annotated"))])),[<"trm"("ATerm")>,<"ws-after-trm"("OptLayout")>,<"Annotation"("Annotation")>]). May not be used to assert correctness of the PTPT_ATerm
 * \param[in] arg input PTPT_ATerm
 * \return ATtrue if #arg corresponds to the signature of a annotated, or ATfalse otherwise
 */
inline ATbool PTPT_isATermAnnotated(PTPT_ATerm arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == PTPT_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == PTPT_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: cf */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: sort */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun9) {
            ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
            /* checking for: ATerm */
            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun40) {
              if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                /* checking for: cf */
                if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                  ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                  /* checking for: opt */
                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                    ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                    /* checking for: layout */
                    if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                      if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                        /* checking for: cf */
                        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                          /* checking for: sort */
                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun9) {
                            ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                            /* checking for: Annotation */
                            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun10) {
                              if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                                ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                /* checking for: cf */
                                if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == PTPT_afun2) {
                                  ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                  /* checking for: sort */
                                  if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == PTPT_afun9) {
                                    ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                    /* checking for: ATerm */
                                    if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == PTPT_afun40) {
                                      ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                      /* checking for: attrs */
                                      if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == PTPT_afun12) {
                                        ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                        if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                          ATerm arg_arg0_arg2_arg0_head;
                                          ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                          arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                          arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                          /* checking for: term */
                                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == PTPT_afun13) {
                                            ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                            /* checking for: cons */
                                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == PTPT_afun14) {
                                              ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                              /* checking for: annotated */
                                              if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == PTPT_afun15) {
                                                if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                  ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                  if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                    ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                    arg_arg1_list = ATgetNext(arg_arg1_list);
                                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                      arg_arg1_list = ATgetNext(arg_arg1_list);
                                                      if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                        arg_arg1_list = ATgetNext(arg_arg1_list);
                                                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                          return ATtrue;
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_ATerm has a IntCon. 
 * \param[in] arg input PTPT_ATerm
 * \return ATtrue if the PTPT_ATerm had a IntCon, or ATfalse otherwise
 */
ATbool PTPT_hasATermIntCon(PTPT_ATerm arg) {
  if (PTPT_isATermInt(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_ATerm has a RealCon. 
 * \param[in] arg input PTPT_ATerm
 * \return ATtrue if the PTPT_ATerm had a RealCon, or ATfalse otherwise
 */
ATbool PTPT_hasATermRealCon(PTPT_ATerm arg) {
  if (PTPT_isATermReal(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_ATerm has a fun. 
 * \param[in] arg input PTPT_ATerm
 * \return ATtrue if the PTPT_ATerm had a fun, or ATfalse otherwise
 */
ATbool PTPT_hasATermFun(PTPT_ATerm arg) {
  if (PTPT_isATermFun(arg)) {
    return ATtrue;
  }
  else if (PTPT_isATermAppl(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_ATerm has a ws-after-fun. 
 * \param[in] arg input PTPT_ATerm
 * \return ATtrue if the PTPT_ATerm had a ws-after-fun, or ATfalse otherwise
 */
ATbool PTPT_hasATermWsAfterFun(PTPT_ATerm arg) {
  if (PTPT_isATermAppl(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_ATerm has a ws-after-(. 
 * \param[in] arg input PTPT_ATerm
 * \return ATtrue if the PTPT_ATerm had a ws-after-(, or ATfalse otherwise
 */
ATbool PTPT_hasATermWsAfterParenOpen(PTPT_ATerm arg) {
  if (PTPT_isATermAppl(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_ATerm has a args. 
 * \param[in] arg input PTPT_ATerm
 * \return ATtrue if the PTPT_ATerm had a args, or ATfalse otherwise
 */
ATbool PTPT_hasATermArgs(PTPT_ATerm arg) {
  if (PTPT_isATermAppl(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_ATerm has a ws-after-args. 
 * \param[in] arg input PTPT_ATerm
 * \return ATtrue if the PTPT_ATerm had a ws-after-args, or ATfalse otherwise
 */
ATbool PTPT_hasATermWsAfterArgs(PTPT_ATerm arg) {
  if (PTPT_isATermAppl(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_ATerm has a ws-after-<. 
 * \param[in] arg input PTPT_ATerm
 * \return ATtrue if the PTPT_ATerm had a ws-after-<, or ATfalse otherwise
 */
ATbool PTPT_hasATermWsAfterLessThan(PTPT_ATerm arg) {
  if (PTPT_isATermPlaceholder(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_ATerm has a type. 
 * \param[in] arg input PTPT_ATerm
 * \return ATtrue if the PTPT_ATerm had a type, or ATfalse otherwise
 */
ATbool PTPT_hasATermType(PTPT_ATerm arg) {
  if (PTPT_isATermPlaceholder(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_ATerm has a ws-after-type. 
 * \param[in] arg input PTPT_ATerm
 * \return ATtrue if the PTPT_ATerm had a ws-after-type, or ATfalse otherwise
 */
ATbool PTPT_hasATermWsAfterType(PTPT_ATerm arg) {
  if (PTPT_isATermPlaceholder(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_ATerm has a ws-after-[. 
 * \param[in] arg input PTPT_ATerm
 * \return ATtrue if the PTPT_ATerm had a ws-after-[, or ATfalse otherwise
 */
ATbool PTPT_hasATermWsAfterBracketOpen(PTPT_ATerm arg) {
  if (PTPT_isATermList(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_ATerm has a elems. 
 * \param[in] arg input PTPT_ATerm
 * \return ATtrue if the PTPT_ATerm had a elems, or ATfalse otherwise
 */
ATbool PTPT_hasATermElems(PTPT_ATerm arg) {
  if (PTPT_isATermList(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_ATerm has a ws-after-elems. 
 * \param[in] arg input PTPT_ATerm
 * \return ATtrue if the PTPT_ATerm had a ws-after-elems, or ATfalse otherwise
 */
ATbool PTPT_hasATermWsAfterElems(PTPT_ATerm arg) {
  if (PTPT_isATermList(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_ATerm has a trm. 
 * \param[in] arg input PTPT_ATerm
 * \return ATtrue if the PTPT_ATerm had a trm, or ATfalse otherwise
 */
ATbool PTPT_hasATermTrm(PTPT_ATerm arg) {
  if (PTPT_isATermAnnotated(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_ATerm has a ws-after-trm. 
 * \param[in] arg input PTPT_ATerm
 * \return ATtrue if the PTPT_ATerm had a ws-after-trm, or ATfalse otherwise
 */
ATbool PTPT_hasATermWsAfterTrm(PTPT_ATerm arg) {
  if (PTPT_isATermAnnotated(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_ATerm has a Annotation. 
 * \param[in] arg input PTPT_ATerm
 * \return ATtrue if the PTPT_ATerm had a Annotation, or ATfalse otherwise
 */
ATbool PTPT_hasATermAnnotation(PTPT_ATerm arg) {
  if (PTPT_isATermAnnotated(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Get the IntCon PTPT_IntCon of a PTPT_ATerm. Note that the precondition is that this PTPT_ATerm actually has a IntCon
 * \param[in] arg input PTPT_ATerm
 * \return the IntCon of #arg, if it exist or an undefined value if it does not
 */
PTPT_IntCon PTPT_getATermIntCon(PTPT_ATerm arg) {
  
    return (PTPT_IntCon)ATgetFirst((ATermList)ATgetArgument((ATermAppl)arg, 1));
}

/**
 * Get the RealCon PTPT_RealCon of a PTPT_ATerm. Note that the precondition is that this PTPT_ATerm actually has a RealCon
 * \param[in] arg input PTPT_ATerm
 * \return the RealCon of #arg, if it exist or an undefined value if it does not
 */
PTPT_RealCon PTPT_getATermRealCon(PTPT_ATerm arg) {
  
    return (PTPT_RealCon)ATgetFirst((ATermList)ATgetArgument((ATermAppl)arg, 1));
}

/**
 * Get the fun PTPT_AFun of a PTPT_ATerm. Note that the precondition is that this PTPT_ATerm actually has a fun
 * \param[in] arg input PTPT_ATerm
 * \return the fun of #arg, if it exist or an undefined value if it does not
 */
PTPT_AFun PTPT_getATermFun(PTPT_ATerm arg) {
  if (PTPT_isATermFun(arg)) {
    return (PTPT_AFun)ATgetFirst((ATermList)ATgetArgument((ATermAppl)arg, 1));
  }
  else 
    return (PTPT_AFun)ATgetFirst((ATermList)ATgetArgument((ATermAppl)arg, 1));
}

/**
 * Get the ws-after-fun PTPT_OptLayout of a PTPT_ATerm. Note that the precondition is that this PTPT_ATerm actually has a ws-after-fun
 * \param[in] arg input PTPT_ATerm
 * \return the ws-after-fun of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getATermWsAfterFun(PTPT_ATerm arg) {
  
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1);
}

/**
 * Get the ws-after-( PTPT_OptLayout of a PTPT_ATerm. Note that the precondition is that this PTPT_ATerm actually has a ws-after-(
 * \param[in] arg input PTPT_ATerm
 * \return the ws-after-( of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getATermWsAfterParenOpen(PTPT_ATerm arg) {
  
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 3);
}

/**
 * Get the args PTPT_ATermArgs of a PTPT_ATerm. Note that the precondition is that this PTPT_ATerm actually has a args
 * \param[in] arg input PTPT_ATerm
 * \return the args of #arg, if it exist or an undefined value if it does not
 */
PTPT_ATermArgs PTPT_getATermArgs(PTPT_ATerm arg) {
  
    return (PTPT_ATermArgs)ATgetArgument((ATermAppl)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 4), 1);
}

/**
 * Get the ws-after-args PTPT_OptLayout of a PTPT_ATerm. Note that the precondition is that this PTPT_ATerm actually has a ws-after-args
 * \param[in] arg input PTPT_ATerm
 * \return the ws-after-args of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getATermWsAfterArgs(PTPT_ATerm arg) {
  
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 5);
}

/**
 * Get the ws-after-< PTPT_OptLayout of a PTPT_ATerm. Note that the precondition is that this PTPT_ATerm actually has a ws-after-<
 * \param[in] arg input PTPT_ATerm
 * \return the ws-after-< of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getATermWsAfterLessThan(PTPT_ATerm arg) {
  
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1);
}

/**
 * Get the type PTPT_ATerm of a PTPT_ATerm. Note that the precondition is that this PTPT_ATerm actually has a type
 * \param[in] arg input PTPT_ATerm
 * \return the type of #arg, if it exist or an undefined value if it does not
 */
PTPT_ATerm PTPT_getATermType(PTPT_ATerm arg) {
  
    return (PTPT_ATerm)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 2);
}

/**
 * Get the ws-after-type PTPT_OptLayout of a PTPT_ATerm. Note that the precondition is that this PTPT_ATerm actually has a ws-after-type
 * \param[in] arg input PTPT_ATerm
 * \return the ws-after-type of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getATermWsAfterType(PTPT_ATerm arg) {
  
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 3);
}

/**
 * Get the ws-after-[ PTPT_OptLayout of a PTPT_ATerm. Note that the precondition is that this PTPT_ATerm actually has a ws-after-[
 * \param[in] arg input PTPT_ATerm
 * \return the ws-after-[ of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getATermWsAfterBracketOpen(PTPT_ATerm arg) {
  
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1);
}

/**
 * Get the elems PTPT_ATermElems of a PTPT_ATerm. Note that the precondition is that this PTPT_ATerm actually has a elems
 * \param[in] arg input PTPT_ATerm
 * \return the elems of #arg, if it exist or an undefined value if it does not
 */
PTPT_ATermElems PTPT_getATermElems(PTPT_ATerm arg) {
  
    return (PTPT_ATermElems)ATgetArgument((ATermAppl)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 2), 1);
}

/**
 * Get the ws-after-elems PTPT_OptLayout of a PTPT_ATerm. Note that the precondition is that this PTPT_ATerm actually has a ws-after-elems
 * \param[in] arg input PTPT_ATerm
 * \return the ws-after-elems of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getATermWsAfterElems(PTPT_ATerm arg) {
  
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 3);
}

/**
 * Get the trm PTPT_ATerm of a PTPT_ATerm. Note that the precondition is that this PTPT_ATerm actually has a trm
 * \param[in] arg input PTPT_ATerm
 * \return the trm of #arg, if it exist or an undefined value if it does not
 */
PTPT_ATerm PTPT_getATermTrm(PTPT_ATerm arg) {
  
    return (PTPT_ATerm)ATgetFirst((ATermList)ATgetArgument((ATermAppl)arg, 1));
}

/**
 * Get the ws-after-trm PTPT_OptLayout of a PTPT_ATerm. Note that the precondition is that this PTPT_ATerm actually has a ws-after-trm
 * \param[in] arg input PTPT_ATerm
 * \return the ws-after-trm of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getATermWsAfterTrm(PTPT_ATerm arg) {
  
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1);
}

/**
 * Get the Annotation PTPT_Annotation of a PTPT_ATerm. Note that the precondition is that this PTPT_ATerm actually has a Annotation
 * \param[in] arg input PTPT_ATerm
 * \return the Annotation of #arg, if it exist or an undefined value if it does not
 */
PTPT_Annotation PTPT_getATermAnnotation(PTPT_ATerm arg) {
  
    return (PTPT_Annotation)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 2);
}

/**
 * Set the IntCon of a PTPT_ATerm. The precondition being that this PTPT_ATerm actually has a IntCon
 * \param[in] arg input PTPT_ATerm
 * \param[in] IntCon new PTPT_IntCon to set in #arg
 * \return A new PTPT_ATerm with IntCon at the right place, or a core dump if #arg did not have a IntCon
 */
PTPT_ATerm PTPT_setATermIntCon(PTPT_ATerm arg, PTPT_IntCon IntCon) {
  if (PTPT_isATermInt(arg)) {
    return (PTPT_ATerm)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) IntCon), 0), 1);
  }

  ATabort("ATerm has no IntCon: %t\n", arg);
  return (PTPT_ATerm)NULL;
}

/**
 * Set the RealCon of a PTPT_ATerm. The precondition being that this PTPT_ATerm actually has a RealCon
 * \param[in] arg input PTPT_ATerm
 * \param[in] RealCon new PTPT_RealCon to set in #arg
 * \return A new PTPT_ATerm with RealCon at the right place, or a core dump if #arg did not have a RealCon
 */
PTPT_ATerm PTPT_setATermRealCon(PTPT_ATerm arg, PTPT_RealCon RealCon) {
  if (PTPT_isATermReal(arg)) {
    return (PTPT_ATerm)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) RealCon), 0), 1);
  }

  ATabort("ATerm has no RealCon: %t\n", arg);
  return (PTPT_ATerm)NULL;
}

/**
 * Set the fun of a PTPT_ATerm. The precondition being that this PTPT_ATerm actually has a fun
 * \param[in] arg input PTPT_ATerm
 * \param[in] fun new PTPT_AFun to set in #arg
 * \return A new PTPT_ATerm with fun at the right place, or a core dump if #arg did not have a fun
 */
PTPT_ATerm PTPT_setATermFun(PTPT_ATerm arg, PTPT_AFun fun) {
  if (PTPT_isATermFun(arg)) {
    return (PTPT_ATerm)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) fun), 0), 1);
  }
  else if (PTPT_isATermAppl(arg)) {
    return (PTPT_ATerm)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) fun), 0), 1);
  }

  ATabort("ATerm has no Fun: %t\n", arg);
  return (PTPT_ATerm)NULL;
}

/**
 * Set the ws-after-fun of a PTPT_ATerm. The precondition being that this PTPT_ATerm actually has a ws-after-fun
 * \param[in] arg input PTPT_ATerm
 * \param[in] wsAfterFun new PTPT_OptLayout to set in #arg
 * \return A new PTPT_ATerm with wsAfterFun at the right place, or a core dump if #arg did not have a wsAfterFun
 */
PTPT_ATerm PTPT_setATermWsAfterFun(PTPT_ATerm arg, PTPT_OptLayout wsAfterFun) {
  if (PTPT_isATermAppl(arg)) {
    return (PTPT_ATerm)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterFun), 1), 1);
  }

  ATabort("ATerm has no WsAfterFun: %t\n", arg);
  return (PTPT_ATerm)NULL;
}

/**
 * Set the ws-after-( of a PTPT_ATerm. The precondition being that this PTPT_ATerm actually has a ws-after-(
 * \param[in] arg input PTPT_ATerm
 * \param[in] wsAfterParenOpen new PTPT_OptLayout to set in #arg
 * \return A new PTPT_ATerm with wsAfterParenOpen at the right place, or a core dump if #arg did not have a wsAfterParenOpen
 */
PTPT_ATerm PTPT_setATermWsAfterParenOpen(PTPT_ATerm arg, PTPT_OptLayout wsAfterParenOpen) {
  if (PTPT_isATermAppl(arg)) {
    return (PTPT_ATerm)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterParenOpen), 3), 1);
  }

  ATabort("ATerm has no WsAfterParenOpen: %t\n", arg);
  return (PTPT_ATerm)NULL;
}

/**
 * Set the args of a PTPT_ATerm. The precondition being that this PTPT_ATerm actually has a args
 * \param[in] arg input PTPT_ATerm
 * \param[in] args new PTPT_ATermArgs to set in #arg
 * \return A new PTPT_ATerm with args at the right place, or a core dump if #arg did not have a args
 */
PTPT_ATerm PTPT_setATermArgs(PTPT_ATerm arg, PTPT_ATermArgs args) {
  if (PTPT_isATermAppl(arg)) {
    return (PTPT_ATerm)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)ATsetArgument((ATermAppl)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 4), (ATerm)((ATerm) args), 1), 4), 1);
  }

  ATabort("ATerm has no Args: %t\n", arg);
  return (PTPT_ATerm)NULL;
}

/**
 * Set the ws-after-args of a PTPT_ATerm. The precondition being that this PTPT_ATerm actually has a ws-after-args
 * \param[in] arg input PTPT_ATerm
 * \param[in] wsAfterArgs new PTPT_OptLayout to set in #arg
 * \return A new PTPT_ATerm with wsAfterArgs at the right place, or a core dump if #arg did not have a wsAfterArgs
 */
PTPT_ATerm PTPT_setATermWsAfterArgs(PTPT_ATerm arg, PTPT_OptLayout wsAfterArgs) {
  if (PTPT_isATermAppl(arg)) {
    return (PTPT_ATerm)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterArgs), 5), 1);
  }

  ATabort("ATerm has no WsAfterArgs: %t\n", arg);
  return (PTPT_ATerm)NULL;
}

/**
 * Set the ws-after-< of a PTPT_ATerm. The precondition being that this PTPT_ATerm actually has a ws-after-<
 * \param[in] arg input PTPT_ATerm
 * \param[in] wsAfterLessThan new PTPT_OptLayout to set in #arg
 * \return A new PTPT_ATerm with wsAfterLessThan at the right place, or a core dump if #arg did not have a wsAfterLessThan
 */
PTPT_ATerm PTPT_setATermWsAfterLessThan(PTPT_ATerm arg, PTPT_OptLayout wsAfterLessThan) {
  if (PTPT_isATermPlaceholder(arg)) {
    return (PTPT_ATerm)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterLessThan), 1), 1);
  }

  ATabort("ATerm has no WsAfterLessThan: %t\n", arg);
  return (PTPT_ATerm)NULL;
}

/**
 * Set the type of a PTPT_ATerm. The precondition being that this PTPT_ATerm actually has a type
 * \param[in] arg input PTPT_ATerm
 * \param[in] type new PTPT_ATerm to set in #arg
 * \return A new PTPT_ATerm with type at the right place, or a core dump if #arg did not have a type
 */
PTPT_ATerm PTPT_setATermType(PTPT_ATerm arg, PTPT_ATerm type) {
  if (PTPT_isATermPlaceholder(arg)) {
    return (PTPT_ATerm)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) type), 2), 1);
  }

  ATabort("ATerm has no Type: %t\n", arg);
  return (PTPT_ATerm)NULL;
}

/**
 * Set the ws-after-type of a PTPT_ATerm. The precondition being that this PTPT_ATerm actually has a ws-after-type
 * \param[in] arg input PTPT_ATerm
 * \param[in] wsAfterType new PTPT_OptLayout to set in #arg
 * \return A new PTPT_ATerm with wsAfterType at the right place, or a core dump if #arg did not have a wsAfterType
 */
PTPT_ATerm PTPT_setATermWsAfterType(PTPT_ATerm arg, PTPT_OptLayout wsAfterType) {
  if (PTPT_isATermPlaceholder(arg)) {
    return (PTPT_ATerm)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterType), 3), 1);
  }

  ATabort("ATerm has no WsAfterType: %t\n", arg);
  return (PTPT_ATerm)NULL;
}

/**
 * Set the ws-after-[ of a PTPT_ATerm. The precondition being that this PTPT_ATerm actually has a ws-after-[
 * \param[in] arg input PTPT_ATerm
 * \param[in] wsAfterBracketOpen new PTPT_OptLayout to set in #arg
 * \return A new PTPT_ATerm with wsAfterBracketOpen at the right place, or a core dump if #arg did not have a wsAfterBracketOpen
 */
PTPT_ATerm PTPT_setATermWsAfterBracketOpen(PTPT_ATerm arg, PTPT_OptLayout wsAfterBracketOpen) {
  if (PTPT_isATermList(arg)) {
    return (PTPT_ATerm)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterBracketOpen), 1), 1);
  }

  ATabort("ATerm has no WsAfterBracketOpen: %t\n", arg);
  return (PTPT_ATerm)NULL;
}

/**
 * Set the elems of a PTPT_ATerm. The precondition being that this PTPT_ATerm actually has a elems
 * \param[in] arg input PTPT_ATerm
 * \param[in] elems new PTPT_ATermElems to set in #arg
 * \return A new PTPT_ATerm with elems at the right place, or a core dump if #arg did not have a elems
 */
PTPT_ATerm PTPT_setATermElems(PTPT_ATerm arg, PTPT_ATermElems elems) {
  if (PTPT_isATermList(arg)) {
    return (PTPT_ATerm)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)ATsetArgument((ATermAppl)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 2), (ATerm)((ATerm) elems), 1), 2), 1);
  }

  ATabort("ATerm has no Elems: %t\n", arg);
  return (PTPT_ATerm)NULL;
}

/**
 * Set the ws-after-elems of a PTPT_ATerm. The precondition being that this PTPT_ATerm actually has a ws-after-elems
 * \param[in] arg input PTPT_ATerm
 * \param[in] wsAfterElems new PTPT_OptLayout to set in #arg
 * \return A new PTPT_ATerm with wsAfterElems at the right place, or a core dump if #arg did not have a wsAfterElems
 */
PTPT_ATerm PTPT_setATermWsAfterElems(PTPT_ATerm arg, PTPT_OptLayout wsAfterElems) {
  if (PTPT_isATermList(arg)) {
    return (PTPT_ATerm)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterElems), 3), 1);
  }

  ATabort("ATerm has no WsAfterElems: %t\n", arg);
  return (PTPT_ATerm)NULL;
}

/**
 * Set the trm of a PTPT_ATerm. The precondition being that this PTPT_ATerm actually has a trm
 * \param[in] arg input PTPT_ATerm
 * \param[in] trm new PTPT_ATerm to set in #arg
 * \return A new PTPT_ATerm with trm at the right place, or a core dump if #arg did not have a trm
 */
PTPT_ATerm PTPT_setATermTrm(PTPT_ATerm arg, PTPT_ATerm trm) {
  if (PTPT_isATermAnnotated(arg)) {
    return (PTPT_ATerm)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) trm), 0), 1);
  }

  ATabort("ATerm has no Trm: %t\n", arg);
  return (PTPT_ATerm)NULL;
}

/**
 * Set the ws-after-trm of a PTPT_ATerm. The precondition being that this PTPT_ATerm actually has a ws-after-trm
 * \param[in] arg input PTPT_ATerm
 * \param[in] wsAfterTrm new PTPT_OptLayout to set in #arg
 * \return A new PTPT_ATerm with wsAfterTrm at the right place, or a core dump if #arg did not have a wsAfterTrm
 */
PTPT_ATerm PTPT_setATermWsAfterTrm(PTPT_ATerm arg, PTPT_OptLayout wsAfterTrm) {
  if (PTPT_isATermAnnotated(arg)) {
    return (PTPT_ATerm)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterTrm), 1), 1);
  }

  ATabort("ATerm has no WsAfterTrm: %t\n", arg);
  return (PTPT_ATerm)NULL;
}

/**
 * Set the Annotation of a PTPT_ATerm. The precondition being that this PTPT_ATerm actually has a Annotation
 * \param[in] arg input PTPT_ATerm
 * \param[in] Annotation new PTPT_Annotation to set in #arg
 * \return A new PTPT_ATerm with Annotation at the right place, or a core dump if #arg did not have a Annotation
 */
PTPT_ATerm PTPT_setATermAnnotation(PTPT_ATerm arg, PTPT_Annotation Annotation) {
  if (PTPT_isATermAnnotated(arg)) {
    return (PTPT_ATerm)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) Annotation), 2), 1);
  }

  ATabort("ATerm has no Annotation: %t\n", arg);
  return (PTPT_ATerm)NULL;
}

/**
 * Assert whether a PTPT_Annotation is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input PTPT_Annotation
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool PTPT_isValidAnnotation(PTPT_Annotation arg) {
  if (PTPT_isAnnotationDefault(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Annotation is a default by checking against the following ATerm pattern: appl(prod([lit("{"),cf(opt(layout)),cf(iter-sep(sort("ATerm"),lit(","))),cf(opt(layout)),lit("}")],cf(sort("Annotation")),attrs([term(cons("default"))])),[appl(prod([char-class([123])],lit("{"),no-attrs),[123]),<"ws-after-{"("OptLayout")>,appl(list(cf(iter-sep(sort("ATerm"),lit(",")))),<"annos"("ATerm-annos")>),<"ws-after-annos"("OptLayout")>,appl(prod([char-class([125])],lit("}"),no-attrs),[125])]). Always returns ATtrue
 * \param[in] arg input PTPT_Annotation
 * \return ATtrue if #arg corresponds to the signature of a default, or ATfalse otherwise
 */
inline ATbool PTPT_isAnnotationDefault(PTPT_Annotation arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == PTPT_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == PTPT_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lit */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: { */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun100) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
              /* checking for: cf */
              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                /* checking for: opt */
                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                  /* checking for: layout */
                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                      arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                      arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                      /* checking for: cf */
                      if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                        ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                        /* checking for: iter-sep */
                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun34) {
                          ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                          /* checking for: sort */
                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun9) {
                            ATerm arg_arg0_arg0_head_arg0_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0_arg0, 0);
                            /* checking for: ATerm */
                            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0_arg0) == PTPT_afun40) {
                              ATerm arg_arg0_arg0_head_arg0_arg1 = ATgetArgument(arg_arg0_arg0_head_arg0, 1);
                              /* checking for: lit */
                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg1) == PTPT_afun16) {
                                ATerm arg_arg0_arg0_head_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0_arg1, 0);
                                /* checking for: , */
                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg1_arg0) == PTPT_afun19) {
                                  if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                    arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                    arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                    /* checking for: cf */
                                    if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                      ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                      /* checking for: opt */
                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                        ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                        /* checking for: layout */
                                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                            arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                            arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                            /* checking for: lit */
                                            if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
                                              ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                              /* checking for: } */
                                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun99) {
                                                if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                                                  ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                                  /* checking for: cf */
                                                  if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == PTPT_afun2) {
                                                    ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                                    /* checking for: sort */
                                                    if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == PTPT_afun9) {
                                                      ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                                      /* checking for: Annotation */
                                                      if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == PTPT_afun10) {
                                                        ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                                        /* checking for: attrs */
                                                        if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == PTPT_afun12) {
                                                          ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                                          if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                                            ATerm arg_arg0_arg2_arg0_head;
                                                            ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                                            arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                                            arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                                            /* checking for: term */
                                                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == PTPT_afun13) {
                                                              ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                                              /* checking for: cons */
                                                              if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == PTPT_afun14) {
                                                                ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                                                /* checking for: default */
                                                                if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == PTPT_afun88) {
                                                                  if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                                    ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                                    if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                                      ATerm arg_arg1_head;
                                                                      ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                                      arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                      arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                      /* checking for: appl */
                                                                      if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                        ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                        /* checking for: prod */
                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                          ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                            ATerm arg_arg1_head_arg0_arg0_head;
                                                                            ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                            arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                            arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                            /* checking for: char-class */
                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 123) {

                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                      ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                      /* checking for: lit */
                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                        ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                        /* checking for: { */
                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun100) {
                                                                                          ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                          /* checking for: no-attrs */
                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                            ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                              ATerm arg_arg1_head_arg1_head;
                                                                                              ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                              arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                              arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 123) {

                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                  if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                    arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                      arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                      arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                      /* checking for: appl */
                                                                                                      if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                        ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                        /* checking for: list */
                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun8) {
                                                                                                          ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                          /* checking for: cf */
                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0) == PTPT_afun2) {
                                                                                                            ATerm arg_arg1_head_arg0_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0, 0);
                                                                                                            /* checking for: iter-sep */
                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0) == PTPT_afun34) {
                                                                                                              ATerm arg_arg1_head_arg0_arg0_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0, 0);
                                                                                                              /* checking for: sort */
                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg0) == PTPT_afun9) {
                                                                                                                ATerm arg_arg1_head_arg0_arg0_arg0_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0_arg0, 0);
                                                                                                                /* checking for: ATerm */
                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg0_arg0) == PTPT_afun40) {
                                                                                                                  ATerm arg_arg1_head_arg0_arg0_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0, 1);
                                                                                                                  /* checking for: lit */
                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg1) == PTPT_afun16) {
                                                                                                                    ATerm arg_arg1_head_arg0_arg0_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0_arg1, 0);
                                                                                                                    /* checking for: , */
                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg1_arg0) == PTPT_afun19) {
                                                                                                                      if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                        arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                          arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                          arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                          /* checking for: appl */
                                                                                                                          if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                                                            ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                            /* checking for: prod */
                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                                                              ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                /* checking for: char-class */
                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                    ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                    arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                    arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 125) {

                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                          ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                          /* checking for: lit */
                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                                                            ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                            /* checking for: } */
                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun99) {
                                                                                                                                              ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                              /* checking for: no-attrs */
                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                                                                ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                  ATerm arg_arg1_head_arg1_head;
                                                                                                                                                  ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                  arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                  arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 125) {

                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                                                                        return ATtrue;
                                                                                                                                                      }
                                                                                                                                                    }
                                                                                                                                                  }
                                                                                                                                                }
                                                                                                                                              }
                                                                                                                                            }
                                                                                                                                          }
                                                                                                                                        }
                                                                                                                                      }
                                                                                                                                    }
                                                                                                                                  }
                                                                                                                                }
                                                                                                                              }
                                                                                                                            }
                                                                                                                          }
                                                                                                                        }
                                                                                                                      }
                                                                                                                    }
                                                                                                                  }
                                                                                                                }
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Annotation has a ws-after-{. 
 * \param[in] arg input PTPT_Annotation
 * \return ATtrue if the PTPT_Annotation had a ws-after-{, or ATfalse otherwise
 */
ATbool PTPT_hasAnnotationWsAfterBraceOpen(PTPT_Annotation arg) {
  if (PTPT_isAnnotationDefault(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Annotation has a annos. 
 * \param[in] arg input PTPT_Annotation
 * \return ATtrue if the PTPT_Annotation had a annos, or ATfalse otherwise
 */
ATbool PTPT_hasAnnotationAnnos(PTPT_Annotation arg) {
  if (PTPT_isAnnotationDefault(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_Annotation has a ws-after-annos. 
 * \param[in] arg input PTPT_Annotation
 * \return ATtrue if the PTPT_Annotation had a ws-after-annos, or ATfalse otherwise
 */
ATbool PTPT_hasAnnotationWsAfterAnnos(PTPT_Annotation arg) {
  if (PTPT_isAnnotationDefault(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Get the ws-after-{ PTPT_OptLayout of a PTPT_Annotation. Note that the precondition is that this PTPT_Annotation actually has a ws-after-{
 * \param[in] arg input PTPT_Annotation
 * \return the ws-after-{ of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getAnnotationWsAfterBraceOpen(PTPT_Annotation arg) {
  
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1);
}

/**
 * Get the annos PTPT_ATermAnnos of a PTPT_Annotation. Note that the precondition is that this PTPT_Annotation actually has a annos
 * \param[in] arg input PTPT_Annotation
 * \return the annos of #arg, if it exist or an undefined value if it does not
 */
PTPT_ATermAnnos PTPT_getAnnotationAnnos(PTPT_Annotation arg) {
  
    return (PTPT_ATermAnnos)ATgetArgument((ATermAppl)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 2), 1);
}

/**
 * Get the ws-after-annos PTPT_OptLayout of a PTPT_Annotation. Note that the precondition is that this PTPT_Annotation actually has a ws-after-annos
 * \param[in] arg input PTPT_Annotation
 * \return the ws-after-annos of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getAnnotationWsAfterAnnos(PTPT_Annotation arg) {
  
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 3);
}

/**
 * Set the ws-after-{ of a PTPT_Annotation. The precondition being that this PTPT_Annotation actually has a ws-after-{
 * \param[in] arg input PTPT_Annotation
 * \param[in] wsAfterBraceOpen new PTPT_OptLayout to set in #arg
 * \return A new PTPT_Annotation with wsAfterBraceOpen at the right place, or a core dump if #arg did not have a wsAfterBraceOpen
 */
PTPT_Annotation PTPT_setAnnotationWsAfterBraceOpen(PTPT_Annotation arg, PTPT_OptLayout wsAfterBraceOpen) {
  if (PTPT_isAnnotationDefault(arg)) {
    return (PTPT_Annotation)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterBraceOpen), 1), 1);
  }

  ATabort("Annotation has no WsAfterBraceOpen: %t\n", arg);
  return (PTPT_Annotation)NULL;
}

/**
 * Set the annos of a PTPT_Annotation. The precondition being that this PTPT_Annotation actually has a annos
 * \param[in] arg input PTPT_Annotation
 * \param[in] annos new PTPT_ATermAnnos to set in #arg
 * \return A new PTPT_Annotation with annos at the right place, or a core dump if #arg did not have a annos
 */
PTPT_Annotation PTPT_setAnnotationAnnos(PTPT_Annotation arg, PTPT_ATermAnnos annos) {
  if (PTPT_isAnnotationDefault(arg)) {
    return (PTPT_Annotation)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)ATsetArgument((ATermAppl)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 2), (ATerm)((ATerm) annos), 1), 2), 1);
  }

  ATabort("Annotation has no Annos: %t\n", arg);
  return (PTPT_Annotation)NULL;
}

/**
 * Set the ws-after-annos of a PTPT_Annotation. The precondition being that this PTPT_Annotation actually has a ws-after-annos
 * \param[in] arg input PTPT_Annotation
 * \param[in] wsAfterAnnos new PTPT_OptLayout to set in #arg
 * \return A new PTPT_Annotation with wsAfterAnnos at the right place, or a core dump if #arg did not have a wsAfterAnnos
 */
PTPT_Annotation PTPT_setAnnotationWsAfterAnnos(PTPT_Annotation arg, PTPT_OptLayout wsAfterAnnos) {
  if (PTPT_isAnnotationDefault(arg)) {
    return (PTPT_Annotation)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterAnnos), 3), 1);
  }

  ATabort("Annotation has no WsAfterAnnos: %t\n", arg);
  return (PTPT_Annotation)NULL;
}

/**
 * Assert whether a PTPT_ATermArgs is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input PTPT_ATermArgs
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool PTPT_isValidATermArgs(PTPT_ATermArgs arg) {
  if (PTPT_isATermArgsEmpty(arg)) {
    return ATtrue;
  }
  else if (PTPT_isATermArgsSingle(arg)) {
    return ATtrue;
  }
  else if (PTPT_isATermArgsMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_ATermArgs is a empty by checking against the following ATerm pattern: []. May not be used to assert correctness of the PTPT_ATermArgs
 * \param[in] arg input PTPT_ATermArgs
 * \return ATtrue if #arg corresponds to the signature of a empty, or ATfalse otherwise
 */
inline ATbool PTPT_isATermArgsEmpty(PTPT_ATermArgs arg){
  if (ATisEmpty((ATermList)arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_ATermArgs is a single by checking against the following ATerm pattern: [<head(ATerm)>]. May not be used to assert correctness of the PTPT_ATermArgs
 * \param[in] arg input PTPT_ATermArgs
 * \return ATtrue if #arg corresponds to the signature of a single, or ATfalse otherwise
 */
inline ATbool PTPT_isATermArgsSingle(PTPT_ATermArgs arg){
  if (ATgetType((ATerm)arg) == AT_LIST && ATisEmpty((ATermList)arg) == ATfalse) {
    ATermList arg_list = (ATermList)arg;
    arg_list = ATgetNext(arg_list);
    if (ATgetType((ATerm)arg_list) == AT_LIST && ATisEmpty((ATermList)arg_list) == ATtrue) {
      return ATtrue;
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_ATermArgs is a many by checking against the following ATerm pattern: [<head(ATerm)>,<ws-after-head("OptLayout")>,appl(prod([char-class([44])],lit(","),no-attrs),[44]),<ws-after-sep("OptLayout")>,<[tail(ATerm-args)]>]. May not be used to assert correctness of the PTPT_ATermArgs
 * \param[in] arg input PTPT_ATermArgs
 * \return ATtrue if #arg corresponds to the signature of a many, or ATfalse otherwise
 */
inline ATbool PTPT_isATermArgsMany(PTPT_ATermArgs arg){
  if (ATgetType((ATerm)arg) == AT_LIST && ATisEmpty((ATermList)arg) == ATfalse) {
    ATerm arg_head;
    ATermList arg_list = (ATermList)arg;
    arg_list = ATgetNext(arg_list);
    if (ATgetType((ATerm)arg_list) == AT_LIST && ATisEmpty((ATermList)arg_list) == ATfalse) {
      arg_list = ATgetNext(arg_list);
      if (ATgetType((ATerm)arg_list) == AT_LIST && ATisEmpty((ATermList)arg_list) == ATfalse) {
        arg_head = ATgetFirst(arg_list);
        arg_list = ATgetNext(arg_list);
        /* checking for: appl */
        if (ATgetType((ATerm)arg_head) == AT_APPL && ATgetAFun((ATermAppl)arg_head) == PTPT_afun0) {
          ATerm arg_head_arg0 = ATgetArgument(arg_head, 0);
          /* checking for: prod */
          if (ATgetType((ATerm)arg_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_head_arg0) == PTPT_afun1) {
            ATerm arg_head_arg0_arg0 = ATgetArgument(arg_head_arg0, 0);
            if (ATgetType((ATerm)arg_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_head_arg0_arg0) == ATfalse) {
              ATerm arg_head_arg0_arg0_head;
              ATermList arg_head_arg0_arg0_list = (ATermList)arg_head_arg0_arg0;
              arg_head_arg0_arg0_head = ATgetFirst(arg_head_arg0_arg0_list);
              arg_head_arg0_arg0_list = ATgetNext(arg_head_arg0_arg0_list);
              /* checking for: char-class */
              if (ATgetType((ATerm)arg_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_head_arg0_arg0_head) == PTPT_afun23) {
                ATerm arg_head_arg0_arg0_head_arg0 = ATgetArgument(arg_head_arg0_arg0_head, 0);
                if (ATgetType((ATerm)arg_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_head_arg0_arg0_head_arg0) == ATfalse) {
                  ATerm arg_head_arg0_arg0_head_arg0_head;
                  ATermList arg_head_arg0_arg0_head_arg0_list = (ATermList)arg_head_arg0_arg0_head_arg0;
                  arg_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_head_arg0_arg0_head_arg0_list);
                  arg_head_arg0_arg0_head_arg0_list = ATgetNext(arg_head_arg0_arg0_head_arg0_list);
                  if (ATgetInt((ATermInt)arg_head_arg0_arg0_head_arg0_head) == 44) {

                    if (ATgetType((ATerm)arg_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_head_arg0_arg0_head_arg0_list) == ATtrue) {
                      if (ATgetType((ATerm)arg_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_head_arg0_arg0_list) == ATtrue) {
                        ATerm arg_head_arg0_arg1 = ATgetArgument(arg_head_arg0, 1);
                        /* checking for: lit */
                        if (ATgetType((ATerm)arg_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_head_arg0_arg1) == PTPT_afun16) {
                          ATerm arg_head_arg0_arg1_arg0 = ATgetArgument(arg_head_arg0_arg1, 0);
                          /* checking for: , */
                          if (ATgetType((ATerm)arg_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_head_arg0_arg1_arg0) == PTPT_afun19) {
                            ATerm arg_head_arg0_arg2 = ATgetArgument(arg_head_arg0, 2);
                            /* checking for: no-attrs */
                            if (ATgetType((ATerm)arg_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_head_arg0_arg2) == PTPT_afun5) {
                              ATerm arg_head_arg1 = ATgetArgument(arg_head, 1);
                              if (ATgetType((ATerm)arg_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_head_arg1) == ATfalse) {
                                ATerm arg_head_arg1_head;
                                ATermList arg_head_arg1_list = (ATermList)arg_head_arg1;
                                arg_head_arg1_head = ATgetFirst(arg_head_arg1_list);
                                arg_head_arg1_list = ATgetNext(arg_head_arg1_list);
                                if (ATgetInt((ATermInt)arg_head_arg1_head) == 44) {

                                  if (ATgetType((ATerm)arg_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_head_arg1_list) == ATtrue) {
                                    if (ATgetType((ATerm)arg_list) == AT_LIST && ATisEmpty((ATermList)arg_list) == ATfalse) {
                                      return ATtrue;
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_ATermArgs has a head. 
 * \param[in] arg input PTPT_ATermArgs
 * \return ATtrue if the PTPT_ATermArgs had a head, or ATfalse otherwise
 */
ATbool PTPT_hasATermArgsHead(PTPT_ATermArgs arg) {
  if (PTPT_isATermArgsSingle(arg)) {
    return ATtrue;
  }
  else if (PTPT_isATermArgsMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_ATermArgs has a ws-after-head. 
 * \param[in] arg input PTPT_ATermArgs
 * \return ATtrue if the PTPT_ATermArgs had a ws-after-head, or ATfalse otherwise
 */
ATbool PTPT_hasATermArgsWsAfterHead(PTPT_ATermArgs arg) {
  if (PTPT_isATermArgsMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_ATermArgs has a ws-after-sep. 
 * \param[in] arg input PTPT_ATermArgs
 * \return ATtrue if the PTPT_ATermArgs had a ws-after-sep, or ATfalse otherwise
 */
ATbool PTPT_hasATermArgsWsAfterSep(PTPT_ATermArgs arg) {
  if (PTPT_isATermArgsMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_ATermArgs has a tail. 
 * \param[in] arg input PTPT_ATermArgs
 * \return ATtrue if the PTPT_ATermArgs had a tail, or ATfalse otherwise
 */
ATbool PTPT_hasATermArgsTail(PTPT_ATermArgs arg) {
  if (PTPT_isATermArgsMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Returns a list of all but the first element of a PTPT_ATermArgs. 
 * \param[in] arg input PTPT_ATermArgs
 * \return A new PTPT_ATermArgs, without the first element and the separator(s) just after it.)
 */
PTPT_ATermArgs PTPT_getATermArgsTail(PTPT_ATermArgs arg) {
  assert(!PTPT_isATermArgsEmpty(arg) && "getTail on an empty list");
  if (PTPT_isATermArgsSingle(arg)) {
    return (PTPT_ATermArgs) PTPT_makeATermArgsEmpty();
  }
  else {
  
    return (PTPT_ATermArgs)ATgetTail((ATermList)arg, 4);
  }
}

/**
 * Get the head PTPT_ATerm of a PTPT_ATermArgs. Note that the precondition is that this PTPT_ATermArgs actually has a head
 * \param[in] arg input PTPT_ATermArgs
 * \return the head of #arg, if it exist or an undefined value if it does not
 */
PTPT_ATerm PTPT_getATermArgsHead(PTPT_ATermArgs arg) {
  if (PTPT_isATermArgsSingle(arg)) {
    return (PTPT_ATerm)ATgetFirst((ATermList)arg);
  }
  else 
    return (PTPT_ATerm)ATgetFirst((ATermList)arg);
}

/**
 * Get the ws-after-head PTPT_OptLayout of a PTPT_ATermArgs. Note that the precondition is that this PTPT_ATermArgs actually has a ws-after-head
 * \param[in] arg input PTPT_ATermArgs
 * \return the ws-after-head of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getATermArgsWsAfterHead(PTPT_ATermArgs arg) {
  
    return (PTPT_OptLayout)ATelementAt((ATermList)arg, 1);
}

/**
 * Get the ws-after-sep PTPT_OptLayout of a PTPT_ATermArgs. Note that the precondition is that this PTPT_ATermArgs actually has a ws-after-sep
 * \param[in] arg input PTPT_ATermArgs
 * \return the ws-after-sep of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getATermArgsWsAfterSep(PTPT_ATermArgs arg) {
  
    return (PTPT_OptLayout)ATelementAt((ATermList)arg, 3);
}

/**
 * Set the head of a PTPT_ATermArgs. The precondition being that this PTPT_ATermArgs actually has a head
 * \param[in] arg input PTPT_ATermArgs
 * \param[in] head new PTPT_ATerm to set in #arg
 * \return A new PTPT_ATermArgs with head at the right place, or a core dump if #arg did not have a head
 */
PTPT_ATermArgs PTPT_setATermArgsHead(PTPT_ATermArgs arg, PTPT_ATerm head) {
  if (PTPT_isATermArgsSingle(arg)) {
    return (PTPT_ATermArgs)ATreplace((ATermList)arg, (ATerm)((ATerm) head), 0);
  }
  else if (PTPT_isATermArgsMany(arg)) {
    return (PTPT_ATermArgs)ATreplace((ATermList)arg, (ATerm)((ATerm) head), 0);
  }

  ATabort("ATermArgs has no Head: %t\n", arg);
  return (PTPT_ATermArgs)NULL;
}

/**
 * Set the ws-after-head of a PTPT_ATermArgs. The precondition being that this PTPT_ATermArgs actually has a ws-after-head
 * \param[in] arg input PTPT_ATermArgs
 * \param[in] wsAfterHead new PTPT_OptLayout to set in #arg
 * \return A new PTPT_ATermArgs with wsAfterHead at the right place, or a core dump if #arg did not have a wsAfterHead
 */
PTPT_ATermArgs PTPT_setATermArgsWsAfterHead(PTPT_ATermArgs arg, PTPT_OptLayout wsAfterHead) {
  if (PTPT_isATermArgsMany(arg)) {
    return (PTPT_ATermArgs)ATreplace((ATermList)arg, (ATerm)((ATerm) wsAfterHead), 1);
  }

  ATabort("ATermArgs has no WsAfterHead: %t\n", arg);
  return (PTPT_ATermArgs)NULL;
}

/**
 * Set the ws-after-sep of a PTPT_ATermArgs. The precondition being that this PTPT_ATermArgs actually has a ws-after-sep
 * \param[in] arg input PTPT_ATermArgs
 * \param[in] wsAfterSep new PTPT_OptLayout to set in #arg
 * \return A new PTPT_ATermArgs with wsAfterSep at the right place, or a core dump if #arg did not have a wsAfterSep
 */
PTPT_ATermArgs PTPT_setATermArgsWsAfterSep(PTPT_ATermArgs arg, PTPT_OptLayout wsAfterSep) {
  if (PTPT_isATermArgsMany(arg)) {
    return (PTPT_ATermArgs)ATreplace((ATermList)arg, (ATerm)((ATerm) wsAfterSep), 3);
  }

  ATabort("ATermArgs has no WsAfterSep: %t\n", arg);
  return (PTPT_ATermArgs)NULL;
}

/**
 * Set the tail of a PTPT_ATermArgs. The precondition being that this PTPT_ATermArgs actually has a tail
 * \param[in] arg input PTPT_ATermArgs
 * \param[in] tail new PTPT_ATermArgs to set in #arg
 * \return A new PTPT_ATermArgs with tail at the right place, or a core dump if #arg did not have a tail
 */
PTPT_ATermArgs PTPT_setATermArgsTail(PTPT_ATermArgs arg, PTPT_ATermArgs tail) {
  if (PTPT_isATermArgsMany(arg)) {
    return (PTPT_ATermArgs)ATreplaceTail((ATermList)arg, (ATermList)((ATerm) tail), 4);
  }

  ATabort("ATermArgs has no Tail: %t\n", arg);
  return (PTPT_ATermArgs)NULL;
}

/**
 * Assert whether a PTPT_ATermElems is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input PTPT_ATermElems
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool PTPT_isValidATermElems(PTPT_ATermElems arg) {
  if (PTPT_isATermElemsEmpty(arg)) {
    return ATtrue;
  }
  else if (PTPT_isATermElemsSingle(arg)) {
    return ATtrue;
  }
  else if (PTPT_isATermElemsMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_ATermElems is a empty by checking against the following ATerm pattern: []. May not be used to assert correctness of the PTPT_ATermElems
 * \param[in] arg input PTPT_ATermElems
 * \return ATtrue if #arg corresponds to the signature of a empty, or ATfalse otherwise
 */
inline ATbool PTPT_isATermElemsEmpty(PTPT_ATermElems arg){
  if (ATisEmpty((ATermList)arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_ATermElems is a single by checking against the following ATerm pattern: [<head(ATerm)>]. May not be used to assert correctness of the PTPT_ATermElems
 * \param[in] arg input PTPT_ATermElems
 * \return ATtrue if #arg corresponds to the signature of a single, or ATfalse otherwise
 */
inline ATbool PTPT_isATermElemsSingle(PTPT_ATermElems arg){
  if (ATgetType((ATerm)arg) == AT_LIST && ATisEmpty((ATermList)arg) == ATfalse) {
    ATermList arg_list = (ATermList)arg;
    arg_list = ATgetNext(arg_list);
    if (ATgetType((ATerm)arg_list) == AT_LIST && ATisEmpty((ATermList)arg_list) == ATtrue) {
      return ATtrue;
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_ATermElems is a many by checking against the following ATerm pattern: [<head(ATerm)>,<ws-after-head("OptLayout")>,appl(prod([char-class([44])],lit(","),no-attrs),[44]),<ws-after-sep("OptLayout")>,<[tail(ATerm-elems)]>]. May not be used to assert correctness of the PTPT_ATermElems
 * \param[in] arg input PTPT_ATermElems
 * \return ATtrue if #arg corresponds to the signature of a many, or ATfalse otherwise
 */
inline ATbool PTPT_isATermElemsMany(PTPT_ATermElems arg){
  if (ATgetType((ATerm)arg) == AT_LIST && ATisEmpty((ATermList)arg) == ATfalse) {
    ATerm arg_head;
    ATermList arg_list = (ATermList)arg;
    arg_list = ATgetNext(arg_list);
    if (ATgetType((ATerm)arg_list) == AT_LIST && ATisEmpty((ATermList)arg_list) == ATfalse) {
      arg_list = ATgetNext(arg_list);
      if (ATgetType((ATerm)arg_list) == AT_LIST && ATisEmpty((ATermList)arg_list) == ATfalse) {
        arg_head = ATgetFirst(arg_list);
        arg_list = ATgetNext(arg_list);
        /* checking for: appl */
        if (ATgetType((ATerm)arg_head) == AT_APPL && ATgetAFun((ATermAppl)arg_head) == PTPT_afun0) {
          ATerm arg_head_arg0 = ATgetArgument(arg_head, 0);
          /* checking for: prod */
          if (ATgetType((ATerm)arg_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_head_arg0) == PTPT_afun1) {
            ATerm arg_head_arg0_arg0 = ATgetArgument(arg_head_arg0, 0);
            if (ATgetType((ATerm)arg_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_head_arg0_arg0) == ATfalse) {
              ATerm arg_head_arg0_arg0_head;
              ATermList arg_head_arg0_arg0_list = (ATermList)arg_head_arg0_arg0;
              arg_head_arg0_arg0_head = ATgetFirst(arg_head_arg0_arg0_list);
              arg_head_arg0_arg0_list = ATgetNext(arg_head_arg0_arg0_list);
              /* checking for: char-class */
              if (ATgetType((ATerm)arg_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_head_arg0_arg0_head) == PTPT_afun23) {
                ATerm arg_head_arg0_arg0_head_arg0 = ATgetArgument(arg_head_arg0_arg0_head, 0);
                if (ATgetType((ATerm)arg_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_head_arg0_arg0_head_arg0) == ATfalse) {
                  ATerm arg_head_arg0_arg0_head_arg0_head;
                  ATermList arg_head_arg0_arg0_head_arg0_list = (ATermList)arg_head_arg0_arg0_head_arg0;
                  arg_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_head_arg0_arg0_head_arg0_list);
                  arg_head_arg0_arg0_head_arg0_list = ATgetNext(arg_head_arg0_arg0_head_arg0_list);
                  if (ATgetInt((ATermInt)arg_head_arg0_arg0_head_arg0_head) == 44) {

                    if (ATgetType((ATerm)arg_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_head_arg0_arg0_head_arg0_list) == ATtrue) {
                      if (ATgetType((ATerm)arg_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_head_arg0_arg0_list) == ATtrue) {
                        ATerm arg_head_arg0_arg1 = ATgetArgument(arg_head_arg0, 1);
                        /* checking for: lit */
                        if (ATgetType((ATerm)arg_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_head_arg0_arg1) == PTPT_afun16) {
                          ATerm arg_head_arg0_arg1_arg0 = ATgetArgument(arg_head_arg0_arg1, 0);
                          /* checking for: , */
                          if (ATgetType((ATerm)arg_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_head_arg0_arg1_arg0) == PTPT_afun19) {
                            ATerm arg_head_arg0_arg2 = ATgetArgument(arg_head_arg0, 2);
                            /* checking for: no-attrs */
                            if (ATgetType((ATerm)arg_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_head_arg0_arg2) == PTPT_afun5) {
                              ATerm arg_head_arg1 = ATgetArgument(arg_head, 1);
                              if (ATgetType((ATerm)arg_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_head_arg1) == ATfalse) {
                                ATerm arg_head_arg1_head;
                                ATermList arg_head_arg1_list = (ATermList)arg_head_arg1;
                                arg_head_arg1_head = ATgetFirst(arg_head_arg1_list);
                                arg_head_arg1_list = ATgetNext(arg_head_arg1_list);
                                if (ATgetInt((ATermInt)arg_head_arg1_head) == 44) {

                                  if (ATgetType((ATerm)arg_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_head_arg1_list) == ATtrue) {
                                    if (ATgetType((ATerm)arg_list) == AT_LIST && ATisEmpty((ATermList)arg_list) == ATfalse) {
                                      return ATtrue;
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_ATermElems has a head. 
 * \param[in] arg input PTPT_ATermElems
 * \return ATtrue if the PTPT_ATermElems had a head, or ATfalse otherwise
 */
ATbool PTPT_hasATermElemsHead(PTPT_ATermElems arg) {
  if (PTPT_isATermElemsSingle(arg)) {
    return ATtrue;
  }
  else if (PTPT_isATermElemsMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_ATermElems has a ws-after-head. 
 * \param[in] arg input PTPT_ATermElems
 * \return ATtrue if the PTPT_ATermElems had a ws-after-head, or ATfalse otherwise
 */
ATbool PTPT_hasATermElemsWsAfterHead(PTPT_ATermElems arg) {
  if (PTPT_isATermElemsMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_ATermElems has a ws-after-sep. 
 * \param[in] arg input PTPT_ATermElems
 * \return ATtrue if the PTPT_ATermElems had a ws-after-sep, or ATfalse otherwise
 */
ATbool PTPT_hasATermElemsWsAfterSep(PTPT_ATermElems arg) {
  if (PTPT_isATermElemsMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_ATermElems has a tail. 
 * \param[in] arg input PTPT_ATermElems
 * \return ATtrue if the PTPT_ATermElems had a tail, or ATfalse otherwise
 */
ATbool PTPT_hasATermElemsTail(PTPT_ATermElems arg) {
  if (PTPT_isATermElemsMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Returns a list of all but the first element of a PTPT_ATermElems. 
 * \param[in] arg input PTPT_ATermElems
 * \return A new PTPT_ATermElems, without the first element and the separator(s) just after it.)
 */
PTPT_ATermElems PTPT_getATermElemsTail(PTPT_ATermElems arg) {
  assert(!PTPT_isATermElemsEmpty(arg) && "getTail on an empty list");
  if (PTPT_isATermElemsSingle(arg)) {
    return (PTPT_ATermElems) PTPT_makeATermElemsEmpty();
  }
  else {
  
    return (PTPT_ATermElems)ATgetTail((ATermList)arg, 4);
  }
}

/**
 * Get the head PTPT_ATerm of a PTPT_ATermElems. Note that the precondition is that this PTPT_ATermElems actually has a head
 * \param[in] arg input PTPT_ATermElems
 * \return the head of #arg, if it exist or an undefined value if it does not
 */
PTPT_ATerm PTPT_getATermElemsHead(PTPT_ATermElems arg) {
  if (PTPT_isATermElemsSingle(arg)) {
    return (PTPT_ATerm)ATgetFirst((ATermList)arg);
  }
  else 
    return (PTPT_ATerm)ATgetFirst((ATermList)arg);
}

/**
 * Get the ws-after-head PTPT_OptLayout of a PTPT_ATermElems. Note that the precondition is that this PTPT_ATermElems actually has a ws-after-head
 * \param[in] arg input PTPT_ATermElems
 * \return the ws-after-head of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getATermElemsWsAfterHead(PTPT_ATermElems arg) {
  
    return (PTPT_OptLayout)ATelementAt((ATermList)arg, 1);
}

/**
 * Get the ws-after-sep PTPT_OptLayout of a PTPT_ATermElems. Note that the precondition is that this PTPT_ATermElems actually has a ws-after-sep
 * \param[in] arg input PTPT_ATermElems
 * \return the ws-after-sep of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getATermElemsWsAfterSep(PTPT_ATermElems arg) {
  
    return (PTPT_OptLayout)ATelementAt((ATermList)arg, 3);
}

/**
 * Set the head of a PTPT_ATermElems. The precondition being that this PTPT_ATermElems actually has a head
 * \param[in] arg input PTPT_ATermElems
 * \param[in] head new PTPT_ATerm to set in #arg
 * \return A new PTPT_ATermElems with head at the right place, or a core dump if #arg did not have a head
 */
PTPT_ATermElems PTPT_setATermElemsHead(PTPT_ATermElems arg, PTPT_ATerm head) {
  if (PTPT_isATermElemsSingle(arg)) {
    return (PTPT_ATermElems)ATreplace((ATermList)arg, (ATerm)((ATerm) head), 0);
  }
  else if (PTPT_isATermElemsMany(arg)) {
    return (PTPT_ATermElems)ATreplace((ATermList)arg, (ATerm)((ATerm) head), 0);
  }

  ATabort("ATermElems has no Head: %t\n", arg);
  return (PTPT_ATermElems)NULL;
}

/**
 * Set the ws-after-head of a PTPT_ATermElems. The precondition being that this PTPT_ATermElems actually has a ws-after-head
 * \param[in] arg input PTPT_ATermElems
 * \param[in] wsAfterHead new PTPT_OptLayout to set in #arg
 * \return A new PTPT_ATermElems with wsAfterHead at the right place, or a core dump if #arg did not have a wsAfterHead
 */
PTPT_ATermElems PTPT_setATermElemsWsAfterHead(PTPT_ATermElems arg, PTPT_OptLayout wsAfterHead) {
  if (PTPT_isATermElemsMany(arg)) {
    return (PTPT_ATermElems)ATreplace((ATermList)arg, (ATerm)((ATerm) wsAfterHead), 1);
  }

  ATabort("ATermElems has no WsAfterHead: %t\n", arg);
  return (PTPT_ATermElems)NULL;
}

/**
 * Set the ws-after-sep of a PTPT_ATermElems. The precondition being that this PTPT_ATermElems actually has a ws-after-sep
 * \param[in] arg input PTPT_ATermElems
 * \param[in] wsAfterSep new PTPT_OptLayout to set in #arg
 * \return A new PTPT_ATermElems with wsAfterSep at the right place, or a core dump if #arg did not have a wsAfterSep
 */
PTPT_ATermElems PTPT_setATermElemsWsAfterSep(PTPT_ATermElems arg, PTPT_OptLayout wsAfterSep) {
  if (PTPT_isATermElemsMany(arg)) {
    return (PTPT_ATermElems)ATreplace((ATermList)arg, (ATerm)((ATerm) wsAfterSep), 3);
  }

  ATabort("ATermElems has no WsAfterSep: %t\n", arg);
  return (PTPT_ATermElems)NULL;
}

/**
 * Set the tail of a PTPT_ATermElems. The precondition being that this PTPT_ATermElems actually has a tail
 * \param[in] arg input PTPT_ATermElems
 * \param[in] tail new PTPT_ATermElems to set in #arg
 * \return A new PTPT_ATermElems with tail at the right place, or a core dump if #arg did not have a tail
 */
PTPT_ATermElems PTPT_setATermElemsTail(PTPT_ATermElems arg, PTPT_ATermElems tail) {
  if (PTPT_isATermElemsMany(arg)) {
    return (PTPT_ATermElems)ATreplaceTail((ATermList)arg, (ATermList)((ATerm) tail), 4);
  }

  ATabort("ATermElems has no Tail: %t\n", arg);
  return (PTPT_ATermElems)NULL;
}

/**
 * Assert whether a PTPT_ATermAnnos is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input PTPT_ATermAnnos
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool PTPT_isValidATermAnnos(PTPT_ATermAnnos arg) {
  if (PTPT_isATermAnnosEmpty(arg)) {
    return ATtrue;
  }
  else if (PTPT_isATermAnnosSingle(arg)) {
    return ATtrue;
  }
  else if (PTPT_isATermAnnosMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_ATermAnnos is a empty by checking against the following ATerm pattern: []. May not be used to assert correctness of the PTPT_ATermAnnos
 * \param[in] arg input PTPT_ATermAnnos
 * \return ATtrue if #arg corresponds to the signature of a empty, or ATfalse otherwise
 */
inline ATbool PTPT_isATermAnnosEmpty(PTPT_ATermAnnos arg){
  if (ATisEmpty((ATermList)arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_ATermAnnos is a single by checking against the following ATerm pattern: [<head(ATerm)>]. May not be used to assert correctness of the PTPT_ATermAnnos
 * \param[in] arg input PTPT_ATermAnnos
 * \return ATtrue if #arg corresponds to the signature of a single, or ATfalse otherwise
 */
inline ATbool PTPT_isATermAnnosSingle(PTPT_ATermAnnos arg){
  if (ATgetType((ATerm)arg) == AT_LIST && ATisEmpty((ATermList)arg) == ATfalse) {
    ATermList arg_list = (ATermList)arg;
    arg_list = ATgetNext(arg_list);
    if (ATgetType((ATerm)arg_list) == AT_LIST && ATisEmpty((ATermList)arg_list) == ATtrue) {
      return ATtrue;
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_ATermAnnos is a many by checking against the following ATerm pattern: [<head(ATerm)>,<ws-after-head("OptLayout")>,appl(prod([char-class([44])],lit(","),no-attrs),[44]),<ws-after-sep("OptLayout")>,<[tail(ATerm-annos)]>]. May not be used to assert correctness of the PTPT_ATermAnnos
 * \param[in] arg input PTPT_ATermAnnos
 * \return ATtrue if #arg corresponds to the signature of a many, or ATfalse otherwise
 */
inline ATbool PTPT_isATermAnnosMany(PTPT_ATermAnnos arg){
  if (ATgetType((ATerm)arg) == AT_LIST && ATisEmpty((ATermList)arg) == ATfalse) {
    ATerm arg_head;
    ATermList arg_list = (ATermList)arg;
    arg_list = ATgetNext(arg_list);
    if (ATgetType((ATerm)arg_list) == AT_LIST && ATisEmpty((ATermList)arg_list) == ATfalse) {
      arg_list = ATgetNext(arg_list);
      if (ATgetType((ATerm)arg_list) == AT_LIST && ATisEmpty((ATermList)arg_list) == ATfalse) {
        arg_head = ATgetFirst(arg_list);
        arg_list = ATgetNext(arg_list);
        /* checking for: appl */
        if (ATgetType((ATerm)arg_head) == AT_APPL && ATgetAFun((ATermAppl)arg_head) == PTPT_afun0) {
          ATerm arg_head_arg0 = ATgetArgument(arg_head, 0);
          /* checking for: prod */
          if (ATgetType((ATerm)arg_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_head_arg0) == PTPT_afun1) {
            ATerm arg_head_arg0_arg0 = ATgetArgument(arg_head_arg0, 0);
            if (ATgetType((ATerm)arg_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_head_arg0_arg0) == ATfalse) {
              ATerm arg_head_arg0_arg0_head;
              ATermList arg_head_arg0_arg0_list = (ATermList)arg_head_arg0_arg0;
              arg_head_arg0_arg0_head = ATgetFirst(arg_head_arg0_arg0_list);
              arg_head_arg0_arg0_list = ATgetNext(arg_head_arg0_arg0_list);
              /* checking for: char-class */
              if (ATgetType((ATerm)arg_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_head_arg0_arg0_head) == PTPT_afun23) {
                ATerm arg_head_arg0_arg0_head_arg0 = ATgetArgument(arg_head_arg0_arg0_head, 0);
                if (ATgetType((ATerm)arg_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_head_arg0_arg0_head_arg0) == ATfalse) {
                  ATerm arg_head_arg0_arg0_head_arg0_head;
                  ATermList arg_head_arg0_arg0_head_arg0_list = (ATermList)arg_head_arg0_arg0_head_arg0;
                  arg_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_head_arg0_arg0_head_arg0_list);
                  arg_head_arg0_arg0_head_arg0_list = ATgetNext(arg_head_arg0_arg0_head_arg0_list);
                  if (ATgetInt((ATermInt)arg_head_arg0_arg0_head_arg0_head) == 44) {

                    if (ATgetType((ATerm)arg_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_head_arg0_arg0_head_arg0_list) == ATtrue) {
                      if (ATgetType((ATerm)arg_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_head_arg0_arg0_list) == ATtrue) {
                        ATerm arg_head_arg0_arg1 = ATgetArgument(arg_head_arg0, 1);
                        /* checking for: lit */
                        if (ATgetType((ATerm)arg_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_head_arg0_arg1) == PTPT_afun16) {
                          ATerm arg_head_arg0_arg1_arg0 = ATgetArgument(arg_head_arg0_arg1, 0);
                          /* checking for: , */
                          if (ATgetType((ATerm)arg_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_head_arg0_arg1_arg0) == PTPT_afun19) {
                            ATerm arg_head_arg0_arg2 = ATgetArgument(arg_head_arg0, 2);
                            /* checking for: no-attrs */
                            if (ATgetType((ATerm)arg_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_head_arg0_arg2) == PTPT_afun5) {
                              ATerm arg_head_arg1 = ATgetArgument(arg_head, 1);
                              if (ATgetType((ATerm)arg_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_head_arg1) == ATfalse) {
                                ATerm arg_head_arg1_head;
                                ATermList arg_head_arg1_list = (ATermList)arg_head_arg1;
                                arg_head_arg1_head = ATgetFirst(arg_head_arg1_list);
                                arg_head_arg1_list = ATgetNext(arg_head_arg1_list);
                                if (ATgetInt((ATermInt)arg_head_arg1_head) == 44) {

                                  if (ATgetType((ATerm)arg_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_head_arg1_list) == ATtrue) {
                                    if (ATgetType((ATerm)arg_list) == AT_LIST && ATisEmpty((ATermList)arg_list) == ATfalse) {
                                      return ATtrue;
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_ATermAnnos has a head. 
 * \param[in] arg input PTPT_ATermAnnos
 * \return ATtrue if the PTPT_ATermAnnos had a head, or ATfalse otherwise
 */
ATbool PTPT_hasATermAnnosHead(PTPT_ATermAnnos arg) {
  if (PTPT_isATermAnnosSingle(arg)) {
    return ATtrue;
  }
  else if (PTPT_isATermAnnosMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_ATermAnnos has a ws-after-head. 
 * \param[in] arg input PTPT_ATermAnnos
 * \return ATtrue if the PTPT_ATermAnnos had a ws-after-head, or ATfalse otherwise
 */
ATbool PTPT_hasATermAnnosWsAfterHead(PTPT_ATermAnnos arg) {
  if (PTPT_isATermAnnosMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_ATermAnnos has a ws-after-sep. 
 * \param[in] arg input PTPT_ATermAnnos
 * \return ATtrue if the PTPT_ATermAnnos had a ws-after-sep, or ATfalse otherwise
 */
ATbool PTPT_hasATermAnnosWsAfterSep(PTPT_ATermAnnos arg) {
  if (PTPT_isATermAnnosMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_ATermAnnos has a tail. 
 * \param[in] arg input PTPT_ATermAnnos
 * \return ATtrue if the PTPT_ATermAnnos had a tail, or ATfalse otherwise
 */
ATbool PTPT_hasATermAnnosTail(PTPT_ATermAnnos arg) {
  if (PTPT_isATermAnnosMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Returns a list of all but the first element of a PTPT_ATermAnnos. 
 * \param[in] arg input PTPT_ATermAnnos
 * \return A new PTPT_ATermAnnos, without the first element and the separator(s) just after it.)
 */
PTPT_ATermAnnos PTPT_getATermAnnosTail(PTPT_ATermAnnos arg) {
  assert(!PTPT_isATermAnnosEmpty(arg) && "getTail on an empty list");
  if (PTPT_isATermAnnosSingle(arg)) {
    return (PTPT_ATermAnnos) PTPT_makeATermAnnosEmpty();
  }
  else {
  
    return (PTPT_ATermAnnos)ATgetTail((ATermList)arg, 4);
  }
}

/**
 * Get the head PTPT_ATerm of a PTPT_ATermAnnos. Note that the precondition is that this PTPT_ATermAnnos actually has a head
 * \param[in] arg input PTPT_ATermAnnos
 * \return the head of #arg, if it exist or an undefined value if it does not
 */
PTPT_ATerm PTPT_getATermAnnosHead(PTPT_ATermAnnos arg) {
  if (PTPT_isATermAnnosSingle(arg)) {
    return (PTPT_ATerm)ATgetFirst((ATermList)arg);
  }
  else 
    return (PTPT_ATerm)ATgetFirst((ATermList)arg);
}

/**
 * Get the ws-after-head PTPT_OptLayout of a PTPT_ATermAnnos. Note that the precondition is that this PTPT_ATermAnnos actually has a ws-after-head
 * \param[in] arg input PTPT_ATermAnnos
 * \return the ws-after-head of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getATermAnnosWsAfterHead(PTPT_ATermAnnos arg) {
  
    return (PTPT_OptLayout)ATelementAt((ATermList)arg, 1);
}

/**
 * Get the ws-after-sep PTPT_OptLayout of a PTPT_ATermAnnos. Note that the precondition is that this PTPT_ATermAnnos actually has a ws-after-sep
 * \param[in] arg input PTPT_ATermAnnos
 * \return the ws-after-sep of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getATermAnnosWsAfterSep(PTPT_ATermAnnos arg) {
  
    return (PTPT_OptLayout)ATelementAt((ATermList)arg, 3);
}

/**
 * Set the head of a PTPT_ATermAnnos. The precondition being that this PTPT_ATermAnnos actually has a head
 * \param[in] arg input PTPT_ATermAnnos
 * \param[in] head new PTPT_ATerm to set in #arg
 * \return A new PTPT_ATermAnnos with head at the right place, or a core dump if #arg did not have a head
 */
PTPT_ATermAnnos PTPT_setATermAnnosHead(PTPT_ATermAnnos arg, PTPT_ATerm head) {
  if (PTPT_isATermAnnosSingle(arg)) {
    return (PTPT_ATermAnnos)ATreplace((ATermList)arg, (ATerm)((ATerm) head), 0);
  }
  else if (PTPT_isATermAnnosMany(arg)) {
    return (PTPT_ATermAnnos)ATreplace((ATermList)arg, (ATerm)((ATerm) head), 0);
  }

  ATabort("ATermAnnos has no Head: %t\n", arg);
  return (PTPT_ATermAnnos)NULL;
}

/**
 * Set the ws-after-head of a PTPT_ATermAnnos. The precondition being that this PTPT_ATermAnnos actually has a ws-after-head
 * \param[in] arg input PTPT_ATermAnnos
 * \param[in] wsAfterHead new PTPT_OptLayout to set in #arg
 * \return A new PTPT_ATermAnnos with wsAfterHead at the right place, or a core dump if #arg did not have a wsAfterHead
 */
PTPT_ATermAnnos PTPT_setATermAnnosWsAfterHead(PTPT_ATermAnnos arg, PTPT_OptLayout wsAfterHead) {
  if (PTPT_isATermAnnosMany(arg)) {
    return (PTPT_ATermAnnos)ATreplace((ATermList)arg, (ATerm)((ATerm) wsAfterHead), 1);
  }

  ATabort("ATermAnnos has no WsAfterHead: %t\n", arg);
  return (PTPT_ATermAnnos)NULL;
}

/**
 * Set the ws-after-sep of a PTPT_ATermAnnos. The precondition being that this PTPT_ATermAnnos actually has a ws-after-sep
 * \param[in] arg input PTPT_ATermAnnos
 * \param[in] wsAfterSep new PTPT_OptLayout to set in #arg
 * \return A new PTPT_ATermAnnos with wsAfterSep at the right place, or a core dump if #arg did not have a wsAfterSep
 */
PTPT_ATermAnnos PTPT_setATermAnnosWsAfterSep(PTPT_ATermAnnos arg, PTPT_OptLayout wsAfterSep) {
  if (PTPT_isATermAnnosMany(arg)) {
    return (PTPT_ATermAnnos)ATreplace((ATermList)arg, (ATerm)((ATerm) wsAfterSep), 3);
  }

  ATabort("ATermAnnos has no WsAfterSep: %t\n", arg);
  return (PTPT_ATermAnnos)NULL;
}

/**
 * Set the tail of a PTPT_ATermAnnos. The precondition being that this PTPT_ATermAnnos actually has a tail
 * \param[in] arg input PTPT_ATermAnnos
 * \param[in] tail new PTPT_ATermAnnos to set in #arg
 * \return A new PTPT_ATermAnnos with tail at the right place, or a core dump if #arg did not have a tail
 */
PTPT_ATermAnnos PTPT_setATermAnnosTail(PTPT_ATermAnnos arg, PTPT_ATermAnnos tail) {
  if (PTPT_isATermAnnosMany(arg)) {
    return (PTPT_ATermAnnos)ATreplaceTail((ATermList)arg, (ATermList)((ATerm) tail), 4);
  }

  ATabort("ATermAnnos has no Tail: %t\n", arg);
  return (PTPT_ATermAnnos)NULL;
}

/**
 * Assert whether a PTPT_IntCon is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input PTPT_IntCon
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool PTPT_isValidIntCon(PTPT_IntCon arg) {
  if (PTPT_isIntConNatural(arg)) {
    return ATtrue;
  }
  else if (PTPT_isIntConPositive(arg)) {
    return ATtrue;
  }
  else if (PTPT_isIntConNegative(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_IntCon is a natural by checking against the following ATerm pattern: appl(prod([cf(sort("NatCon"))],cf(sort("IntCon")),attrs([term(cons("natural"))])),[<"NatCon"("NatCon")>]). May not be used to assert correctness of the PTPT_IntCon
 * \param[in] arg input PTPT_IntCon
 * \return ATtrue if #arg corresponds to the signature of a natural, or ATfalse otherwise
 */
inline ATbool PTPT_isIntConNatural(PTPT_IntCon arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == PTPT_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == PTPT_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: cf */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: sort */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun9) {
            ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
            /* checking for: NatCon */
            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun24) {
              if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                /* checking for: cf */
                if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == PTPT_afun2) {
                  ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                  /* checking for: sort */
                  if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == PTPT_afun9) {
                    ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                    /* checking for: IntCon */
                    if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == PTPT_afun85) {
                      ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                      /* checking for: attrs */
                      if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == PTPT_afun12) {
                        ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                        if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                          ATerm arg_arg0_arg2_arg0_head;
                          ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                          arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                          arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                          /* checking for: term */
                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == PTPT_afun13) {
                            ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                            /* checking for: cons */
                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == PTPT_afun14) {
                              ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                              /* checking for: natural */
                              if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == PTPT_afun101) {
                                if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                  ATerm arg_arg1 = ATgetArgument(arg, 1);
                                  if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                    ATermList arg_arg1_list = (ATermList)arg_arg1;
                                    arg_arg1_list = ATgetNext(arg_arg1_list);
                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                      return ATtrue;
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_IntCon is a positive by checking against the following ATerm pattern: appl(prod([lit("+"),cf(opt(layout)),cf(sort("NatCon"))],cf(sort("IntCon")),attrs([term(cons("positive"))])),[appl(prod([char-class([43])],lit("+"),no-attrs),[43]),<"ws-after-pos"("OptLayout")>,<"NatCon"("NatCon")>]). May not be used to assert correctness of the PTPT_IntCon
 * \param[in] arg input PTPT_IntCon
 * \return ATtrue if #arg corresponds to the signature of a positive, or ATfalse otherwise
 */
inline ATbool PTPT_isIntConPositive(PTPT_IntCon arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == PTPT_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == PTPT_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lit */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: + */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun102) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
              /* checking for: cf */
              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                /* checking for: opt */
                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                  /* checking for: layout */
                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                      arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                      arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                      /* checking for: cf */
                      if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                        ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                        /* checking for: sort */
                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun9) {
                          ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                          /* checking for: NatCon */
                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun24) {
                            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                              ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                              /* checking for: cf */
                              if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == PTPT_afun2) {
                                ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                /* checking for: sort */
                                if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == PTPT_afun9) {
                                  ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                  /* checking for: IntCon */
                                  if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == PTPT_afun85) {
                                    ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                    /* checking for: attrs */
                                    if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == PTPT_afun12) {
                                      ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                      if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                        ATerm arg_arg0_arg2_arg0_head;
                                        ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                        arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                        arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                        /* checking for: term */
                                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == PTPT_afun13) {
                                          ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                          /* checking for: cons */
                                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == PTPT_afun14) {
                                            ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                            /* checking for: positive */
                                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == PTPT_afun103) {
                                              if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                  ATerm arg_arg1_head;
                                                  ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                  arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                                  /* checking for: appl */
                                                  if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                    ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                    /* checking for: prod */
                                                    if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                      ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                        ATerm arg_arg1_head_arg0_arg0_head;
                                                        ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                        arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                        arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                        /* checking for: char-class */
                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                            ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                            arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                            arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 43) {

                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                  ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                  /* checking for: lit */
                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                    ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                    /* checking for: + */
                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun102) {
                                                                      ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                      /* checking for: no-attrs */
                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                        ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                        if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                          ATerm arg_arg1_head_arg1_head;
                                                                          ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                          arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                          arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 43) {

                                                                            if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                              if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                  if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                    return ATtrue;
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_IntCon is a negative by checking against the following ATerm pattern: appl(prod([lit("-"),cf(opt(layout)),cf(sort("NatCon"))],cf(sort("IntCon")),attrs([term(cons("negative"))])),[appl(prod([char-class([45])],lit("-"),no-attrs),[45]),<"ws-after-neg"("OptLayout")>,<"NatCon"("NatCon")>]). May not be used to assert correctness of the PTPT_IntCon
 * \param[in] arg input PTPT_IntCon
 * \return ATtrue if #arg corresponds to the signature of a negative, or ATfalse otherwise
 */
inline ATbool PTPT_isIntConNegative(PTPT_IntCon arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == PTPT_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == PTPT_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lit */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: - */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun104) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
              /* checking for: cf */
              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                /* checking for: opt */
                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                  /* checking for: layout */
                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                      arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                      arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                      /* checking for: cf */
                      if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                        ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                        /* checking for: sort */
                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun9) {
                          ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                          /* checking for: NatCon */
                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun24) {
                            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                              ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                              /* checking for: cf */
                              if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == PTPT_afun2) {
                                ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                /* checking for: sort */
                                if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == PTPT_afun9) {
                                  ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                  /* checking for: IntCon */
                                  if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == PTPT_afun85) {
                                    ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                    /* checking for: attrs */
                                    if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == PTPT_afun12) {
                                      ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                      if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                        ATerm arg_arg0_arg2_arg0_head;
                                        ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                        arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                        arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                        /* checking for: term */
                                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == PTPT_afun13) {
                                          ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                          /* checking for: cons */
                                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == PTPT_afun14) {
                                            ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                            /* checking for: negative */
                                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == PTPT_afun105) {
                                              if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                  ATerm arg_arg1_head;
                                                  ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                  arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                                  /* checking for: appl */
                                                  if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                    ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                    /* checking for: prod */
                                                    if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                      ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                        ATerm arg_arg1_head_arg0_arg0_head;
                                                        ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                        arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                        arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                        /* checking for: char-class */
                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                            ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                            arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                            arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 45) {

                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                  ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                  /* checking for: lit */
                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                    ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                    /* checking for: - */
                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun104) {
                                                                      ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                      /* checking for: no-attrs */
                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                        ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                        if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                          ATerm arg_arg1_head_arg1_head;
                                                                          ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                          arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                          arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 45) {

                                                                            if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                              if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                  if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                    return ATtrue;
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_IntCon has a NatCon. 
 * \param[in] arg input PTPT_IntCon
 * \return ATtrue if the PTPT_IntCon had a NatCon, or ATfalse otherwise
 */
ATbool PTPT_hasIntConNatCon(PTPT_IntCon arg) {
  if (PTPT_isIntConNatural(arg)) {
    return ATtrue;
  }
  else if (PTPT_isIntConPositive(arg)) {
    return ATtrue;
  }
  else if (PTPT_isIntConNegative(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_IntCon has a ws-after-pos. 
 * \param[in] arg input PTPT_IntCon
 * \return ATtrue if the PTPT_IntCon had a ws-after-pos, or ATfalse otherwise
 */
ATbool PTPT_hasIntConWsAfterPos(PTPT_IntCon arg) {
  if (PTPT_isIntConPositive(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_IntCon has a ws-after-neg. 
 * \param[in] arg input PTPT_IntCon
 * \return ATtrue if the PTPT_IntCon had a ws-after-neg, or ATfalse otherwise
 */
ATbool PTPT_hasIntConWsAfterNeg(PTPT_IntCon arg) {
  if (PTPT_isIntConNegative(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Get the NatCon PTPT_NatCon of a PTPT_IntCon. Note that the precondition is that this PTPT_IntCon actually has a NatCon
 * \param[in] arg input PTPT_IntCon
 * \return the NatCon of #arg, if it exist or an undefined value if it does not
 */
PTPT_NatCon PTPT_getIntConNatCon(PTPT_IntCon arg) {
  if (PTPT_isIntConNatural(arg)) {
    return (PTPT_NatCon)ATgetFirst((ATermList)ATgetArgument((ATermAppl)arg, 1));
  }
  else if (PTPT_isIntConPositive(arg)) {
    return (PTPT_NatCon)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 2);
  }
  else 
    return (PTPT_NatCon)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 2);
}

/**
 * Get the ws-after-pos PTPT_OptLayout of a PTPT_IntCon. Note that the precondition is that this PTPT_IntCon actually has a ws-after-pos
 * \param[in] arg input PTPT_IntCon
 * \return the ws-after-pos of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getIntConWsAfterPos(PTPT_IntCon arg) {
  
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1);
}

/**
 * Get the ws-after-neg PTPT_OptLayout of a PTPT_IntCon. Note that the precondition is that this PTPT_IntCon actually has a ws-after-neg
 * \param[in] arg input PTPT_IntCon
 * \return the ws-after-neg of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getIntConWsAfterNeg(PTPT_IntCon arg) {
  
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1);
}

/**
 * Set the NatCon of a PTPT_IntCon. The precondition being that this PTPT_IntCon actually has a NatCon
 * \param[in] arg input PTPT_IntCon
 * \param[in] NatCon new PTPT_NatCon to set in #arg
 * \return A new PTPT_IntCon with NatCon at the right place, or a core dump if #arg did not have a NatCon
 */
PTPT_IntCon PTPT_setIntConNatCon(PTPT_IntCon arg, PTPT_NatCon NatCon) {
  if (PTPT_isIntConNatural(arg)) {
    return (PTPT_IntCon)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) NatCon), 0), 1);
  }
  else if (PTPT_isIntConPositive(arg)) {
    return (PTPT_IntCon)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) NatCon), 2), 1);
  }
  else if (PTPT_isIntConNegative(arg)) {
    return (PTPT_IntCon)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) NatCon), 2), 1);
  }

  ATabort("IntCon has no NatCon: %t\n", arg);
  return (PTPT_IntCon)NULL;
}

/**
 * Set the ws-after-pos of a PTPT_IntCon. The precondition being that this PTPT_IntCon actually has a ws-after-pos
 * \param[in] arg input PTPT_IntCon
 * \param[in] wsAfterPos new PTPT_OptLayout to set in #arg
 * \return A new PTPT_IntCon with wsAfterPos at the right place, or a core dump if #arg did not have a wsAfterPos
 */
PTPT_IntCon PTPT_setIntConWsAfterPos(PTPT_IntCon arg, PTPT_OptLayout wsAfterPos) {
  if (PTPT_isIntConPositive(arg)) {
    return (PTPT_IntCon)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterPos), 1), 1);
  }

  ATabort("IntCon has no WsAfterPos: %t\n", arg);
  return (PTPT_IntCon)NULL;
}

/**
 * Set the ws-after-neg of a PTPT_IntCon. The precondition being that this PTPT_IntCon actually has a ws-after-neg
 * \param[in] arg input PTPT_IntCon
 * \param[in] wsAfterNeg new PTPT_OptLayout to set in #arg
 * \return A new PTPT_IntCon with wsAfterNeg at the right place, or a core dump if #arg did not have a wsAfterNeg
 */
PTPT_IntCon PTPT_setIntConWsAfterNeg(PTPT_IntCon arg, PTPT_OptLayout wsAfterNeg) {
  if (PTPT_isIntConNegative(arg)) {
    return (PTPT_IntCon)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterNeg), 1), 1);
  }

  ATabort("IntCon has no WsAfterNeg: %t\n", arg);
  return (PTPT_IntCon)NULL;
}

/**
 * Assert whether a PTPT_OptExp is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input PTPT_OptExp
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool PTPT_isValidOptExp(PTPT_OptExp arg) {
  if (PTPT_isOptExpPresent(arg)) {
    return ATtrue;
  }
  else if (PTPT_isOptExpAbsent(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_OptExp is a present by checking against the following ATerm pattern: appl(prod([lit("e"),cf(opt(layout)),cf(sort("IntCon"))],cf(sort("OptExp")),attrs([term(cons("present"))])),[appl(prod([char-class([101])],lit("e"),no-attrs),[101]),<"ws-after-e"("OptLayout")>,<"IntCon"("IntCon")>]). May not be used to assert correctness of the PTPT_OptExp
 * \param[in] arg input PTPT_OptExp
 * \return ATtrue if #arg corresponds to the signature of a present, or ATfalse otherwise
 */
inline ATbool PTPT_isOptExpPresent(PTPT_OptExp arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == PTPT_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == PTPT_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lit */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: e */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun106) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
              /* checking for: cf */
              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                /* checking for: opt */
                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                  /* checking for: layout */
                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                      arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                      arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                      /* checking for: cf */
                      if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                        ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                        /* checking for: sort */
                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun9) {
                          ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                          /* checking for: IntCon */
                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun85) {
                            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                              ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                              /* checking for: cf */
                              if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == PTPT_afun2) {
                                ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                /* checking for: sort */
                                if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == PTPT_afun9) {
                                  ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                  /* checking for: OptExp */
                                  if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == PTPT_afun107) {
                                    ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                    /* checking for: attrs */
                                    if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == PTPT_afun12) {
                                      ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                      if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                        ATerm arg_arg0_arg2_arg0_head;
                                        ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                        arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                        arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                        /* checking for: term */
                                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == PTPT_afun13) {
                                          ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                          /* checking for: cons */
                                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == PTPT_afun14) {
                                            ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                            /* checking for: present */
                                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == PTPT_afun108) {
                                              if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                  ATerm arg_arg1_head;
                                                  ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                  arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                                  /* checking for: appl */
                                                  if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                    ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                    /* checking for: prod */
                                                    if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                      ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                        ATerm arg_arg1_head_arg0_arg0_head;
                                                        ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                        arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                        arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                        /* checking for: char-class */
                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                            ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                            arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                            arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 101) {

                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                  ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                  /* checking for: lit */
                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                    ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                    /* checking for: e */
                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun106) {
                                                                      ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                      /* checking for: no-attrs */
                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                        ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                        if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                          ATerm arg_arg1_head_arg1_head;
                                                                          ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                          arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                          arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 101) {

                                                                            if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                              if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                  if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                    return ATtrue;
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_OptExp is a absent by checking against the following ATerm pattern: appl(prod([],cf(sort("OptExp")),attrs([term(cons("absent"))])),[]). May not be used to assert correctness of the PTPT_OptExp
 * \param[in] arg input PTPT_OptExp
 * \return ATtrue if #arg corresponds to the signature of a absent, or ATfalse otherwise
 */
inline ATbool PTPT_isOptExpAbsent(PTPT_OptExp arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == PTPT_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == PTPT_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATisEmpty((ATermList)arg_arg0_arg0)) {
        ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
        /* checking for: cf */
        if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == PTPT_afun2) {
          ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
          /* checking for: sort */
          if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == PTPT_afun9) {
            ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
            /* checking for: OptExp */
            if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == PTPT_afun107) {
              ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
              /* checking for: attrs */
              if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == PTPT_afun12) {
                ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                  ATerm arg_arg0_arg2_arg0_head;
                  ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                  arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                  arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                  /* checking for: term */
                  if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == PTPT_afun13) {
                    ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                    /* checking for: cons */
                    if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == PTPT_afun14) {
                      ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                      /* checking for: absent */
                      if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == PTPT_afun109) {
                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                          ATerm arg_arg1 = ATgetArgument(arg, 1);
                          if (ATisEmpty((ATermList)arg_arg1)) {
                            return ATtrue;
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_OptExp has a ws-after-e. 
 * \param[in] arg input PTPT_OptExp
 * \return ATtrue if the PTPT_OptExp had a ws-after-e, or ATfalse otherwise
 */
ATbool PTPT_hasOptExpWsAfterE(PTPT_OptExp arg) {
  if (PTPT_isOptExpPresent(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_OptExp has a IntCon. 
 * \param[in] arg input PTPT_OptExp
 * \return ATtrue if the PTPT_OptExp had a IntCon, or ATfalse otherwise
 */
ATbool PTPT_hasOptExpIntCon(PTPT_OptExp arg) {
  if (PTPT_isOptExpPresent(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Get the ws-after-e PTPT_OptLayout of a PTPT_OptExp. Note that the precondition is that this PTPT_OptExp actually has a ws-after-e
 * \param[in] arg input PTPT_OptExp
 * \return the ws-after-e of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getOptExpWsAfterE(PTPT_OptExp arg) {
  
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1);
}

/**
 * Get the IntCon PTPT_IntCon of a PTPT_OptExp. Note that the precondition is that this PTPT_OptExp actually has a IntCon
 * \param[in] arg input PTPT_OptExp
 * \return the IntCon of #arg, if it exist or an undefined value if it does not
 */
PTPT_IntCon PTPT_getOptExpIntCon(PTPT_OptExp arg) {
  
    return (PTPT_IntCon)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 2);
}

/**
 * Set the ws-after-e of a PTPT_OptExp. The precondition being that this PTPT_OptExp actually has a ws-after-e
 * \param[in] arg input PTPT_OptExp
 * \param[in] wsAfterE new PTPT_OptLayout to set in #arg
 * \return A new PTPT_OptExp with wsAfterE at the right place, or a core dump if #arg did not have a wsAfterE
 */
PTPT_OptExp PTPT_setOptExpWsAfterE(PTPT_OptExp arg, PTPT_OptLayout wsAfterE) {
  if (PTPT_isOptExpPresent(arg)) {
    return (PTPT_OptExp)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterE), 1), 1);
  }

  ATabort("OptExp has no WsAfterE: %t\n", arg);
  return (PTPT_OptExp)NULL;
}

/**
 * Set the IntCon of a PTPT_OptExp. The precondition being that this PTPT_OptExp actually has a IntCon
 * \param[in] arg input PTPT_OptExp
 * \param[in] IntCon new PTPT_IntCon to set in #arg
 * \return A new PTPT_OptExp with IntCon at the right place, or a core dump if #arg did not have a IntCon
 */
PTPT_OptExp PTPT_setOptExpIntCon(PTPT_OptExp arg, PTPT_IntCon IntCon) {
  if (PTPT_isOptExpPresent(arg)) {
    return (PTPT_OptExp)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) IntCon), 2), 1);
  }

  ATabort("OptExp has no IntCon: %t\n", arg);
  return (PTPT_OptExp)NULL;
}

/**
 * Assert whether a PTPT_RealCon is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input PTPT_RealCon
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool PTPT_isValidRealCon(PTPT_RealCon arg) {
  if (PTPT_isRealConRealCon(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_RealCon is a real-con by checking against the following ATerm pattern: appl(prod([cf(sort("IntCon")),cf(opt(layout)),lit("."),cf(opt(layout)),cf(sort("NatCon")),cf(opt(layout)),cf(sort("OptExp"))],cf(sort("RealCon")),attrs([term(cons("real-con"))])),[<"base"("IntCon")>,<"ws-after-base"("OptLayout")>,appl(prod([char-class([46])],lit("."),no-attrs),[46]),<"ws-after-."("OptLayout")>,<"decimal"("NatCon")>,<"ws-after-decimal"("OptLayout")>,<"exp"("OptExp")>]). Always returns ATtrue
 * \param[in] arg input PTPT_RealCon
 * \return ATtrue if #arg corresponds to the signature of a real-con, or ATfalse otherwise
 */
inline ATbool PTPT_isRealConRealCon(PTPT_RealCon arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == PTPT_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == PTPT_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: cf */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: sort */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun9) {
            ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
            /* checking for: IntCon */
            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun85) {
              if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                /* checking for: cf */
                if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                  ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                  /* checking for: opt */
                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                    ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                    /* checking for: layout */
                    if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                      if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                        /* checking for: lit */
                        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
                          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                          /* checking for: . */
                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun110) {
                            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                              /* checking for: cf */
                              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                /* checking for: opt */
                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                  /* checking for: layout */
                                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                      arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                      arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                      /* checking for: cf */
                                      if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                        ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                        /* checking for: sort */
                                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun9) {
                                          ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                          /* checking for: NatCon */
                                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun24) {
                                            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                              /* checking for: cf */
                                              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                /* checking for: opt */
                                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun3) {
                                                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                  /* checking for: layout */
                                                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun4) {
                                                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                      arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                      arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                      /* checking for: cf */
                                                      if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun2) {
                                                        ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                        /* checking for: sort */
                                                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun9) {
                                                          ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                          /* checking for: OptExp */
                                                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun107) {
                                                            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                                                              ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                                              /* checking for: cf */
                                                              if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == PTPT_afun2) {
                                                                ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                                                /* checking for: sort */
                                                                if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == PTPT_afun9) {
                                                                  ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                                                  /* checking for: RealCon */
                                                                  if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == PTPT_afun86) {
                                                                    ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                                                    /* checking for: attrs */
                                                                    if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == PTPT_afun12) {
                                                                      ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                                                      if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                                                        ATerm arg_arg0_arg2_arg0_head;
                                                                        ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                                                        arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                                                        arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                                                        /* checking for: term */
                                                                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == PTPT_afun13) {
                                                                          ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                                                          /* checking for: cons */
                                                                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == PTPT_afun14) {
                                                                            ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                                                            /* checking for: real-con */
                                                                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == PTPT_afun111) {
                                                                              if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                                                ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                                                if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                                                  ATerm arg_arg1_head;
                                                                                  ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                  if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                    arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                      arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                      arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                      /* checking for: appl */
                                                                                      if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                        ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                        /* checking for: prod */
                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                          ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                            ATerm arg_arg1_head_arg0_arg0_head;
                                                                                            ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                            arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                            arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                            /* checking for: char-class */
                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 46) {

                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                      ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                      /* checking for: lit */
                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                                        ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                        /* checking for: . */
                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun110) {
                                                                                                          ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                          /* checking for: no-attrs */
                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                            ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                              ATerm arg_arg1_head_arg1_head;
                                                                                                              ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                              arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                              arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 46) {

                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                  if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                    arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                      arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                      if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                        arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                          arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                          if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                                            return ATtrue;
                                                                                                                          }
                                                                                                                        }
                                                                                                                      }
                                                                                                                    }
                                                                                                                  }
                                                                                                                }
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_RealCon has a base. 
 * \param[in] arg input PTPT_RealCon
 * \return ATtrue if the PTPT_RealCon had a base, or ATfalse otherwise
 */
ATbool PTPT_hasRealConBase(PTPT_RealCon arg) {
  if (PTPT_isRealConRealCon(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_RealCon has a ws-after-base. 
 * \param[in] arg input PTPT_RealCon
 * \return ATtrue if the PTPT_RealCon had a ws-after-base, or ATfalse otherwise
 */
ATbool PTPT_hasRealConWsAfterBase(PTPT_RealCon arg) {
  if (PTPT_isRealConRealCon(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_RealCon has a ws-after-.. 
 * \param[in] arg input PTPT_RealCon
 * \return ATtrue if the PTPT_RealCon had a ws-after-., or ATfalse otherwise
 */
ATbool PTPT_hasRealConWsAfterPeriod(PTPT_RealCon arg) {
  if (PTPT_isRealConRealCon(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_RealCon has a decimal. 
 * \param[in] arg input PTPT_RealCon
 * \return ATtrue if the PTPT_RealCon had a decimal, or ATfalse otherwise
 */
ATbool PTPT_hasRealConDecimal(PTPT_RealCon arg) {
  if (PTPT_isRealConRealCon(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_RealCon has a ws-after-decimal. 
 * \param[in] arg input PTPT_RealCon
 * \return ATtrue if the PTPT_RealCon had a ws-after-decimal, or ATfalse otherwise
 */
ATbool PTPT_hasRealConWsAfterDecimal(PTPT_RealCon arg) {
  if (PTPT_isRealConRealCon(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_RealCon has a exp. 
 * \param[in] arg input PTPT_RealCon
 * \return ATtrue if the PTPT_RealCon had a exp, or ATfalse otherwise
 */
ATbool PTPT_hasRealConExp(PTPT_RealCon arg) {
  if (PTPT_isRealConRealCon(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Get the base PTPT_IntCon of a PTPT_RealCon. Note that the precondition is that this PTPT_RealCon actually has a base
 * \param[in] arg input PTPT_RealCon
 * \return the base of #arg, if it exist or an undefined value if it does not
 */
PTPT_IntCon PTPT_getRealConBase(PTPT_RealCon arg) {
  
    return (PTPT_IntCon)ATgetFirst((ATermList)ATgetArgument((ATermAppl)arg, 1));
}

/**
 * Get the ws-after-base PTPT_OptLayout of a PTPT_RealCon. Note that the precondition is that this PTPT_RealCon actually has a ws-after-base
 * \param[in] arg input PTPT_RealCon
 * \return the ws-after-base of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getRealConWsAfterBase(PTPT_RealCon arg) {
  
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1);
}

/**
 * Get the ws-after-. PTPT_OptLayout of a PTPT_RealCon. Note that the precondition is that this PTPT_RealCon actually has a ws-after-.
 * \param[in] arg input PTPT_RealCon
 * \return the ws-after-. of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getRealConWsAfterPeriod(PTPT_RealCon arg) {
  
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 3);
}

/**
 * Get the decimal PTPT_NatCon of a PTPT_RealCon. Note that the precondition is that this PTPT_RealCon actually has a decimal
 * \param[in] arg input PTPT_RealCon
 * \return the decimal of #arg, if it exist or an undefined value if it does not
 */
PTPT_NatCon PTPT_getRealConDecimal(PTPT_RealCon arg) {
  
    return (PTPT_NatCon)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 4);
}

/**
 * Get the ws-after-decimal PTPT_OptLayout of a PTPT_RealCon. Note that the precondition is that this PTPT_RealCon actually has a ws-after-decimal
 * \param[in] arg input PTPT_RealCon
 * \return the ws-after-decimal of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptLayout PTPT_getRealConWsAfterDecimal(PTPT_RealCon arg) {
  
    return (PTPT_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 5);
}

/**
 * Get the exp PTPT_OptExp of a PTPT_RealCon. Note that the precondition is that this PTPT_RealCon actually has a exp
 * \param[in] arg input PTPT_RealCon
 * \return the exp of #arg, if it exist or an undefined value if it does not
 */
PTPT_OptExp PTPT_getRealConExp(PTPT_RealCon arg) {
  
    return (PTPT_OptExp)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 6);
}

/**
 * Set the base of a PTPT_RealCon. The precondition being that this PTPT_RealCon actually has a base
 * \param[in] arg input PTPT_RealCon
 * \param[in] base new PTPT_IntCon to set in #arg
 * \return A new PTPT_RealCon with base at the right place, or a core dump if #arg did not have a base
 */
PTPT_RealCon PTPT_setRealConBase(PTPT_RealCon arg, PTPT_IntCon base) {
  if (PTPT_isRealConRealCon(arg)) {
    return (PTPT_RealCon)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) base), 0), 1);
  }

  ATabort("RealCon has no Base: %t\n", arg);
  return (PTPT_RealCon)NULL;
}

/**
 * Set the ws-after-base of a PTPT_RealCon. The precondition being that this PTPT_RealCon actually has a ws-after-base
 * \param[in] arg input PTPT_RealCon
 * \param[in] wsAfterBase new PTPT_OptLayout to set in #arg
 * \return A new PTPT_RealCon with wsAfterBase at the right place, or a core dump if #arg did not have a wsAfterBase
 */
PTPT_RealCon PTPT_setRealConWsAfterBase(PTPT_RealCon arg, PTPT_OptLayout wsAfterBase) {
  if (PTPT_isRealConRealCon(arg)) {
    return (PTPT_RealCon)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterBase), 1), 1);
  }

  ATabort("RealCon has no WsAfterBase: %t\n", arg);
  return (PTPT_RealCon)NULL;
}

/**
 * Set the ws-after-. of a PTPT_RealCon. The precondition being that this PTPT_RealCon actually has a ws-after-.
 * \param[in] arg input PTPT_RealCon
 * \param[in] wsAfterPeriod new PTPT_OptLayout to set in #arg
 * \return A new PTPT_RealCon with wsAfterPeriod at the right place, or a core dump if #arg did not have a wsAfterPeriod
 */
PTPT_RealCon PTPT_setRealConWsAfterPeriod(PTPT_RealCon arg, PTPT_OptLayout wsAfterPeriod) {
  if (PTPT_isRealConRealCon(arg)) {
    return (PTPT_RealCon)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterPeriod), 3), 1);
  }

  ATabort("RealCon has no WsAfterPeriod: %t\n", arg);
  return (PTPT_RealCon)NULL;
}

/**
 * Set the decimal of a PTPT_RealCon. The precondition being that this PTPT_RealCon actually has a decimal
 * \param[in] arg input PTPT_RealCon
 * \param[in] decimal new PTPT_NatCon to set in #arg
 * \return A new PTPT_RealCon with decimal at the right place, or a core dump if #arg did not have a decimal
 */
PTPT_RealCon PTPT_setRealConDecimal(PTPT_RealCon arg, PTPT_NatCon decimal) {
  if (PTPT_isRealConRealCon(arg)) {
    return (PTPT_RealCon)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) decimal), 4), 1);
  }

  ATabort("RealCon has no Decimal: %t\n", arg);
  return (PTPT_RealCon)NULL;
}

/**
 * Set the ws-after-decimal of a PTPT_RealCon. The precondition being that this PTPT_RealCon actually has a ws-after-decimal
 * \param[in] arg input PTPT_RealCon
 * \param[in] wsAfterDecimal new PTPT_OptLayout to set in #arg
 * \return A new PTPT_RealCon with wsAfterDecimal at the right place, or a core dump if #arg did not have a wsAfterDecimal
 */
PTPT_RealCon PTPT_setRealConWsAfterDecimal(PTPT_RealCon arg, PTPT_OptLayout wsAfterDecimal) {
  if (PTPT_isRealConRealCon(arg)) {
    return (PTPT_RealCon)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterDecimal), 5), 1);
  }

  ATabort("RealCon has no WsAfterDecimal: %t\n", arg);
  return (PTPT_RealCon)NULL;
}

/**
 * Set the exp of a PTPT_RealCon. The precondition being that this PTPT_RealCon actually has a exp
 * \param[in] arg input PTPT_RealCon
 * \param[in] exp new PTPT_OptExp to set in #arg
 * \return A new PTPT_RealCon with exp at the right place, or a core dump if #arg did not have a exp
 */
PTPT_RealCon PTPT_setRealConExp(PTPT_RealCon arg, PTPT_OptExp exp) {
  if (PTPT_isRealConRealCon(arg)) {
    return (PTPT_RealCon)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) exp), 6), 1);
  }

  ATabort("RealCon has no Exp: %t\n", arg);
  return (PTPT_RealCon)NULL;
}

/**
 * Assert whether a PTPT_LexStrChar is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input PTPT_LexStrChar
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool PTPT_isValidLexStrChar(PTPT_LexStrChar arg) {
  if (PTPT_isLexStrCharNewline(arg)) {
    return ATtrue;
  }
  else if (PTPT_isLexStrCharTab(arg)) {
    return ATtrue;
  }
  else if (PTPT_isLexStrCharQuote(arg)) {
    return ATtrue;
  }
  else if (PTPT_isLexStrCharBackslash(arg)) {
    return ATtrue;
  }
  else if (PTPT_isLexStrCharDecimal(arg)) {
    return ATtrue;
  }
  else if (PTPT_isLexStrCharNormal(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_LexStrChar is a newline by checking against the following ATerm pattern: appl(prod([lit("\\n")],lex(sort("StrChar")),attrs([term(cons("newline"))])),[appl(prod([char-class([92]),char-class([110])],lit("\\n"),no-attrs),[92,110])]). May not be used to assert correctness of the PTPT_LexStrChar
 * \param[in] arg input PTPT_LexStrChar
 * \return ATtrue if #arg corresponds to the signature of a newline, or ATfalse otherwise
 */
inline ATbool PTPT_isLexStrCharNewline(PTPT_LexStrChar arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == PTPT_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == PTPT_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lit */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: \n */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun112) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
              ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
              /* checking for: lex */
              if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == PTPT_afun6) {
                ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                /* checking for: sort */
                if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == PTPT_afun9) {
                  ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                  /* checking for: StrChar */
                  if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == PTPT_afun113) {
                    ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                    /* checking for: attrs */
                    if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == PTPT_afun12) {
                      ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                      if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                        ATerm arg_arg0_arg2_arg0_head;
                        ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                        arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                        arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                        /* checking for: term */
                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == PTPT_afun13) {
                          ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                          /* checking for: cons */
                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == PTPT_afun14) {
                            ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                            /* checking for: newline */
                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == PTPT_afun114) {
                              if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                ATerm arg_arg1 = ATgetArgument(arg, 1);
                                if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                  ATerm arg_arg1_head;
                                  ATermList arg_arg1_list = (ATermList)arg_arg1;
                                  arg_arg1_head = ATgetFirst(arg_arg1_list);
                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                  /* checking for: appl */
                                  if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                    ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                    /* checking for: prod */
                                    if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                      ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                        ATerm arg_arg1_head_arg0_arg0_head;
                                        ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                        arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                        arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                        /* checking for: char-class */
                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                          ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                            ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                            ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                            arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                            arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                            if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 92) {

                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                  arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                  arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                  /* checking for: char-class */
                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                      ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                      arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                      arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 110) {

                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                            ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                            /* checking for: lit */
                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                              ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                              /* checking for: \n */
                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun112) {
                                                                ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                /* checking for: no-attrs */
                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                  ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                    ATerm arg_arg1_head_arg1_head;
                                                                    ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                    arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                    arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 92) {

                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                        arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                        arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 110) {

                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                            if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                              return ATtrue;
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_LexStrChar is a tab by checking against the following ATerm pattern: appl(prod([lit("\\t")],lex(sort("StrChar")),attrs([term(cons("tab"))])),[appl(prod([char-class([92]),char-class([116])],lit("\\t"),no-attrs),[92,116])]). May not be used to assert correctness of the PTPT_LexStrChar
 * \param[in] arg input PTPT_LexStrChar
 * \return ATtrue if #arg corresponds to the signature of a tab, or ATfalse otherwise
 */
inline ATbool PTPT_isLexStrCharTab(PTPT_LexStrChar arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == PTPT_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == PTPT_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lit */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: \t */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun115) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
              ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
              /* checking for: lex */
              if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == PTPT_afun6) {
                ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                /* checking for: sort */
                if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == PTPT_afun9) {
                  ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                  /* checking for: StrChar */
                  if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == PTPT_afun113) {
                    ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                    /* checking for: attrs */
                    if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == PTPT_afun12) {
                      ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                      if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                        ATerm arg_arg0_arg2_arg0_head;
                        ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                        arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                        arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                        /* checking for: term */
                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == PTPT_afun13) {
                          ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                          /* checking for: cons */
                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == PTPT_afun14) {
                            ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                            /* checking for: tab */
                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == PTPT_afun116) {
                              if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                ATerm arg_arg1 = ATgetArgument(arg, 1);
                                if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                  ATerm arg_arg1_head;
                                  ATermList arg_arg1_list = (ATermList)arg_arg1;
                                  arg_arg1_head = ATgetFirst(arg_arg1_list);
                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                  /* checking for: appl */
                                  if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                    ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                    /* checking for: prod */
                                    if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                      ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                        ATerm arg_arg1_head_arg0_arg0_head;
                                        ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                        arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                        arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                        /* checking for: char-class */
                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                          ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                            ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                            ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                            arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                            arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                            if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 92) {

                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                  arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                  arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                  /* checking for: char-class */
                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                      ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                      arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                      arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 116) {

                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                            ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                            /* checking for: lit */
                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                              ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                              /* checking for: \t */
                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun115) {
                                                                ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                /* checking for: no-attrs */
                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                  ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                    ATerm arg_arg1_head_arg1_head;
                                                                    ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                    arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                    arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 92) {

                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                        arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                        arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 116) {

                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                            if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                              return ATtrue;
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_LexStrChar is a quote by checking against the following ATerm pattern: appl(prod([lit("\\\"")],lex(sort("StrChar")),attrs([term(cons("quote"))])),[appl(prod([char-class([92]),char-class([34])],lit("\\\""),no-attrs),[92,34])]). May not be used to assert correctness of the PTPT_LexStrChar
 * \param[in] arg input PTPT_LexStrChar
 * \return ATtrue if #arg corresponds to the signature of a quote, or ATfalse otherwise
 */
inline ATbool PTPT_isLexStrCharQuote(PTPT_LexStrChar arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == PTPT_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == PTPT_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lit */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: \" */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun117) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
              ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
              /* checking for: lex */
              if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == PTPT_afun6) {
                ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                /* checking for: sort */
                if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == PTPT_afun9) {
                  ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                  /* checking for: StrChar */
                  if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == PTPT_afun113) {
                    ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                    /* checking for: attrs */
                    if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == PTPT_afun12) {
                      ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                      if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                        ATerm arg_arg0_arg2_arg0_head;
                        ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                        arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                        arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                        /* checking for: term */
                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == PTPT_afun13) {
                          ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                          /* checking for: cons */
                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == PTPT_afun14) {
                            ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                            /* checking for: quote */
                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == PTPT_afun118) {
                              if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                ATerm arg_arg1 = ATgetArgument(arg, 1);
                                if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                  ATerm arg_arg1_head;
                                  ATermList arg_arg1_list = (ATermList)arg_arg1;
                                  arg_arg1_head = ATgetFirst(arg_arg1_list);
                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                  /* checking for: appl */
                                  if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                    ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                    /* checking for: prod */
                                    if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                      ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                        ATerm arg_arg1_head_arg0_arg0_head;
                                        ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                        arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                        arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                        /* checking for: char-class */
                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                          ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                            ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                            ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                            arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                            arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                            if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 92) {

                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                  arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                  arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                  /* checking for: char-class */
                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                      ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                      arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                      arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 34) {

                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                            ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                            /* checking for: lit */
                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                              ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                              /* checking for: \" */
                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun117) {
                                                                ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                /* checking for: no-attrs */
                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                  ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                    ATerm arg_arg1_head_arg1_head;
                                                                    ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                    arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                    arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 92) {

                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                        arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                        arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 34) {

                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                            if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                              return ATtrue;
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_LexStrChar is a backslash by checking against the following ATerm pattern: appl(prod([lit("\\\\")],lex(sort("StrChar")),attrs([term(cons("backslash"))])),[appl(prod([char-class([92]),char-class([92])],lit("\\\\"),no-attrs),[92,92])]). May not be used to assert correctness of the PTPT_LexStrChar
 * \param[in] arg input PTPT_LexStrChar
 * \return ATtrue if #arg corresponds to the signature of a backslash, or ATfalse otherwise
 */
inline ATbool PTPT_isLexStrCharBackslash(PTPT_LexStrChar arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == PTPT_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == PTPT_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lit */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: \\ */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun119) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
              ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
              /* checking for: lex */
              if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == PTPT_afun6) {
                ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                /* checking for: sort */
                if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == PTPT_afun9) {
                  ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                  /* checking for: StrChar */
                  if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == PTPT_afun113) {
                    ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                    /* checking for: attrs */
                    if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == PTPT_afun12) {
                      ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                      if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                        ATerm arg_arg0_arg2_arg0_head;
                        ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                        arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                        arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                        /* checking for: term */
                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == PTPT_afun13) {
                          ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                          /* checking for: cons */
                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == PTPT_afun14) {
                            ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                            /* checking for: backslash */
                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == PTPT_afun120) {
                              if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                ATerm arg_arg1 = ATgetArgument(arg, 1);
                                if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                  ATerm arg_arg1_head;
                                  ATermList arg_arg1_list = (ATermList)arg_arg1;
                                  arg_arg1_head = ATgetFirst(arg_arg1_list);
                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                  /* checking for: appl */
                                  if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                    ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                    /* checking for: prod */
                                    if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                      ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                        ATerm arg_arg1_head_arg0_arg0_head;
                                        ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                        arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                        arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                        /* checking for: char-class */
                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                          ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                            ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                            ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                            arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                            arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                            if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 92) {

                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                  arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                  arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                  /* checking for: char-class */
                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                      ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                      arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                      arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 92) {

                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                            ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                            /* checking for: lit */
                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                              ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                              /* checking for: \\ */
                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun119) {
                                                                ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                /* checking for: no-attrs */
                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                  ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                    ATerm arg_arg1_head_arg1_head;
                                                                    ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                    arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                    arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 92) {

                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                        arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                        arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 92) {

                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                            if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                              return ATtrue;
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_LexStrChar is a decimal by checking against the following ATerm pattern: appl(prod([lit("\\"),char-class([range(48,57)]),char-class([range(48,57)]),char-class([range(48,57)])],lex(sort("StrChar")),attrs([term(cons("decimal"))])),[appl(prod([char-class([92])],lit("\\"),no-attrs),[92]),<"a"(char)>,<"b"(char)>,<"c"(char)>]). May not be used to assert correctness of the PTPT_LexStrChar
 * \param[in] arg input PTPT_LexStrChar
 * \return ATtrue if #arg corresponds to the signature of a decimal, or ATfalse otherwise
 */
inline ATbool PTPT_isLexStrCharDecimal(PTPT_LexStrChar arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == PTPT_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == PTPT_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lit */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun16) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: \ */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun122) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
              /* checking for: char-class */
              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun23) {
                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0) == ATfalse) {
                  ATerm arg_arg0_arg0_head_arg0_head;
                  ATermList arg_arg0_arg0_head_arg0_list = (ATermList)arg_arg0_arg0_head_arg0;
                  arg_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg0_arg0_head_arg0_list);
                  arg_arg0_arg0_head_arg0_list = ATgetNext(arg_arg0_arg0_head_arg0_list);
                  /* checking for: range */
                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_head) == PTPT_afun121) {
                    ATerm arg_arg0_arg0_head_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0_head, 0);
                    if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_head_arg0) == 48) {

                      ATerm arg_arg0_arg0_head_arg0_head_arg1 = ATgetArgument(arg_arg0_arg0_head_arg0_head, 1);
                      if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_head_arg1) == 57) {

                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0_list) == ATtrue) {
                          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                            arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                            arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                            /* checking for: char-class */
                            if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun23) {
                              ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0) == ATfalse) {
                                ATerm arg_arg0_arg0_head_arg0_head;
                                ATermList arg_arg0_arg0_head_arg0_list = (ATermList)arg_arg0_arg0_head_arg0;
                                arg_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg0_arg0_head_arg0_list);
                                arg_arg0_arg0_head_arg0_list = ATgetNext(arg_arg0_arg0_head_arg0_list);
                                /* checking for: range */
                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_head) == PTPT_afun121) {
                                  ATerm arg_arg0_arg0_head_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0_head, 0);
                                  if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_head_arg0) == 48) {

                                    ATerm arg_arg0_arg0_head_arg0_head_arg1 = ATgetArgument(arg_arg0_arg0_head_arg0_head, 1);
                                    if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_head_arg1) == 57) {

                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0_list) == ATtrue) {
                                        if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                          arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                          arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                          /* checking for: char-class */
                                          if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun23) {
                                            ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0) == ATfalse) {
                                              ATerm arg_arg0_arg0_head_arg0_head;
                                              ATermList arg_arg0_arg0_head_arg0_list = (ATermList)arg_arg0_arg0_head_arg0;
                                              arg_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg0_arg0_head_arg0_list);
                                              arg_arg0_arg0_head_arg0_list = ATgetNext(arg_arg0_arg0_head_arg0_list);
                                              /* checking for: range */
                                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_head) == PTPT_afun121) {
                                                ATerm arg_arg0_arg0_head_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0_head, 0);
                                                if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_head_arg0) == 48) {

                                                  ATerm arg_arg0_arg0_head_arg0_head_arg1 = ATgetArgument(arg_arg0_arg0_head_arg0_head, 1);
                                                  if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_head_arg1) == 57) {

                                                    if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0_list) == ATtrue) {
                                                      if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                                                        ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                                        /* checking for: lex */
                                                        if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == PTPT_afun6) {
                                                          ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                                          /* checking for: sort */
                                                          if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == PTPT_afun9) {
                                                            ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                                            /* checking for: StrChar */
                                                            if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == PTPT_afun113) {
                                                              ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                                              /* checking for: attrs */
                                                              if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == PTPT_afun12) {
                                                                ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                                                if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                                                  ATerm arg_arg0_arg2_arg0_head;
                                                                  ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                                                  arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                                                  arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                                                  /* checking for: term */
                                                                  if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == PTPT_afun13) {
                                                                    ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                                                    /* checking for: cons */
                                                                    if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == PTPT_afun14) {
                                                                      ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                                                      /* checking for: decimal */
                                                                      if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == PTPT_afun123) {
                                                                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                                          ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                                          if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                                            ATerm arg_arg1_head;
                                                                            ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                                            arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                            arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                            /* checking for: appl */
                                                                            if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                              ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                              /* checking for: prod */
                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun1) {
                                                                                ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                  ATerm arg_arg1_head_arg0_arg0_head;
                                                                                  ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                  arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                  arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                  /* checking for: char-class */
                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == PTPT_afun23) {
                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                      ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                      arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                      arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 92) {

                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                            ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                            /* checking for: lit */
                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == PTPT_afun16) {
                                                                                              ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                              /* checking for: \ */
                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == PTPT_afun122) {
                                                                                                ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                /* checking for: no-attrs */
                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == PTPT_afun5) {
                                                                                                  ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                    ATerm arg_arg1_head_arg1_head;
                                                                                                    ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                    arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                    arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 92) {

                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                          arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                          arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                          if (ATgetType((ATerm)arg_arg1_head) == AT_INT) {
                                                                                                            if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                              arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                              arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                              if (ATgetType((ATerm)arg_arg1_head) == AT_INT) {
                                                                                                                if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                  arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                  if (ATgetType((ATerm)arg_arg1_head) == AT_INT) {
                                                                                                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                                      return ATtrue;
                                                                                                                    }
                                                                                                                  }
                                                                                                                }
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_LexStrChar is a normal by checking against the following ATerm pattern: appl(prod([char-class([range(32,33),range(35,91),range(93,255)])],lex(sort("StrChar")),attrs([term(cons("normal"))])),[<"ch"(char)>]). May not be used to assert correctness of the PTPT_LexStrChar
 * \param[in] arg input PTPT_LexStrChar
 * \return ATtrue if #arg corresponds to the signature of a normal, or ATfalse otherwise
 */
inline ATbool PTPT_isLexStrCharNormal(PTPT_LexStrChar arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == PTPT_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == PTPT_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: char-class */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun23) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0) == ATfalse) {
            ATerm arg_arg0_arg0_head_arg0_head;
            ATermList arg_arg0_arg0_head_arg0_list = (ATermList)arg_arg0_arg0_head_arg0;
            arg_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg0_arg0_head_arg0_list);
            arg_arg0_arg0_head_arg0_list = ATgetNext(arg_arg0_arg0_head_arg0_list);
            /* checking for: range */
            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_head) == PTPT_afun121) {
              ATerm arg_arg0_arg0_head_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0_head, 0);
              if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_head_arg0) == 32) {

                ATerm arg_arg0_arg0_head_arg0_head_arg1 = ATgetArgument(arg_arg0_arg0_head_arg0_head, 1);
                if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_head_arg1) == 33) {

                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0_list) == ATfalse) {
                    arg_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg0_arg0_head_arg0_list);
                    arg_arg0_arg0_head_arg0_list = ATgetNext(arg_arg0_arg0_head_arg0_list);
                    /* checking for: range */
                    if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_head) == PTPT_afun121) {
                      ATerm arg_arg0_arg0_head_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0_head, 0);
                      if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_head_arg0) == 35) {

                        ATerm arg_arg0_arg0_head_arg0_head_arg1 = ATgetArgument(arg_arg0_arg0_head_arg0_head, 1);
                        if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_head_arg1) == 91) {

                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0_list) == ATfalse) {
                            arg_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg0_arg0_head_arg0_list);
                            arg_arg0_arg0_head_arg0_list = ATgetNext(arg_arg0_arg0_head_arg0_list);
                            /* checking for: range */
                            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_head) == PTPT_afun121) {
                              ATerm arg_arg0_arg0_head_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0_head, 0);
                              if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_head_arg0) == 93) {

                                ATerm arg_arg0_arg0_head_arg0_head_arg1 = ATgetArgument(arg_arg0_arg0_head_arg0_head, 1);
                                if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_head_arg1) == 255) {

                                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0_list) == ATtrue) {
                                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                                      ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                      /* checking for: lex */
                                      if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == PTPT_afun6) {
                                        ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                        /* checking for: sort */
                                        if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == PTPT_afun9) {
                                          ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                          /* checking for: StrChar */
                                          if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == PTPT_afun113) {
                                            ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                            /* checking for: attrs */
                                            if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == PTPT_afun12) {
                                              ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                              if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                                ATerm arg_arg0_arg2_arg0_head;
                                                ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                                arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                                arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                                /* checking for: term */
                                                if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == PTPT_afun13) {
                                                  ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                                  /* checking for: cons */
                                                  if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == PTPT_afun14) {
                                                    ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                                    /* checking for: normal */
                                                    if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == PTPT_afun124) {
                                                      if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                        ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                        if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                          ATerm arg_arg1_head;
                                                          ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                          arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                          arg_arg1_list = ATgetNext(arg_arg1_list);
                                                          if (ATgetType((ATerm)arg_arg1_head) == AT_INT) {
                                                            if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                              return ATtrue;
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_LexStrChar has a a. 
 * \param[in] arg input PTPT_LexStrChar
 * \return ATtrue if the PTPT_LexStrChar had a a, or ATfalse otherwise
 */
ATbool PTPT_hasLexStrCharA(PTPT_LexStrChar arg) {
  if (PTPT_isLexStrCharDecimal(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_LexStrChar has a b. 
 * \param[in] arg input PTPT_LexStrChar
 * \return ATtrue if the PTPT_LexStrChar had a b, or ATfalse otherwise
 */
ATbool PTPT_hasLexStrCharB(PTPT_LexStrChar arg) {
  if (PTPT_isLexStrCharDecimal(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_LexStrChar has a c. 
 * \param[in] arg input PTPT_LexStrChar
 * \return ATtrue if the PTPT_LexStrChar had a c, or ATfalse otherwise
 */
ATbool PTPT_hasLexStrCharC(PTPT_LexStrChar arg) {
  if (PTPT_isLexStrCharDecimal(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_LexStrChar has a ch. 
 * \param[in] arg input PTPT_LexStrChar
 * \return ATtrue if the PTPT_LexStrChar had a ch, or ATfalse otherwise
 */
ATbool PTPT_hasLexStrCharCh(PTPT_LexStrChar arg) {
  if (PTPT_isLexStrCharNormal(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Get the a char of a PTPT_LexStrChar. Note that the precondition is that this PTPT_LexStrChar actually has a a
 * \param[in] arg input PTPT_LexStrChar
 * \return the a of #arg, if it exist or an undefined value if it does not
 */
char PTPT_getLexStrCharA(PTPT_LexStrChar arg) {
  
    return (char)PTPT_charToByte((ATerm)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1));
}

/**
 * Get the b char of a PTPT_LexStrChar. Note that the precondition is that this PTPT_LexStrChar actually has a b
 * \param[in] arg input PTPT_LexStrChar
 * \return the b of #arg, if it exist or an undefined value if it does not
 */
char PTPT_getLexStrCharB(PTPT_LexStrChar arg) {
  
    return (char)PTPT_charToByte((ATerm)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 2));
}

/**
 * Get the c char of a PTPT_LexStrChar. Note that the precondition is that this PTPT_LexStrChar actually has a c
 * \param[in] arg input PTPT_LexStrChar
 * \return the c of #arg, if it exist or an undefined value if it does not
 */
char PTPT_getLexStrCharC(PTPT_LexStrChar arg) {
  
    return (char)PTPT_charToByte((ATerm)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 3));
}

/**
 * Get the ch char of a PTPT_LexStrChar. Note that the precondition is that this PTPT_LexStrChar actually has a ch
 * \param[in] arg input PTPT_LexStrChar
 * \return the ch of #arg, if it exist or an undefined value if it does not
 */
char PTPT_getLexStrCharCh(PTPT_LexStrChar arg) {
  
    return (char)PTPT_charToByte((ATerm)ATgetFirst((ATermList)ATgetArgument((ATermAppl)arg, 1)));
}

/**
 * Set the a of a PTPT_LexStrChar. The precondition being that this PTPT_LexStrChar actually has a a
 * \param[in] arg input PTPT_LexStrChar
 * \param[in] a new char to set in #arg
 * \return A new PTPT_LexStrChar with a at the right place, or a core dump if #arg did not have a a
 */
PTPT_LexStrChar PTPT_setLexStrCharA(PTPT_LexStrChar arg, char a) {
  if (PTPT_isLexStrCharDecimal(arg)) {
    return (PTPT_LexStrChar)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) ((ATerm) PTPT_byteToChar(a))), 1), 1);
  }

  ATabort("LexStrChar has no A: %t\n", arg);
  return (PTPT_LexStrChar)NULL;
}

/**
 * Set the b of a PTPT_LexStrChar. The precondition being that this PTPT_LexStrChar actually has a b
 * \param[in] arg input PTPT_LexStrChar
 * \param[in] b new char to set in #arg
 * \return A new PTPT_LexStrChar with b at the right place, or a core dump if #arg did not have a b
 */
PTPT_LexStrChar PTPT_setLexStrCharB(PTPT_LexStrChar arg, char b) {
  if (PTPT_isLexStrCharDecimal(arg)) {
    return (PTPT_LexStrChar)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) ((ATerm) PTPT_byteToChar(b))), 2), 1);
  }

  ATabort("LexStrChar has no B: %t\n", arg);
  return (PTPT_LexStrChar)NULL;
}

/**
 * Set the c of a PTPT_LexStrChar. The precondition being that this PTPT_LexStrChar actually has a c
 * \param[in] arg input PTPT_LexStrChar
 * \param[in] c new char to set in #arg
 * \return A new PTPT_LexStrChar with c at the right place, or a core dump if #arg did not have a c
 */
PTPT_LexStrChar PTPT_setLexStrCharC(PTPT_LexStrChar arg, char c) {
  if (PTPT_isLexStrCharDecimal(arg)) {
    return (PTPT_LexStrChar)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) ((ATerm) PTPT_byteToChar(c))), 3), 1);
  }

  ATabort("LexStrChar has no C: %t\n", arg);
  return (PTPT_LexStrChar)NULL;
}

/**
 * Set the ch of a PTPT_LexStrChar. The precondition being that this PTPT_LexStrChar actually has a ch
 * \param[in] arg input PTPT_LexStrChar
 * \param[in] ch new char to set in #arg
 * \return A new PTPT_LexStrChar with ch at the right place, or a core dump if #arg did not have a ch
 */
PTPT_LexStrChar PTPT_setLexStrCharCh(PTPT_LexStrChar arg, char ch) {
  if (PTPT_isLexStrCharNormal(arg)) {
    return (PTPT_LexStrChar)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) ((ATerm) PTPT_byteToChar(ch))), 0), 1);
  }

  ATabort("LexStrChar has no Ch: %t\n", arg);
  return (PTPT_LexStrChar)NULL;
}

/**
 * Assert whether a PTPT_StrChar is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input PTPT_StrChar
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool PTPT_isValidStrChar(PTPT_StrChar arg) {
  if (PTPT_isStrCharLexToCf(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_StrChar is a Lex-to-cf by checking against the following ATerm pattern: appl(prod([lex(sort("StrChar"))],cf(sort("StrChar")),no-attrs),[<"StrChar"("Lex-StrChar")>]). Always returns ATtrue
 * \param[in] arg input PTPT_StrChar
 * \return ATtrue if #arg corresponds to the signature of a Lex-to-cf, or ATfalse otherwise
 */
inline ATbool PTPT_isStrCharLexToCf(PTPT_StrChar arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == PTPT_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == PTPT_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lex */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun6) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: sort */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun9) {
            ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
            /* checking for: StrChar */
            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun113) {
              if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                /* checking for: cf */
                if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == PTPT_afun2) {
                  ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                  /* checking for: sort */
                  if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == PTPT_afun9) {
                    ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                    /* checking for: StrChar */
                    if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == PTPT_afun113) {
                      ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                      /* checking for: no-attrs */
                      if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == PTPT_afun5) {
                        ATerm arg_arg1 = ATgetArgument(arg, 1);
                        if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                          ATermList arg_arg1_list = (ATermList)arg_arg1;
                          arg_arg1_list = ATgetNext(arg_arg1_list);
                          if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                            return ATtrue;
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_StrChar has a StrChar. 
 * \param[in] arg input PTPT_StrChar
 * \return ATtrue if the PTPT_StrChar had a StrChar, or ATfalse otherwise
 */
ATbool PTPT_hasStrCharStrChar(PTPT_StrChar arg) {
  if (PTPT_isStrCharLexToCf(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Get the StrChar PTPT_LexStrChar of a PTPT_StrChar. Note that the precondition is that this PTPT_StrChar actually has a StrChar
 * \param[in] arg input PTPT_StrChar
 * \return the StrChar of #arg, if it exist or an undefined value if it does not
 */
PTPT_LexStrChar PTPT_getStrCharStrChar(PTPT_StrChar arg) {
  
    return (PTPT_LexStrChar)ATgetFirst((ATermList)ATgetArgument((ATermAppl)arg, 1));
}

/**
 * Set the StrChar of a PTPT_StrChar. The precondition being that this PTPT_StrChar actually has a StrChar
 * \param[in] arg input PTPT_StrChar
 * \param[in] StrChar new PTPT_LexStrChar to set in #arg
 * \return A new PTPT_StrChar with StrChar at the right place, or a core dump if #arg did not have a StrChar
 */
PTPT_StrChar PTPT_setStrCharStrChar(PTPT_StrChar arg, PTPT_LexStrChar StrChar) {
  if (PTPT_isStrCharLexToCf(arg)) {
    return (PTPT_StrChar)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) StrChar), 0), 1);
  }

  ATabort("StrChar has no StrChar: %t\n", arg);
  return (PTPT_StrChar)NULL;
}

/**
 * Assert whether a PTPT_LexStrCon is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input PTPT_LexStrCon
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool PTPT_isValidLexStrCon(PTPT_LexStrCon arg) {
  if (PTPT_isLexStrConDefault(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_LexStrCon is a default by checking against the following ATerm pattern: appl(prod([char-class([34]),lex(iter-star(sort("StrChar"))),char-class([34])],lex(sort("StrCon")),attrs([term(cons("default"))])),[34,appl(list(lex(iter-star(sort("StrChar")))),<"chars"("Lex-StrChar-chars")>),34]). Always returns ATtrue
 * \param[in] arg input PTPT_LexStrCon
 * \return ATtrue if #arg corresponds to the signature of a default, or ATfalse otherwise
 */
inline ATbool PTPT_isLexStrConDefault(PTPT_LexStrCon arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == PTPT_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == PTPT_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: char-class */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun23) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0) == ATfalse) {
            ATerm arg_arg0_arg0_head_arg0_head;
            ATermList arg_arg0_arg0_head_arg0_list = (ATermList)arg_arg0_arg0_head_arg0;
            arg_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg0_arg0_head_arg0_list);
            arg_arg0_arg0_head_arg0_list = ATgetNext(arg_arg0_arg0_head_arg0_list);
            if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_head) == 34) {

              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0_list) == ATtrue) {
                if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                  arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                  arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                  /* checking for: lex */
                  if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun6) {
                    ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                    /* checking for: iter-star */
                    if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun125) {
                      ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                      /* checking for: sort */
                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun9) {
                        ATerm arg_arg0_arg0_head_arg0_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0_arg0, 0);
                        /* checking for: StrChar */
                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0_arg0) == PTPT_afun113) {
                          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                            arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                            arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                            /* checking for: char-class */
                            if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun23) {
                              ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0) == ATfalse) {
                                ATerm arg_arg0_arg0_head_arg0_head;
                                ATermList arg_arg0_arg0_head_arg0_list = (ATermList)arg_arg0_arg0_head_arg0;
                                arg_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg0_arg0_head_arg0_list);
                                arg_arg0_arg0_head_arg0_list = ATgetNext(arg_arg0_arg0_head_arg0_list);
                                if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_head) == 34) {

                                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0_list) == ATtrue) {
                                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                                      ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                      /* checking for: lex */
                                      if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == PTPT_afun6) {
                                        ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                        /* checking for: sort */
                                        if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == PTPT_afun9) {
                                          ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                          /* checking for: StrCon */
                                          if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == PTPT_afun42) {
                                            ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                            /* checking for: attrs */
                                            if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == PTPT_afun12) {
                                              ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                              if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                                ATerm arg_arg0_arg2_arg0_head;
                                                ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                                arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                                arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                                /* checking for: term */
                                                if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == PTPT_afun13) {
                                                  ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                                  /* checking for: cons */
                                                  if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == PTPT_afun14) {
                                                    ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                                    /* checking for: default */
                                                    if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == PTPT_afun88) {
                                                      if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                        ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                        if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                          ATerm arg_arg1_head;
                                                          ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                          arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                          arg_arg1_list = ATgetNext(arg_arg1_list);
                                                          if (ATgetInt((ATermInt)arg_arg1_head) == 34) {

                                                            if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                              arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                              arg_arg1_list = ATgetNext(arg_arg1_list);
                                                              /* checking for: appl */
                                                              if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                /* checking for: list */
                                                                if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun8) {
                                                                  ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                  /* checking for: lex */
                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0) == PTPT_afun6) {
                                                                    ATerm arg_arg1_head_arg0_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0, 0);
                                                                    /* checking for: iter-star */
                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0) == PTPT_afun125) {
                                                                      ATerm arg_arg1_head_arg0_arg0_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0, 0);
                                                                      /* checking for: sort */
                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg0) == PTPT_afun9) {
                                                                        ATerm arg_arg1_head_arg0_arg0_arg0_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0_arg0, 0);
                                                                        /* checking for: StrChar */
                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg0_arg0) == PTPT_afun113) {
                                                                          if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                            arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                            arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                            if (ATgetInt((ATermInt)arg_arg1_head) == 34) {

                                                                              if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                return ATtrue;
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_LexStrCon has a chars. 
 * \param[in] arg input PTPT_LexStrCon
 * \return ATtrue if the PTPT_LexStrCon had a chars, or ATfalse otherwise
 */
ATbool PTPT_hasLexStrConChars(PTPT_LexStrCon arg) {
  if (PTPT_isLexStrConDefault(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Get the chars PTPT_LexStrCharChars of a PTPT_LexStrCon. Note that the precondition is that this PTPT_LexStrCon actually has a chars
 * \param[in] arg input PTPT_LexStrCon
 * \return the chars of #arg, if it exist or an undefined value if it does not
 */
PTPT_LexStrCharChars PTPT_getLexStrConChars(PTPT_LexStrCon arg) {
  
    return (PTPT_LexStrCharChars)ATgetArgument((ATermAppl)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1), 1);
}

/**
 * Set the chars of a PTPT_LexStrCon. The precondition being that this PTPT_LexStrCon actually has a chars
 * \param[in] arg input PTPT_LexStrCon
 * \param[in] chars new PTPT_LexStrCharChars to set in #arg
 * \return A new PTPT_LexStrCon with chars at the right place, or a core dump if #arg did not have a chars
 */
PTPT_LexStrCon PTPT_setLexStrConChars(PTPT_LexStrCon arg, PTPT_LexStrCharChars chars) {
  if (PTPT_isLexStrConDefault(arg)) {
    return (PTPT_LexStrCon)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)ATsetArgument((ATermAppl)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1), (ATerm)((ATerm) chars), 1), 1), 1);
  }

  ATabort("LexStrCon has no Chars: %t\n", arg);
  return (PTPT_LexStrCon)NULL;
}

/**
 * Assert whether a PTPT_StrCon is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input PTPT_StrCon
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool PTPT_isValidStrCon(PTPT_StrCon arg) {
  if (PTPT_isStrConLexToCf(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_StrCon is a Lex-to-cf by checking against the following ATerm pattern: appl(prod([lex(sort("StrCon"))],cf(sort("StrCon")),no-attrs),[<"StrCon"("Lex-StrCon")>]). Always returns ATtrue
 * \param[in] arg input PTPT_StrCon
 * \return ATtrue if #arg corresponds to the signature of a Lex-to-cf, or ATfalse otherwise
 */
inline ATbool PTPT_isStrConLexToCf(PTPT_StrCon arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == PTPT_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == PTPT_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lex */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun6) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: sort */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun9) {
            ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
            /* checking for: StrCon */
            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun42) {
              if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                /* checking for: cf */
                if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == PTPT_afun2) {
                  ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                  /* checking for: sort */
                  if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == PTPT_afun9) {
                    ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                    /* checking for: StrCon */
                    if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == PTPT_afun42) {
                      ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                      /* checking for: no-attrs */
                      if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == PTPT_afun5) {
                        ATerm arg_arg1 = ATgetArgument(arg, 1);
                        if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                          ATermList arg_arg1_list = (ATermList)arg_arg1;
                          arg_arg1_list = ATgetNext(arg_arg1_list);
                          if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                            return ATtrue;
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_StrCon has a StrCon. 
 * \param[in] arg input PTPT_StrCon
 * \return ATtrue if the PTPT_StrCon had a StrCon, or ATfalse otherwise
 */
ATbool PTPT_hasStrConStrCon(PTPT_StrCon arg) {
  if (PTPT_isStrConLexToCf(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Get the StrCon PTPT_LexStrCon of a PTPT_StrCon. Note that the precondition is that this PTPT_StrCon actually has a StrCon
 * \param[in] arg input PTPT_StrCon
 * \return the StrCon of #arg, if it exist or an undefined value if it does not
 */
PTPT_LexStrCon PTPT_getStrConStrCon(PTPT_StrCon arg) {
  
    return (PTPT_LexStrCon)ATgetFirst((ATermList)ATgetArgument((ATermAppl)arg, 1));
}

/**
 * Set the StrCon of a PTPT_StrCon. The precondition being that this PTPT_StrCon actually has a StrCon
 * \param[in] arg input PTPT_StrCon
 * \param[in] StrCon new PTPT_LexStrCon to set in #arg
 * \return A new PTPT_StrCon with StrCon at the right place, or a core dump if #arg did not have a StrCon
 */
PTPT_StrCon PTPT_setStrConStrCon(PTPT_StrCon arg, PTPT_LexStrCon StrCon) {
  if (PTPT_isStrConLexToCf(arg)) {
    return (PTPT_StrCon)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) StrCon), 0), 1);
  }

  ATabort("StrCon has no StrCon: %t\n", arg);
  return (PTPT_StrCon)NULL;
}

/**
 * Assert whether a PTPT_LexStrCharChars is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input PTPT_LexStrCharChars
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool PTPT_isValidLexStrCharChars(PTPT_LexStrCharChars arg) {
  if (PTPT_isLexStrCharCharsEmpty(arg)) {
    return ATtrue;
  }
  else if (PTPT_isLexStrCharCharsSingle(arg)) {
    return ATtrue;
  }
  else if (PTPT_isLexStrCharCharsMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_LexStrCharChars is a empty by checking against the following ATerm pattern: []. May not be used to assert correctness of the PTPT_LexStrCharChars
 * \param[in] arg input PTPT_LexStrCharChars
 * \return ATtrue if #arg corresponds to the signature of a empty, or ATfalse otherwise
 */
inline ATbool PTPT_isLexStrCharCharsEmpty(PTPT_LexStrCharChars arg){
  if (ATisEmpty((ATermList)arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_LexStrCharChars is a single by checking against the following ATerm pattern: [<head(Lex-StrChar)>]. May not be used to assert correctness of the PTPT_LexStrCharChars
 * \param[in] arg input PTPT_LexStrCharChars
 * \return ATtrue if #arg corresponds to the signature of a single, or ATfalse otherwise
 */
inline ATbool PTPT_isLexStrCharCharsSingle(PTPT_LexStrCharChars arg){
  if (ATgetType((ATerm)arg) == AT_LIST && ATisEmpty((ATermList)arg) == ATfalse) {
    ATermList arg_list = (ATermList)arg;
    arg_list = ATgetNext(arg_list);
    if (ATgetType((ATerm)arg_list) == AT_LIST && ATisEmpty((ATermList)arg_list) == ATtrue) {
      return ATtrue;
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_LexStrCharChars is a many by checking against the following ATerm pattern: [<head(Lex-StrChar)>,<[tail(Lex-StrChar-chars)]>]. May not be used to assert correctness of the PTPT_LexStrCharChars
 * \param[in] arg input PTPT_LexStrCharChars
 * \return ATtrue if #arg corresponds to the signature of a many, or ATfalse otherwise
 */
inline ATbool PTPT_isLexStrCharCharsMany(PTPT_LexStrCharChars arg){
  if (ATgetType((ATerm)arg) == AT_LIST && ATisEmpty((ATermList)arg) == ATfalse) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_LexStrCharChars has a head. 
 * \param[in] arg input PTPT_LexStrCharChars
 * \return ATtrue if the PTPT_LexStrCharChars had a head, or ATfalse otherwise
 */
ATbool PTPT_hasLexStrCharCharsHead(PTPT_LexStrCharChars arg) {
  if (PTPT_isLexStrCharCharsSingle(arg)) {
    return ATtrue;
  }
  else if (PTPT_isLexStrCharCharsMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_LexStrCharChars has a tail. 
 * \param[in] arg input PTPT_LexStrCharChars
 * \return ATtrue if the PTPT_LexStrCharChars had a tail, or ATfalse otherwise
 */
ATbool PTPT_hasLexStrCharCharsTail(PTPT_LexStrCharChars arg) {
  if (PTPT_isLexStrCharCharsMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Get the head PTPT_LexStrChar of a PTPT_LexStrCharChars. Note that the precondition is that this PTPT_LexStrCharChars actually has a head
 * \param[in] arg input PTPT_LexStrCharChars
 * \return the head of #arg, if it exist or an undefined value if it does not
 */
PTPT_LexStrChar PTPT_getLexStrCharCharsHead(PTPT_LexStrCharChars arg) {
  if (PTPT_isLexStrCharCharsSingle(arg)) {
    return (PTPT_LexStrChar)ATgetFirst((ATermList)arg);
  }
  else 
    return (PTPT_LexStrChar)ATgetFirst((ATermList)arg);
}

/**
 * Get the tail PTPT_LexStrCharChars of a PTPT_LexStrCharChars. Note that the precondition is that this PTPT_LexStrCharChars actually has a tail
 * \param[in] arg input PTPT_LexStrCharChars
 * \return the tail of #arg, if it exist or an undefined value if it does not
 */
PTPT_LexStrCharChars PTPT_getLexStrCharCharsTail(PTPT_LexStrCharChars arg) {
  
    return (PTPT_LexStrCharChars)ATgetNext((ATermList)arg);
}

/**
 * Set the head of a PTPT_LexStrCharChars. The precondition being that this PTPT_LexStrCharChars actually has a head
 * \param[in] arg input PTPT_LexStrCharChars
 * \param[in] head new PTPT_LexStrChar to set in #arg
 * \return A new PTPT_LexStrCharChars with head at the right place, or a core dump if #arg did not have a head
 */
PTPT_LexStrCharChars PTPT_setLexStrCharCharsHead(PTPT_LexStrCharChars arg, PTPT_LexStrChar head) {
  if (PTPT_isLexStrCharCharsSingle(arg)) {
    return (PTPT_LexStrCharChars)ATreplace((ATermList)arg, (ATerm)((ATerm) head), 0);
  }
  else if (PTPT_isLexStrCharCharsMany(arg)) {
    return (PTPT_LexStrCharChars)ATreplace((ATermList)arg, (ATerm)((ATerm) head), 0);
  }

  ATabort("LexStrCharChars has no Head: %t\n", arg);
  return (PTPT_LexStrCharChars)NULL;
}

/**
 * Set the tail of a PTPT_LexStrCharChars. The precondition being that this PTPT_LexStrCharChars actually has a tail
 * \param[in] arg input PTPT_LexStrCharChars
 * \param[in] tail new PTPT_LexStrCharChars to set in #arg
 * \return A new PTPT_LexStrCharChars with tail at the right place, or a core dump if #arg did not have a tail
 */
PTPT_LexStrCharChars PTPT_setLexStrCharCharsTail(PTPT_LexStrCharChars arg, PTPT_LexStrCharChars tail) {
  if (PTPT_isLexStrCharCharsMany(arg)) {
    return (PTPT_LexStrCharChars)ATreplaceTail((ATermList)arg, (ATermList)((ATerm) tail), 1);
  }

  ATabort("LexStrCharChars has no Tail: %t\n", arg);
  return (PTPT_LexStrCharChars)NULL;
}

/**
 * Assert whether a PTPT_LexNatCon is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input PTPT_LexNatCon
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool PTPT_isValidLexNatCon(PTPT_LexNatCon arg) {
  if (PTPT_isLexNatConDigits(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_LexNatCon is a digits by checking against the following ATerm pattern: appl(prod([lex(iter(char-class([range(48,57)])))],lex(sort("NatCon")),attrs([term(cons("digits"))])),[appl(list(lex(iter(char-class([range(48,57)])))),<"list"(chars)>)]). Always returns ATtrue
 * \param[in] arg input PTPT_LexNatCon
 * \return ATtrue if #arg corresponds to the signature of a digits, or ATfalse otherwise
 */
inline ATbool PTPT_isLexNatConDigits(PTPT_LexNatCon arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == PTPT_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == PTPT_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lex */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun6) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: iter */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun7) {
            ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
            /* checking for: char-class */
            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun23) {
              ATerm arg_arg0_arg0_head_arg0_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0_arg0, 0);
              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0_arg0_arg0) == ATfalse) {
                ATerm arg_arg0_arg0_head_arg0_arg0_arg0_head;
                ATermList arg_arg0_arg0_head_arg0_arg0_arg0_list = (ATermList)arg_arg0_arg0_head_arg0_arg0_arg0;
                arg_arg0_arg0_head_arg0_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_head_arg0_arg0_arg0_list);
                arg_arg0_arg0_head_arg0_arg0_arg0_list = ATgetNext(arg_arg0_arg0_head_arg0_arg0_arg0_list);
                /* checking for: range */
                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0_arg0_head) == PTPT_afun121) {
                  ATerm arg_arg0_arg0_head_arg0_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0_arg0_arg0_head, 0);
                  if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_arg0_arg0_head_arg0) == 48) {

                    ATerm arg_arg0_arg0_head_arg0_arg0_arg0_head_arg1 = ATgetArgument(arg_arg0_arg0_head_arg0_arg0_arg0_head, 1);
                    if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_arg0_arg0_head_arg1) == 57) {

                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0_arg0_arg0_list) == ATtrue) {
                        if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                          ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                          /* checking for: lex */
                          if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == PTPT_afun6) {
                            ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                            /* checking for: sort */
                            if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == PTPT_afun9) {
                              ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                              /* checking for: NatCon */
                              if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == PTPT_afun24) {
                                ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                /* checking for: attrs */
                                if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == PTPT_afun12) {
                                  ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                  if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                    ATerm arg_arg0_arg2_arg0_head;
                                    ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                    arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                    arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                    /* checking for: term */
                                    if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == PTPT_afun13) {
                                      ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                      /* checking for: cons */
                                      if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == PTPT_afun14) {
                                        ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                        /* checking for: digits */
                                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == PTPT_afun126) {
                                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                            ATerm arg_arg1 = ATgetArgument(arg, 1);
                                            if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                              ATerm arg_arg1_head;
                                              ATermList arg_arg1_list = (ATermList)arg_arg1;
                                              arg_arg1_head = ATgetFirst(arg_arg1_list);
                                              arg_arg1_list = ATgetNext(arg_arg1_list);
                                              /* checking for: appl */
                                              if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                /* checking for: list */
                                                if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun8) {
                                                  ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                  /* checking for: lex */
                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0) == PTPT_afun6) {
                                                    ATerm arg_arg1_head_arg0_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0, 0);
                                                    /* checking for: iter */
                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0) == PTPT_afun7) {
                                                      ATerm arg_arg1_head_arg0_arg0_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0, 0);
                                                      /* checking for: char-class */
                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg0) == PTPT_afun23) {
                                                        ATerm arg_arg1_head_arg0_arg0_arg0_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0_arg0, 0);
                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_arg0_arg0_arg0) == ATfalse) {
                                                          ATerm arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head;
                                                          ATermList arg_arg1_head_arg0_arg0_arg0_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_arg0_arg0_arg0;
                                                          arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_arg0_arg0_arg0_list);
                                                          arg_arg1_head_arg0_arg0_arg0_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_arg0_arg0_arg0_list);
                                                          /* checking for: range */
                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head) == PTPT_afun121) {
                                                            ATerm arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head, 0);
                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head_arg0) == 48) {

                                                              ATerm arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head_arg1 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head, 1);
                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head_arg1) == 57) {

                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_arg0_arg0_arg0_list) == ATtrue) {
                                                                  ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST) {
                                                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                      return ATtrue;
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_LexNatCon has a list. 
 * \param[in] arg input PTPT_LexNatCon
 * \return ATtrue if the PTPT_LexNatCon had a list, or ATfalse otherwise
 */
ATbool PTPT_hasLexNatConList(PTPT_LexNatCon arg) {
  if (PTPT_isLexNatConDigits(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Get the list char* of a PTPT_LexNatCon. Note that the precondition is that this PTPT_LexNatCon actually has a list
 * \param[in] arg input PTPT_LexNatCon
 * \return the list of #arg, if it exist or an undefined value if it does not
 */
char* PTPT_getLexNatConList(PTPT_LexNatCon arg) {
  
    return (char*)PTPT_charsToString((ATerm)ATgetArgument((ATermAppl)ATgetFirst((ATermList)ATgetArgument((ATermAppl)arg, 1)), 1));
}

/**
 * Set the list of a PTPT_LexNatCon. The precondition being that this PTPT_LexNatCon actually has a list
 * \param[in] arg input PTPT_LexNatCon
 * \param[in] list new const char* to set in #arg
 * \return A new PTPT_LexNatCon with list at the right place, or a core dump if #arg did not have a list
 */
PTPT_LexNatCon PTPT_setLexNatConList(PTPT_LexNatCon arg, const char* list) {
  if (PTPT_isLexNatConDigits(arg)) {
    return (PTPT_LexNatCon)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)ATsetArgument((ATermAppl)ATgetFirst((ATermList)ATgetArgument((ATermAppl)arg, 1)), (ATerm)((ATerm) ((ATerm) PTPT_stringToChars(list))), 1), 0), 1);
  }

  ATabort("LexNatCon has no List: %t\n", arg);
  return (PTPT_LexNatCon)NULL;
}

/**
 * Assert whether a PTPT_NatCon is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input PTPT_NatCon
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool PTPT_isValidNatCon(PTPT_NatCon arg) {
  if (PTPT_isNatConLexToCf(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_NatCon is a Lex-to-cf by checking against the following ATerm pattern: appl(prod([lex(sort("NatCon"))],cf(sort("NatCon")),no-attrs),[<"NatCon"("Lex-NatCon")>]). Always returns ATtrue
 * \param[in] arg input PTPT_NatCon
 * \return ATtrue if #arg corresponds to the signature of a Lex-to-cf, or ATfalse otherwise
 */
inline ATbool PTPT_isNatConLexToCf(PTPT_NatCon arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == PTPT_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == PTPT_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lex */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun6) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: sort */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun9) {
            ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
            /* checking for: NatCon */
            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun24) {
              if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                /* checking for: cf */
                if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == PTPT_afun2) {
                  ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                  /* checking for: sort */
                  if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == PTPT_afun9) {
                    ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                    /* checking for: NatCon */
                    if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == PTPT_afun24) {
                      ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                      /* checking for: no-attrs */
                      if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == PTPT_afun5) {
                        ATerm arg_arg1 = ATgetArgument(arg, 1);
                        if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                          ATermList arg_arg1_list = (ATermList)arg_arg1;
                          arg_arg1_list = ATgetNext(arg_arg1_list);
                          if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                            return ATtrue;
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_NatCon has a NatCon. 
 * \param[in] arg input PTPT_NatCon
 * \return ATtrue if the PTPT_NatCon had a NatCon, or ATfalse otherwise
 */
ATbool PTPT_hasNatConNatCon(PTPT_NatCon arg) {
  if (PTPT_isNatConLexToCf(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Get the NatCon PTPT_LexNatCon of a PTPT_NatCon. Note that the precondition is that this PTPT_NatCon actually has a NatCon
 * \param[in] arg input PTPT_NatCon
 * \return the NatCon of #arg, if it exist or an undefined value if it does not
 */
PTPT_LexNatCon PTPT_getNatConNatCon(PTPT_NatCon arg) {
  
    return (PTPT_LexNatCon)ATgetFirst((ATermList)ATgetArgument((ATermAppl)arg, 1));
}

/**
 * Set the NatCon of a PTPT_NatCon. The precondition being that this PTPT_NatCon actually has a NatCon
 * \param[in] arg input PTPT_NatCon
 * \param[in] NatCon new PTPT_LexNatCon to set in #arg
 * \return A new PTPT_NatCon with NatCon at the right place, or a core dump if #arg did not have a NatCon
 */
PTPT_NatCon PTPT_setNatConNatCon(PTPT_NatCon arg, PTPT_LexNatCon NatCon) {
  if (PTPT_isNatConLexToCf(arg)) {
    return (PTPT_NatCon)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) NatCon), 0), 1);
  }

  ATabort("NatCon has no NatCon: %t\n", arg);
  return (PTPT_NatCon)NULL;
}

/**
 * Assert whether a PTPT_LexIdCon is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input PTPT_LexIdCon
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool PTPT_isValidLexIdCon(PTPT_LexIdCon arg) {
  if (PTPT_isLexIdConDefault(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_LexIdCon is a default by checking against the following ATerm pattern: appl(prod([char-class([range(65,90),range(97,122)]),lex(iter-star(char-class([45,range(48,57),range(65,90),range(97,122)])))],lex(sort("IdCon")),attrs([term(cons("default"))])),[<"head"(char)>,appl(list(lex(iter-star(char-class([45,range(48,57),range(65,90),range(97,122)])))),<"tail"(chars)>)]). Always returns ATtrue
 * \param[in] arg input PTPT_LexIdCon
 * \return ATtrue if #arg corresponds to the signature of a default, or ATfalse otherwise
 */
inline ATbool PTPT_isLexIdConDefault(PTPT_LexIdCon arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == PTPT_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == PTPT_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: char-class */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun23) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0) == ATfalse) {
            ATerm arg_arg0_arg0_head_arg0_head;
            ATermList arg_arg0_arg0_head_arg0_list = (ATermList)arg_arg0_arg0_head_arg0;
            arg_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg0_arg0_head_arg0_list);
            arg_arg0_arg0_head_arg0_list = ATgetNext(arg_arg0_arg0_head_arg0_list);
            /* checking for: range */
            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_head) == PTPT_afun121) {
              ATerm arg_arg0_arg0_head_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0_head, 0);
              if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_head_arg0) == 65) {

                ATerm arg_arg0_arg0_head_arg0_head_arg1 = ATgetArgument(arg_arg0_arg0_head_arg0_head, 1);
                if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_head_arg1) == 90) {

                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0_list) == ATfalse) {
                    arg_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg0_arg0_head_arg0_list);
                    arg_arg0_arg0_head_arg0_list = ATgetNext(arg_arg0_arg0_head_arg0_list);
                    /* checking for: range */
                    if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_head) == PTPT_afun121) {
                      ATerm arg_arg0_arg0_head_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0_head, 0);
                      if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_head_arg0) == 97) {

                        ATerm arg_arg0_arg0_head_arg0_head_arg1 = ATgetArgument(arg_arg0_arg0_head_arg0_head, 1);
                        if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_head_arg1) == 122) {

                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0_list) == ATtrue) {
                            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                              /* checking for: lex */
                              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun6) {
                                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                /* checking for: iter-star */
                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun125) {
                                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                  /* checking for: char-class */
                                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun23) {
                                    ATerm arg_arg0_arg0_head_arg0_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0_arg0, 0);
                                    if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0_arg0_arg0) == ATfalse) {
                                      ATerm arg_arg0_arg0_head_arg0_arg0_arg0_head;
                                      ATermList arg_arg0_arg0_head_arg0_arg0_arg0_list = (ATermList)arg_arg0_arg0_head_arg0_arg0_arg0;
                                      arg_arg0_arg0_head_arg0_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_head_arg0_arg0_arg0_list);
                                      arg_arg0_arg0_head_arg0_arg0_arg0_list = ATgetNext(arg_arg0_arg0_head_arg0_arg0_arg0_list);
                                      if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_arg0_arg0_head) == 45) {

                                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0_arg0_arg0_list) == ATfalse) {
                                          arg_arg0_arg0_head_arg0_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_head_arg0_arg0_arg0_list);
                                          arg_arg0_arg0_head_arg0_arg0_arg0_list = ATgetNext(arg_arg0_arg0_head_arg0_arg0_arg0_list);
                                          /* checking for: range */
                                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0_arg0_head) == PTPT_afun121) {
                                            ATerm arg_arg0_arg0_head_arg0_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0_arg0_arg0_head, 0);
                                            if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_arg0_arg0_head_arg0) == 48) {

                                              ATerm arg_arg0_arg0_head_arg0_arg0_arg0_head_arg1 = ATgetArgument(arg_arg0_arg0_head_arg0_arg0_arg0_head, 1);
                                              if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_arg0_arg0_head_arg1) == 57) {

                                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0_arg0_arg0_list) == ATfalse) {
                                                  arg_arg0_arg0_head_arg0_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_head_arg0_arg0_arg0_list);
                                                  arg_arg0_arg0_head_arg0_arg0_arg0_list = ATgetNext(arg_arg0_arg0_head_arg0_arg0_arg0_list);
                                                  /* checking for: range */
                                                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0_arg0_head) == PTPT_afun121) {
                                                    ATerm arg_arg0_arg0_head_arg0_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0_arg0_arg0_head, 0);
                                                    if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_arg0_arg0_head_arg0) == 65) {

                                                      ATerm arg_arg0_arg0_head_arg0_arg0_arg0_head_arg1 = ATgetArgument(arg_arg0_arg0_head_arg0_arg0_arg0_head, 1);
                                                      if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_arg0_arg0_head_arg1) == 90) {

                                                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0_arg0_arg0_list) == ATfalse) {
                                                          arg_arg0_arg0_head_arg0_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_head_arg0_arg0_arg0_list);
                                                          arg_arg0_arg0_head_arg0_arg0_arg0_list = ATgetNext(arg_arg0_arg0_head_arg0_arg0_arg0_list);
                                                          /* checking for: range */
                                                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0_arg0_head) == PTPT_afun121) {
                                                            ATerm arg_arg0_arg0_head_arg0_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0_arg0_arg0_head, 0);
                                                            if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_arg0_arg0_head_arg0) == 97) {

                                                              ATerm arg_arg0_arg0_head_arg0_arg0_arg0_head_arg1 = ATgetArgument(arg_arg0_arg0_head_arg0_arg0_arg0_head, 1);
                                                              if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_arg0_arg0_head_arg1) == 122) {

                                                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0_arg0_arg0_list) == ATtrue) {
                                                                  if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                                                                    ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                                                    /* checking for: lex */
                                                                    if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == PTPT_afun6) {
                                                                      ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                                                      /* checking for: sort */
                                                                      if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == PTPT_afun9) {
                                                                        ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                                                        /* checking for: IdCon */
                                                                        if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == PTPT_afun91) {
                                                                          ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                                                          /* checking for: attrs */
                                                                          if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == PTPT_afun12) {
                                                                            ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                                                            if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                                                              ATerm arg_arg0_arg2_arg0_head;
                                                                              ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                                                              arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                                                              arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                                                              /* checking for: term */
                                                                              if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == PTPT_afun13) {
                                                                                ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                                                                /* checking for: cons */
                                                                                if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == PTPT_afun14) {
                                                                                  ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                                                                  /* checking for: default */
                                                                                  if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == PTPT_afun88) {
                                                                                    if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                                                      ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                                                      if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                                                        ATerm arg_arg1_head;
                                                                                        ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                                                        arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                        arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                        if (ATgetType((ATerm)arg_arg1_head) == AT_INT) {
                                                                                          if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                            arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                            arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                            /* checking for: appl */
                                                                                            if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == PTPT_afun0) {
                                                                                              ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                              /* checking for: list */
                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == PTPT_afun8) {
                                                                                                ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                /* checking for: lex */
                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0) == PTPT_afun6) {
                                                                                                  ATerm arg_arg1_head_arg0_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0, 0);
                                                                                                  /* checking for: iter-star */
                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0) == PTPT_afun125) {
                                                                                                    ATerm arg_arg1_head_arg0_arg0_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0, 0);
                                                                                                    /* checking for: char-class */
                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg0) == PTPT_afun23) {
                                                                                                      ATerm arg_arg1_head_arg0_arg0_arg0_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0_arg0, 0);
                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_arg0_arg0_arg0) == ATfalse) {
                                                                                                        ATerm arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head;
                                                                                                        ATermList arg_arg1_head_arg0_arg0_arg0_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_arg0_arg0_arg0;
                                                                                                        arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_arg0_arg0_arg0_list);
                                                                                                        arg_arg1_head_arg0_arg0_arg0_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_arg0_arg0_arg0_list);
                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head) == 45) {

                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_arg0_arg0_arg0_list) == ATfalse) {
                                                                                                            arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_arg0_arg0_arg0_list);
                                                                                                            arg_arg1_head_arg0_arg0_arg0_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_arg0_arg0_arg0_list);
                                                                                                            /* checking for: range */
                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head) == PTPT_afun121) {
                                                                                                              ATerm arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head, 0);
                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head_arg0) == 48) {

                                                                                                                ATerm arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head_arg1 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head, 1);
                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head_arg1) == 57) {

                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_arg0_arg0_arg0_list) == ATfalse) {
                                                                                                                    arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_arg0_arg0_arg0_list);
                                                                                                                    arg_arg1_head_arg0_arg0_arg0_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_arg0_arg0_arg0_list);
                                                                                                                    /* checking for: range */
                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head) == PTPT_afun121) {
                                                                                                                      ATerm arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head, 0);
                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head_arg0) == 65) {

                                                                                                                        ATerm arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head_arg1 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head, 1);
                                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head_arg1) == 90) {

                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_arg0_arg0_arg0_list) == ATfalse) {
                                                                                                                            arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_arg0_arg0_arg0_list);
                                                                                                                            arg_arg1_head_arg0_arg0_arg0_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_arg0_arg0_arg0_list);
                                                                                                                            /* checking for: range */
                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head) == PTPT_afun121) {
                                                                                                                              ATerm arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head, 0);
                                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head_arg0) == 97) {

                                                                                                                                ATerm arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head_arg1 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head, 1);
                                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head_arg1) == 122) {

                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_arg0_arg0_arg0_list) == ATtrue) {
                                                                                                                                    ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST) {
                                                                                                                                      if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                                                        return ATtrue;
                                                                                                                                      }
                                                                                                                                    }
                                                                                                                                  }
                                                                                                                                }
                                                                                                                              }
                                                                                                                            }
                                                                                                                          }
                                                                                                                        }
                                                                                                                      }
                                                                                                                    }
                                                                                                                  }
                                                                                                                }
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_LexIdCon has a head. 
 * \param[in] arg input PTPT_LexIdCon
 * \return ATtrue if the PTPT_LexIdCon had a head, or ATfalse otherwise
 */
ATbool PTPT_hasLexIdConHead(PTPT_LexIdCon arg) {
  if (PTPT_isLexIdConDefault(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_LexIdCon has a tail. 
 * \param[in] arg input PTPT_LexIdCon
 * \return ATtrue if the PTPT_LexIdCon had a tail, or ATfalse otherwise
 */
ATbool PTPT_hasLexIdConTail(PTPT_LexIdCon arg) {
  if (PTPT_isLexIdConDefault(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Get the head char of a PTPT_LexIdCon. Note that the precondition is that this PTPT_LexIdCon actually has a head
 * \param[in] arg input PTPT_LexIdCon
 * \return the head of #arg, if it exist or an undefined value if it does not
 */
char PTPT_getLexIdConHead(PTPT_LexIdCon arg) {
  
    return (char)PTPT_charToByte((ATerm)ATgetFirst((ATermList)ATgetArgument((ATermAppl)arg, 1)));
}

/**
 * Get the tail char* of a PTPT_LexIdCon. Note that the precondition is that this PTPT_LexIdCon actually has a tail
 * \param[in] arg input PTPT_LexIdCon
 * \return the tail of #arg, if it exist or an undefined value if it does not
 */
char* PTPT_getLexIdConTail(PTPT_LexIdCon arg) {
  
    return (char*)PTPT_charsToString((ATerm)ATgetArgument((ATermAppl)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1), 1));
}

/**
 * Set the head of a PTPT_LexIdCon. The precondition being that this PTPT_LexIdCon actually has a head
 * \param[in] arg input PTPT_LexIdCon
 * \param[in] head new char to set in #arg
 * \return A new PTPT_LexIdCon with head at the right place, or a core dump if #arg did not have a head
 */
PTPT_LexIdCon PTPT_setLexIdConHead(PTPT_LexIdCon arg, char head) {
  if (PTPT_isLexIdConDefault(arg)) {
    return (PTPT_LexIdCon)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) ((ATerm) PTPT_byteToChar(head))), 0), 1);
  }

  ATabort("LexIdCon has no Head: %t\n", arg);
  return (PTPT_LexIdCon)NULL;
}

/**
 * Set the tail of a PTPT_LexIdCon. The precondition being that this PTPT_LexIdCon actually has a tail
 * \param[in] arg input PTPT_LexIdCon
 * \param[in] tail new const char* to set in #arg
 * \return A new PTPT_LexIdCon with tail at the right place, or a core dump if #arg did not have a tail
 */
PTPT_LexIdCon PTPT_setLexIdConTail(PTPT_LexIdCon arg, const char* tail) {
  if (PTPT_isLexIdConDefault(arg)) {
    return (PTPT_LexIdCon)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)ATsetArgument((ATermAppl)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1), (ATerm)((ATerm) ((ATerm) PTPT_stringToChars(tail))), 1), 1), 1);
  }

  ATabort("LexIdCon has no Tail: %t\n", arg);
  return (PTPT_LexIdCon)NULL;
}

/**
 * Assert whether a PTPT_IdCon is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input PTPT_IdCon
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool PTPT_isValidIdCon(PTPT_IdCon arg) {
  if (PTPT_isIdConLexToCf(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_IdCon is a Lex-to-cf by checking against the following ATerm pattern: appl(prod([lex(sort("IdCon"))],cf(sort("IdCon")),no-attrs),[<"IdCon"("Lex-IdCon")>]). Always returns ATtrue
 * \param[in] arg input PTPT_IdCon
 * \return ATtrue if #arg corresponds to the signature of a Lex-to-cf, or ATfalse otherwise
 */
inline ATbool PTPT_isIdConLexToCf(PTPT_IdCon arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == PTPT_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == PTPT_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lex */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun6) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: sort */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == PTPT_afun9) {
            ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
            /* checking for: IdCon */
            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == PTPT_afun91) {
              if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                /* checking for: cf */
                if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == PTPT_afun2) {
                  ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                  /* checking for: sort */
                  if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == PTPT_afun9) {
                    ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                    /* checking for: IdCon */
                    if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == PTPT_afun91) {
                      ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                      /* checking for: no-attrs */
                      if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == PTPT_afun5) {
                        ATerm arg_arg1 = ATgetArgument(arg, 1);
                        if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                          ATermList arg_arg1_list = (ATermList)arg_arg1;
                          arg_arg1_list = ATgetNext(arg_arg1_list);
                          if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                            return ATtrue;
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_IdCon has a IdCon. 
 * \param[in] arg input PTPT_IdCon
 * \return ATtrue if the PTPT_IdCon had a IdCon, or ATfalse otherwise
 */
ATbool PTPT_hasIdConIdCon(PTPT_IdCon arg) {
  if (PTPT_isIdConLexToCf(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Get the IdCon PTPT_LexIdCon of a PTPT_IdCon. Note that the precondition is that this PTPT_IdCon actually has a IdCon
 * \param[in] arg input PTPT_IdCon
 * \return the IdCon of #arg, if it exist or an undefined value if it does not
 */
PTPT_LexIdCon PTPT_getIdConIdCon(PTPT_IdCon arg) {
  
    return (PTPT_LexIdCon)ATgetFirst((ATermList)ATgetArgument((ATermAppl)arg, 1));
}

/**
 * Set the IdCon of a PTPT_IdCon. The precondition being that this PTPT_IdCon actually has a IdCon
 * \param[in] arg input PTPT_IdCon
 * \param[in] IdCon new PTPT_LexIdCon to set in #arg
 * \return A new PTPT_IdCon with IdCon at the right place, or a core dump if #arg did not have a IdCon
 */
PTPT_IdCon PTPT_setIdConIdCon(PTPT_IdCon arg, PTPT_LexIdCon IdCon) {
  if (PTPT_isIdConLexToCf(arg)) {
    return (PTPT_IdCon)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) IdCon), 0), 1);
  }

  ATabort("IdCon has no IdCon: %t\n", arg);
  return (PTPT_IdCon)NULL;
}

/**
 * Assert whether a PTPT_LexLayout is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input PTPT_LexLayout
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool PTPT_isValidLexLayout(PTPT_LexLayout arg) {
  if (PTPT_isLexLayoutWhitespace(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_LexLayout is a whitespace by checking against the following ATerm pattern: appl(prod([char-class([range(9,10),13,32])],lex(layout),attrs([term(cons("whitespace"))])),[<"ch"(char)>]). Always returns ATtrue
 * \param[in] arg input PTPT_LexLayout
 * \return ATtrue if #arg corresponds to the signature of a whitespace, or ATfalse otherwise
 */
inline ATbool PTPT_isLexLayoutWhitespace(PTPT_LexLayout arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == PTPT_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == PTPT_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: char-class */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == PTPT_afun23) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0) == ATfalse) {
            ATerm arg_arg0_arg0_head_arg0_head;
            ATermList arg_arg0_arg0_head_arg0_list = (ATermList)arg_arg0_arg0_head_arg0;
            arg_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg0_arg0_head_arg0_list);
            arg_arg0_arg0_head_arg0_list = ATgetNext(arg_arg0_arg0_head_arg0_list);
            /* checking for: range */
            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_head) == PTPT_afun121) {
              ATerm arg_arg0_arg0_head_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0_head, 0);
              if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_head_arg0) == 9) {

                ATerm arg_arg0_arg0_head_arg0_head_arg1 = ATgetArgument(arg_arg0_arg0_head_arg0_head, 1);
                if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_head_arg1) == 10) {

                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0_list) == ATfalse) {
                    arg_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg0_arg0_head_arg0_list);
                    arg_arg0_arg0_head_arg0_list = ATgetNext(arg_arg0_arg0_head_arg0_list);
                    if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_head) == 13) {

                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0_list) == ATfalse) {
                        arg_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg0_arg0_head_arg0_list);
                        arg_arg0_arg0_head_arg0_list = ATgetNext(arg_arg0_arg0_head_arg0_list);
                        if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_head) == 32) {

                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0_list) == ATtrue) {
                            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                              ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                              /* checking for: lex */
                              if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == PTPT_afun6) {
                                ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                /* checking for: layout */
                                if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == PTPT_afun4) {
                                  ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                  /* checking for: attrs */
                                  if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == PTPT_afun12) {
                                    ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                    if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                      ATerm arg_arg0_arg2_arg0_head;
                                      ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                      arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                      arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                      /* checking for: term */
                                      if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == PTPT_afun13) {
                                        ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                        /* checking for: cons */
                                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == PTPT_afun14) {
                                          ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                          /* checking for: whitespace */
                                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == PTPT_afun127) {
                                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                              ATerm arg_arg1 = ATgetArgument(arg, 1);
                                              if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                ATerm arg_arg1_head;
                                                ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                arg_arg1_list = ATgetNext(arg_arg1_list);
                                                if (ATgetType((ATerm)arg_arg1_head) == AT_INT) {
                                                  if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                    return ATtrue;
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a PTPT_LexLayout has a ch. 
 * \param[in] arg input PTPT_LexLayout
 * \return ATtrue if the PTPT_LexLayout had a ch, or ATfalse otherwise
 */
ATbool PTPT_hasLexLayoutCh(PTPT_LexLayout arg) {
  if (PTPT_isLexLayoutWhitespace(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Get the ch char of a PTPT_LexLayout. Note that the precondition is that this PTPT_LexLayout actually has a ch
 * \param[in] arg input PTPT_LexLayout
 * \return the ch of #arg, if it exist or an undefined value if it does not
 */
char PTPT_getLexLayoutCh(PTPT_LexLayout arg) {
  
    return (char)PTPT_charToByte((ATerm)ATgetFirst((ATermList)ATgetArgument((ATermAppl)arg, 1)));
}

/**
 * Set the ch of a PTPT_LexLayout. The precondition being that this PTPT_LexLayout actually has a ch
 * \param[in] arg input PTPT_LexLayout
 * \param[in] ch new char to set in #arg
 * \return A new PTPT_LexLayout with ch at the right place, or a core dump if #arg did not have a ch
 */
PTPT_LexLayout PTPT_setLexLayoutCh(PTPT_LexLayout arg, char ch) {
  if (PTPT_isLexLayoutWhitespace(arg)) {
    return (PTPT_LexLayout)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) ((ATerm) PTPT_byteToChar(ch))), 0), 1);
  }

  ATabort("LexLayout has no Ch: %t\n", arg);
  return (PTPT_LexLayout)NULL;
}

/**
 * Apply functions to the children of a PTPT_OptLayout. 
 * \return A new PTPT_OptLayout with new children where the argument functions might have applied
 */
PTPT_OptLayout PTPT_visitOptLayout(PTPT_OptLayout arg, PTPT_Layout (*acceptLayout)(PTPT_Layout)) {
  if (PTPT_isOptLayoutAbsent(arg)) {
    return PTPT_makeOptLayoutAbsent();
  }
  if (PTPT_isOptLayoutPresent(arg)) {
    return PTPT_makeOptLayoutPresent(
        acceptLayout ? acceptLayout(PTPT_getOptLayoutLayout(arg)) : PTPT_getOptLayoutLayout(arg));
  }
  ATabort("not a OptLayout: %t\n", arg);
  return (PTPT_OptLayout)NULL;
}
/**
 * Apply functions to the children of a PTPT_Layout. 
 * \return A new PTPT_Layout with new children where the argument functions might have applied
 */
PTPT_Layout PTPT_visitLayout(PTPT_Layout arg, PTPT_LexLayoutList (*acceptList)(PTPT_LexLayoutList)) {
  if (PTPT_isLayoutLexToCf(arg)) {
    return PTPT_makeLayoutLexToCf(
        acceptList ? acceptList(PTPT_getLayoutList(arg)) : PTPT_getLayoutList(arg));
  }
  ATabort("not a Layout: %t\n", arg);
  return (PTPT_Layout)NULL;
}
/**
 * Apply functions to the children of a PTPT_LexLayoutList. 
 * \return A new PTPT_LexLayoutList with new children where the argument functions might have applied
 */
PTPT_LexLayoutList PTPT_visitLexLayoutList(PTPT_LexLayoutList arg, PTPT_LexLayout (*acceptHead)(PTPT_LexLayout)) {
  if (PTPT_isLexLayoutListEmpty(arg)) {
    return PTPT_makeLexLayoutListEmpty();
  }
  if (PTPT_isLexLayoutListSingle(arg)) {
    return PTPT_makeLexLayoutListSingle(
        acceptHead ? acceptHead(PTPT_getLexLayoutListHead(arg)) : PTPT_getLexLayoutListHead(arg));
  }
  if (PTPT_isLexLayoutListMany(arg)) {
    return PTPT_makeLexLayoutListMany(
        acceptHead ? acceptHead(PTPT_getLexLayoutListHead(arg)) : PTPT_getLexLayoutListHead(arg),
        PTPT_visitLexLayoutList(PTPT_getLexLayoutListTail(arg), acceptHead));
  }
  ATabort("not a LexLayoutList: %t\n", arg);
  return (PTPT_LexLayoutList)NULL;
}
/**
 * Apply functions to the children of a PTPT_Tree. 
 * \return A new PTPT_Tree with new children where the argument functions might have applied
 */
PTPT_Tree PTPT_visitTree(PTPT_Tree arg, PTPT_OptLayout (*acceptWsAfterTree)(PTPT_OptLayout), PTPT_Annotation (*acceptAnnotation)(PTPT_Annotation), PTPT_OptLayout (*acceptWsAfterAppl)(PTPT_OptLayout), PTPT_OptLayout (*acceptWsAfterParenOpen)(PTPT_OptLayout), PTPT_Production (*acceptProd)(PTPT_Production), PTPT_OptLayout (*acceptWsAfterProd)(PTPT_OptLayout), PTPT_OptLayout (*acceptWsAfterComma)(PTPT_OptLayout), PTPT_Args (*acceptArgs)(PTPT_Args), PTPT_OptLayout (*acceptWsAfterArgs)(PTPT_OptLayout), PTPT_OptLayout (*acceptWsAfterCycle)(PTPT_OptLayout), PTPT_Symbol (*acceptSymbol)(PTPT_Symbol), PTPT_OptLayout (*acceptWsAfterSymbol)(PTPT_OptLayout), PTPT_NatCon (*acceptLength)(PTPT_NatCon), PTPT_OptLayout (*acceptWsAfterLength)(PTPT_OptLayout), PTPT_OptLayout (*acceptWsAfterAmb)(PTPT_OptLayout), PTPT_NatCon (*acceptCharacter)(PTPT_NatCon)) {
  if (PTPT_isTreeAnnotated(arg)) {
    return PTPT_makeTreeAnnotated(
        PTPT_visitTree(PTPT_getTreeTree(arg), acceptWsAfterTree, acceptAnnotation, acceptWsAfterAppl, acceptWsAfterParenOpen, acceptProd, acceptWsAfterProd, acceptWsAfterComma, acceptArgs, acceptWsAfterArgs, acceptWsAfterCycle, acceptSymbol, acceptWsAfterSymbol, acceptLength, acceptWsAfterLength, acceptWsAfterAmb, acceptCharacter),
        acceptWsAfterTree ? acceptWsAfterTree(PTPT_getTreeWsAfterTree(arg)) : PTPT_getTreeWsAfterTree(arg),
        acceptAnnotation ? acceptAnnotation(PTPT_getTreeAnnotation(arg)) : PTPT_getTreeAnnotation(arg));
  }
  if (PTPT_isTreeAppl(arg)) {
    return PTPT_makeTreeAppl(
        acceptWsAfterAppl ? acceptWsAfterAppl(PTPT_getTreeWsAfterAppl(arg)) : PTPT_getTreeWsAfterAppl(arg),
        acceptWsAfterParenOpen ? acceptWsAfterParenOpen(PTPT_getTreeWsAfterParenOpen(arg)) : PTPT_getTreeWsAfterParenOpen(arg),
        acceptProd ? acceptProd(PTPT_getTreeProd(arg)) : PTPT_getTreeProd(arg),
        acceptWsAfterProd ? acceptWsAfterProd(PTPT_getTreeWsAfterProd(arg)) : PTPT_getTreeWsAfterProd(arg),
        acceptWsAfterComma ? acceptWsAfterComma(PTPT_getTreeWsAfterComma(arg)) : PTPT_getTreeWsAfterComma(arg),
        acceptArgs ? acceptArgs(PTPT_getTreeArgs(arg)) : PTPT_getTreeArgs(arg),
        acceptWsAfterArgs ? acceptWsAfterArgs(PTPT_getTreeWsAfterArgs(arg)) : PTPT_getTreeWsAfterArgs(arg));
  }
  if (PTPT_isTreeCycle(arg)) {
    return PTPT_makeTreeCycle(
        acceptWsAfterCycle ? acceptWsAfterCycle(PTPT_getTreeWsAfterCycle(arg)) : PTPT_getTreeWsAfterCycle(arg),
        acceptWsAfterParenOpen ? acceptWsAfterParenOpen(PTPT_getTreeWsAfterParenOpen(arg)) : PTPT_getTreeWsAfterParenOpen(arg),
        acceptSymbol ? acceptSymbol(PTPT_getTreeSymbol(arg)) : PTPT_getTreeSymbol(arg),
        acceptWsAfterSymbol ? acceptWsAfterSymbol(PTPT_getTreeWsAfterSymbol(arg)) : PTPT_getTreeWsAfterSymbol(arg),
        acceptWsAfterComma ? acceptWsAfterComma(PTPT_getTreeWsAfterComma(arg)) : PTPT_getTreeWsAfterComma(arg),
        acceptLength ? acceptLength(PTPT_getTreeLength(arg)) : PTPT_getTreeLength(arg),
        acceptWsAfterLength ? acceptWsAfterLength(PTPT_getTreeWsAfterLength(arg)) : PTPT_getTreeWsAfterLength(arg));
  }
  if (PTPT_isTreeAmb(arg)) {
    return PTPT_makeTreeAmb(
        acceptWsAfterAmb ? acceptWsAfterAmb(PTPT_getTreeWsAfterAmb(arg)) : PTPT_getTreeWsAfterAmb(arg),
        acceptWsAfterParenOpen ? acceptWsAfterParenOpen(PTPT_getTreeWsAfterParenOpen(arg)) : PTPT_getTreeWsAfterParenOpen(arg),
        acceptArgs ? acceptArgs(PTPT_getTreeArgs(arg)) : PTPT_getTreeArgs(arg),
        acceptWsAfterArgs ? acceptWsAfterArgs(PTPT_getTreeWsAfterArgs(arg)) : PTPT_getTreeWsAfterArgs(arg));
  }
  if (PTPT_isTreeChar(arg)) {
    return PTPT_makeTreeChar(
        acceptCharacter ? acceptCharacter(PTPT_getTreeCharacter(arg)) : PTPT_getTreeCharacter(arg));
  }
  ATabort("not a Tree: %t\n", arg);
  return (PTPT_Tree)NULL;
}
/**
 * Apply functions to the children of a PTPT_Attributes. 
 * \return A new PTPT_Attributes with new children where the argument functions might have applied
 */
PTPT_Attributes PTPT_visitAttributes(PTPT_Attributes arg, PTPT_OptLayout (*acceptWsAfterAttrs)(PTPT_OptLayout), PTPT_OptLayout (*acceptWsAfterParenOpen)(PTPT_OptLayout), PTPT_Attrs (*acceptAttributes)(PTPT_Attrs), PTPT_OptLayout (*acceptWsAfterAttributes)(PTPT_OptLayout)) {
  if (PTPT_isAttributesNoAttrs(arg)) {
    return PTPT_makeAttributesNoAttrs();
  }
  if (PTPT_isAttributesAttrs(arg)) {
    return PTPT_makeAttributesAttrs(
        acceptWsAfterAttrs ? acceptWsAfterAttrs(PTPT_getAttributesWsAfterAttrs(arg)) : PTPT_getAttributesWsAfterAttrs(arg),
        acceptWsAfterParenOpen ? acceptWsAfterParenOpen(PTPT_getAttributesWsAfterParenOpen(arg)) : PTPT_getAttributesWsAfterParenOpen(arg),
        acceptAttributes ? acceptAttributes(PTPT_getAttributesAttributes(arg)) : PTPT_getAttributesAttributes(arg),
        acceptWsAfterAttributes ? acceptWsAfterAttributes(PTPT_getAttributesWsAfterAttributes(arg)) : PTPT_getAttributesWsAfterAttributes(arg));
  }
  ATabort("not a Attributes: %t\n", arg);
  return (PTPT_Attributes)NULL;
}
/**
 * Apply functions to the children of a PTPT_Attrs. 
 * \return A new PTPT_Attrs with new children where the argument functions might have applied
 */
PTPT_Attrs PTPT_visitAttrs(PTPT_Attrs arg, PTPT_OptLayout (*acceptWsAfterBracketOpen)(PTPT_OptLayout), PTPT_AttrList (*acceptList)(PTPT_AttrList), PTPT_OptLayout (*acceptWsAfterList)(PTPT_OptLayout)) {
  if (PTPT_isAttrsMany(arg)) {
    return PTPT_makeAttrsMany(
        acceptWsAfterBracketOpen ? acceptWsAfterBracketOpen(PTPT_getAttrsWsAfterBracketOpen(arg)) : PTPT_getAttrsWsAfterBracketOpen(arg),
        acceptList ? acceptList(PTPT_getAttrsList(arg)) : PTPT_getAttrsList(arg),
        acceptWsAfterList ? acceptWsAfterList(PTPT_getAttrsWsAfterList(arg)) : PTPT_getAttrsWsAfterList(arg));
  }
  ATabort("not a Attrs: %t\n", arg);
  return (PTPT_Attrs)NULL;
}
/**
 * Apply functions to the children of a PTPT_Attr. 
 * \return A new PTPT_Attr with new children where the argument functions might have applied
 */
PTPT_Attr PTPT_visitAttr(PTPT_Attr arg, PTPT_OptLayout (*acceptWsAfterAssoc)(PTPT_OptLayout), PTPT_OptLayout (*acceptWsAfterParenOpen)(PTPT_OptLayout), PTPT_Associativity (*acceptAssociativity)(PTPT_Associativity), PTPT_OptLayout (*acceptWsAfterAssociativity)(PTPT_OptLayout), PTPT_OptLayout (*acceptWsAfterTerm)(PTPT_OptLayout), PTPT_ATerm (*acceptAterm)(PTPT_ATerm), PTPT_OptLayout (*acceptWsAfterAterm)(PTPT_OptLayout), PTPT_OptLayout (*acceptWsAfterId)(PTPT_OptLayout), PTPT_StrCon (*acceptModuleName)(PTPT_StrCon), PTPT_OptLayout (*acceptWsAfterModuleName)(PTPT_OptLayout)) {
  if (PTPT_isAttrAssoc(arg)) {
    return PTPT_makeAttrAssoc(
        acceptWsAfterAssoc ? acceptWsAfterAssoc(PTPT_getAttrWsAfterAssoc(arg)) : PTPT_getAttrWsAfterAssoc(arg),
        acceptWsAfterParenOpen ? acceptWsAfterParenOpen(PTPT_getAttrWsAfterParenOpen(arg)) : PTPT_getAttrWsAfterParenOpen(arg),
        acceptAssociativity ? acceptAssociativity(PTPT_getAttrAssociativity(arg)) : PTPT_getAttrAssociativity(arg),
        acceptWsAfterAssociativity ? acceptWsAfterAssociativity(PTPT_getAttrWsAfterAssociativity(arg)) : PTPT_getAttrWsAfterAssociativity(arg));
  }
  if (PTPT_isAttrTerm(arg)) {
    return PTPT_makeAttrTerm(
        acceptWsAfterTerm ? acceptWsAfterTerm(PTPT_getAttrWsAfterTerm(arg)) : PTPT_getAttrWsAfterTerm(arg),
        acceptWsAfterParenOpen ? acceptWsAfterParenOpen(PTPT_getAttrWsAfterParenOpen(arg)) : PTPT_getAttrWsAfterParenOpen(arg),
        acceptAterm ? acceptAterm(PTPT_getAttrAterm(arg)) : PTPT_getAttrAterm(arg),
        acceptWsAfterAterm ? acceptWsAfterAterm(PTPT_getAttrWsAfterAterm(arg)) : PTPT_getAttrWsAfterAterm(arg));
  }
  if (PTPT_isAttrId(arg)) {
    return PTPT_makeAttrId(
        acceptWsAfterId ? acceptWsAfterId(PTPT_getAttrWsAfterId(arg)) : PTPT_getAttrWsAfterId(arg),
        acceptWsAfterParenOpen ? acceptWsAfterParenOpen(PTPT_getAttrWsAfterParenOpen(arg)) : PTPT_getAttrWsAfterParenOpen(arg),
        acceptModuleName ? acceptModuleName(PTPT_getAttrModuleName(arg)) : PTPT_getAttrModuleName(arg),
        acceptWsAfterModuleName ? acceptWsAfterModuleName(PTPT_getAttrWsAfterModuleName(arg)) : PTPT_getAttrWsAfterModuleName(arg));
  }
  if (PTPT_isAttrBracket(arg)) {
    return PTPT_makeAttrBracket();
  }
  if (PTPT_isAttrReject(arg)) {
    return PTPT_makeAttrReject();
  }
  if (PTPT_isAttrPrefer(arg)) {
    return PTPT_makeAttrPrefer();
  }
  if (PTPT_isAttrAvoid(arg)) {
    return PTPT_makeAttrAvoid();
  }
  ATabort("not a Attr: %t\n", arg);
  return (PTPT_Attr)NULL;
}
/**
 * Apply functions to the children of a PTPT_Associativity. 
 * \return A new PTPT_Associativity with new children where the argument functions might have applied
 */
PTPT_Associativity PTPT_visitAssociativity(PTPT_Associativity arg) {
  if (PTPT_isAssociativityLeft(arg)) {
    return PTPT_makeAssociativityLeft();
  }
  if (PTPT_isAssociativityRight(arg)) {
    return PTPT_makeAssociativityRight();
  }
  if (PTPT_isAssociativityAssoc(arg)) {
    return PTPT_makeAssociativityAssoc();
  }
  if (PTPT_isAssociativityNonAssoc(arg)) {
    return PTPT_makeAssociativityNonAssoc();
  }
  ATabort("not a Associativity: %t\n", arg);
  return (PTPT_Associativity)NULL;
}
/**
 * Apply functions to the children of a PTPT_AttrList. 
 * \return A new PTPT_AttrList with new children where the argument functions might have applied
 */
PTPT_AttrList PTPT_visitAttrList(PTPT_AttrList arg, PTPT_Attr (*acceptHead)(PTPT_Attr), PTPT_OptLayout (*acceptWsAfterHead)(PTPT_OptLayout), PTPT_OptLayout (*acceptWsAfterSep)(PTPT_OptLayout)) {
  if (PTPT_isAttrListEmpty(arg)) {
    return PTPT_makeAttrListEmpty();
  }
  if (PTPT_isAttrListSingle(arg)) {
    return PTPT_makeAttrListSingle(
        acceptHead ? acceptHead(PTPT_getAttrListHead(arg)) : PTPT_getAttrListHead(arg));
  }
  if (PTPT_isAttrListMany(arg)) {
    return PTPT_makeAttrListMany(
        acceptHead ? acceptHead(PTPT_getAttrListHead(arg)) : PTPT_getAttrListHead(arg),
        acceptWsAfterHead ? acceptWsAfterHead(PTPT_getAttrListWsAfterHead(arg)) : PTPT_getAttrListWsAfterHead(arg),
        acceptWsAfterSep ? acceptWsAfterSep(PTPT_getAttrListWsAfterSep(arg)) : PTPT_getAttrListWsAfterSep(arg),
        PTPT_visitAttrList(PTPT_getAttrListTail(arg), acceptHead, acceptWsAfterHead, acceptWsAfterSep));
  }
  ATabort("not a AttrList: %t\n", arg);
  return (PTPT_AttrList)NULL;
}
/**
 * Apply functions to the children of a PTPT_ParseTree. 
 * \return A new PTPT_ParseTree with new children where the argument functions might have applied
 */
PTPT_ParseTree PTPT_visitParseTree(PTPT_ParseTree arg, PTPT_OptLayout (*acceptWsAfterParsetree)(PTPT_OptLayout), PTPT_OptLayout (*acceptWsAfterParenOpen)(PTPT_OptLayout), PTPT_Tree (*acceptTop)(PTPT_Tree), PTPT_OptLayout (*acceptWsAfterTop)(PTPT_OptLayout), PTPT_OptLayout (*acceptWsAfterComma)(PTPT_OptLayout), PTPT_NatCon (*acceptAmbCnt)(PTPT_NatCon), PTPT_OptLayout (*acceptWsAfterAmbCnt)(PTPT_OptLayout)) {
  if (PTPT_isParseTreeTop(arg)) {
    return PTPT_makeParseTreeTop(
        acceptWsAfterParsetree ? acceptWsAfterParsetree(PTPT_getParseTreeWsAfterParsetree(arg)) : PTPT_getParseTreeWsAfterParsetree(arg),
        acceptWsAfterParenOpen ? acceptWsAfterParenOpen(PTPT_getParseTreeWsAfterParenOpen(arg)) : PTPT_getParseTreeWsAfterParenOpen(arg),
        acceptTop ? acceptTop(PTPT_getParseTreeTop(arg)) : PTPT_getParseTreeTop(arg),
        acceptWsAfterTop ? acceptWsAfterTop(PTPT_getParseTreeWsAfterTop(arg)) : PTPT_getParseTreeWsAfterTop(arg),
        acceptWsAfterComma ? acceptWsAfterComma(PTPT_getParseTreeWsAfterComma(arg)) : PTPT_getParseTreeWsAfterComma(arg),
        acceptAmbCnt ? acceptAmbCnt(PTPT_getParseTreeAmbCnt(arg)) : PTPT_getParseTreeAmbCnt(arg),
        acceptWsAfterAmbCnt ? acceptWsAfterAmbCnt(PTPT_getParseTreeWsAfterAmbCnt(arg)) : PTPT_getParseTreeWsAfterAmbCnt(arg));
  }
  ATabort("not a ParseTree: %t\n", arg);
  return (PTPT_ParseTree)NULL;
}
/**
 * Apply functions to the children of a PTPT_Symbol. 
 * \return A new PTPT_Symbol with new children where the argument functions might have applied
 */
PTPT_Symbol PTPT_visitSymbol(PTPT_Symbol arg, PTPT_OptLayout (*acceptWsAfterLit)(PTPT_OptLayout), PTPT_OptLayout (*acceptWsAfterParenOpen)(PTPT_OptLayout), PTPT_StrCon (*acceptString)(PTPT_StrCon), PTPT_OptLayout (*acceptWsAfterString)(PTPT_OptLayout), PTPT_OptLayout (*acceptWsAfterCilit)(PTPT_OptLayout), PTPT_OptLayout (*acceptWsAfterCf)(PTPT_OptLayout), PTPT_OptLayout (*acceptWsAfterSymbol)(PTPT_OptLayout), PTPT_OptLayout (*acceptWsAfterLex)(PTPT_OptLayout), PTPT_OptLayout (*acceptWsAfterOpt)(PTPT_OptLayout), PTPT_OptLayout (*acceptWsAfterAlt)(PTPT_OptLayout), PTPT_OptLayout (*acceptWsAfterLhs)(PTPT_OptLayout), PTPT_OptLayout (*acceptWsAfterComma)(PTPT_OptLayout), PTPT_OptLayout (*acceptWsAfterRhs)(PTPT_OptLayout), PTPT_OptLayout (*acceptWsAfterSeq)(PTPT_OptLayout), PTPT_Symbols (*acceptSymbols)(PTPT_Symbols), PTPT_OptLayout (*acceptWsAfterSymbols)(PTPT_OptLayout), PTPT_OptLayout (*acceptWsAfterTuple)(PTPT_OptLayout), PTPT_OptLayout (*acceptWsAfterHead)(PTPT_OptLayout), PTPT_Symbols (*acceptRest)(PTPT_Symbols), PTPT_OptLayout (*acceptWsAfterRest)(PTPT_OptLayout), PTPT_OptLayout (*acceptWsAfterSort)(PTPT_OptLayout), PTPT_OptLayout (*acceptWsAfterIter)(PTPT_OptLayout), PTPT_OptLayout (*acceptWsAfterIterStar)(PTPT_OptLayout), PTPT_OptLayout (*acceptWsAfterIterSep)(PTPT_OptLayout), PTPT_OptLayout (*acceptWsAfterSeparator)(PTPT_OptLayout), PTPT_OptLayout (*acceptWsAfterIterStarSep)(PTPT_OptLayout), PTPT_OptLayout (*acceptWsAfterIterN)(PTPT_OptLayout), PTPT_NatCon (*acceptNumber)(PTPT_NatCon), PTPT_OptLayout (*acceptWsAfterNumber)(PTPT_OptLayout), PTPT_OptLayout (*acceptWsAfterIterSepN)(PTPT_OptLayout), PTPT_OptLayout (*acceptWsAfterComma1)(PTPT_OptLayout), PTPT_OptLayout (*acceptWsAfterComma2)(PTPT_OptLayout), PTPT_OptLayout (*acceptWsAfterFunc)(PTPT_OptLayout), PTPT_OptLayout (*acceptWsAfterVarsym)(PTPT_OptLayout), PTPT_OptLayout (*acceptWsAfterCharClass)(PTPT_OptLayout), PTPT_CharRanges (*acceptCharRanges)(PTPT_CharRanges), PTPT_OptLayout (*acceptWsAfterCharRanges)(PTPT_OptLayout), PTPT_OptLayout (*acceptWsAfterStrategy)(PTPT_OptLayout), PTPT_OptLayout (*acceptWsAfterParameterizedSort)(PTPT_OptLayout), PTPT_StrCon (*acceptSort)(PTPT_StrCon), PTPT_Symbols (*acceptParameters)(PTPT_Symbols), PTPT_OptLayout (*acceptWsAfterParameters)(PTPT_OptLayout)) {
  if (PTPT_isSymbolEmpty(arg)) {
    return PTPT_makeSymbolEmpty();
  }
  if (PTPT_isSymbolLit(arg)) {
    return PTPT_makeSymbolLit(
        acceptWsAfterLit ? acceptWsAfterLit(PTPT_getSymbolWsAfterLit(arg)) : PTPT_getSymbolWsAfterLit(arg),
        acceptWsAfterParenOpen ? acceptWsAfterParenOpen(PTPT_getSymbolWsAfterParenOpen(arg)) : PTPT_getSymbolWsAfterParenOpen(arg),
        acceptString ? acceptString(PTPT_getSymbolString(arg)) : PTPT_getSymbolString(arg),
        acceptWsAfterString ? acceptWsAfterString(PTPT_getSymbolWsAfterString(arg)) : PTPT_getSymbolWsAfterString(arg));
  }
  if (PTPT_isSymbolCilit(arg)) {
    return PTPT_makeSymbolCilit(
        acceptWsAfterCilit ? acceptWsAfterCilit(PTPT_getSymbolWsAfterCilit(arg)) : PTPT_getSymbolWsAfterCilit(arg),
        acceptWsAfterParenOpen ? acceptWsAfterParenOpen(PTPT_getSymbolWsAfterParenOpen(arg)) : PTPT_getSymbolWsAfterParenOpen(arg),
        acceptString ? acceptString(PTPT_getSymbolString(arg)) : PTPT_getSymbolString(arg),
        acceptWsAfterString ? acceptWsAfterString(PTPT_getSymbolWsAfterString(arg)) : PTPT_getSymbolWsAfterString(arg));
  }
  if (PTPT_isSymbolCf(arg)) {
    return PTPT_makeSymbolCf(
        acceptWsAfterCf ? acceptWsAfterCf(PTPT_getSymbolWsAfterCf(arg)) : PTPT_getSymbolWsAfterCf(arg),
        acceptWsAfterParenOpen ? acceptWsAfterParenOpen(PTPT_getSymbolWsAfterParenOpen(arg)) : PTPT_getSymbolWsAfterParenOpen(arg),
        PTPT_visitSymbol(PTPT_getSymbolSymbol(arg), acceptWsAfterLit, acceptWsAfterParenOpen, acceptString, acceptWsAfterString, acceptWsAfterCilit, acceptWsAfterCf, acceptWsAfterSymbol, acceptWsAfterLex, acceptWsAfterOpt, acceptWsAfterAlt, acceptWsAfterLhs, acceptWsAfterComma, acceptWsAfterRhs, acceptWsAfterSeq, acceptSymbols, acceptWsAfterSymbols, acceptWsAfterTuple, acceptWsAfterHead, acceptRest, acceptWsAfterRest, acceptWsAfterSort, acceptWsAfterIter, acceptWsAfterIterStar, acceptWsAfterIterSep, acceptWsAfterSeparator, acceptWsAfterIterStarSep, acceptWsAfterIterN, acceptNumber, acceptWsAfterNumber, acceptWsAfterIterSepN, acceptWsAfterComma1, acceptWsAfterComma2, acceptWsAfterFunc, acceptWsAfterVarsym, acceptWsAfterCharClass, acceptCharRanges, acceptWsAfterCharRanges, acceptWsAfterStrategy, acceptWsAfterParameterizedSort, acceptSort, acceptParameters, acceptWsAfterParameters),
        acceptWsAfterSymbol ? acceptWsAfterSymbol(PTPT_getSymbolWsAfterSymbol(arg)) : PTPT_getSymbolWsAfterSymbol(arg));
  }
  if (PTPT_isSymbolLex(arg)) {
    return PTPT_makeSymbolLex(
        acceptWsAfterLex ? acceptWsAfterLex(PTPT_getSymbolWsAfterLex(arg)) : PTPT_getSymbolWsAfterLex(arg),
        acceptWsAfterParenOpen ? acceptWsAfterParenOpen(PTPT_getSymbolWsAfterParenOpen(arg)) : PTPT_getSymbolWsAfterParenOpen(arg),
        PTPT_visitSymbol(PTPT_getSymbolSymbol(arg), acceptWsAfterLit, acceptWsAfterParenOpen, acceptString, acceptWsAfterString, acceptWsAfterCilit, acceptWsAfterCf, acceptWsAfterSymbol, acceptWsAfterLex, acceptWsAfterOpt, acceptWsAfterAlt, acceptWsAfterLhs, acceptWsAfterComma, acceptWsAfterRhs, acceptWsAfterSeq, acceptSymbols, acceptWsAfterSymbols, acceptWsAfterTuple, acceptWsAfterHead, acceptRest, acceptWsAfterRest, acceptWsAfterSort, acceptWsAfterIter, acceptWsAfterIterStar, acceptWsAfterIterSep, acceptWsAfterSeparator, acceptWsAfterIterStarSep, acceptWsAfterIterN, acceptNumber, acceptWsAfterNumber, acceptWsAfterIterSepN, acceptWsAfterComma1, acceptWsAfterComma2, acceptWsAfterFunc, acceptWsAfterVarsym, acceptWsAfterCharClass, acceptCharRanges, acceptWsAfterCharRanges, acceptWsAfterStrategy, acceptWsAfterParameterizedSort, acceptSort, acceptParameters, acceptWsAfterParameters),
        acceptWsAfterSymbol ? acceptWsAfterSymbol(PTPT_getSymbolWsAfterSymbol(arg)) : PTPT_getSymbolWsAfterSymbol(arg));
  }
  if (PTPT_isSymbolOpt(arg)) {
    return PTPT_makeSymbolOpt(
        acceptWsAfterOpt ? acceptWsAfterOpt(PTPT_getSymbolWsAfterOpt(arg)) : PTPT_getSymbolWsAfterOpt(arg),
        acceptWsAfterParenOpen ? acceptWsAfterParenOpen(PTPT_getSymbolWsAfterParenOpen(arg)) : PTPT_getSymbolWsAfterParenOpen(arg),
        PTPT_visitSymbol(PTPT_getSymbolSymbol(arg), acceptWsAfterLit, acceptWsAfterParenOpen, acceptString, acceptWsAfterString, acceptWsAfterCilit, acceptWsAfterCf, acceptWsAfterSymbol, acceptWsAfterLex, acceptWsAfterOpt, acceptWsAfterAlt, acceptWsAfterLhs, acceptWsAfterComma, acceptWsAfterRhs, acceptWsAfterSeq, acceptSymbols, acceptWsAfterSymbols, acceptWsAfterTuple, acceptWsAfterHead, acceptRest, acceptWsAfterRest, acceptWsAfterSort, acceptWsAfterIter, acceptWsAfterIterStar, acceptWsAfterIterSep, acceptWsAfterSeparator, acceptWsAfterIterStarSep, acceptWsAfterIterN, acceptNumber, acceptWsAfterNumber, acceptWsAfterIterSepN, acceptWsAfterComma1, acceptWsAfterComma2, acceptWsAfterFunc, acceptWsAfterVarsym, acceptWsAfterCharClass, acceptCharRanges, acceptWsAfterCharRanges, acceptWsAfterStrategy, acceptWsAfterParameterizedSort, acceptSort, acceptParameters, acceptWsAfterParameters),
        acceptWsAfterSymbol ? acceptWsAfterSymbol(PTPT_getSymbolWsAfterSymbol(arg)) : PTPT_getSymbolWsAfterSymbol(arg));
  }
  if (PTPT_isSymbolAlt(arg)) {
    return PTPT_makeSymbolAlt(
        acceptWsAfterAlt ? acceptWsAfterAlt(PTPT_getSymbolWsAfterAlt(arg)) : PTPT_getSymbolWsAfterAlt(arg),
        acceptWsAfterParenOpen ? acceptWsAfterParenOpen(PTPT_getSymbolWsAfterParenOpen(arg)) : PTPT_getSymbolWsAfterParenOpen(arg),
        PTPT_visitSymbol(PTPT_getSymbolLhs(arg), acceptWsAfterLit, acceptWsAfterParenOpen, acceptString, acceptWsAfterString, acceptWsAfterCilit, acceptWsAfterCf, acceptWsAfterSymbol, acceptWsAfterLex, acceptWsAfterOpt, acceptWsAfterAlt, acceptWsAfterLhs, acceptWsAfterComma, acceptWsAfterRhs, acceptWsAfterSeq, acceptSymbols, acceptWsAfterSymbols, acceptWsAfterTuple, acceptWsAfterHead, acceptRest, acceptWsAfterRest, acceptWsAfterSort, acceptWsAfterIter, acceptWsAfterIterStar, acceptWsAfterIterSep, acceptWsAfterSeparator, acceptWsAfterIterStarSep, acceptWsAfterIterN, acceptNumber, acceptWsAfterNumber, acceptWsAfterIterSepN, acceptWsAfterComma1, acceptWsAfterComma2, acceptWsAfterFunc, acceptWsAfterVarsym, acceptWsAfterCharClass, acceptCharRanges, acceptWsAfterCharRanges, acceptWsAfterStrategy, acceptWsAfterParameterizedSort, acceptSort, acceptParameters, acceptWsAfterParameters),
        acceptWsAfterLhs ? acceptWsAfterLhs(PTPT_getSymbolWsAfterLhs(arg)) : PTPT_getSymbolWsAfterLhs(arg),
        acceptWsAfterComma ? acceptWsAfterComma(PTPT_getSymbolWsAfterComma(arg)) : PTPT_getSymbolWsAfterComma(arg),
        PTPT_visitSymbol(PTPT_getSymbolRhs(arg), acceptWsAfterLit, acceptWsAfterParenOpen, acceptString, acceptWsAfterString, acceptWsAfterCilit, acceptWsAfterCf, acceptWsAfterSymbol, acceptWsAfterLex, acceptWsAfterOpt, acceptWsAfterAlt, acceptWsAfterLhs, acceptWsAfterComma, acceptWsAfterRhs, acceptWsAfterSeq, acceptSymbols, acceptWsAfterSymbols, acceptWsAfterTuple, acceptWsAfterHead, acceptRest, acceptWsAfterRest, acceptWsAfterSort, acceptWsAfterIter, acceptWsAfterIterStar, acceptWsAfterIterSep, acceptWsAfterSeparator, acceptWsAfterIterStarSep, acceptWsAfterIterN, acceptNumber, acceptWsAfterNumber, acceptWsAfterIterSepN, acceptWsAfterComma1, acceptWsAfterComma2, acceptWsAfterFunc, acceptWsAfterVarsym, acceptWsAfterCharClass, acceptCharRanges, acceptWsAfterCharRanges, acceptWsAfterStrategy, acceptWsAfterParameterizedSort, acceptSort, acceptParameters, acceptWsAfterParameters),
        acceptWsAfterRhs ? acceptWsAfterRhs(PTPT_getSymbolWsAfterRhs(arg)) : PTPT_getSymbolWsAfterRhs(arg));
  }
  if (PTPT_isSymbolSeq(arg)) {
    return PTPT_makeSymbolSeq(
        acceptWsAfterSeq ? acceptWsAfterSeq(PTPT_getSymbolWsAfterSeq(arg)) : PTPT_getSymbolWsAfterSeq(arg),
        acceptWsAfterParenOpen ? acceptWsAfterParenOpen(PTPT_getSymbolWsAfterParenOpen(arg)) : PTPT_getSymbolWsAfterParenOpen(arg),
        acceptSymbols ? acceptSymbols(PTPT_getSymbolSymbols(arg)) : PTPT_getSymbolSymbols(arg),
        acceptWsAfterSymbols ? acceptWsAfterSymbols(PTPT_getSymbolWsAfterSymbols(arg)) : PTPT_getSymbolWsAfterSymbols(arg));
  }
  if (PTPT_isSymbolTuple(arg)) {
    return PTPT_makeSymbolTuple(
        acceptWsAfterTuple ? acceptWsAfterTuple(PTPT_getSymbolWsAfterTuple(arg)) : PTPT_getSymbolWsAfterTuple(arg),
        acceptWsAfterParenOpen ? acceptWsAfterParenOpen(PTPT_getSymbolWsAfterParenOpen(arg)) : PTPT_getSymbolWsAfterParenOpen(arg),
        PTPT_visitSymbol(PTPT_getSymbolHead(arg), acceptWsAfterLit, acceptWsAfterParenOpen, acceptString, acceptWsAfterString, acceptWsAfterCilit, acceptWsAfterCf, acceptWsAfterSymbol, acceptWsAfterLex, acceptWsAfterOpt, acceptWsAfterAlt, acceptWsAfterLhs, acceptWsAfterComma, acceptWsAfterRhs, acceptWsAfterSeq, acceptSymbols, acceptWsAfterSymbols, acceptWsAfterTuple, acceptWsAfterHead, acceptRest, acceptWsAfterRest, acceptWsAfterSort, acceptWsAfterIter, acceptWsAfterIterStar, acceptWsAfterIterSep, acceptWsAfterSeparator, acceptWsAfterIterStarSep, acceptWsAfterIterN, acceptNumber, acceptWsAfterNumber, acceptWsAfterIterSepN, acceptWsAfterComma1, acceptWsAfterComma2, acceptWsAfterFunc, acceptWsAfterVarsym, acceptWsAfterCharClass, acceptCharRanges, acceptWsAfterCharRanges, acceptWsAfterStrategy, acceptWsAfterParameterizedSort, acceptSort, acceptParameters, acceptWsAfterParameters),
        acceptWsAfterHead ? acceptWsAfterHead(PTPT_getSymbolWsAfterHead(arg)) : PTPT_getSymbolWsAfterHead(arg),
        acceptWsAfterComma ? acceptWsAfterComma(PTPT_getSymbolWsAfterComma(arg)) : PTPT_getSymbolWsAfterComma(arg),
        acceptRest ? acceptRest(PTPT_getSymbolRest(arg)) : PTPT_getSymbolRest(arg),
        acceptWsAfterRest ? acceptWsAfterRest(PTPT_getSymbolWsAfterRest(arg)) : PTPT_getSymbolWsAfterRest(arg));
  }
  if (PTPT_isSymbolSort(arg)) {
    return PTPT_makeSymbolSort(
        acceptWsAfterSort ? acceptWsAfterSort(PTPT_getSymbolWsAfterSort(arg)) : PTPT_getSymbolWsAfterSort(arg),
        acceptWsAfterParenOpen ? acceptWsAfterParenOpen(PTPT_getSymbolWsAfterParenOpen(arg)) : PTPT_getSymbolWsAfterParenOpen(arg),
        acceptString ? acceptString(PTPT_getSymbolString(arg)) : PTPT_getSymbolString(arg),
        acceptWsAfterString ? acceptWsAfterString(PTPT_getSymbolWsAfterString(arg)) : PTPT_getSymbolWsAfterString(arg));
  }
  if (PTPT_isSymbolIter(arg)) {
    return PTPT_makeSymbolIter(
        acceptWsAfterIter ? acceptWsAfterIter(PTPT_getSymbolWsAfterIter(arg)) : PTPT_getSymbolWsAfterIter(arg),
        acceptWsAfterParenOpen ? acceptWsAfterParenOpen(PTPT_getSymbolWsAfterParenOpen(arg)) : PTPT_getSymbolWsAfterParenOpen(arg),
        PTPT_visitSymbol(PTPT_getSymbolSymbol(arg), acceptWsAfterLit, acceptWsAfterParenOpen, acceptString, acceptWsAfterString, acceptWsAfterCilit, acceptWsAfterCf, acceptWsAfterSymbol, acceptWsAfterLex, acceptWsAfterOpt, acceptWsAfterAlt, acceptWsAfterLhs, acceptWsAfterComma, acceptWsAfterRhs, acceptWsAfterSeq, acceptSymbols, acceptWsAfterSymbols, acceptWsAfterTuple, acceptWsAfterHead, acceptRest, acceptWsAfterRest, acceptWsAfterSort, acceptWsAfterIter, acceptWsAfterIterStar, acceptWsAfterIterSep, acceptWsAfterSeparator, acceptWsAfterIterStarSep, acceptWsAfterIterN, acceptNumber, acceptWsAfterNumber, acceptWsAfterIterSepN, acceptWsAfterComma1, acceptWsAfterComma2, acceptWsAfterFunc, acceptWsAfterVarsym, acceptWsAfterCharClass, acceptCharRanges, acceptWsAfterCharRanges, acceptWsAfterStrategy, acceptWsAfterParameterizedSort, acceptSort, acceptParameters, acceptWsAfterParameters),
        acceptWsAfterSymbol ? acceptWsAfterSymbol(PTPT_getSymbolWsAfterSymbol(arg)) : PTPT_getSymbolWsAfterSymbol(arg));
  }
  if (PTPT_isSymbolIterStar(arg)) {
    return PTPT_makeSymbolIterStar(
        acceptWsAfterIterStar ? acceptWsAfterIterStar(PTPT_getSymbolWsAfterIterStar(arg)) : PTPT_getSymbolWsAfterIterStar(arg),
        acceptWsAfterParenOpen ? acceptWsAfterParenOpen(PTPT_getSymbolWsAfterParenOpen(arg)) : PTPT_getSymbolWsAfterParenOpen(arg),
        PTPT_visitSymbol(PTPT_getSymbolSymbol(arg), acceptWsAfterLit, acceptWsAfterParenOpen, acceptString, acceptWsAfterString, acceptWsAfterCilit, acceptWsAfterCf, acceptWsAfterSymbol, acceptWsAfterLex, acceptWsAfterOpt, acceptWsAfterAlt, acceptWsAfterLhs, acceptWsAfterComma, acceptWsAfterRhs, acceptWsAfterSeq, acceptSymbols, acceptWsAfterSymbols, acceptWsAfterTuple, acceptWsAfterHead, acceptRest, acceptWsAfterRest, acceptWsAfterSort, acceptWsAfterIter, acceptWsAfterIterStar, acceptWsAfterIterSep, acceptWsAfterSeparator, acceptWsAfterIterStarSep, acceptWsAfterIterN, acceptNumber, acceptWsAfterNumber, acceptWsAfterIterSepN, acceptWsAfterComma1, acceptWsAfterComma2, acceptWsAfterFunc, acceptWsAfterVarsym, acceptWsAfterCharClass, acceptCharRanges, acceptWsAfterCharRanges, acceptWsAfterStrategy, acceptWsAfterParameterizedSort, acceptSort, acceptParameters, acceptWsAfterParameters),
        acceptWsAfterSymbol ? acceptWsAfterSymbol(PTPT_getSymbolWsAfterSymbol(arg)) : PTPT_getSymbolWsAfterSymbol(arg));
  }
  if (PTPT_isSymbolIterSep(arg)) {
    return PTPT_makeSymbolIterSep(
        acceptWsAfterIterSep ? acceptWsAfterIterSep(PTPT_getSymbolWsAfterIterSep(arg)) : PTPT_getSymbolWsAfterIterSep(arg),
        acceptWsAfterParenOpen ? acceptWsAfterParenOpen(PTPT_getSymbolWsAfterParenOpen(arg)) : PTPT_getSymbolWsAfterParenOpen(arg),
        PTPT_visitSymbol(PTPT_getSymbolSymbol(arg), acceptWsAfterLit, acceptWsAfterParenOpen, acceptString, acceptWsAfterString, acceptWsAfterCilit, acceptWsAfterCf, acceptWsAfterSymbol, acceptWsAfterLex, acceptWsAfterOpt, acceptWsAfterAlt, acceptWsAfterLhs, acceptWsAfterComma, acceptWsAfterRhs, acceptWsAfterSeq, acceptSymbols, acceptWsAfterSymbols, acceptWsAfterTuple, acceptWsAfterHead, acceptRest, acceptWsAfterRest, acceptWsAfterSort, acceptWsAfterIter, acceptWsAfterIterStar, acceptWsAfterIterSep, acceptWsAfterSeparator, acceptWsAfterIterStarSep, acceptWsAfterIterN, acceptNumber, acceptWsAfterNumber, acceptWsAfterIterSepN, acceptWsAfterComma1, acceptWsAfterComma2, acceptWsAfterFunc, acceptWsAfterVarsym, acceptWsAfterCharClass, acceptCharRanges, acceptWsAfterCharRanges, acceptWsAfterStrategy, acceptWsAfterParameterizedSort, acceptSort, acceptParameters, acceptWsAfterParameters),
        acceptWsAfterSymbol ? acceptWsAfterSymbol(PTPT_getSymbolWsAfterSymbol(arg)) : PTPT_getSymbolWsAfterSymbol(arg),
        acceptWsAfterComma ? acceptWsAfterComma(PTPT_getSymbolWsAfterComma(arg)) : PTPT_getSymbolWsAfterComma(arg),
        PTPT_visitSymbol(PTPT_getSymbolSeparator(arg), acceptWsAfterLit, acceptWsAfterParenOpen, acceptString, acceptWsAfterString, acceptWsAfterCilit, acceptWsAfterCf, acceptWsAfterSymbol, acceptWsAfterLex, acceptWsAfterOpt, acceptWsAfterAlt, acceptWsAfterLhs, acceptWsAfterComma, acceptWsAfterRhs, acceptWsAfterSeq, acceptSymbols, acceptWsAfterSymbols, acceptWsAfterTuple, acceptWsAfterHead, acceptRest, acceptWsAfterRest, acceptWsAfterSort, acceptWsAfterIter, acceptWsAfterIterStar, acceptWsAfterIterSep, acceptWsAfterSeparator, acceptWsAfterIterStarSep, acceptWsAfterIterN, acceptNumber, acceptWsAfterNumber, acceptWsAfterIterSepN, acceptWsAfterComma1, acceptWsAfterComma2, acceptWsAfterFunc, acceptWsAfterVarsym, acceptWsAfterCharClass, acceptCharRanges, acceptWsAfterCharRanges, acceptWsAfterStrategy, acceptWsAfterParameterizedSort, acceptSort, acceptParameters, acceptWsAfterParameters),
        acceptWsAfterSeparator ? acceptWsAfterSeparator(PTPT_getSymbolWsAfterSeparator(arg)) : PTPT_getSymbolWsAfterSeparator(arg));
  }
  if (PTPT_isSymbolIterStarSep(arg)) {
    return PTPT_makeSymbolIterStarSep(
        acceptWsAfterIterStarSep ? acceptWsAfterIterStarSep(PTPT_getSymbolWsAfterIterStarSep(arg)) : PTPT_getSymbolWsAfterIterStarSep(arg),
        acceptWsAfterParenOpen ? acceptWsAfterParenOpen(PTPT_getSymbolWsAfterParenOpen(arg)) : PTPT_getSymbolWsAfterParenOpen(arg),
        PTPT_visitSymbol(PTPT_getSymbolSymbol(arg), acceptWsAfterLit, acceptWsAfterParenOpen, acceptString, acceptWsAfterString, acceptWsAfterCilit, acceptWsAfterCf, acceptWsAfterSymbol, acceptWsAfterLex, acceptWsAfterOpt, acceptWsAfterAlt, acceptWsAfterLhs, acceptWsAfterComma, acceptWsAfterRhs, acceptWsAfterSeq, acceptSymbols, acceptWsAfterSymbols, acceptWsAfterTuple, acceptWsAfterHead, acceptRest, acceptWsAfterRest, acceptWsAfterSort, acceptWsAfterIter, acceptWsAfterIterStar, acceptWsAfterIterSep, acceptWsAfterSeparator, acceptWsAfterIterStarSep, acceptWsAfterIterN, acceptNumber, acceptWsAfterNumber, acceptWsAfterIterSepN, acceptWsAfterComma1, acceptWsAfterComma2, acceptWsAfterFunc, acceptWsAfterVarsym, acceptWsAfterCharClass, acceptCharRanges, acceptWsAfterCharRanges, acceptWsAfterStrategy, acceptWsAfterParameterizedSort, acceptSort, acceptParameters, acceptWsAfterParameters),
        acceptWsAfterSymbol ? acceptWsAfterSymbol(PTPT_getSymbolWsAfterSymbol(arg)) : PTPT_getSymbolWsAfterSymbol(arg),
        acceptWsAfterComma ? acceptWsAfterComma(PTPT_getSymbolWsAfterComma(arg)) : PTPT_getSymbolWsAfterComma(arg),
        PTPT_visitSymbol(PTPT_getSymbolSeparator(arg), acceptWsAfterLit, acceptWsAfterParenOpen, acceptString, acceptWsAfterString, acceptWsAfterCilit, acceptWsAfterCf, acceptWsAfterSymbol, acceptWsAfterLex, acceptWsAfterOpt, acceptWsAfterAlt, acceptWsAfterLhs, acceptWsAfterComma, acceptWsAfterRhs, acceptWsAfterSeq, acceptSymbols, acceptWsAfterSymbols, acceptWsAfterTuple, acceptWsAfterHead, acceptRest, acceptWsAfterRest, acceptWsAfterSort, acceptWsAfterIter, acceptWsAfterIterStar, acceptWsAfterIterSep, acceptWsAfterSeparator, acceptWsAfterIterStarSep, acceptWsAfterIterN, acceptNumber, acceptWsAfterNumber, acceptWsAfterIterSepN, acceptWsAfterComma1, acceptWsAfterComma2, acceptWsAfterFunc, acceptWsAfterVarsym, acceptWsAfterCharClass, acceptCharRanges, acceptWsAfterCharRanges, acceptWsAfterStrategy, acceptWsAfterParameterizedSort, acceptSort, acceptParameters, acceptWsAfterParameters),
        acceptWsAfterSeparator ? acceptWsAfterSeparator(PTPT_getSymbolWsAfterSeparator(arg)) : PTPT_getSymbolWsAfterSeparator(arg));
  }
  if (PTPT_isSymbolIterN(arg)) {
    return PTPT_makeSymbolIterN(
        acceptWsAfterIterN ? acceptWsAfterIterN(PTPT_getSymbolWsAfterIterN(arg)) : PTPT_getSymbolWsAfterIterN(arg),
        acceptWsAfterParenOpen ? acceptWsAfterParenOpen(PTPT_getSymbolWsAfterParenOpen(arg)) : PTPT_getSymbolWsAfterParenOpen(arg),
        PTPT_visitSymbol(PTPT_getSymbolSymbol(arg), acceptWsAfterLit, acceptWsAfterParenOpen, acceptString, acceptWsAfterString, acceptWsAfterCilit, acceptWsAfterCf, acceptWsAfterSymbol, acceptWsAfterLex, acceptWsAfterOpt, acceptWsAfterAlt, acceptWsAfterLhs, acceptWsAfterComma, acceptWsAfterRhs, acceptWsAfterSeq, acceptSymbols, acceptWsAfterSymbols, acceptWsAfterTuple, acceptWsAfterHead, acceptRest, acceptWsAfterRest, acceptWsAfterSort, acceptWsAfterIter, acceptWsAfterIterStar, acceptWsAfterIterSep, acceptWsAfterSeparator, acceptWsAfterIterStarSep, acceptWsAfterIterN, acceptNumber, acceptWsAfterNumber, acceptWsAfterIterSepN, acceptWsAfterComma1, acceptWsAfterComma2, acceptWsAfterFunc, acceptWsAfterVarsym, acceptWsAfterCharClass, acceptCharRanges, acceptWsAfterCharRanges, acceptWsAfterStrategy, acceptWsAfterParameterizedSort, acceptSort, acceptParameters, acceptWsAfterParameters),
        acceptWsAfterSymbol ? acceptWsAfterSymbol(PTPT_getSymbolWsAfterSymbol(arg)) : PTPT_getSymbolWsAfterSymbol(arg),
        acceptWsAfterComma ? acceptWsAfterComma(PTPT_getSymbolWsAfterComma(arg)) : PTPT_getSymbolWsAfterComma(arg),
        acceptNumber ? acceptNumber(PTPT_getSymbolNumber(arg)) : PTPT_getSymbolNumber(arg),
        acceptWsAfterNumber ? acceptWsAfterNumber(PTPT_getSymbolWsAfterNumber(arg)) : PTPT_getSymbolWsAfterNumber(arg));
  }
  if (PTPT_isSymbolIterSepN(arg)) {
    return PTPT_makeSymbolIterSepN(
        acceptWsAfterIterSepN ? acceptWsAfterIterSepN(PTPT_getSymbolWsAfterIterSepN(arg)) : PTPT_getSymbolWsAfterIterSepN(arg),
        acceptWsAfterParenOpen ? acceptWsAfterParenOpen(PTPT_getSymbolWsAfterParenOpen(arg)) : PTPT_getSymbolWsAfterParenOpen(arg),
        PTPT_visitSymbol(PTPT_getSymbolSymbol(arg), acceptWsAfterLit, acceptWsAfterParenOpen, acceptString, acceptWsAfterString, acceptWsAfterCilit, acceptWsAfterCf, acceptWsAfterSymbol, acceptWsAfterLex, acceptWsAfterOpt, acceptWsAfterAlt, acceptWsAfterLhs, acceptWsAfterComma, acceptWsAfterRhs, acceptWsAfterSeq, acceptSymbols, acceptWsAfterSymbols, acceptWsAfterTuple, acceptWsAfterHead, acceptRest, acceptWsAfterRest, acceptWsAfterSort, acceptWsAfterIter, acceptWsAfterIterStar, acceptWsAfterIterSep, acceptWsAfterSeparator, acceptWsAfterIterStarSep, acceptWsAfterIterN, acceptNumber, acceptWsAfterNumber, acceptWsAfterIterSepN, acceptWsAfterComma1, acceptWsAfterComma2, acceptWsAfterFunc, acceptWsAfterVarsym, acceptWsAfterCharClass, acceptCharRanges, acceptWsAfterCharRanges, acceptWsAfterStrategy, acceptWsAfterParameterizedSort, acceptSort, acceptParameters, acceptWsAfterParameters),
        acceptWsAfterSymbol ? acceptWsAfterSymbol(PTPT_getSymbolWsAfterSymbol(arg)) : PTPT_getSymbolWsAfterSymbol(arg),
        acceptWsAfterComma1 ? acceptWsAfterComma1(PTPT_getSymbolWsAfterComma1(arg)) : PTPT_getSymbolWsAfterComma1(arg),
        PTPT_visitSymbol(PTPT_getSymbolSeparator(arg), acceptWsAfterLit, acceptWsAfterParenOpen, acceptString, acceptWsAfterString, acceptWsAfterCilit, acceptWsAfterCf, acceptWsAfterSymbol, acceptWsAfterLex, acceptWsAfterOpt, acceptWsAfterAlt, acceptWsAfterLhs, acceptWsAfterComma, acceptWsAfterRhs, acceptWsAfterSeq, acceptSymbols, acceptWsAfterSymbols, acceptWsAfterTuple, acceptWsAfterHead, acceptRest, acceptWsAfterRest, acceptWsAfterSort, acceptWsAfterIter, acceptWsAfterIterStar, acceptWsAfterIterSep, acceptWsAfterSeparator, acceptWsAfterIterStarSep, acceptWsAfterIterN, acceptNumber, acceptWsAfterNumber, acceptWsAfterIterSepN, acceptWsAfterComma1, acceptWsAfterComma2, acceptWsAfterFunc, acceptWsAfterVarsym, acceptWsAfterCharClass, acceptCharRanges, acceptWsAfterCharRanges, acceptWsAfterStrategy, acceptWsAfterParameterizedSort, acceptSort, acceptParameters, acceptWsAfterParameters),
        acceptWsAfterSeparator ? acceptWsAfterSeparator(PTPT_getSymbolWsAfterSeparator(arg)) : PTPT_getSymbolWsAfterSeparator(arg),
        acceptWsAfterComma2 ? acceptWsAfterComma2(PTPT_getSymbolWsAfterComma2(arg)) : PTPT_getSymbolWsAfterComma2(arg),
        acceptNumber ? acceptNumber(PTPT_getSymbolNumber(arg)) : PTPT_getSymbolNumber(arg),
        acceptWsAfterNumber ? acceptWsAfterNumber(PTPT_getSymbolWsAfterNumber(arg)) : PTPT_getSymbolWsAfterNumber(arg));
  }
  if (PTPT_isSymbolFunc(arg)) {
    return PTPT_makeSymbolFunc(
        acceptWsAfterFunc ? acceptWsAfterFunc(PTPT_getSymbolWsAfterFunc(arg)) : PTPT_getSymbolWsAfterFunc(arg),
        acceptWsAfterParenOpen ? acceptWsAfterParenOpen(PTPT_getSymbolWsAfterParenOpen(arg)) : PTPT_getSymbolWsAfterParenOpen(arg),
        acceptSymbols ? acceptSymbols(PTPT_getSymbolSymbols(arg)) : PTPT_getSymbolSymbols(arg),
        acceptWsAfterSymbols ? acceptWsAfterSymbols(PTPT_getSymbolWsAfterSymbols(arg)) : PTPT_getSymbolWsAfterSymbols(arg),
        acceptWsAfterComma ? acceptWsAfterComma(PTPT_getSymbolWsAfterComma(arg)) : PTPT_getSymbolWsAfterComma(arg),
        PTPT_visitSymbol(PTPT_getSymbolSymbol(arg), acceptWsAfterLit, acceptWsAfterParenOpen, acceptString, acceptWsAfterString, acceptWsAfterCilit, acceptWsAfterCf, acceptWsAfterSymbol, acceptWsAfterLex, acceptWsAfterOpt, acceptWsAfterAlt, acceptWsAfterLhs, acceptWsAfterComma, acceptWsAfterRhs, acceptWsAfterSeq, acceptSymbols, acceptWsAfterSymbols, acceptWsAfterTuple, acceptWsAfterHead, acceptRest, acceptWsAfterRest, acceptWsAfterSort, acceptWsAfterIter, acceptWsAfterIterStar, acceptWsAfterIterSep, acceptWsAfterSeparator, acceptWsAfterIterStarSep, acceptWsAfterIterN, acceptNumber, acceptWsAfterNumber, acceptWsAfterIterSepN, acceptWsAfterComma1, acceptWsAfterComma2, acceptWsAfterFunc, acceptWsAfterVarsym, acceptWsAfterCharClass, acceptCharRanges, acceptWsAfterCharRanges, acceptWsAfterStrategy, acceptWsAfterParameterizedSort, acceptSort, acceptParameters, acceptWsAfterParameters),
        acceptWsAfterSymbol ? acceptWsAfterSymbol(PTPT_getSymbolWsAfterSymbol(arg)) : PTPT_getSymbolWsAfterSymbol(arg));
  }
  if (PTPT_isSymbolVarsym(arg)) {
    return PTPT_makeSymbolVarsym(
        acceptWsAfterVarsym ? acceptWsAfterVarsym(PTPT_getSymbolWsAfterVarsym(arg)) : PTPT_getSymbolWsAfterVarsym(arg),
        acceptWsAfterParenOpen ? acceptWsAfterParenOpen(PTPT_getSymbolWsAfterParenOpen(arg)) : PTPT_getSymbolWsAfterParenOpen(arg),
        PTPT_visitSymbol(PTPT_getSymbolSymbol(arg), acceptWsAfterLit, acceptWsAfterParenOpen, acceptString, acceptWsAfterString, acceptWsAfterCilit, acceptWsAfterCf, acceptWsAfterSymbol, acceptWsAfterLex, acceptWsAfterOpt, acceptWsAfterAlt, acceptWsAfterLhs, acceptWsAfterComma, acceptWsAfterRhs, acceptWsAfterSeq, acceptSymbols, acceptWsAfterSymbols, acceptWsAfterTuple, acceptWsAfterHead, acceptRest, acceptWsAfterRest, acceptWsAfterSort, acceptWsAfterIter, acceptWsAfterIterStar, acceptWsAfterIterSep, acceptWsAfterSeparator, acceptWsAfterIterStarSep, acceptWsAfterIterN, acceptNumber, acceptWsAfterNumber, acceptWsAfterIterSepN, acceptWsAfterComma1, acceptWsAfterComma2, acceptWsAfterFunc, acceptWsAfterVarsym, acceptWsAfterCharClass, acceptCharRanges, acceptWsAfterCharRanges, acceptWsAfterStrategy, acceptWsAfterParameterizedSort, acceptSort, acceptParameters, acceptWsAfterParameters),
        acceptWsAfterSymbol ? acceptWsAfterSymbol(PTPT_getSymbolWsAfterSymbol(arg)) : PTPT_getSymbolWsAfterSymbol(arg));
  }
  if (PTPT_isSymbolLayout(arg)) {
    return PTPT_makeSymbolLayout();
  }
  if (PTPT_isSymbolCharClass(arg)) {
    return PTPT_makeSymbolCharClass(
        acceptWsAfterCharClass ? acceptWsAfterCharClass(PTPT_getSymbolWsAfterCharClass(arg)) : PTPT_getSymbolWsAfterCharClass(arg),
        acceptWsAfterParenOpen ? acceptWsAfterParenOpen(PTPT_getSymbolWsAfterParenOpen(arg)) : PTPT_getSymbolWsAfterParenOpen(arg),
        acceptCharRanges ? acceptCharRanges(PTPT_getSymbolCharRanges(arg)) : PTPT_getSymbolCharRanges(arg),
        acceptWsAfterCharRanges ? acceptWsAfterCharRanges(PTPT_getSymbolWsAfterCharRanges(arg)) : PTPT_getSymbolWsAfterCharRanges(arg));
  }
  if (PTPT_isSymbolStrategy(arg)) {
    return PTPT_makeSymbolStrategy(
        acceptWsAfterStrategy ? acceptWsAfterStrategy(PTPT_getSymbolWsAfterStrategy(arg)) : PTPT_getSymbolWsAfterStrategy(arg),
        acceptWsAfterParenOpen ? acceptWsAfterParenOpen(PTPT_getSymbolWsAfterParenOpen(arg)) : PTPT_getSymbolWsAfterParenOpen(arg),
        PTPT_visitSymbol(PTPT_getSymbolLhs(arg), acceptWsAfterLit, acceptWsAfterParenOpen, acceptString, acceptWsAfterString, acceptWsAfterCilit, acceptWsAfterCf, acceptWsAfterSymbol, acceptWsAfterLex, acceptWsAfterOpt, acceptWsAfterAlt, acceptWsAfterLhs, acceptWsAfterComma, acceptWsAfterRhs, acceptWsAfterSeq, acceptSymbols, acceptWsAfterSymbols, acceptWsAfterTuple, acceptWsAfterHead, acceptRest, acceptWsAfterRest, acceptWsAfterSort, acceptWsAfterIter, acceptWsAfterIterStar, acceptWsAfterIterSep, acceptWsAfterSeparator, acceptWsAfterIterStarSep, acceptWsAfterIterN, acceptNumber, acceptWsAfterNumber, acceptWsAfterIterSepN, acceptWsAfterComma1, acceptWsAfterComma2, acceptWsAfterFunc, acceptWsAfterVarsym, acceptWsAfterCharClass, acceptCharRanges, acceptWsAfterCharRanges, acceptWsAfterStrategy, acceptWsAfterParameterizedSort, acceptSort, acceptParameters, acceptWsAfterParameters),
        acceptWsAfterLhs ? acceptWsAfterLhs(PTPT_getSymbolWsAfterLhs(arg)) : PTPT_getSymbolWsAfterLhs(arg),
        acceptWsAfterComma ? acceptWsAfterComma(PTPT_getSymbolWsAfterComma(arg)) : PTPT_getSymbolWsAfterComma(arg),
        PTPT_visitSymbol(PTPT_getSymbolRhs(arg), acceptWsAfterLit, acceptWsAfterParenOpen, acceptString, acceptWsAfterString, acceptWsAfterCilit, acceptWsAfterCf, acceptWsAfterSymbol, acceptWsAfterLex, acceptWsAfterOpt, acceptWsAfterAlt, acceptWsAfterLhs, acceptWsAfterComma, acceptWsAfterRhs, acceptWsAfterSeq, acceptSymbols, acceptWsAfterSymbols, acceptWsAfterTuple, acceptWsAfterHead, acceptRest, acceptWsAfterRest, acceptWsAfterSort, acceptWsAfterIter, acceptWsAfterIterStar, acceptWsAfterIterSep, acceptWsAfterSeparator, acceptWsAfterIterStarSep, acceptWsAfterIterN, acceptNumber, acceptWsAfterNumber, acceptWsAfterIterSepN, acceptWsAfterComma1, acceptWsAfterComma2, acceptWsAfterFunc, acceptWsAfterVarsym, acceptWsAfterCharClass, acceptCharRanges, acceptWsAfterCharRanges, acceptWsAfterStrategy, acceptWsAfterParameterizedSort, acceptSort, acceptParameters, acceptWsAfterParameters),
        acceptWsAfterRhs ? acceptWsAfterRhs(PTPT_getSymbolWsAfterRhs(arg)) : PTPT_getSymbolWsAfterRhs(arg));
  }
  if (PTPT_isSymbolParameterizedSort(arg)) {
    return PTPT_makeSymbolParameterizedSort(
        acceptWsAfterParameterizedSort ? acceptWsAfterParameterizedSort(PTPT_getSymbolWsAfterParameterizedSort(arg)) : PTPT_getSymbolWsAfterParameterizedSort(arg),
        acceptWsAfterParenOpen ? acceptWsAfterParenOpen(PTPT_getSymbolWsAfterParenOpen(arg)) : PTPT_getSymbolWsAfterParenOpen(arg),
        acceptSort ? acceptSort(PTPT_getSymbolSort(arg)) : PTPT_getSymbolSort(arg),
        acceptWsAfterSort ? acceptWsAfterSort(PTPT_getSymbolWsAfterSort(arg)) : PTPT_getSymbolWsAfterSort(arg),
        acceptWsAfterComma ? acceptWsAfterComma(PTPT_getSymbolWsAfterComma(arg)) : PTPT_getSymbolWsAfterComma(arg),
        acceptParameters ? acceptParameters(PTPT_getSymbolParameters(arg)) : PTPT_getSymbolParameters(arg),
        acceptWsAfterParameters ? acceptWsAfterParameters(PTPT_getSymbolWsAfterParameters(arg)) : PTPT_getSymbolWsAfterParameters(arg));
  }
  ATabort("not a Symbol: %t\n", arg);
  return (PTPT_Symbol)NULL;
}
/**
 * Apply functions to the children of a PTPT_Symbols. 
 * \return A new PTPT_Symbols with new children where the argument functions might have applied
 */
PTPT_Symbols PTPT_visitSymbols(PTPT_Symbols arg, PTPT_OptLayout (*acceptWsAfterBracketOpen)(PTPT_OptLayout), PTPT_SymbolList (*acceptList)(PTPT_SymbolList), PTPT_OptLayout (*acceptWsAfterList)(PTPT_OptLayout)) {
  if (PTPT_isSymbolsList(arg)) {
    return PTPT_makeSymbolsList(
        acceptWsAfterBracketOpen ? acceptWsAfterBracketOpen(PTPT_getSymbolsWsAfterBracketOpen(arg)) : PTPT_getSymbolsWsAfterBracketOpen(arg),
        acceptList ? acceptList(PTPT_getSymbolsList(arg)) : PTPT_getSymbolsList(arg),
        acceptWsAfterList ? acceptWsAfterList(PTPT_getSymbolsWsAfterList(arg)) : PTPT_getSymbolsWsAfterList(arg));
  }
  ATabort("not a Symbols: %t\n", arg);
  return (PTPT_Symbols)NULL;
}
/**
 * Apply functions to the children of a PTPT_CharRanges. 
 * \return A new PTPT_CharRanges with new children where the argument functions might have applied
 */
PTPT_CharRanges PTPT_visitCharRanges(PTPT_CharRanges arg, PTPT_OptLayout (*acceptWsAfterBracketOpen)(PTPT_OptLayout), PTPT_CharRangeList (*acceptList)(PTPT_CharRangeList), PTPT_OptLayout (*acceptWsAfterList)(PTPT_OptLayout)) {
  if (PTPT_isCharRangesList(arg)) {
    return PTPT_makeCharRangesList(
        acceptWsAfterBracketOpen ? acceptWsAfterBracketOpen(PTPT_getCharRangesWsAfterBracketOpen(arg)) : PTPT_getCharRangesWsAfterBracketOpen(arg),
        acceptList ? acceptList(PTPT_getCharRangesList(arg)) : PTPT_getCharRangesList(arg),
        acceptWsAfterList ? acceptWsAfterList(PTPT_getCharRangesWsAfterList(arg)) : PTPT_getCharRangesWsAfterList(arg));
  }
  ATabort("not a CharRanges: %t\n", arg);
  return (PTPT_CharRanges)NULL;
}
/**
 * Apply functions to the children of a PTPT_CharRange. 
 * \return A new PTPT_CharRange with new children where the argument functions might have applied
 */
PTPT_CharRange PTPT_visitCharRange(PTPT_CharRange arg, PTPT_NatCon (*acceptInteger)(PTPT_NatCon), PTPT_OptLayout (*acceptWsAfterRange)(PTPT_OptLayout), PTPT_OptLayout (*acceptWsAfterParenOpen)(PTPT_OptLayout), PTPT_NatCon (*acceptStart)(PTPT_NatCon), PTPT_OptLayout (*acceptWsAfterStart)(PTPT_OptLayout), PTPT_OptLayout (*acceptWsAfterComma)(PTPT_OptLayout), PTPT_NatCon (*acceptEnd)(PTPT_NatCon), PTPT_OptLayout (*acceptWsAfterEnd)(PTPT_OptLayout)) {
  if (PTPT_isCharRangeCharacter(arg)) {
    return PTPT_makeCharRangeCharacter(
        acceptInteger ? acceptInteger(PTPT_getCharRangeInteger(arg)) : PTPT_getCharRangeInteger(arg));
  }
  if (PTPT_isCharRangeRange(arg)) {
    return PTPT_makeCharRangeRange(
        acceptWsAfterRange ? acceptWsAfterRange(PTPT_getCharRangeWsAfterRange(arg)) : PTPT_getCharRangeWsAfterRange(arg),
        acceptWsAfterParenOpen ? acceptWsAfterParenOpen(PTPT_getCharRangeWsAfterParenOpen(arg)) : PTPT_getCharRangeWsAfterParenOpen(arg),
        acceptStart ? acceptStart(PTPT_getCharRangeStart(arg)) : PTPT_getCharRangeStart(arg),
        acceptWsAfterStart ? acceptWsAfterStart(PTPT_getCharRangeWsAfterStart(arg)) : PTPT_getCharRangeWsAfterStart(arg),
        acceptWsAfterComma ? acceptWsAfterComma(PTPT_getCharRangeWsAfterComma(arg)) : PTPT_getCharRangeWsAfterComma(arg),
        acceptEnd ? acceptEnd(PTPT_getCharRangeEnd(arg)) : PTPT_getCharRangeEnd(arg),
        acceptWsAfterEnd ? acceptWsAfterEnd(PTPT_getCharRangeWsAfterEnd(arg)) : PTPT_getCharRangeWsAfterEnd(arg));
  }
  ATabort("not a CharRange: %t\n", arg);
  return (PTPT_CharRange)NULL;
}
/**
 * Apply functions to the children of a PTPT_Start. 
 * \return A new PTPT_Start with new children where the argument functions might have applied
 */
PTPT_Start PTPT_visitStart(PTPT_Start arg, PTPT_OptLayout (*acceptWsBefore)(PTPT_OptLayout), PTPT_Symbol (*acceptTopSymbol)(PTPT_Symbol), PTPT_OptLayout (*acceptWsAfter)(PTPT_OptLayout), int (*acceptAmbCnt)(int), PTPT_Tree (*acceptTopTree)(PTPT_Tree), PTPT_ATerm (*acceptTopATerm)(PTPT_ATerm), PTPT_IntCon (*acceptTopIntCon)(PTPT_IntCon), PTPT_RealCon (*acceptTopRealCon)(PTPT_RealCon)) {
  if (PTPT_isStartSymbol(arg)) {
    return PTPT_makeStartSymbol(
        acceptWsBefore ? acceptWsBefore(PTPT_getStartWsBefore(arg)) : PTPT_getStartWsBefore(arg),
        acceptTopSymbol ? acceptTopSymbol(PTPT_getStartTopSymbol(arg)) : PTPT_getStartTopSymbol(arg),
        acceptWsAfter ? acceptWsAfter(PTPT_getStartWsAfter(arg)) : PTPT_getStartWsAfter(arg),
        acceptAmbCnt ? acceptAmbCnt(PTPT_getStartAmbCnt(arg)) : PTPT_getStartAmbCnt(arg));
  }
  if (PTPT_isStartTree(arg)) {
    return PTPT_makeStartTree(
        acceptWsBefore ? acceptWsBefore(PTPT_getStartWsBefore(arg)) : PTPT_getStartWsBefore(arg),
        acceptTopTree ? acceptTopTree(PTPT_getStartTopTree(arg)) : PTPT_getStartTopTree(arg),
        acceptWsAfter ? acceptWsAfter(PTPT_getStartWsAfter(arg)) : PTPT_getStartWsAfter(arg),
        acceptAmbCnt ? acceptAmbCnt(PTPT_getStartAmbCnt(arg)) : PTPT_getStartAmbCnt(arg));
  }
  if (PTPT_isStartATerm(arg)) {
    return PTPT_makeStartATerm(
        acceptWsBefore ? acceptWsBefore(PTPT_getStartWsBefore(arg)) : PTPT_getStartWsBefore(arg),
        acceptTopATerm ? acceptTopATerm(PTPT_getStartTopATerm(arg)) : PTPT_getStartTopATerm(arg),
        acceptWsAfter ? acceptWsAfter(PTPT_getStartWsAfter(arg)) : PTPT_getStartWsAfter(arg),
        acceptAmbCnt ? acceptAmbCnt(PTPT_getStartAmbCnt(arg)) : PTPT_getStartAmbCnt(arg));
  }
  if (PTPT_isStartIntCon(arg)) {
    return PTPT_makeStartIntCon(
        acceptWsBefore ? acceptWsBefore(PTPT_getStartWsBefore(arg)) : PTPT_getStartWsBefore(arg),
        acceptTopIntCon ? acceptTopIntCon(PTPT_getStartTopIntCon(arg)) : PTPT_getStartTopIntCon(arg),
        acceptWsAfter ? acceptWsAfter(PTPT_getStartWsAfter(arg)) : PTPT_getStartWsAfter(arg),
        acceptAmbCnt ? acceptAmbCnt(PTPT_getStartAmbCnt(arg)) : PTPT_getStartAmbCnt(arg));
  }
  if (PTPT_isStartRealCon(arg)) {
    return PTPT_makeStartRealCon(
        acceptWsBefore ? acceptWsBefore(PTPT_getStartWsBefore(arg)) : PTPT_getStartWsBefore(arg),
        acceptTopRealCon ? acceptTopRealCon(PTPT_getStartTopRealCon(arg)) : PTPT_getStartTopRealCon(arg),
        acceptWsAfter ? acceptWsAfter(PTPT_getStartWsAfter(arg)) : PTPT_getStartWsAfter(arg),
        acceptAmbCnt ? acceptAmbCnt(PTPT_getStartAmbCnt(arg)) : PTPT_getStartAmbCnt(arg));
  }
  ATabort("not a Start: %t\n", arg);
  return (PTPT_Start)NULL;
}
/**
 * Apply functions to the children of a PTPT_SymbolList. 
 * \return A new PTPT_SymbolList with new children where the argument functions might have applied
 */
PTPT_SymbolList PTPT_visitSymbolList(PTPT_SymbolList arg, PTPT_Symbol (*acceptHead)(PTPT_Symbol), PTPT_OptLayout (*acceptWsAfterHead)(PTPT_OptLayout), PTPT_OptLayout (*acceptWsAfterSep)(PTPT_OptLayout)) {
  if (PTPT_isSymbolListEmpty(arg)) {
    return PTPT_makeSymbolListEmpty();
  }
  if (PTPT_isSymbolListSingle(arg)) {
    return PTPT_makeSymbolListSingle(
        acceptHead ? acceptHead(PTPT_getSymbolListHead(arg)) : PTPT_getSymbolListHead(arg));
  }
  if (PTPT_isSymbolListMany(arg)) {
    return PTPT_makeSymbolListMany(
        acceptHead ? acceptHead(PTPT_getSymbolListHead(arg)) : PTPT_getSymbolListHead(arg),
        acceptWsAfterHead ? acceptWsAfterHead(PTPT_getSymbolListWsAfterHead(arg)) : PTPT_getSymbolListWsAfterHead(arg),
        acceptWsAfterSep ? acceptWsAfterSep(PTPT_getSymbolListWsAfterSep(arg)) : PTPT_getSymbolListWsAfterSep(arg),
        PTPT_visitSymbolList(PTPT_getSymbolListTail(arg), acceptHead, acceptWsAfterHead, acceptWsAfterSep));
  }
  ATabort("not a SymbolList: %t\n", arg);
  return (PTPT_SymbolList)NULL;
}
/**
 * Apply functions to the children of a PTPT_CharRangeList. 
 * \return A new PTPT_CharRangeList with new children where the argument functions might have applied
 */
PTPT_CharRangeList PTPT_visitCharRangeList(PTPT_CharRangeList arg, PTPT_CharRange (*acceptHead)(PTPT_CharRange), PTPT_OptLayout (*acceptWsAfterHead)(PTPT_OptLayout), PTPT_OptLayout (*acceptWsAfterSep)(PTPT_OptLayout)) {
  if (PTPT_isCharRangeListEmpty(arg)) {
    return PTPT_makeCharRangeListEmpty();
  }
  if (PTPT_isCharRangeListSingle(arg)) {
    return PTPT_makeCharRangeListSingle(
        acceptHead ? acceptHead(PTPT_getCharRangeListHead(arg)) : PTPT_getCharRangeListHead(arg));
  }
  if (PTPT_isCharRangeListMany(arg)) {
    return PTPT_makeCharRangeListMany(
        acceptHead ? acceptHead(PTPT_getCharRangeListHead(arg)) : PTPT_getCharRangeListHead(arg),
        acceptWsAfterHead ? acceptWsAfterHead(PTPT_getCharRangeListWsAfterHead(arg)) : PTPT_getCharRangeListWsAfterHead(arg),
        acceptWsAfterSep ? acceptWsAfterSep(PTPT_getCharRangeListWsAfterSep(arg)) : PTPT_getCharRangeListWsAfterSep(arg),
        PTPT_visitCharRangeList(PTPT_getCharRangeListTail(arg), acceptHead, acceptWsAfterHead, acceptWsAfterSep));
  }
  ATabort("not a CharRangeList: %t\n", arg);
  return (PTPT_CharRangeList)NULL;
}
/**
 * Apply functions to the children of a PTPT_Args. 
 * \return A new PTPT_Args with new children where the argument functions might have applied
 */
PTPT_Args PTPT_visitArgs(PTPT_Args arg, PTPT_OptLayout (*acceptWsAfterBracketOpen)(PTPT_OptLayout), PTPT_TreeList (*acceptList)(PTPT_TreeList), PTPT_OptLayout (*acceptWsAfterList)(PTPT_OptLayout)) {
  if (PTPT_isArgsList(arg)) {
    return PTPT_makeArgsList(
        acceptWsAfterBracketOpen ? acceptWsAfterBracketOpen(PTPT_getArgsWsAfterBracketOpen(arg)) : PTPT_getArgsWsAfterBracketOpen(arg),
        acceptList ? acceptList(PTPT_getArgsList(arg)) : PTPT_getArgsList(arg),
        acceptWsAfterList ? acceptWsAfterList(PTPT_getArgsWsAfterList(arg)) : PTPT_getArgsWsAfterList(arg));
  }
  ATabort("not a Args: %t\n", arg);
  return (PTPT_Args)NULL;
}
/**
 * Apply functions to the children of a PTPT_Production. 
 * \return A new PTPT_Production with new children where the argument functions might have applied
 */
PTPT_Production PTPT_visitProduction(PTPT_Production arg, PTPT_OptLayout (*acceptWsAfterProd)(PTPT_OptLayout), PTPT_OptLayout (*acceptWsAfterParenOpen)(PTPT_OptLayout), PTPT_Symbols (*acceptLhs)(PTPT_Symbols), PTPT_OptLayout (*acceptWsAfterLhs)(PTPT_OptLayout), PTPT_OptLayout (*acceptWsAfterComma1)(PTPT_OptLayout), PTPT_Symbol (*acceptRhs)(PTPT_Symbol), PTPT_OptLayout (*acceptWsAfterRhs)(PTPT_OptLayout), PTPT_OptLayout (*acceptWsAfterComma2)(PTPT_OptLayout), PTPT_Attributes (*acceptAttributes)(PTPT_Attributes), PTPT_OptLayout (*acceptWsAfterAttributes)(PTPT_OptLayout), PTPT_OptLayout (*acceptWsAfterList)(PTPT_OptLayout)) {
  if (PTPT_isProductionDefault(arg)) {
    return PTPT_makeProductionDefault(
        acceptWsAfterProd ? acceptWsAfterProd(PTPT_getProductionWsAfterProd(arg)) : PTPT_getProductionWsAfterProd(arg),
        acceptWsAfterParenOpen ? acceptWsAfterParenOpen(PTPT_getProductionWsAfterParenOpen(arg)) : PTPT_getProductionWsAfterParenOpen(arg),
        acceptLhs ? acceptLhs(PTPT_getProductionLhs(arg)) : PTPT_getProductionLhs(arg),
        acceptWsAfterLhs ? acceptWsAfterLhs(PTPT_getProductionWsAfterLhs(arg)) : PTPT_getProductionWsAfterLhs(arg),
        acceptWsAfterComma1 ? acceptWsAfterComma1(PTPT_getProductionWsAfterComma1(arg)) : PTPT_getProductionWsAfterComma1(arg),
        acceptRhs ? acceptRhs(PTPT_getProductionRhs(arg)) : PTPT_getProductionRhs(arg),
        acceptWsAfterRhs ? acceptWsAfterRhs(PTPT_getProductionWsAfterRhs(arg)) : PTPT_getProductionWsAfterRhs(arg),
        acceptWsAfterComma2 ? acceptWsAfterComma2(PTPT_getProductionWsAfterComma2(arg)) : PTPT_getProductionWsAfterComma2(arg),
        acceptAttributes ? acceptAttributes(PTPT_getProductionAttributes(arg)) : PTPT_getProductionAttributes(arg),
        acceptWsAfterAttributes ? acceptWsAfterAttributes(PTPT_getProductionWsAfterAttributes(arg)) : PTPT_getProductionWsAfterAttributes(arg));
  }
  if (PTPT_isProductionList(arg)) {
    return PTPT_makeProductionList(
        acceptWsAfterList ? acceptWsAfterList(PTPT_getProductionWsAfterList(arg)) : PTPT_getProductionWsAfterList(arg),
        acceptWsAfterParenOpen ? acceptWsAfterParenOpen(PTPT_getProductionWsAfterParenOpen(arg)) : PTPT_getProductionWsAfterParenOpen(arg),
        acceptRhs ? acceptRhs(PTPT_getProductionRhs(arg)) : PTPT_getProductionRhs(arg),
        acceptWsAfterRhs ? acceptWsAfterRhs(PTPT_getProductionWsAfterRhs(arg)) : PTPT_getProductionWsAfterRhs(arg));
  }
  ATabort("not a Production: %t\n", arg);
  return (PTPT_Production)NULL;
}
/**
 * Apply functions to the children of a PTPT_TreeList. 
 * \return A new PTPT_TreeList with new children where the argument functions might have applied
 */
PTPT_TreeList PTPT_visitTreeList(PTPT_TreeList arg, PTPT_Tree (*acceptHead)(PTPT_Tree), PTPT_OptLayout (*acceptWsAfterHead)(PTPT_OptLayout), PTPT_OptLayout (*acceptWsAfterSep)(PTPT_OptLayout)) {
  if (PTPT_isTreeListEmpty(arg)) {
    return PTPT_makeTreeListEmpty();
  }
  if (PTPT_isTreeListSingle(arg)) {
    return PTPT_makeTreeListSingle(
        acceptHead ? acceptHead(PTPT_getTreeListHead(arg)) : PTPT_getTreeListHead(arg));
  }
  if (PTPT_isTreeListMany(arg)) {
    return PTPT_makeTreeListMany(
        acceptHead ? acceptHead(PTPT_getTreeListHead(arg)) : PTPT_getTreeListHead(arg),
        acceptWsAfterHead ? acceptWsAfterHead(PTPT_getTreeListWsAfterHead(arg)) : PTPT_getTreeListWsAfterHead(arg),
        acceptWsAfterSep ? acceptWsAfterSep(PTPT_getTreeListWsAfterSep(arg)) : PTPT_getTreeListWsAfterSep(arg),
        PTPT_visitTreeList(PTPT_getTreeListTail(arg), acceptHead, acceptWsAfterHead, acceptWsAfterSep));
  }
  ATabort("not a TreeList: %t\n", arg);
  return (PTPT_TreeList)NULL;
}
/**
 * Apply functions to the children of a PTPT_AFun. 
 * \return A new PTPT_AFun with new children where the argument functions might have applied
 */
PTPT_AFun PTPT_visitAFun(PTPT_AFun arg, PTPT_StrCon (*acceptStrCon)(PTPT_StrCon), PTPT_IdCon (*acceptIdCon)(PTPT_IdCon)) {
  if (PTPT_isAFunQuoted(arg)) {
    return PTPT_makeAFunQuoted(
        acceptStrCon ? acceptStrCon(PTPT_getAFunStrCon(arg)) : PTPT_getAFunStrCon(arg));
  }
  if (PTPT_isAFunUnquoted(arg)) {
    return PTPT_makeAFunUnquoted(
        acceptIdCon ? acceptIdCon(PTPT_getAFunIdCon(arg)) : PTPT_getAFunIdCon(arg));
  }
  ATabort("not a AFun: %t\n", arg);
  return (PTPT_AFun)NULL;
}
/**
 * Apply functions to the children of a PTPT_ATerm. 
 * \return A new PTPT_ATerm with new children where the argument functions might have applied
 */
PTPT_ATerm PTPT_visitATerm(PTPT_ATerm arg, PTPT_IntCon (*acceptIntCon)(PTPT_IntCon), PTPT_RealCon (*acceptRealCon)(PTPT_RealCon), PTPT_AFun (*acceptFun)(PTPT_AFun), PTPT_OptLayout (*acceptWsAfterFun)(PTPT_OptLayout), PTPT_OptLayout (*acceptWsAfterParenOpen)(PTPT_OptLayout), PTPT_ATermArgs (*acceptArgs)(PTPT_ATermArgs), PTPT_OptLayout (*acceptWsAfterArgs)(PTPT_OptLayout), PTPT_OptLayout (*acceptWsAfterLessThan)(PTPT_OptLayout), PTPT_OptLayout (*acceptWsAfterType)(PTPT_OptLayout), PTPT_OptLayout (*acceptWsAfterBracketOpen)(PTPT_OptLayout), PTPT_ATermElems (*acceptElems)(PTPT_ATermElems), PTPT_OptLayout (*acceptWsAfterElems)(PTPT_OptLayout), PTPT_OptLayout (*acceptWsAfterTrm)(PTPT_OptLayout), PTPT_Annotation (*acceptAnnotation)(PTPT_Annotation)) {
  if (PTPT_isATermInt(arg)) {
    return PTPT_makeATermInt(
        acceptIntCon ? acceptIntCon(PTPT_getATermIntCon(arg)) : PTPT_getATermIntCon(arg));
  }
  if (PTPT_isATermReal(arg)) {
    return PTPT_makeATermReal(
        acceptRealCon ? acceptRealCon(PTPT_getATermRealCon(arg)) : PTPT_getATermRealCon(arg));
  }
  if (PTPT_isATermFun(arg)) {
    return PTPT_makeATermFun(
        acceptFun ? acceptFun(PTPT_getATermFun(arg)) : PTPT_getATermFun(arg));
  }
  if (PTPT_isATermAppl(arg)) {
    return PTPT_makeATermAppl(
        acceptFun ? acceptFun(PTPT_getATermFun(arg)) : PTPT_getATermFun(arg),
        acceptWsAfterFun ? acceptWsAfterFun(PTPT_getATermWsAfterFun(arg)) : PTPT_getATermWsAfterFun(arg),
        acceptWsAfterParenOpen ? acceptWsAfterParenOpen(PTPT_getATermWsAfterParenOpen(arg)) : PTPT_getATermWsAfterParenOpen(arg),
        acceptArgs ? acceptArgs(PTPT_getATermArgs(arg)) : PTPT_getATermArgs(arg),
        acceptWsAfterArgs ? acceptWsAfterArgs(PTPT_getATermWsAfterArgs(arg)) : PTPT_getATermWsAfterArgs(arg));
  }
  if (PTPT_isATermPlaceholder(arg)) {
    return PTPT_makeATermPlaceholder(
        acceptWsAfterLessThan ? acceptWsAfterLessThan(PTPT_getATermWsAfterLessThan(arg)) : PTPT_getATermWsAfterLessThan(arg),
        PTPT_visitATerm(PTPT_getATermType(arg), acceptIntCon, acceptRealCon, acceptFun, acceptWsAfterFun, acceptWsAfterParenOpen, acceptArgs, acceptWsAfterArgs, acceptWsAfterLessThan, acceptWsAfterType, acceptWsAfterBracketOpen, acceptElems, acceptWsAfterElems, acceptWsAfterTrm, acceptAnnotation),
        acceptWsAfterType ? acceptWsAfterType(PTPT_getATermWsAfterType(arg)) : PTPT_getATermWsAfterType(arg));
  }
  if (PTPT_isATermList(arg)) {
    return PTPT_makeATermList(
        acceptWsAfterBracketOpen ? acceptWsAfterBracketOpen(PTPT_getATermWsAfterBracketOpen(arg)) : PTPT_getATermWsAfterBracketOpen(arg),
        acceptElems ? acceptElems(PTPT_getATermElems(arg)) : PTPT_getATermElems(arg),
        acceptWsAfterElems ? acceptWsAfterElems(PTPT_getATermWsAfterElems(arg)) : PTPT_getATermWsAfterElems(arg));
  }
  if (PTPT_isATermAnnotated(arg)) {
    return PTPT_makeATermAnnotated(
        PTPT_visitATerm(PTPT_getATermTrm(arg), acceptIntCon, acceptRealCon, acceptFun, acceptWsAfterFun, acceptWsAfterParenOpen, acceptArgs, acceptWsAfterArgs, acceptWsAfterLessThan, acceptWsAfterType, acceptWsAfterBracketOpen, acceptElems, acceptWsAfterElems, acceptWsAfterTrm, acceptAnnotation),
        acceptWsAfterTrm ? acceptWsAfterTrm(PTPT_getATermWsAfterTrm(arg)) : PTPT_getATermWsAfterTrm(arg),
        acceptAnnotation ? acceptAnnotation(PTPT_getATermAnnotation(arg)) : PTPT_getATermAnnotation(arg));
  }
  ATabort("not a ATerm: %t\n", arg);
  return (PTPT_ATerm)NULL;
}
/**
 * Apply functions to the children of a PTPT_Annotation. 
 * \return A new PTPT_Annotation with new children where the argument functions might have applied
 */
PTPT_Annotation PTPT_visitAnnotation(PTPT_Annotation arg, PTPT_OptLayout (*acceptWsAfterBraceOpen)(PTPT_OptLayout), PTPT_ATermAnnos (*acceptAnnos)(PTPT_ATermAnnos), PTPT_OptLayout (*acceptWsAfterAnnos)(PTPT_OptLayout)) {
  if (PTPT_isAnnotationDefault(arg)) {
    return PTPT_makeAnnotationDefault(
        acceptWsAfterBraceOpen ? acceptWsAfterBraceOpen(PTPT_getAnnotationWsAfterBraceOpen(arg)) : PTPT_getAnnotationWsAfterBraceOpen(arg),
        acceptAnnos ? acceptAnnos(PTPT_getAnnotationAnnos(arg)) : PTPT_getAnnotationAnnos(arg),
        acceptWsAfterAnnos ? acceptWsAfterAnnos(PTPT_getAnnotationWsAfterAnnos(arg)) : PTPT_getAnnotationWsAfterAnnos(arg));
  }
  ATabort("not a Annotation: %t\n", arg);
  return (PTPT_Annotation)NULL;
}
/**
 * Apply functions to the children of a PTPT_ATermArgs. 
 * \return A new PTPT_ATermArgs with new children where the argument functions might have applied
 */
PTPT_ATermArgs PTPT_visitATermArgs(PTPT_ATermArgs arg, PTPT_ATerm (*acceptHead)(PTPT_ATerm), PTPT_OptLayout (*acceptWsAfterHead)(PTPT_OptLayout), PTPT_OptLayout (*acceptWsAfterSep)(PTPT_OptLayout)) {
  if (PTPT_isATermArgsEmpty(arg)) {
    return PTPT_makeATermArgsEmpty();
  }
  if (PTPT_isATermArgsSingle(arg)) {
    return PTPT_makeATermArgsSingle(
        acceptHead ? acceptHead(PTPT_getATermArgsHead(arg)) : PTPT_getATermArgsHead(arg));
  }
  if (PTPT_isATermArgsMany(arg)) {
    return PTPT_makeATermArgsMany(
        acceptHead ? acceptHead(PTPT_getATermArgsHead(arg)) : PTPT_getATermArgsHead(arg),
        acceptWsAfterHead ? acceptWsAfterHead(PTPT_getATermArgsWsAfterHead(arg)) : PTPT_getATermArgsWsAfterHead(arg),
        acceptWsAfterSep ? acceptWsAfterSep(PTPT_getATermArgsWsAfterSep(arg)) : PTPT_getATermArgsWsAfterSep(arg),
        PTPT_visitATermArgs(PTPT_getATermArgsTail(arg), acceptHead, acceptWsAfterHead, acceptWsAfterSep));
  }
  ATabort("not a ATermArgs: %t\n", arg);
  return (PTPT_ATermArgs)NULL;
}
/**
 * Apply functions to the children of a PTPT_ATermElems. 
 * \return A new PTPT_ATermElems with new children where the argument functions might have applied
 */
PTPT_ATermElems PTPT_visitATermElems(PTPT_ATermElems arg, PTPT_ATerm (*acceptHead)(PTPT_ATerm), PTPT_OptLayout (*acceptWsAfterHead)(PTPT_OptLayout), PTPT_OptLayout (*acceptWsAfterSep)(PTPT_OptLayout)) {
  if (PTPT_isATermElemsEmpty(arg)) {
    return PTPT_makeATermElemsEmpty();
  }
  if (PTPT_isATermElemsSingle(arg)) {
    return PTPT_makeATermElemsSingle(
        acceptHead ? acceptHead(PTPT_getATermElemsHead(arg)) : PTPT_getATermElemsHead(arg));
  }
  if (PTPT_isATermElemsMany(arg)) {
    return PTPT_makeATermElemsMany(
        acceptHead ? acceptHead(PTPT_getATermElemsHead(arg)) : PTPT_getATermElemsHead(arg),
        acceptWsAfterHead ? acceptWsAfterHead(PTPT_getATermElemsWsAfterHead(arg)) : PTPT_getATermElemsWsAfterHead(arg),
        acceptWsAfterSep ? acceptWsAfterSep(PTPT_getATermElemsWsAfterSep(arg)) : PTPT_getATermElemsWsAfterSep(arg),
        PTPT_visitATermElems(PTPT_getATermElemsTail(arg), acceptHead, acceptWsAfterHead, acceptWsAfterSep));
  }
  ATabort("not a ATermElems: %t\n", arg);
  return (PTPT_ATermElems)NULL;
}
/**
 * Apply functions to the children of a PTPT_ATermAnnos. 
 * \return A new PTPT_ATermAnnos with new children where the argument functions might have applied
 */
PTPT_ATermAnnos PTPT_visitATermAnnos(PTPT_ATermAnnos arg, PTPT_ATerm (*acceptHead)(PTPT_ATerm), PTPT_OptLayout (*acceptWsAfterHead)(PTPT_OptLayout), PTPT_OptLayout (*acceptWsAfterSep)(PTPT_OptLayout)) {
  if (PTPT_isATermAnnosEmpty(arg)) {
    return PTPT_makeATermAnnosEmpty();
  }
  if (PTPT_isATermAnnosSingle(arg)) {
    return PTPT_makeATermAnnosSingle(
        acceptHead ? acceptHead(PTPT_getATermAnnosHead(arg)) : PTPT_getATermAnnosHead(arg));
  }
  if (PTPT_isATermAnnosMany(arg)) {
    return PTPT_makeATermAnnosMany(
        acceptHead ? acceptHead(PTPT_getATermAnnosHead(arg)) : PTPT_getATermAnnosHead(arg),
        acceptWsAfterHead ? acceptWsAfterHead(PTPT_getATermAnnosWsAfterHead(arg)) : PTPT_getATermAnnosWsAfterHead(arg),
        acceptWsAfterSep ? acceptWsAfterSep(PTPT_getATermAnnosWsAfterSep(arg)) : PTPT_getATermAnnosWsAfterSep(arg),
        PTPT_visitATermAnnos(PTPT_getATermAnnosTail(arg), acceptHead, acceptWsAfterHead, acceptWsAfterSep));
  }
  ATabort("not a ATermAnnos: %t\n", arg);
  return (PTPT_ATermAnnos)NULL;
}
/**
 * Apply functions to the children of a PTPT_IntCon. 
 * \return A new PTPT_IntCon with new children where the argument functions might have applied
 */
PTPT_IntCon PTPT_visitIntCon(PTPT_IntCon arg, PTPT_NatCon (*acceptNatCon)(PTPT_NatCon), PTPT_OptLayout (*acceptWsAfterPos)(PTPT_OptLayout), PTPT_OptLayout (*acceptWsAfterNeg)(PTPT_OptLayout)) {
  if (PTPT_isIntConNatural(arg)) {
    return PTPT_makeIntConNatural(
        acceptNatCon ? acceptNatCon(PTPT_getIntConNatCon(arg)) : PTPT_getIntConNatCon(arg));
  }
  if (PTPT_isIntConPositive(arg)) {
    return PTPT_makeIntConPositive(
        acceptWsAfterPos ? acceptWsAfterPos(PTPT_getIntConWsAfterPos(arg)) : PTPT_getIntConWsAfterPos(arg),
        acceptNatCon ? acceptNatCon(PTPT_getIntConNatCon(arg)) : PTPT_getIntConNatCon(arg));
  }
  if (PTPT_isIntConNegative(arg)) {
    return PTPT_makeIntConNegative(
        acceptWsAfterNeg ? acceptWsAfterNeg(PTPT_getIntConWsAfterNeg(arg)) : PTPT_getIntConWsAfterNeg(arg),
        acceptNatCon ? acceptNatCon(PTPT_getIntConNatCon(arg)) : PTPT_getIntConNatCon(arg));
  }
  ATabort("not a IntCon: %t\n", arg);
  return (PTPT_IntCon)NULL;
}
/**
 * Apply functions to the children of a PTPT_OptExp. 
 * \return A new PTPT_OptExp with new children where the argument functions might have applied
 */
PTPT_OptExp PTPT_visitOptExp(PTPT_OptExp arg, PTPT_OptLayout (*acceptWsAfterE)(PTPT_OptLayout), PTPT_IntCon (*acceptIntCon)(PTPT_IntCon)) {
  if (PTPT_isOptExpPresent(arg)) {
    return PTPT_makeOptExpPresent(
        acceptWsAfterE ? acceptWsAfterE(PTPT_getOptExpWsAfterE(arg)) : PTPT_getOptExpWsAfterE(arg),
        acceptIntCon ? acceptIntCon(PTPT_getOptExpIntCon(arg)) : PTPT_getOptExpIntCon(arg));
  }
  if (PTPT_isOptExpAbsent(arg)) {
    return PTPT_makeOptExpAbsent();
  }
  ATabort("not a OptExp: %t\n", arg);
  return (PTPT_OptExp)NULL;
}
/**
 * Apply functions to the children of a PTPT_RealCon. 
 * \return A new PTPT_RealCon with new children where the argument functions might have applied
 */
PTPT_RealCon PTPT_visitRealCon(PTPT_RealCon arg, PTPT_IntCon (*acceptBase)(PTPT_IntCon), PTPT_OptLayout (*acceptWsAfterBase)(PTPT_OptLayout), PTPT_OptLayout (*acceptWsAfterPeriod)(PTPT_OptLayout), PTPT_NatCon (*acceptDecimal)(PTPT_NatCon), PTPT_OptLayout (*acceptWsAfterDecimal)(PTPT_OptLayout), PTPT_OptExp (*acceptExp)(PTPT_OptExp)) {
  if (PTPT_isRealConRealCon(arg)) {
    return PTPT_makeRealConRealCon(
        acceptBase ? acceptBase(PTPT_getRealConBase(arg)) : PTPT_getRealConBase(arg),
        acceptWsAfterBase ? acceptWsAfterBase(PTPT_getRealConWsAfterBase(arg)) : PTPT_getRealConWsAfterBase(arg),
        acceptWsAfterPeriod ? acceptWsAfterPeriod(PTPT_getRealConWsAfterPeriod(arg)) : PTPT_getRealConWsAfterPeriod(arg),
        acceptDecimal ? acceptDecimal(PTPT_getRealConDecimal(arg)) : PTPT_getRealConDecimal(arg),
        acceptWsAfterDecimal ? acceptWsAfterDecimal(PTPT_getRealConWsAfterDecimal(arg)) : PTPT_getRealConWsAfterDecimal(arg),
        acceptExp ? acceptExp(PTPT_getRealConExp(arg)) : PTPT_getRealConExp(arg));
  }
  ATabort("not a RealCon: %t\n", arg);
  return (PTPT_RealCon)NULL;
}
/**
 * Apply functions to the children of a PTPT_LexStrChar. 
 * \return A new PTPT_LexStrChar with new children where the argument functions might have applied
 */
PTPT_LexStrChar PTPT_visitLexStrChar(PTPT_LexStrChar arg, char (*acceptA)(char), char (*acceptB)(char), char (*acceptC)(char), char (*acceptCh)(char)) {
  if (PTPT_isLexStrCharNewline(arg)) {
    return PTPT_makeLexStrCharNewline();
  }
  if (PTPT_isLexStrCharTab(arg)) {
    return PTPT_makeLexStrCharTab();
  }
  if (PTPT_isLexStrCharQuote(arg)) {
    return PTPT_makeLexStrCharQuote();
  }
  if (PTPT_isLexStrCharBackslash(arg)) {
    return PTPT_makeLexStrCharBackslash();
  }
  if (PTPT_isLexStrCharDecimal(arg)) {
    return PTPT_makeLexStrCharDecimal(
        acceptA ? acceptA(PTPT_getLexStrCharA(arg)) : PTPT_getLexStrCharA(arg),
        acceptB ? acceptB(PTPT_getLexStrCharB(arg)) : PTPT_getLexStrCharB(arg),
        acceptC ? acceptC(PTPT_getLexStrCharC(arg)) : PTPT_getLexStrCharC(arg));
  }
  if (PTPT_isLexStrCharNormal(arg)) {
    return PTPT_makeLexStrCharNormal(
        acceptCh ? acceptCh(PTPT_getLexStrCharCh(arg)) : PTPT_getLexStrCharCh(arg));
  }
  ATabort("not a LexStrChar: %t\n", arg);
  return (PTPT_LexStrChar)NULL;
}
/**
 * Apply functions to the children of a PTPT_StrChar. 
 * \return A new PTPT_StrChar with new children where the argument functions might have applied
 */
PTPT_StrChar PTPT_visitStrChar(PTPT_StrChar arg, PTPT_LexStrChar (*acceptStrChar)(PTPT_LexStrChar)) {
  if (PTPT_isStrCharLexToCf(arg)) {
    return PTPT_makeStrCharLexToCf(
        acceptStrChar ? acceptStrChar(PTPT_getStrCharStrChar(arg)) : PTPT_getStrCharStrChar(arg));
  }
  ATabort("not a StrChar: %t\n", arg);
  return (PTPT_StrChar)NULL;
}
/**
 * Apply functions to the children of a PTPT_LexStrCon. 
 * \return A new PTPT_LexStrCon with new children where the argument functions might have applied
 */
PTPT_LexStrCon PTPT_visitLexStrCon(PTPT_LexStrCon arg, PTPT_LexStrCharChars (*acceptChars)(PTPT_LexStrCharChars)) {
  if (PTPT_isLexStrConDefault(arg)) {
    return PTPT_makeLexStrConDefault(
        acceptChars ? acceptChars(PTPT_getLexStrConChars(arg)) : PTPT_getLexStrConChars(arg));
  }
  ATabort("not a LexStrCon: %t\n", arg);
  return (PTPT_LexStrCon)NULL;
}
/**
 * Apply functions to the children of a PTPT_StrCon. 
 * \return A new PTPT_StrCon with new children where the argument functions might have applied
 */
PTPT_StrCon PTPT_visitStrCon(PTPT_StrCon arg, PTPT_LexStrCon (*acceptStrCon)(PTPT_LexStrCon)) {
  if (PTPT_isStrConLexToCf(arg)) {
    return PTPT_makeStrConLexToCf(
        acceptStrCon ? acceptStrCon(PTPT_getStrConStrCon(arg)) : PTPT_getStrConStrCon(arg));
  }
  ATabort("not a StrCon: %t\n", arg);
  return (PTPT_StrCon)NULL;
}
/**
 * Apply functions to the children of a PTPT_LexStrCharChars. 
 * \return A new PTPT_LexStrCharChars with new children where the argument functions might have applied
 */
PTPT_LexStrCharChars PTPT_visitLexStrCharChars(PTPT_LexStrCharChars arg, PTPT_LexStrChar (*acceptHead)(PTPT_LexStrChar)) {
  if (PTPT_isLexStrCharCharsEmpty(arg)) {
    return PTPT_makeLexStrCharCharsEmpty();
  }
  if (PTPT_isLexStrCharCharsSingle(arg)) {
    return PTPT_makeLexStrCharCharsSingle(
        acceptHead ? acceptHead(PTPT_getLexStrCharCharsHead(arg)) : PTPT_getLexStrCharCharsHead(arg));
  }
  if (PTPT_isLexStrCharCharsMany(arg)) {
    return PTPT_makeLexStrCharCharsMany(
        acceptHead ? acceptHead(PTPT_getLexStrCharCharsHead(arg)) : PTPT_getLexStrCharCharsHead(arg),
        PTPT_visitLexStrCharChars(PTPT_getLexStrCharCharsTail(arg), acceptHead));
  }
  ATabort("not a LexStrCharChars: %t\n", arg);
  return (PTPT_LexStrCharChars)NULL;
}
/**
 * Apply functions to the children of a PTPT_LexNatCon. 
 * \return A new PTPT_LexNatCon with new children where the argument functions might have applied
 */
PTPT_LexNatCon PTPT_visitLexNatCon(PTPT_LexNatCon arg, char* (*acceptList)(char*)) {
  if (PTPT_isLexNatConDigits(arg)) {
    return PTPT_makeLexNatConDigits(
        acceptList ? acceptList(PTPT_getLexNatConList(arg)) : PTPT_getLexNatConList(arg));
  }
  ATabort("not a LexNatCon: %t\n", arg);
  return (PTPT_LexNatCon)NULL;
}
/**
 * Apply functions to the children of a PTPT_NatCon. 
 * \return A new PTPT_NatCon with new children where the argument functions might have applied
 */
PTPT_NatCon PTPT_visitNatCon(PTPT_NatCon arg, PTPT_LexNatCon (*acceptNatCon)(PTPT_LexNatCon)) {
  if (PTPT_isNatConLexToCf(arg)) {
    return PTPT_makeNatConLexToCf(
        acceptNatCon ? acceptNatCon(PTPT_getNatConNatCon(arg)) : PTPT_getNatConNatCon(arg));
  }
  ATabort("not a NatCon: %t\n", arg);
  return (PTPT_NatCon)NULL;
}
/**
 * Apply functions to the children of a PTPT_LexIdCon. 
 * \return A new PTPT_LexIdCon with new children where the argument functions might have applied
 */
PTPT_LexIdCon PTPT_visitLexIdCon(PTPT_LexIdCon arg, char (*acceptHead)(char), char* (*acceptTail)(char*)) {
  if (PTPT_isLexIdConDefault(arg)) {
    return PTPT_makeLexIdConDefault(
        acceptHead ? acceptHead(PTPT_getLexIdConHead(arg)) : PTPT_getLexIdConHead(arg),
        acceptTail ? acceptTail(PTPT_getLexIdConTail(arg)) : PTPT_getLexIdConTail(arg));
  }
  ATabort("not a LexIdCon: %t\n", arg);
  return (PTPT_LexIdCon)NULL;
}
/**
 * Apply functions to the children of a PTPT_IdCon. 
 * \return A new PTPT_IdCon with new children where the argument functions might have applied
 */
PTPT_IdCon PTPT_visitIdCon(PTPT_IdCon arg, PTPT_LexIdCon (*acceptIdCon)(PTPT_LexIdCon)) {
  if (PTPT_isIdConLexToCf(arg)) {
    return PTPT_makeIdConLexToCf(
        acceptIdCon ? acceptIdCon(PTPT_getIdConIdCon(arg)) : PTPT_getIdConIdCon(arg));
  }
  ATabort("not a IdCon: %t\n", arg);
  return (PTPT_IdCon)NULL;
}
/**
 * Apply functions to the children of a PTPT_LexLayout. 
 * \return A new PTPT_LexLayout with new children where the argument functions might have applied
 */
PTPT_LexLayout PTPT_visitLexLayout(PTPT_LexLayout arg, char (*acceptCh)(char)) {
  if (PTPT_isLexLayoutWhitespace(arg)) {
    return PTPT_makeLexLayoutWhitespace(
        acceptCh ? acceptCh(PTPT_getLexLayoutCh(arg)) : PTPT_getLexLayoutCh(arg));
  }
  ATabort("not a LexLayout: %t\n", arg);
  return (PTPT_LexLayout)NULL;
}

